EventButton

Enum EventButton 

#[repr(u8)]
pub enum EventButton { Left, Right, Middle, X1, X2, X3, X4, X5, Other(u8), }
Available on crate feature event only.
๐ŸŽซ ๐ŸŽฎ โˆˆ A normalized pressable pointer/mouse button.


๐Ÿ“ ui/event::EventButton

๐Ÿ“ฆ size_of::<EventButton>() == 2 bytes / 16 bits โš—๏ธOption<T> ๐ŸŸฐ T


Left, Middle, and Right represent the three primary conventional buttons. X1..X5 represent additional auxiliary button slots when a backend can report them.

These variants name normalized button slots, not guaranteed user actions. For example, X1 is often used as โ€œbackโ€, X2 as โ€œforwardโ€, and on Pointer Events a pen eraser may be reported through an auxiliary slot.

Variants



Left

๐ŸŒฑ Left mouse button.



Right

Right mouse button.



Middle

Middle mouse button (usually the scroll wheel button).



X1

The first auxiliary mouse button, commonly โ€œbackโ€.



X2

The second auxiliary mouse button, commonly โ€œforwardโ€.



X3

The third auxiliary mouse button.



X4

The fourth auxiliary mouse button.



X5

The fifth auxiliary mouse button.



Other(u8)

Additional buttons (e.g., side buttons on advanced mice).

Implementations

Source

impl EventButton

pub const fn new(number: u8) -> Option<Self> โ“˜

Returns some button as long as itโ€™s not 0.

pub const fn from_one_bit_mask(mask: EventButtons) -> Option<EventButton> โ“˜

Returns the button represented by the mask, if exactly one button is set.

pub const fn to_mask(self) -> EventButtons

Returns this button as a held-button mask, if it has a normalized role.

Source

impl EventButton

pub const fn from_web(js_button: u8) -> Option<Self> โ“˜

Available on crate feature web only.

Converts a DOM-compatible button value into a normalized button slot.

This preserves the reported button slot. It does not assign contextual roles such as โ€œbackโ€, โ€œforwardโ€, โ€œbarrelโ€, or โ€œeraserโ€.

pub const fn to_web(self) -> u8

Available on crate feature web only.

Converts a normalized button slot into a DOM-compatible button value.