#[non_exhaustive]pub enum NumError {
NotImplemented,
NotSupported,
Unspecified,
Invalid,
NoInverse,
MismatchedSizes,
IncompatibleBounds,
NonNegativeRequired,
PositiveRequired,
NonZeroRequired,
Overflow(Option<Sign>),
}Expand description
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotImplemented
The requested numerical functionality is not implemented.
This is the default implementation of every numeric trait method.
NotSupported
The requested numerical functionality is not supported.
Unspecified
Unspecified error.
When no clearer error can be given.
Invalid
An invalid value was received for the given type or operation.
NoInverse
An inverse doesn’t exist.
MismatchedSizes
The provided values are not compatible in size.
IncompatibleBounds
The given bounds are not compatible.
NonNegativeRequired
A non-negative value is required.
PositiveRequired
A positive value is required.
NonZeroRequired
A non-zero value is required.
Overflow(Option<Sign>)
An arithmetic overflow error, with an optional associated sign.