EnumSetExample

Struct EnumSetExample 

pub struct EnumSetExample { /* private fields */ }
An example set of enum variants, generated by enumset!.


📍 data/codec/bin::EnumSetExample

📦 size_of::<EnumSetExample>() == 1 bytes / 8 bits ⚗️Option<T> ❗🟰 T


Represents a set of EnumExample variants.

Implementations

Source

impl EnumSetExample

Named subsets.

pub const DATA: Self

Variants carrying payload data.

pub const BORROW_OR_ALLOC: Self

Variants that can hold either borrowed or allocated data.

Source

impl EnumSetExample

Named constants

pub const Variant0: Self

1 The bit index that corresponds to EnumExample::Variant0.

pub const Variant1: Self

1 The bit index that corresponds to EnumExample::Variant1.

pub const Variant2: Self

1 The bit index that corresponds to EnumExample::Variant2.

pub const Variant3: Self

1 The bit index that corresponds to EnumExample::Variant3.

pub const Variant4: Self

1 The bit index that corresponds to EnumExample::Variant4.

Source

impl EnumSetExample

Convenience methods derived from each named constant.

pub const fn has_variant0(self) -> bool

Returns true if Variant0 is present.

pub const fn contains_variant0(self) -> bool

Returns true if all bits in Variant0 are present.

pub const fn intersects_variant0(self) -> bool

Returns true if the set shares any bit with Variant0.

pub const fn with_variant0(self) -> Self

Returns self with Variant0 inserted.

pub const fn with_variant0_if(self, condition: bool) -> Self

Returns self with Variant0 inserted if condition is true.

pub const fn without_variant0(self) -> Self

Returns self with Variant0 removed.

pub const fn set_variant0(&mut self)

Sets Variant0.

pub const fn set_variant0_if(&mut self, condition: bool)

Sets Variant0 if condition is true.

pub const fn unset_variant0(&mut self)

Unsets Variant0.

pub const fn has_variant1(self) -> bool

Returns true if Variant1 is present.

pub const fn contains_variant1(self) -> bool

Returns true if all bits in Variant1 are present.

pub const fn intersects_variant1(self) -> bool

Returns true if the set shares any bit with Variant1.

pub const fn with_variant1(self) -> Self

Returns self with Variant1 inserted.

pub const fn with_variant1_if(self, condition: bool) -> Self

Returns self with Variant1 inserted if condition is true.

pub const fn without_variant1(self) -> Self

Returns self with Variant1 removed.

pub const fn set_variant1(&mut self)

Sets Variant1.

pub const fn set_variant1_if(&mut self, condition: bool)

Sets Variant1 if condition is true.

pub const fn unset_variant1(&mut self)

Unsets Variant1.

pub const fn has_variant2(self) -> bool

Returns true if Variant2 is present.

pub const fn contains_variant2(self) -> bool

Returns true if all bits in Variant2 are present.

pub const fn intersects_variant2(self) -> bool

Returns true if the set shares any bit with Variant2.

pub const fn with_variant2(self) -> Self

Returns self with Variant2 inserted.

pub const fn with_variant2_if(self, condition: bool) -> Self

Returns self with Variant2 inserted if condition is true.

pub const fn without_variant2(self) -> Self

Returns self with Variant2 removed.

pub const fn set_variant2(&mut self)

Sets Variant2.

pub const fn set_variant2_if(&mut self, condition: bool)

Sets Variant2 if condition is true.

pub const fn unset_variant2(&mut self)

Unsets Variant2.

pub const fn has_variant3(self) -> bool

Returns true if Variant3 is present.

pub const fn contains_variant3(self) -> bool

Returns true if all bits in Variant3 are present.

pub const fn intersects_variant3(self) -> bool

Returns true if the set shares any bit with Variant3.

pub const fn with_variant3(self) -> Self

Returns self with Variant3 inserted.

pub const fn with_variant3_if(self, condition: bool) -> Self

Returns self with Variant3 inserted if condition is true.

pub const fn without_variant3(self) -> Self

Returns self with Variant3 removed.

pub const fn set_variant3(&mut self)

Sets Variant3.

pub const fn set_variant3_if(&mut self, condition: bool)

Sets Variant3 if condition is true.

pub const fn unset_variant3(&mut self)

Unsets Variant3.

pub const fn has_variant4(self) -> bool

Returns true if Variant4 is present.

pub const fn contains_variant4(self) -> bool

Returns true if all bits in Variant4 are present.

pub const fn intersects_variant4(self) -> bool

Returns true if the set shares any bit with Variant4.

pub const fn with_variant4(self) -> Self

Returns self with Variant4 inserted.

pub const fn with_variant4_if(self, condition: bool) -> Self

Returns self with Variant4 inserted if condition is true.

pub const fn without_variant4(self) -> Self

Returns self with Variant4 removed.

pub const fn set_variant4(&mut self)

Sets Variant4.

pub const fn set_variant4_if(&mut self, condition: bool)

Sets Variant4 if condition is true.

pub const fn unset_variant4(&mut self)

Unsets Variant4.

Source

impl EnumSetExample

Common set methods

pub const fn new() -> Self

Returns an empty set.

pub const fn from_bits(bits: u8) -> Self

Returns a set from raw bits.

pub const fn bits(self) -> u8

Returns the raw backing bits.

pub const fn all() -> Self

Returns the union of all declared sets.

pub const fn is_empty(self) -> bool

Returns true if no bits are set.

pub const fn is_full(self) -> bool

Returns true if all the declared bits are set.

pub const fn contains(self, other: Self) -> bool

Returns true if all bits in other are also set in self.

pub const fn has(self, other: Self) -> bool

An alias of contains.

pub const fn with(self, other: Self) -> Self

Returns self with other inserted.

pub const fn with_if(self, condition: bool, other: Self) -> Self

Returns self with other inserted if condition is true.

pub const fn without(self, other: Self) -> Self

Returns self with other removed.

pub const fn toggled(self, other: Self) -> Self

Returns self with other toggled.

Source

impl EnumSetExample

Set operations

pub const fn intersects(self, other: Self) -> bool

Returns true if self and other share any bit.

pub const fn is_subset(self, other: Self) -> bool

Returns true if all bits in self are also set in other.

pub const fn is_superset(self, other: Self) -> bool

Returns true if all bits in other are also set in self.

pub const fn union(self, other: Self) -> Self

Returns the union of self and other.

pub const fn intersection(self, other: Self) -> Self

Returns the intersection of self and other.

pub const fn difference(self, other: Self) -> Self

Returns the difference of self and other.

pub const fn symmetric_difference(self, other: Self) -> Self

Returns the symmetric difference of self and other.

Source

impl EnumSetExample

Mutating set operations

pub const fn clear(&mut self)

Clears the set.

pub const fn insert(&mut self, other: Self)

Inserts all bits from other.

pub const fn remove(&mut self, other: Self)

Removes all bits from other.

pub const fn toggle(&mut self, other: Self)

Toggles all bits from other.

Source

impl EnumSetExample

Associated set methods

pub const fn contains_variant<'a, 'b, T>( self, value: &EnumExample<'a, 'b, T>, ) -> bool
where T: Clone,

Returns true if the set contains the variant of value.

pub const fn has_variant<'a, 'b, T>( self, value: &EnumExample<'a, 'b, T>, ) -> bool
where T: Clone,

An alias of contains_variant.

pub const fn with_variant<'a, 'b, T>( self, value: &EnumExample<'a, 'b, T>, ) -> Self
where T: Clone,

Returns self with the variant of value inserted.

pub const fn without_variant<'a, 'b, T>( self, value: &EnumExample<'a, 'b, T>, ) -> Self
where T: Clone,

Returns self with the variant of value removed.

pub const fn toggled_variant<'a, 'b, T>( self, value: &EnumExample<'a, 'b, T>, ) -> Self
where T: Clone,

Returns self with the variant of value toggled.

pub const fn insert_variant<'a, 'b, T>( &mut self, value: &EnumExample<'a, 'b, T>, )
where T: Clone,

Inserts the variant of value.

pub const fn remove_variant<'a, 'b, T>( &mut self, value: &EnumExample<'a, 'b, T>, )
where T: Clone,

Removes the variant of value.

pub const fn toggle_variant<'a, 'b, T>( &mut self, value: &EnumExample<'a, 'b, T>, )
where T: Clone,

Toggles the variant of value.

pub fn for_each_set(self, f: impl FnMut(Self))

Calls f for each associated set constant present in this set.

pub fn for_each_set_while(self, f: impl FnMut(Self) -> bool) -> bool

Calls f for each associated set constant present in this set while it returns true.

Returns true if all set constants were visited, or false if iteration stopped early.