RangeToInclusive

Struct RangeToInclusive 

1.96.0 ยท Source
pub struct RangeToInclusive<Idx> {
    pub last: Idx,
}
๐Ÿ“ core A range value bounded inclusively above (..=end).


๐Ÿ“code/ops::RangeToInclusive re-exported from core::range



๐Ÿ“œ
A range only bounded inclusively above.

The RangeToInclusive contains all values with x <= last. It cannot serve as an Iterator because it doesnโ€™t have a starting point.

Examples

#![feature(new_range)]
assert_eq!((..=5), std::range::RangeToInclusive { last: 5 });

It does not have an IntoIterator implementation, so you canโ€™t use it in a for loop directly. This wonโ€™t compile:

โ“˜
// error[E0277]: the trait bound `std::range::RangeToInclusive<{integer}>:
// std::iter::Iterator` is not satisfied
for i in ..=5 {
    // ...
}

When used as a slicing index, RangeToInclusive produces a slice of all array elements up to and including the index indicated by last.

let arr = [0, 1, 2, 3, 4];
assert_eq!(arr[ ..  ], [0, 1, 2, 3, 4]);
assert_eq!(arr[ .. 3], [0, 1, 2      ]);
assert_eq!(arr[ ..=3], [0, 1, 2, 3   ]); // This is a `RangeToInclusive`
assert_eq!(arr[1..  ], [   1, 2, 3, 4]);
assert_eq!(arr[1.. 3], [   1, 2      ]);
assert_eq!(arr[1..=3], [   1, 2, 3   ]);

Edition notes

It is planned that the syntax ..=last will construct this type in a future edition, but it does not do so today.

Fields

last: Idx

The upper bound of the range (inclusive)

Implementations

Source

impl<Idx> RangeToInclusive<Idx>
where Idx: PartialOrd,

1.96.0 (const: unstable) ยท Source

pub fn contains<U>(&self, item: &U) -> bool
where Idx: PartialOrd<U>, U: PartialOrd<Idx> + ?Sized,

Returns true if item is contained in the range.

Examples
assert!( (..=5).contains(&-1_000_000_000));
assert!( (..=5).contains(&5));
assert!(!(..=5).contains(&6));

assert!( (..=1.0).contains(&1.0));
assert!(!(..=1.0).contains(&f32::NAN));
assert!(!(..=f32::NAN).contains(&0.5));