pub struct UiView { /* private fields */ }Available on crate feature
ui only.Expand description
▦ Frame-local visual record for a UI identity.
📦 size_of::<UiView>() == 28 bytes / 224 bits #️⃣ #[cfg(target_pointer_width = “32”)]
⚗️Option<T> 🟰 T
📦 size_of::<UiView>() == 32 bytes / 256 bits #️⃣ #[cfg(target_pointer_width = “64”)]
⚗️Option<T> 🟰 T
Connects a resolved UI identity with the visual region and ordering layer used for presentation.
Implementations
Sourceimpl UiView
impl UiView
Sourcepub const fn new(id: UiId, rect: UiRect) -> Self
pub const fn new(id: UiId, rect: UiRect) -> Self
Constructs a visual record on the base layer with no flags.
Sourcepub const fn from_parts(
id: UiId,
rect: UiRect,
layer: UiLayer,
flags: UiViewFlags,
) -> Self
pub const fn from_parts( id: UiId, rect: UiRect, layer: UiLayer, flags: UiViewFlags, ) -> Self
Constructs a visual record from all parts.
Sourcepub const fn flags(&self) -> UiViewFlags
pub const fn flags(&self) -> UiViewFlags
Returns the visual flags.
Returns whether the view is visually hidden.
Sourcepub const fn is_visible(&self) -> bool
pub const fn is_visible(&self) -> bool
Returns whether the view is visually present.
Sourcepub const fn with_layer(self, layer: UiLayer) -> Self
pub const fn with_layer(self, layer: UiLayer) -> Self
Returns this view with another layer.
Sourcepub const fn replace_flags(self, flags: UiViewFlags) -> Self
pub const fn replace_flags(self, flags: UiViewFlags) -> Self
Returns this view with another flag set.
Sourcepub const fn with_flags(self, flags: UiViewFlags) -> Self
pub const fn with_flags(self, flags: UiViewFlags) -> Self
Returns this view with flags included.
Sourcepub const fn without_flags(self, flags: UiViewFlags) -> Self
pub const fn without_flags(self, flags: UiViewFlags) -> Self
Returns this view with flags removed.