pub enum LinuxSeekFrom {
Start(c_off_t),
Current(c_off_t),
End(c_off_t),
Data(c_off_t),
Hole(c_off_t),
}Available on crate feature
linux only.Expand description
๐ง ๐ A Linux file-positioning directive.
๐ sys/os/linux/io::LinuxSeekFrom
๐ฆ size_of::<LinuxSeekFrom>() == 12 bytes / 96 bits #๏ธโฃ #[cfg(target_pointer_width = โ32โ)]
โ๏ธOption<T> ๐ฐ T
๐ฆ size_of::<LinuxSeekFrom>() == 16 bytes / 128 bits #๏ธโฃ #[cfg(target_pointer_width = โ64โ)]
โ๏ธOption<T> ๐ฐ T
Variants
Start(c_off_t)
Seek from the start of the file.
Current(c_off_t)
Seek from the current file position.
End(c_off_t)
Seek from the end of the file.
Data(c_off_t)
Seek to the next data region at or after the offset.
Hole(c_off_t)
Seek to the next hole at or after the offset.