pub struct IoPipeReader(/* private fields */);Available on crate features
std only.Expand description
๐
std
Read end of an anonymous pipe.
๐sys/io::IoPipeReader re-exported from std::io ::PipeReader as IoPipeReader
๐
Read end of an anonymous pipe.
Implementations
Sourceimpl PipeReader
impl PipeReader
1.87.0 ยท Sourcepub fn try_clone(&self) -> Result<PipeReader, Error> โ
pub fn try_clone(&self) -> Result<PipeReader, Error> โ
Creates a new PipeReader instance that shares the same underlying file description.
Examples
use std::fs;
use std::io::{pipe, Write};
use std::process::Command;
const NUM_SLOT: u8 = 2;
const NUM_PROC: u8 = 5;
const OUTPUT: &str = "work.txt";
let mut jobs = vec![];
let (reader, mut writer) = pipe()?;
// Write NUM_SLOT characters the pipe.
writer.write_all(&[b'|'; NUM_SLOT as usize])?;
// Spawn several processes that read a character from the pipe, do some work, then
// write back to the pipe. When the pipe is empty, the processes block, so only
// NUM_SLOT processes can be working at any given time.
for _ in 0..NUM_PROC {
jobs.push(
Command::new("bash")
.args(["-c",
&format!(
"read -n 1\n\
echo -n 'x' >> '{OUTPUT}'\n\
echo -n '|'",
),
])
.stdin(reader.try_clone()?)
.stdout(writer.try_clone()?)
.spawn()?,
);
}
// Wait for all jobs to finish.
for mut job in jobs {
job.wait()?;
}
// Check our work and clean up.
let xs = fs::read_to_string(OUTPUT)?;
fs::remove_file(OUTPUT)?;
assert_eq!(xs, "x".repeat(NUM_PROC.into()));Trait Implementations
1.87.0 ยท Sourceimpl AsFd for PipeReader
Available on non-Trusty only.
impl AsFd for PipeReader
Available on non-Trusty only.
Sourcefn as_fd(&self) -> BorrowedFd<'_>
fn as_fd(&self) -> BorrowedFd<'_>
Borrows the file descriptor. Read more
1.87.0 ยท Sourceimpl AsRawFd for PipeReader
Available on non-Trusty only.
impl AsRawFd for PipeReader
Available on non-Trusty only.
1.87.0 ยท Sourceimpl Debug for PipeReader
impl Debug for PipeReader
1.87.0 ยท Sourceimpl From<OwnedFd> for PipeReader
Available on non-Trusty only.
impl From<OwnedFd> for PipeReader
Available on non-Trusty only.
1.87.0 ยท Sourceimpl From<PipeReader> for OwnedFd
Available on non-Trusty only.
impl From<PipeReader> for OwnedFd
Available on non-Trusty only.
Sourcefn from(pipe: PipeReader) -> OwnedFd
fn from(pipe: PipeReader) -> OwnedFd
Converts to this type from the input type.
1.87.0 ยท Sourceimpl From<PipeReader> for Stdio
impl From<PipeReader> for Stdio
Sourcefn from(pipe: PipeReader) -> Stdio
fn from(pipe: PipeReader) -> Stdio
Converts to this type from the input type.
1.87.0 ยท Sourceimpl FromRawFd for PipeReader
Available on non-Trusty only.
impl FromRawFd for PipeReader
Available on non-Trusty only.
Sourceunsafe fn from_raw_fd(raw_fd: i32) -> PipeReader โ
unsafe fn from_raw_fd(raw_fd: i32) -> PipeReader โ
Constructs a new instance of
Self from the given raw file
descriptor. Read more1.87.0 ยท Sourceimpl IntoRawFd for PipeReader
Available on non-Trusty only.
impl IntoRawFd for PipeReader
Available on non-Trusty only.
Sourcefn into_raw_fd(self) -> i32
fn into_raw_fd(self) -> i32
Consumes this object, returning the raw underlying file descriptor. Read more
1.87.0 ยท Sourceimpl Read for &PipeReader
impl Read for &PipeReader
Sourcefn read(&mut self, buf: &mut [u8]) -> Result<usize, Error> โ
fn read(&mut self, buf: &mut [u8]) -> Result<usize, Error> โ
Pull some bytes from this source into the specified buffer, returning
how many bytes were read. Read more
Sourcefn read_vectored(&mut self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize, Error> โ
fn read_vectored(&mut self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize, Error> โ
Like
read, except that it reads into a slice of buffers. Read moreSourcefn is_read_vectored(&self) -> bool
fn is_read_vectored(&self) -> bool
๐ฌThis is a nightly-only experimental API. (
can_vector)Sourcefn read_to_end(&mut self, buf: &mut Vec<u8>) -> Result<usize, Error> โ
fn read_to_end(&mut self, buf: &mut Vec<u8>) -> Result<usize, Error> โ
Reads all bytes until EOF in this source, placing them into
buf. Read moreSourcefn read_buf(&mut self, buf: BorrowedCursor<'_, u8>) -> Result<(), Error> โ
fn read_buf(&mut self, buf: BorrowedCursor<'_, u8>) -> Result<(), Error> โ
๐ฌThis is a nightly-only experimental API. (
read_buf)Pull some bytes from this source into the specified buffer. Read more
1.0.0 ยท Sourcefn read_to_string(&mut self, buf: &mut String) -> Result<usize, Error> โ
fn read_to_string(&mut self, buf: &mut String) -> Result<usize, Error> โ
Reads all bytes until EOF in this source, appending them to
buf. Read more1.6.0 ยท Sourcefn read_exact(&mut self, buf: &mut [u8]) -> Result<(), Error> โ
fn read_exact(&mut self, buf: &mut [u8]) -> Result<(), Error> โ
Reads the exact number of bytes required to fill
buf. Read moreSourcefn read_buf_exact(
&mut self,
cursor: BorrowedCursor<'_, u8>,
) -> Result<(), Error> โ
fn read_buf_exact( &mut self, cursor: BorrowedCursor<'_, u8>, ) -> Result<(), Error> โ
๐ฌThis is a nightly-only experimental API. (
read_buf)Reads the exact number of bytes required to fill
cursor. Read more1.0.0 ยท Sourcefn by_ref(&mut self) -> &mut Selfwhere
Self: Sized,
fn by_ref(&mut self) -> &mut Selfwhere
Self: Sized,
Creates a โby referenceโ adapter for this instance of
Read. Read more1.0.0 ยท Sourcefn chain<R>(self, next: R) -> Chain<Self, R> โ
fn chain<R>(self, next: R) -> Chain<Self, R> โ
Creates an adapter which will chain this stream with another. Read more
1.0.0 ยท Sourcefn take(self, limit: u64) -> Take<Self> โwhere
Self: Sized,
fn take(self, limit: u64) -> Take<Self> โwhere
Self: Sized,
Creates an adapter which will read at most
limit bytes from it. Read moreSourcefn read_array<const N: usize>(&mut self) -> Result<[u8; N], Error> โwhere
Self: Sized,
fn read_array<const N: usize>(&mut self) -> Result<[u8; N], Error> โwhere
Self: Sized,
๐ฌThis is a nightly-only experimental API. (
read_array)Read and return a fixed array of bytes from this source. Read more
1.87.0 ยท Sourceimpl Read for PipeReader
impl Read for PipeReader
Sourcefn read(&mut self, buf: &mut [u8]) -> Result<usize, Error> โ
fn read(&mut self, buf: &mut [u8]) -> Result<usize, Error> โ
Pull some bytes from this source into the specified buffer, returning
how many bytes were read. Read more
Sourcefn read_vectored(&mut self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize, Error> โ
fn read_vectored(&mut self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize, Error> โ
Like
read, except that it reads into a slice of buffers. Read moreSourcefn is_read_vectored(&self) -> bool
fn is_read_vectored(&self) -> bool
๐ฌThis is a nightly-only experimental API. (
can_vector)Sourcefn read_to_end(&mut self, buf: &mut Vec<u8>) -> Result<usize, Error> โ
fn read_to_end(&mut self, buf: &mut Vec<u8>) -> Result<usize, Error> โ
Reads all bytes until EOF in this source, placing them into
buf. Read moreSourcefn read_buf(&mut self, buf: BorrowedCursor<'_, u8>) -> Result<(), Error> โ
fn read_buf(&mut self, buf: BorrowedCursor<'_, u8>) -> Result<(), Error> โ
๐ฌThis is a nightly-only experimental API. (
read_buf)Pull some bytes from this source into the specified buffer. Read more
1.0.0 ยท Sourcefn read_to_string(&mut self, buf: &mut String) -> Result<usize, Error> โ
fn read_to_string(&mut self, buf: &mut String) -> Result<usize, Error> โ
Reads all bytes until EOF in this source, appending them to
buf. Read more1.6.0 ยท Sourcefn read_exact(&mut self, buf: &mut [u8]) -> Result<(), Error> โ
fn read_exact(&mut self, buf: &mut [u8]) -> Result<(), Error> โ
Reads the exact number of bytes required to fill
buf. Read moreSourcefn read_buf_exact(
&mut self,
cursor: BorrowedCursor<'_, u8>,
) -> Result<(), Error> โ
fn read_buf_exact( &mut self, cursor: BorrowedCursor<'_, u8>, ) -> Result<(), Error> โ
๐ฌThis is a nightly-only experimental API. (
read_buf)Reads the exact number of bytes required to fill
cursor. Read more1.0.0 ยท Sourcefn by_ref(&mut self) -> &mut Selfwhere
Self: Sized,
fn by_ref(&mut self) -> &mut Selfwhere
Self: Sized,
Creates a โby referenceโ adapter for this instance of
Read. Read more1.0.0 ยท Sourcefn chain<R>(self, next: R) -> Chain<Self, R> โ
fn chain<R>(self, next: R) -> Chain<Self, R> โ
Creates an adapter which will chain this stream with another. Read more
1.0.0 ยท Sourcefn take(self, limit: u64) -> Take<Self> โwhere
Self: Sized,
fn take(self, limit: u64) -> Take<Self> โwhere
Self: Sized,
Creates an adapter which will read at most
limit bytes from it. Read moreSourcefn read_array<const N: usize>(&mut self) -> Result<[u8; N], Error> โwhere
Self: Sized,
fn read_array<const N: usize>(&mut self) -> Result<[u8; N], Error> โwhere
Self: Sized,
๐ฌThis is a nightly-only experimental API. (
read_array)Read and return a fixed array of bytes from this source. Read more