pub struct TextSegment {
pub span: TextLayoutSpan,
pub kind: TextSegmentKind,
}Expand description
๐ ๐งฑ A semantic text segment used for wrapping.
๐ text/layout::TextSegment
๐ฆ size_of::<TextSegment>() == 16 bytes / 128 bits
โ๏ธOption<T> ๐ฐ T
Fields
span: TextLayoutSpanCovered symbol range and whole-segment inline extent.
kind: TextSegmentKindSegment behavior during wrapping.
Implementations
Sourceimpl TextSegment
impl TextSegment
Sourcepub const fn new(span: TextLayoutSpan, kind: TextSegmentKind) -> Self
pub const fn new(span: TextLayoutSpan, kind: TextSegmentKind) -> Self
Creates a text segment.
Sourcepub const fn box_from_prim(start: u32, end: u32, units: TextUnit) -> Self
pub const fn box_from_prim(start: u32, end: u32, units: TextUnit) -> Self
Creates a box segment from primitive indices and units.
Sourcepub const fn glue_from_prim(start: u32, end: u32, units: TextUnit) -> Self
pub const fn glue_from_prim(start: u32, end: u32, units: TextUnit) -> Self
Creates a glue segment from primitive indices and units.
Sourcepub const fn hard_break_from_prim(start: u32, end: u32) -> Self
pub const fn hard_break_from_prim(start: u32, end: u32) -> Self
Creates a hard-break segment from primitive indices.
Sourcepub const fn is_hard_break(self) -> bool
pub const fn is_hard_break(self) -> bool
Returns whether this segment is a hard break.
Sourcepub const fn segments_from_chars(text: &str, out: &mut [TextSegment]) -> usize
pub const fn segments_from_chars(text: &str, out: &mut [TextSegment]) -> usize
Fills out with simple paragraph-oriented segments derived from chars.
Current policy:
- contiguous non-whitespace chars become
TextSegmentKind::Box - contiguous inline whitespace becomes one
TextSegmentKind::Glue \nand\r\nbecomeTextSegmentKind::HardBreak
Returns the initialized prefix length.