Mismatch

Struct Mismatch 

pub struct Mismatch<N, H> {
    pub need: N,
    pub have: H,
    pub info: &'static str,
}
⚖️ Represents a mismatch between an expected need and an encountered have.


📍 code/result


A diagnostic description of a mismatch between an expected requirement and an observed value. This type does not encode failure semantics on its own.

Fields

need: N

Information about something that was needed, expected or anticipated.

have: H

Information about something that was obtained, observed, or encountered.

info: &'static str

Contextual static information about the mismatch.

Implementations

Source

impl<N, H> Mismatch<N, H>

pub const fn new(need: N, have: H) -> Self

Creates a new Mismatch with the specified need and have.

pub const fn with_info(need: N, have: H, info: &'static str) -> Self

Creates a new Mismatch with the specified need, have, and info.

Source

impl<N, H> Mismatch<Interval<N>, H>

pub fn in_point_interval(need_point: N, have: H, info: &'static str) -> Self
where N: Clone,

Creates a mismatch where need is an Interval::point, and have does not match.

pub fn in_empty_interval(have: H, info: &'static str) -> Self
where N: Default,

Creates a mismatch where need is an Interval::empty, but have was provided.

pub const fn in_empty_const_interval(have: H, info: &'static str) -> Self
where N: ConstInit,

Creates a mismatch where need is an Interval::empty_const, but have was provided.

pub fn in_empty_interval_with(value: N, have: H, info: &'static str) -> Self
where N: Clone,

Creates a mismatch where need is an Interval::empty_with, but have was provided.

pub const fn in_closed_interval( lower: N, upper: N, have: H, info: &'static str, ) -> Self

Creates a mismatch where need is an Interval::closed, and have is outside it.

pub const fn in_closed_open_interval( lower: N, upper: N, have: H, info: &'static str, ) -> Self

Creates a mismatch where need is an Interval::closed_open, and have is outside it.

pub const fn in_open_interval( lower: N, upper: N, have: H, info: &'static str, ) -> Self

Creates a mismatch where need is an Interval::open, and have is outside it.