Struct devela::data::collections::UninitArray
source · pub struct UninitArray<T, const CAP: usize, S: Storage = Bare> { /* private fields */ }unsafe_array only.Expand description
A static array allowing uninitialized elements.
Implementations
sourceimpl<T, const CAP: usize, S: Storage> UninitArray<T, CAP, S>
impl<T, const CAP: usize, S: Storage> UninitArray<T, CAP, S>
sourcepub fn from_range<I>(iterator: I) -> Result<Self>where
I: IntoIterator<Item = T>,
pub fn from_range<I>(iterator: I) -> Result<Self>where
I: IntoIterator<Item = T>,
Initializes the array from an iterator until it’s either full or the iterator is exhausted.
Returns
- Returns a new array initialized with the elements from the
iterator. - Returns
PartiallyAddedif not all elements could be initialized. - Returns
NotEnoughSpaceif the array had no uninitialized elements.
sourcepub const fn verify_index(&self, index: usize) -> Result<usize>
pub const fn verify_index(&self, index: usize) -> Result<usize>
Returns index back if it’s within the range already initialized.
Errors
Returns OutOfBounds if the index is larger than the initialized length.
sourcepub fn get(&self, index: usize) -> Result<&T>
pub fn get(&self, index: usize) -> Result<&T>
Returns a shared reference to an initialized element at a given index.
Errors
Returns OutOfBounds if the index is larger than the initialized length.
or if the element at that index is not initialized.
sourcepub fn get_mut(&mut self, index: usize) -> Result<&mut T>
pub fn get_mut(&mut self, index: usize) -> Result<&mut T>
Returns an exclusive reference to an initialized element at a given index.
Errors
Returns OutOfBounds if the index is larger than the initialized length.
or if the element at that index is not initialized.
sourcepub fn init_next(&mut self, value: T) -> Result<()>
pub fn init_next(&mut self, value: T) -> Result<()>
Initializes the next uninitialized element with the provided value.
Errors
Returns OutOfBounds if the index is larger than the initialized length.
sourcepub fn init_range<I>(&mut self, values: I) -> Result<usize>where
I: IntoIterator<Item = T>,
pub fn init_range<I>(&mut self, values: I) -> Result<usize>where
I: IntoIterator<Item = T>,
Initializes elements from an iterator
Starts at the last initialized element, continues until either the array is full or the iterator is exhausted.
Returns
- Returns the number of elements initialized.
- Returns
PartiallyAddedif not all elements could be initialized. - Returns
NotEnoughSpaceif the array had no uninitialized elements.