IdPin

Struct IdPin 

pub struct IdPin<'a> { /* private fields */ }
๐Ÿซ† ๐Ÿงบ A unique identifier based on a pinned stack-allocated reference.


๐Ÿ“ data/id


IdPin generates a unique ID by pinning a value on the stack, ensuring that the ID is based on the stack memory address for the lifetime of the reference.

It doesnโ€™t implement Clone or Default.

Examples

let mut data1: u8 = 0;
let id1 = IdPin::new(&mut data1);

Vendored

This is adapted work from object-id.

Implementations

Source

impl<'a> IdPin<'a>

pub fn new(data: &'a mut u8) -> Self

Creates a new IdPin with a unique stack memory address.

Expects a mutable reference to a u8 data that will be pinned.

pub fn as_usize(&self) -> usize

Returns the unique ID as a usize, derived from the stack memory address.