GcdReturn

Struct GcdReturn 

pub struct GcdReturn<G, C> {
    pub gcd: G,
    pub x: C,
    pub y: C,
}
⚖️ A return type for the calculated GCD and the Bézout coeficients.


📍 num/dom/int


The coefficients are the solutions to the equation $ \text{gcd}(a, b) = ax + by $.

Fields

gcd: G

The greatest common divisor.

x: C

The first Bézout’s coefficient x.

y: C

The second Bézout’s coefficient y.

Implementations

Source

impl<G, C> GcdReturn<G, C>

pub const fn new(gcd: G, x: C, y: C) -> Self

Constructs a new GcdReturn.

pub fn as_tuple(self) -> (G, C, C)

Returns the values as a tuple.

Source

impl<G: Copy, C: Copy> GcdReturn<G, C>

pub const fn as_tuple_copy(self) -> (G, C, C)

Returns the values as a tuple, in compile-time.

Source

impl<T> GcdReturn<T, T>

pub fn as_array(self) -> [T; 3]

Returns the values as an array, if all are of the same type.

Source

impl<T: Copy> GcdReturn<T, T>

pub const fn as_array_copy(self) -> [T; 3]

Returns the values as an array, if all are of the same type.