pub enum HttpError {
EmptyRequestLine,
MissingMethod,
MissingTarget,
MissingVersion,
TrailingData,
InvalidHeaderValue,
InvalidMethod,
InvalidTarget,
InvalidVersion,
MissingLineEnding,
NotEnoughSpace(usize),
}Available on crate feature
http only.Expand description
Variants
EmptyRequestLine
The request line is empty.
MissingMethod
The request line is missing the method token.
MissingTarget
The request line is missing the request-target token.
MissingVersion
The request line is missing the HTTP-version token.
TrailingData
The request line contains extra data after the HTTP-version token.
InvalidHeaderValue
A response header value contains a forbidden control byte.
InvalidMethod
The method is not a valid HTTP token.
InvalidTarget
The request target is malformed.
InvalidVersion
The HTTP version token is invalid or unsupported.
MissingLineEnding
A required CRLF line ending was not found.
NotEnoughSpace(usize)
The destination buffer is too small.
Contains the minimum required length in bytes.
Implementations