LinuxSignalSet

Struct LinuxSignalSet 

pub struct LinuxSignalSet { /* private fields */ }
Available on crate feature linux only.
๐Ÿง ๐Ÿ“ถ โІ A compact semantic set of standard Linux signals.


๐Ÿ“ sys/os/linux/process

๐Ÿ“ฆ size_of::<LinuxSignalSet>() == 4 bytes / 32 bits


This is not the raw Linux sigset_t mask. Signal bits are stored compactly from zero: SIGHUP is bit 0, SIGINT is bit 1, โ€ฆ

Implementations

Source

impl LinuxSignalSet

pub const fn from_signal(signal: LinuxSignal) -> Self

Returns a singleton set containing signal.

pub const fn to_signal(self) -> Option<LinuxSignal> โ“˜

Returns the only signal in this set, if it contains exactly one.

pub fn for_each(self, f: impl FnMut(LinuxSignal))

Calls f for each signal in this set.

pub fn for_each_catchable(self, f: impl FnMut(LinuxSignal))

Calls f for each catchable signal in this set.

pub const fn all_catchable(self) -> bool

Returns whether all signals in this set are catchable.

pub const fn catchable_only(self) -> Self

Returns this set without without signals that cannot be caught.

Source

impl LinuxSignalSet

Named constants

pub const SIGHUP: Self

1 The bit index that corresponds to LinuxSignal::SIGHUP.

pub const SIGINT: Self

1 The bit index that corresponds to LinuxSignal::SIGINT.

pub const SIGQUIT: Self

1 The bit index that corresponds to LinuxSignal::SIGQUIT.

pub const SIGILL: Self

1 The bit index that corresponds to LinuxSignal::SIGILL.

pub const SIGTRAP: Self

1 The bit index that corresponds to LinuxSignal::SIGTRAP.

pub const SIGABRT: Self

1 The bit index that corresponds to LinuxSignal::SIGABRT.

pub const SIGBUS: Self

1 The bit index that corresponds to LinuxSignal::SIGBUS.

pub const SIGFPE: Self

1 The bit index that corresponds to LinuxSignal::SIGFPE.

pub const SIGKILL: Self

1 The bit index that corresponds to LinuxSignal::SIGKILL.

pub const SIGUSR1: Self

1 The bit index that corresponds to LinuxSignal::SIGUSR1.

pub const SIGSEGV: Self

1 The bit index that corresponds to LinuxSignal::SIGSEGV.

pub const SIGUSR2: Self

1 The bit index that corresponds to LinuxSignal::SIGUSR2.

pub const SIGPIPE: Self

1 The bit index that corresponds to LinuxSignal::SIGPIPE.

pub const SIGALRM: Self

1 The bit index that corresponds to LinuxSignal::SIGALRM.

pub const SIGTERM: Self

1 The bit index that corresponds to LinuxSignal::SIGTERM.

pub const SIGSTKFLT: Self

1 The bit index that corresponds to LinuxSignal::SIGSTKFLT.

pub const SIGCHLD: Self

1 The bit index that corresponds to LinuxSignal::SIGCHLD.

pub const SIGCONT: Self

1 The bit index that corresponds to LinuxSignal::SIGCONT.

pub const SIGSTOP: Self

1 The bit index that corresponds to LinuxSignal::SIGSTOP.

pub const SIGTSTP: Self

1 The bit index that corresponds to LinuxSignal::SIGTSTP.

pub const SIGTTIN: Self

1 The bit index that corresponds to LinuxSignal::SIGTTIN.

pub const SIGTTOU: Self

1 The bit index that corresponds to LinuxSignal::SIGTTOU.

pub const SIGURG: Self

1 The bit index that corresponds to LinuxSignal::SIGURG.

pub const SIGXCPU: Self

1 The bit index that corresponds to LinuxSignal::SIGXCPU.

pub const SIGXFSZ: Self

1 The bit index that corresponds to LinuxSignal::SIGXFSZ.

pub const SIGVTALRM: Self

1 The bit index that corresponds to LinuxSignal::SIGVTALRM.

pub const SIGPROF: Self

1 The bit index that corresponds to LinuxSignal::SIGPROF.

pub const SIGWINCH: Self

1 The bit index that corresponds to LinuxSignal::SIGWINCH.

pub const SIGIO: Self

1 The bit index that corresponds to LinuxSignal::SIGIO.

pub const SIGPWR: Self

1 The bit index that corresponds to LinuxSignal::SIGPWR.

pub const SIGSYS: Self

1 The bit index that corresponds to LinuxSignal::SIGSYS.

Source

impl LinuxSignalSet

Convenience methods derived from each named constant.

pub const fn has_sighup(self) -> bool

Returns true if SIGHUP is present.

pub const fn contains_sighup(self) -> bool

Returns true if all bits in SIGHUP are present.

pub const fn intersects_sighup(self) -> bool

Returns true if the set shares any bit with SIGHUP.

pub const fn with_sighup(self) -> Self

Returns self with SIGHUP inserted.

pub const fn with_sighup_if(self, condition: bool) -> Self

Returns self with SIGHUP inserted if condition is true.

pub const fn without_sighup(self) -> Self

Returns self with SIGHUP removed.

pub const fn set_sighup(&mut self)

Sets SIGHUP.

pub const fn set_sighup_if(&mut self, condition: bool)

Sets SIGHUP if condition is true.

pub const fn unset_sighup(&mut self)

Unsets SIGHUP.

pub const fn has_sigint(self) -> bool

Returns true if SIGINT is present.

pub const fn contains_sigint(self) -> bool

Returns true if all bits in SIGINT are present.

pub const fn intersects_sigint(self) -> bool

Returns true if the set shares any bit with SIGINT.

pub const fn with_sigint(self) -> Self

Returns self with SIGINT inserted.

pub const fn with_sigint_if(self, condition: bool) -> Self

Returns self with SIGINT inserted if condition is true.

pub const fn without_sigint(self) -> Self

Returns self with SIGINT removed.

pub const fn set_sigint(&mut self)

Sets SIGINT.

pub const fn set_sigint_if(&mut self, condition: bool)

Sets SIGINT if condition is true.

pub const fn unset_sigint(&mut self)

Unsets SIGINT.

pub const fn has_sigquit(self) -> bool

Returns true if SIGQUIT is present.

pub const fn contains_sigquit(self) -> bool

Returns true if all bits in SIGQUIT are present.

pub const fn intersects_sigquit(self) -> bool

Returns true if the set shares any bit with SIGQUIT.

pub const fn with_sigquit(self) -> Self

Returns self with SIGQUIT inserted.

pub const fn with_sigquit_if(self, condition: bool) -> Self

Returns self with SIGQUIT inserted if condition is true.

pub const fn without_sigquit(self) -> Self

Returns self with SIGQUIT removed.

pub const fn set_sigquit(&mut self)

Sets SIGQUIT.

pub const fn set_sigquit_if(&mut self, condition: bool)

Sets SIGQUIT if condition is true.

pub const fn unset_sigquit(&mut self)

Unsets SIGQUIT.

pub const fn has_sigill(self) -> bool

Returns true if SIGILL is present.

pub const fn contains_sigill(self) -> bool

Returns true if all bits in SIGILL are present.

pub const fn intersects_sigill(self) -> bool

Returns true if the set shares any bit with SIGILL.

pub const fn with_sigill(self) -> Self

Returns self with SIGILL inserted.

pub const fn with_sigill_if(self, condition: bool) -> Self

Returns self with SIGILL inserted if condition is true.

pub const fn without_sigill(self) -> Self

Returns self with SIGILL removed.

pub const fn set_sigill(&mut self)

Sets SIGILL.

pub const fn set_sigill_if(&mut self, condition: bool)

Sets SIGILL if condition is true.

pub const fn unset_sigill(&mut self)

Unsets SIGILL.

pub const fn has_sigtrap(self) -> bool

Returns true if SIGTRAP is present.

pub const fn contains_sigtrap(self) -> bool

Returns true if all bits in SIGTRAP are present.

pub const fn intersects_sigtrap(self) -> bool

Returns true if the set shares any bit with SIGTRAP.

pub const fn with_sigtrap(self) -> Self

Returns self with SIGTRAP inserted.

pub const fn with_sigtrap_if(self, condition: bool) -> Self

Returns self with SIGTRAP inserted if condition is true.

pub const fn without_sigtrap(self) -> Self

Returns self with SIGTRAP removed.

pub const fn set_sigtrap(&mut self)

Sets SIGTRAP.

pub const fn set_sigtrap_if(&mut self, condition: bool)

Sets SIGTRAP if condition is true.

pub const fn unset_sigtrap(&mut self)

Unsets SIGTRAP.

pub const fn has_sigabrt(self) -> bool

Returns true if SIGABRT is present.

pub const fn contains_sigabrt(self) -> bool

Returns true if all bits in SIGABRT are present.

pub const fn intersects_sigabrt(self) -> bool

Returns true if the set shares any bit with SIGABRT.

pub const fn with_sigabrt(self) -> Self

Returns self with SIGABRT inserted.

pub const fn with_sigabrt_if(self, condition: bool) -> Self

Returns self with SIGABRT inserted if condition is true.

pub const fn without_sigabrt(self) -> Self

Returns self with SIGABRT removed.

pub const fn set_sigabrt(&mut self)

Sets SIGABRT.

pub const fn set_sigabrt_if(&mut self, condition: bool)

Sets SIGABRT if condition is true.

pub const fn unset_sigabrt(&mut self)

Unsets SIGABRT.

pub const fn has_sigbus(self) -> bool

Returns true if SIGBUS is present.

pub const fn contains_sigbus(self) -> bool

Returns true if all bits in SIGBUS are present.

pub const fn intersects_sigbus(self) -> bool

Returns true if the set shares any bit with SIGBUS.

pub const fn with_sigbus(self) -> Self

Returns self with SIGBUS inserted.

pub const fn with_sigbus_if(self, condition: bool) -> Self

Returns self with SIGBUS inserted if condition is true.

pub const fn without_sigbus(self) -> Self

Returns self with SIGBUS removed.

pub const fn set_sigbus(&mut self)

Sets SIGBUS.

pub const fn set_sigbus_if(&mut self, condition: bool)

Sets SIGBUS if condition is true.

pub const fn unset_sigbus(&mut self)

Unsets SIGBUS.

pub const fn has_sigfpe(self) -> bool

Returns true if SIGFPE is present.

pub const fn contains_sigfpe(self) -> bool

Returns true if all bits in SIGFPE are present.

pub const fn intersects_sigfpe(self) -> bool

Returns true if the set shares any bit with SIGFPE.

pub const fn with_sigfpe(self) -> Self

Returns self with SIGFPE inserted.

pub const fn with_sigfpe_if(self, condition: bool) -> Self

Returns self with SIGFPE inserted if condition is true.

pub const fn without_sigfpe(self) -> Self

Returns self with SIGFPE removed.

pub const fn set_sigfpe(&mut self)

Sets SIGFPE.

pub const fn set_sigfpe_if(&mut self, condition: bool)

Sets SIGFPE if condition is true.

pub const fn unset_sigfpe(&mut self)

Unsets SIGFPE.

pub const fn has_sigkill(self) -> bool

Returns true if SIGKILL is present.

pub const fn contains_sigkill(self) -> bool

Returns true if all bits in SIGKILL are present.

pub const fn intersects_sigkill(self) -> bool

Returns true if the set shares any bit with SIGKILL.

pub const fn with_sigkill(self) -> Self

Returns self with SIGKILL inserted.

pub const fn with_sigkill_if(self, condition: bool) -> Self

Returns self with SIGKILL inserted if condition is true.

pub const fn without_sigkill(self) -> Self

Returns self with SIGKILL removed.

pub const fn set_sigkill(&mut self)

Sets SIGKILL.

pub const fn set_sigkill_if(&mut self, condition: bool)

Sets SIGKILL if condition is true.

pub const fn unset_sigkill(&mut self)

Unsets SIGKILL.

pub const fn has_sigusr1(self) -> bool

Returns true if SIGUSR1 is present.

pub const fn contains_sigusr1(self) -> bool

Returns true if all bits in SIGUSR1 are present.

pub const fn intersects_sigusr1(self) -> bool

Returns true if the set shares any bit with SIGUSR1.

pub const fn with_sigusr1(self) -> Self

Returns self with SIGUSR1 inserted.

pub const fn with_sigusr1_if(self, condition: bool) -> Self

Returns self with SIGUSR1 inserted if condition is true.

pub const fn without_sigusr1(self) -> Self

Returns self with SIGUSR1 removed.

pub const fn set_sigusr1(&mut self)

Sets SIGUSR1.

pub const fn set_sigusr1_if(&mut self, condition: bool)

Sets SIGUSR1 if condition is true.

pub const fn unset_sigusr1(&mut self)

Unsets SIGUSR1.

pub const fn has_sigsegv(self) -> bool

Returns true if SIGSEGV is present.

pub const fn contains_sigsegv(self) -> bool

Returns true if all bits in SIGSEGV are present.

pub const fn intersects_sigsegv(self) -> bool

Returns true if the set shares any bit with SIGSEGV.

pub const fn with_sigsegv(self) -> Self

Returns self with SIGSEGV inserted.

pub const fn with_sigsegv_if(self, condition: bool) -> Self

Returns self with SIGSEGV inserted if condition is true.

pub const fn without_sigsegv(self) -> Self

Returns self with SIGSEGV removed.

pub const fn set_sigsegv(&mut self)

Sets SIGSEGV.

pub const fn set_sigsegv_if(&mut self, condition: bool)

Sets SIGSEGV if condition is true.

pub const fn unset_sigsegv(&mut self)

Unsets SIGSEGV.

pub const fn has_sigusr2(self) -> bool

Returns true if SIGUSR2 is present.

pub const fn contains_sigusr2(self) -> bool

Returns true if all bits in SIGUSR2 are present.

pub const fn intersects_sigusr2(self) -> bool

Returns true if the set shares any bit with SIGUSR2.

pub const fn with_sigusr2(self) -> Self

Returns self with SIGUSR2 inserted.

pub const fn with_sigusr2_if(self, condition: bool) -> Self

Returns self with SIGUSR2 inserted if condition is true.

pub const fn without_sigusr2(self) -> Self

Returns self with SIGUSR2 removed.

pub const fn set_sigusr2(&mut self)

Sets SIGUSR2.

pub const fn set_sigusr2_if(&mut self, condition: bool)

Sets SIGUSR2 if condition is true.

pub const fn unset_sigusr2(&mut self)

Unsets SIGUSR2.

pub const fn has_sigpipe(self) -> bool

Returns true if SIGPIPE is present.

pub const fn contains_sigpipe(self) -> bool

Returns true if all bits in SIGPIPE are present.

pub const fn intersects_sigpipe(self) -> bool

Returns true if the set shares any bit with SIGPIPE.

pub const fn with_sigpipe(self) -> Self

Returns self with SIGPIPE inserted.

pub const fn with_sigpipe_if(self, condition: bool) -> Self

Returns self with SIGPIPE inserted if condition is true.

pub const fn without_sigpipe(self) -> Self

Returns self with SIGPIPE removed.

pub const fn set_sigpipe(&mut self)

Sets SIGPIPE.

pub const fn set_sigpipe_if(&mut self, condition: bool)

Sets SIGPIPE if condition is true.

pub const fn unset_sigpipe(&mut self)

Unsets SIGPIPE.

pub const fn has_sigalrm(self) -> bool

Returns true if SIGALRM is present.

pub const fn contains_sigalrm(self) -> bool

Returns true if all bits in SIGALRM are present.

pub const fn intersects_sigalrm(self) -> bool

Returns true if the set shares any bit with SIGALRM.

pub const fn with_sigalrm(self) -> Self

Returns self with SIGALRM inserted.

pub const fn with_sigalrm_if(self, condition: bool) -> Self

Returns self with SIGALRM inserted if condition is true.

pub const fn without_sigalrm(self) -> Self

Returns self with SIGALRM removed.

pub const fn set_sigalrm(&mut self)

Sets SIGALRM.

pub const fn set_sigalrm_if(&mut self, condition: bool)

Sets SIGALRM if condition is true.

pub const fn unset_sigalrm(&mut self)

Unsets SIGALRM.

pub const fn has_sigterm(self) -> bool

Returns true if SIGTERM is present.

pub const fn contains_sigterm(self) -> bool

Returns true if all bits in SIGTERM are present.

pub const fn intersects_sigterm(self) -> bool

Returns true if the set shares any bit with SIGTERM.

pub const fn with_sigterm(self) -> Self

Returns self with SIGTERM inserted.

pub const fn with_sigterm_if(self, condition: bool) -> Self

Returns self with SIGTERM inserted if condition is true.

pub const fn without_sigterm(self) -> Self

Returns self with SIGTERM removed.

pub const fn set_sigterm(&mut self)

Sets SIGTERM.

pub const fn set_sigterm_if(&mut self, condition: bool)

Sets SIGTERM if condition is true.

pub const fn unset_sigterm(&mut self)

Unsets SIGTERM.

pub const fn has_sigstkflt(self) -> bool

Returns true if SIGSTKFLT is present.

pub const fn contains_sigstkflt(self) -> bool

Returns true if all bits in SIGSTKFLT are present.

pub const fn intersects_sigstkflt(self) -> bool

Returns true if the set shares any bit with SIGSTKFLT.

pub const fn with_sigstkflt(self) -> Self

Returns self with SIGSTKFLT inserted.

pub const fn with_sigstkflt_if(self, condition: bool) -> Self

Returns self with SIGSTKFLT inserted if condition is true.

pub const fn without_sigstkflt(self) -> Self

Returns self with SIGSTKFLT removed.

pub const fn set_sigstkflt(&mut self)

Sets SIGSTKFLT.

pub const fn set_sigstkflt_if(&mut self, condition: bool)

Sets SIGSTKFLT if condition is true.

pub const fn unset_sigstkflt(&mut self)

Unsets SIGSTKFLT.

pub const fn has_sigchld(self) -> bool

Returns true if SIGCHLD is present.

pub const fn contains_sigchld(self) -> bool

Returns true if all bits in SIGCHLD are present.

pub const fn intersects_sigchld(self) -> bool

Returns true if the set shares any bit with SIGCHLD.

pub const fn with_sigchld(self) -> Self

Returns self with SIGCHLD inserted.

pub const fn with_sigchld_if(self, condition: bool) -> Self

Returns self with SIGCHLD inserted if condition is true.

pub const fn without_sigchld(self) -> Self

Returns self with SIGCHLD removed.

pub const fn set_sigchld(&mut self)

Sets SIGCHLD.

pub const fn set_sigchld_if(&mut self, condition: bool)

Sets SIGCHLD if condition is true.

pub const fn unset_sigchld(&mut self)

Unsets SIGCHLD.

pub const fn has_sigcont(self) -> bool

Returns true if SIGCONT is present.

pub const fn contains_sigcont(self) -> bool

Returns true if all bits in SIGCONT are present.

pub const fn intersects_sigcont(self) -> bool

Returns true if the set shares any bit with SIGCONT.

pub const fn with_sigcont(self) -> Self

Returns self with SIGCONT inserted.

pub const fn with_sigcont_if(self, condition: bool) -> Self

Returns self with SIGCONT inserted if condition is true.

pub const fn without_sigcont(self) -> Self

Returns self with SIGCONT removed.

pub const fn set_sigcont(&mut self)

Sets SIGCONT.

pub const fn set_sigcont_if(&mut self, condition: bool)

Sets SIGCONT if condition is true.

pub const fn unset_sigcont(&mut self)

Unsets SIGCONT.

pub const fn has_sigstop(self) -> bool

Returns true if SIGSTOP is present.

pub const fn contains_sigstop(self) -> bool

Returns true if all bits in SIGSTOP are present.

pub const fn intersects_sigstop(self) -> bool

Returns true if the set shares any bit with SIGSTOP.

pub const fn with_sigstop(self) -> Self

Returns self with SIGSTOP inserted.

pub const fn with_sigstop_if(self, condition: bool) -> Self

Returns self with SIGSTOP inserted if condition is true.

pub const fn without_sigstop(self) -> Self

Returns self with SIGSTOP removed.

pub const fn set_sigstop(&mut self)

Sets SIGSTOP.

pub const fn set_sigstop_if(&mut self, condition: bool)

Sets SIGSTOP if condition is true.

pub const fn unset_sigstop(&mut self)

Unsets SIGSTOP.

pub const fn has_sigtstp(self) -> bool

Returns true if SIGTSTP is present.

pub const fn contains_sigtstp(self) -> bool

Returns true if all bits in SIGTSTP are present.

pub const fn intersects_sigtstp(self) -> bool

Returns true if the set shares any bit with SIGTSTP.

pub const fn with_sigtstp(self) -> Self

Returns self with SIGTSTP inserted.

pub const fn with_sigtstp_if(self, condition: bool) -> Self

Returns self with SIGTSTP inserted if condition is true.

pub const fn without_sigtstp(self) -> Self

Returns self with SIGTSTP removed.

pub const fn set_sigtstp(&mut self)

Sets SIGTSTP.

pub const fn set_sigtstp_if(&mut self, condition: bool)

Sets SIGTSTP if condition is true.

pub const fn unset_sigtstp(&mut self)

Unsets SIGTSTP.

pub const fn has_sigttin(self) -> bool

Returns true if SIGTTIN is present.

pub const fn contains_sigttin(self) -> bool

Returns true if all bits in SIGTTIN are present.

pub const fn intersects_sigttin(self) -> bool

Returns true if the set shares any bit with SIGTTIN.

pub const fn with_sigttin(self) -> Self

Returns self with SIGTTIN inserted.

pub const fn with_sigttin_if(self, condition: bool) -> Self

Returns self with SIGTTIN inserted if condition is true.

pub const fn without_sigttin(self) -> Self

Returns self with SIGTTIN removed.

pub const fn set_sigttin(&mut self)

Sets SIGTTIN.

pub const fn set_sigttin_if(&mut self, condition: bool)

Sets SIGTTIN if condition is true.

pub const fn unset_sigttin(&mut self)

Unsets SIGTTIN.

pub const fn has_sigttou(self) -> bool

Returns true if SIGTTOU is present.

pub const fn contains_sigttou(self) -> bool

Returns true if all bits in SIGTTOU are present.

pub const fn intersects_sigttou(self) -> bool

Returns true if the set shares any bit with SIGTTOU.

pub const fn with_sigttou(self) -> Self

Returns self with SIGTTOU inserted.

pub const fn with_sigttou_if(self, condition: bool) -> Self

Returns self with SIGTTOU inserted if condition is true.

pub const fn without_sigttou(self) -> Self

Returns self with SIGTTOU removed.

pub const fn set_sigttou(&mut self)

Sets SIGTTOU.

pub const fn set_sigttou_if(&mut self, condition: bool)

Sets SIGTTOU if condition is true.

pub const fn unset_sigttou(&mut self)

Unsets SIGTTOU.

pub const fn has_sigurg(self) -> bool

Returns true if SIGURG is present.

pub const fn contains_sigurg(self) -> bool

Returns true if all bits in SIGURG are present.

pub const fn intersects_sigurg(self) -> bool

Returns true if the set shares any bit with SIGURG.

pub const fn with_sigurg(self) -> Self

Returns self with SIGURG inserted.

pub const fn with_sigurg_if(self, condition: bool) -> Self

Returns self with SIGURG inserted if condition is true.

pub const fn without_sigurg(self) -> Self

Returns self with SIGURG removed.

pub const fn set_sigurg(&mut self)

Sets SIGURG.

pub const fn set_sigurg_if(&mut self, condition: bool)

Sets SIGURG if condition is true.

pub const fn unset_sigurg(&mut self)

Unsets SIGURG.

pub const fn has_sigxcpu(self) -> bool

Returns true if SIGXCPU is present.

pub const fn contains_sigxcpu(self) -> bool

Returns true if all bits in SIGXCPU are present.

pub const fn intersects_sigxcpu(self) -> bool

Returns true if the set shares any bit with SIGXCPU.

pub const fn with_sigxcpu(self) -> Self

Returns self with SIGXCPU inserted.

pub const fn with_sigxcpu_if(self, condition: bool) -> Self

Returns self with SIGXCPU inserted if condition is true.

pub const fn without_sigxcpu(self) -> Self

Returns self with SIGXCPU removed.

pub const fn set_sigxcpu(&mut self)

Sets SIGXCPU.

pub const fn set_sigxcpu_if(&mut self, condition: bool)

Sets SIGXCPU if condition is true.

pub const fn unset_sigxcpu(&mut self)

Unsets SIGXCPU.

pub const fn has_sigxfsz(self) -> bool

Returns true if SIGXFSZ is present.

pub const fn contains_sigxfsz(self) -> bool

Returns true if all bits in SIGXFSZ are present.

pub const fn intersects_sigxfsz(self) -> bool

Returns true if the set shares any bit with SIGXFSZ.

pub const fn with_sigxfsz(self) -> Self

Returns self with SIGXFSZ inserted.

pub const fn with_sigxfsz_if(self, condition: bool) -> Self

Returns self with SIGXFSZ inserted if condition is true.

pub const fn without_sigxfsz(self) -> Self

Returns self with SIGXFSZ removed.

pub const fn set_sigxfsz(&mut self)

Sets SIGXFSZ.

pub const fn set_sigxfsz_if(&mut self, condition: bool)

Sets SIGXFSZ if condition is true.

pub const fn unset_sigxfsz(&mut self)

Unsets SIGXFSZ.

pub const fn has_sigvtalrm(self) -> bool

Returns true if SIGVTALRM is present.

pub const fn contains_sigvtalrm(self) -> bool

Returns true if all bits in SIGVTALRM are present.

pub const fn intersects_sigvtalrm(self) -> bool

Returns true if the set shares any bit with SIGVTALRM.

pub const fn with_sigvtalrm(self) -> Self

Returns self with SIGVTALRM inserted.

pub const fn with_sigvtalrm_if(self, condition: bool) -> Self

Returns self with SIGVTALRM inserted if condition is true.

pub const fn without_sigvtalrm(self) -> Self

Returns self with SIGVTALRM removed.

pub const fn set_sigvtalrm(&mut self)

Sets SIGVTALRM.

pub const fn set_sigvtalrm_if(&mut self, condition: bool)

Sets SIGVTALRM if condition is true.

pub const fn unset_sigvtalrm(&mut self)

Unsets SIGVTALRM.

pub const fn has_sigprof(self) -> bool

Returns true if SIGPROF is present.

pub const fn contains_sigprof(self) -> bool

Returns true if all bits in SIGPROF are present.

pub const fn intersects_sigprof(self) -> bool

Returns true if the set shares any bit with SIGPROF.

pub const fn with_sigprof(self) -> Self

Returns self with SIGPROF inserted.

pub const fn with_sigprof_if(self, condition: bool) -> Self

Returns self with SIGPROF inserted if condition is true.

pub const fn without_sigprof(self) -> Self

Returns self with SIGPROF removed.

pub const fn set_sigprof(&mut self)

Sets SIGPROF.

pub const fn set_sigprof_if(&mut self, condition: bool)

Sets SIGPROF if condition is true.

pub const fn unset_sigprof(&mut self)

Unsets SIGPROF.

pub const fn has_sigwinch(self) -> bool

Returns true if SIGWINCH is present.

pub const fn contains_sigwinch(self) -> bool

Returns true if all bits in SIGWINCH are present.

pub const fn intersects_sigwinch(self) -> bool

Returns true if the set shares any bit with SIGWINCH.

pub const fn with_sigwinch(self) -> Self

Returns self with SIGWINCH inserted.

pub const fn with_sigwinch_if(self, condition: bool) -> Self

Returns self with SIGWINCH inserted if condition is true.

pub const fn without_sigwinch(self) -> Self

Returns self with SIGWINCH removed.

pub const fn set_sigwinch(&mut self)

Sets SIGWINCH.

pub const fn set_sigwinch_if(&mut self, condition: bool)

Sets SIGWINCH if condition is true.

pub const fn unset_sigwinch(&mut self)

Unsets SIGWINCH.

pub const fn has_sigio(self) -> bool

Returns true if SIGIO is present.

pub const fn contains_sigio(self) -> bool

Returns true if all bits in SIGIO are present.

pub const fn intersects_sigio(self) -> bool

Returns true if the set shares any bit with SIGIO.

pub const fn with_sigio(self) -> Self

Returns self with SIGIO inserted.

pub const fn with_sigio_if(self, condition: bool) -> Self

Returns self with SIGIO inserted if condition is true.

pub const fn without_sigio(self) -> Self

Returns self with SIGIO removed.

pub const fn set_sigio(&mut self)

Sets SIGIO.

pub const fn set_sigio_if(&mut self, condition: bool)

Sets SIGIO if condition is true.

pub const fn unset_sigio(&mut self)

Unsets SIGIO.

pub const fn has_sigpwr(self) -> bool

Returns true if SIGPWR is present.

pub const fn contains_sigpwr(self) -> bool

Returns true if all bits in SIGPWR are present.

pub const fn intersects_sigpwr(self) -> bool

Returns true if the set shares any bit with SIGPWR.

pub const fn with_sigpwr(self) -> Self

Returns self with SIGPWR inserted.

pub const fn with_sigpwr_if(self, condition: bool) -> Self

Returns self with SIGPWR inserted if condition is true.

pub const fn without_sigpwr(self) -> Self

Returns self with SIGPWR removed.

pub const fn set_sigpwr(&mut self)

Sets SIGPWR.

pub const fn set_sigpwr_if(&mut self, condition: bool)

Sets SIGPWR if condition is true.

pub const fn unset_sigpwr(&mut self)

Unsets SIGPWR.

pub const fn has_sigsys(self) -> bool

Returns true if SIGSYS is present.

pub const fn contains_sigsys(self) -> bool

Returns true if all bits in SIGSYS are present.

pub const fn intersects_sigsys(self) -> bool

Returns true if the set shares any bit with SIGSYS.

pub const fn with_sigsys(self) -> Self

Returns self with SIGSYS inserted.

pub const fn with_sigsys_if(self, condition: bool) -> Self

Returns self with SIGSYS inserted if condition is true.

pub const fn without_sigsys(self) -> Self

Returns self with SIGSYS removed.

pub const fn set_sigsys(&mut self)

Sets SIGSYS.

pub const fn set_sigsys_if(&mut self, condition: bool)

Sets SIGSYS if condition is true.

pub const fn unset_sigsys(&mut self)

Unsets SIGSYS.

Source

impl LinuxSignalSet

Common set methods

pub const fn new() -> Self

Returns an empty set.

pub const fn from_bits(bits: u32) -> Self

Returns a set from raw bits.

pub const fn bits(self) -> u32

Returns the raw backing bits.

pub const fn all() -> Self

Returns the union of all declared sets.

pub const fn is_empty(self) -> bool

Returns true if no bits are set.

pub const fn is_full(self) -> bool

Returns true if all the declared bits are set.

pub const fn contains(self, other: Self) -> bool

Returns true if all bits in other are also set in self.

pub const fn has(self, other: Self) -> bool

An alias of contains.

pub const fn with(self, other: Self) -> Self

Returns self with other inserted.

pub const fn with_if(self, condition: bool, other: Self) -> Self

Returns self with other inserted if condition is true.

pub const fn without(self, other: Self) -> Self

Returns self with other removed.

pub const fn toggled(self, other: Self) -> Self

Returns self with other toggled.

Source

impl LinuxSignalSet

Set operations

pub const fn intersects(self, other: Self) -> bool

Returns true if self and other share any bit.

pub const fn is_subset(self, other: Self) -> bool

Returns true if all bits in self are also set in other.

pub const fn is_superset(self, other: Self) -> bool

Returns true if all bits in other are also set in self.

pub const fn union(self, other: Self) -> Self

Returns the union of self and other.

pub const fn intersection(self, other: Self) -> Self

Returns the intersection of self and other.

pub const fn difference(self, other: Self) -> Self

Returns the difference of self and other.

pub const fn symmetric_difference(self, other: Self) -> Self

Returns the symmetric difference of self and other.

Source

impl LinuxSignalSet

Mutating set operations

pub const fn clear(&mut self)

Clears the set.

pub const fn insert(&mut self, other: Self)

Inserts all bits from other.

pub const fn remove(&mut self, other: Self)

Removes all bits from other.

pub const fn toggle(&mut self, other: Self)

Toggles all bits from other.