pub enum CoroutineState<Y, R> {
Yielded(Y),
Complete(R),
}coroutine_trait)nightly_coro only.Expand description
๐งต โฌก โ๏ธ
core
The result of a coroutine resumption.
๐work/task/coro re-exported from core::ops
๐
The result of a coroutine resumption.
This enum is returned from the Coroutine::resume method and indicates the
possible return values of a coroutine. Currently this corresponds to either
a suspension point (Yielded) or a termination point (Complete).
Variants
Yielded(Y)
coroutine_trait)The coroutine suspended with a value.
This state indicates that a coroutine has been suspended, and typically
corresponds to a yield statement. The value provided in this variant
corresponds to the expression passed to yield and allows coroutines to
provide a value each time they yield.
Complete(R)
coroutine_trait)The coroutine completed with a return value.
This state indicates that a coroutine has finished execution with the
provided value. Once a coroutine has returned Complete it is
considered a programmer error to call resume again.