EnumintI8Example

Enum EnumintI8Example 

#[repr(i8)]
pub enum EnumintI8Example {
Show 253 variants N126 = -126, N125 = -125, N124 = -124, N123 = -123, N122 = -122, N121 = -121, N120 = -120, N119 = -119, N118 = -118, N117 = -117, N116 = -116, N115 = -115, N114 = -114, N113 = -113, N112 = -112, N111 = -111, N110 = -110, N109 = -109, N108 = -108, N107 = -107, N106 = -106, N105 = -105, N104 = -104, N103 = -103, N102 = -102, N101 = -101, N100 = -100, N99 = -99, N98 = -98, N97 = -97, N96 = -96, N95 = -95, N94 = -94, N93 = -93, N92 = -92, N91 = -91, N90 = -90, N89 = -89, N88 = -88, N87 = -87, N86 = -86, N85 = -85, N84 = -84, N83 = -83, N82 = -82, N81 = -81, N80 = -80, N79 = -79, N78 = -78, N77 = -77, N76 = -76, N75 = -75, N74 = -74, N73 = -73, N72 = -72, N71 = -71, N70 = -70, N69 = -69, N68 = -68, N67 = -67, N66 = -66, N65 = -65, N64 = -64, N63 = -63, N62 = -62, N61 = -61, N60 = -60, N59 = -59, N58 = -58, N57 = -57, N56 = -56, N55 = -55, N54 = -54, N53 = -53, N52 = -52, N51 = -51, N50 = -50, N49 = -49, N48 = -48, N47 = -47, N46 = -46, N45 = -45, N44 = -44, N43 = -43, N42 = -42, N41 = -41, N40 = -40, N39 = -39, N38 = -38, N37 = -37, N36 = -36, N35 = -35, N34 = -34, N33 = -33, N32 = -32, N31 = -31, N30 = -30, N29 = -29, N28 = -28, N27 = -27, N26 = -26, N25 = -25, N24 = -24, N23 = -23, N22 = -22, N21 = -21, N20 = -20, N19 = -19, N18 = -18, N17 = -17, N16 = -16, N15 = -15, N14 = -14, N13 = -13, N12 = -12, N11 = -11, N10 = -10, N9 = -9, N8 = -8, N7 = -7, N6 = -6, N5 = -5, N4 = -4, N3 = -3, N2 = -2, N1 = -1, P0 = 0, P1 = 1, P2 = 2, P3 = 3, P4 = 4, P5 = 5, P6 = 6, P7 = 7, P8 = 8, P9 = 9, P10 = 10, P11 = 11, P12 = 12, P13 = 13, P14 = 14, P15 = 15, P16 = 16, P17 = 17, P18 = 18, P19 = 19, P20 = 20, P21 = 21, P22 = 22, P23 = 23, P24 = 24, P25 = 25, P26 = 26, P27 = 27, P28 = 28, P29 = 29, P30 = 30, P31 = 31, P32 = 32, P33 = 33, P34 = 34, P35 = 35, P36 = 36, P37 = 37, P38 = 38, P39 = 39, P40 = 40, P41 = 41, P42 = 42, P43 = 43, P44 = 44, P45 = 45, P46 = 46, P47 = 47, P48 = 48, P49 = 49, P50 = 50, P51 = 51, P52 = 52, P53 = 53, P54 = 54, P55 = 55, P56 = 56, P57 = 57, P58 = 58, P59 = 59, P60 = 60, P61 = 61, P62 = 62, P63 = 63, P64 = 64, P65 = 65, P66 = 66, P67 = 67, P68 = 68, P69 = 69, P70 = 70, P71 = 71, P72 = 72, P73 = 73, P74 = 74, P75 = 75, P76 = 76, P77 = 77, P78 = 78, P79 = 79, P80 = 80, P81 = 81, P82 = 82, P83 = 83, P84 = 84, P85 = 85, P86 = 86, P87 = 87, P88 = 88, P89 = 89, P90 = 90, P91 = 91, P92 = 92, P93 = 93, P94 = 94, P95 = 95, P96 = 96, P97 = 97, P98 = 98, P99 = 99, P100 = 100, P101 = 101, P102 = 102, P103 = 103, P104 = 104, P105 = 105, P106 = 106, P107 = 107, P108 = 108, P109 = 109, P110 = 110, P111 = 111, P112 = 112, P113 = 113, P114 = 114, P115 = 115, P116 = 116, P117 = 117, P118 = 118, P119 = 119, P120 = 120, P121 = 121, P122 = 122, P123 = 123, P124 = 124, P125 = 125, P126 = 126,
}
Available on doc or test only.
⚗️ An example compact i8 enum from -126 to 126, generated with enumint!.

Variants



N126 = -126



N125 = -125



N124 = -124



N123 = -123



N122 = -122



N121 = -121



N120 = -120



N119 = -119



N118 = -118



N117 = -117



N116 = -116



N115 = -115



N114 = -114



N113 = -113



N112 = -112



N111 = -111



N110 = -110



N109 = -109



N108 = -108



N107 = -107



N106 = -106



N105 = -105



N104 = -104



N103 = -103



N102 = -102



N101 = -101



N100 = -100



N99 = -99



N98 = -98



N97 = -97



N96 = -96



N95 = -95



N94 = -94



N93 = -93



N92 = -92



N91 = -91



N90 = -90



N89 = -89



N88 = -88



N87 = -87



N86 = -86



N85 = -85



N84 = -84



N83 = -83



N82 = -82



N81 = -81



N80 = -80



N79 = -79



N78 = -78



N77 = -77



N76 = -76



N75 = -75



N74 = -74



N73 = -73



N72 = -72



N71 = -71



N70 = -70



N69 = -69



N68 = -68



N67 = -67



N66 = -66



N65 = -65



N64 = -64



N63 = -63



N62 = -62



N61 = -61



N60 = -60



N59 = -59



N58 = -58



N57 = -57



N56 = -56



N55 = -55



N54 = -54



N53 = -53



N52 = -52



N51 = -51



N50 = -50



N49 = -49



N48 = -48



N47 = -47



N46 = -46



N45 = -45



N44 = -44



N43 = -43



N42 = -42



N41 = -41



N40 = -40



N39 = -39



N38 = -38



N37 = -37



N36 = -36



N35 = -35



N34 = -34



N33 = -33



N32 = -32



N31 = -31



N30 = -30



N29 = -29



N28 = -28



N27 = -27



N26 = -26



N25 = -25



N24 = -24



N23 = -23



N22 = -22



N21 = -21



N20 = -20



N19 = -19



N18 = -18



N17 = -17



N16 = -16



N15 = -15



N14 = -14



N13 = -13



N12 = -12



N11 = -11



N10 = -10



N9 = -9



N8 = -8



N7 = -7



N6 = -6



N5 = -5



N4 = -4



N3 = -3



N2 = -2



N1 = -1



P0 = 0



P1 = 1



P2 = 2



P3 = 3



P4 = 4



P5 = 5



P6 = 6



P7 = 7



P8 = 8



P9 = 9



P10 = 10



P11 = 11



P12 = 12



P13 = 13



P14 = 14



P15 = 15



P16 = 16



P17 = 17



P18 = 18



P19 = 19



P20 = 20



P21 = 21



P22 = 22



P23 = 23



P24 = 24



P25 = 25



P26 = 26



P27 = 27



P28 = 28



P29 = 29



P30 = 30



P31 = 31



P32 = 32



P33 = 33



P34 = 34



P35 = 35



P36 = 36



P37 = 37



P38 = 38



P39 = 39



P40 = 40



P41 = 41



P42 = 42



P43 = 43



P44 = 44



P45 = 45



P46 = 46



P47 = 47



P48 = 48



P49 = 49



P50 = 50



P51 = 51



P52 = 52



P53 = 53



P54 = 54



P55 = 55



P56 = 56



P57 = 57



P58 = 58



P59 = 59



P60 = 60



P61 = 61



P62 = 62



P63 = 63



P64 = 64



P65 = 65



P66 = 66



P67 = 67



P68 = 68



P69 = 69



P70 = 70



P71 = 71



P72 = 72



P73 = 73



P74 = 74



P75 = 75



P76 = 76



P77 = 77



P78 = 78



P79 = 79



P80 = 80



P81 = 81



P82 = 82



P83 = 83



P84 = 84



P85 = 85



P86 = 86



P87 = 87



P88 = 88



P89 = 89



P90 = 90



P91 = 91



P92 = 92



P93 = 93



P94 = 94



P95 = 95



P96 = 96



P97 = 97



P98 = 98



P99 = 99



P100 = 100



P101 = 101



P102 = 102



P103 = 103



P104 = 104



P105 = 105



P106 = 106



P107 = 107



P108 = 108



P109 = 109



P110 = 110



P111 = 111



P112 = 112



P113 = 113



P114 = 114



P115 = 115



P116 = 116



P117 = 117



P118 = 118



P119 = 119



P120 = 120



P121 = 121



P122 = 122



P123 = 123



P124 = 124



P125 = 125



P126 = 126

Implementations

Source

impl EnumintI8Example

pub const VALUES: usize

The number of represented values.

pub const NICHES: usize

The number of unused representation values available as niches.

pub const MIN: i8

The lowest represented integer.

pub const MAX: i8

The highest represented integer.

pub const fn new(value: i8) -> Option<Self>

Returns the variant for value, or None if it is outside the range.

pub const fn new_saturated(value: i8) -> Self

Returns the variant for value, clamped to the represented range.

pub const fn new_wrapped(value: i8) -> Self

Returns the variant for value, wrapped inside the represented range.

pub const fn get(self) -> i8

Returns the underlying integer representation.