Key

Enum Key 

#[non_exhaustive]
pub enum Key {
Show 77 variants Backspace, Enter, Tab, Escape, Space, Left, Right, Up, Down, Home, End, PageUp, PageDown, Delete, Insert, CapsLock, ScrollLock, NumLock, PrintScreen, Pause, Menu, Pad(KeyPad), Mod(KeyMod), Media(KeyMedia), Fn(u8), Char(char), Dead(KeyDead), A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, Digit1, Digit2, Digit3, Digit4, Digit5, Digit6, Digit7, Digit8, Digit9, Digit0, Backquote, Minus, Equal, BracketLeft, BracketRight, Semicolon, Quote, Backslash, IntlBackslash, Comma, Dot, Slash, Scancode(u16), Unknown,
}
Available on crate feature event only.
๐ŸŽฎ Keyboard codes, used in EventKey.


๐Ÿ“ ui/event


See also KeyFfi.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Backspace

Backspace key.



Enter

Enter key.



Tab

Tab key.



Escape

Escape key.



Space

Space bar key.



Left

Left arrow key.



Right

Right arrow key.



Up

Up arrow key.



Down

Down arrow key.



Home

Home key.



End

End key.



PageUp

Page up key.



PageDown

Page down key.



Delete

Delete key.



Insert

Insert key.



CapsLock

Caps Lock key.



ScrollLock

Scroll Lock key.



NumLock

Num Lock key.



PrintScreen

Print Screen key.



Pause

Pause key.



Menu

Menu key.



Pad(KeyPad)

A keypad key.



Mod(KeyMod)

A modifer key.



Media(KeyMedia)

A multimedia key.



Fn(u8)

A function key.

  • Normal: F1-F12
  • +Shift: F13-F24
  • +Control: F25-F36
  • +Shift+Control: F37-F48


Char(char)

A Unicode character (text input, international layouts, fallback).



Dead(KeyDead)

A dead key (accent prefix, composition).



A



B



C



D



E



F



G



H



I



J



K



L



M



N



O



P



Q



R



S



T



U



V



W



X



Y



Z



Digit1



Digit2



Digit3



Digit4



Digit5



Digit6



Digit7



Digit8



Digit9



Digit0



Backquote

Physical key left of โ€˜1โ€™



Minus

Physical - key.



Equal

Physical = key.



BracketLeft

Physical [ key.



BracketRight

Physical ] key.



Semicolon

Physical ; key.



Quote

Physical ' key.



Backslash

Physical \ key.



IntlBackslash

ISO-102 extra key.



Comma

Physical , key.



Dot

Physical . key.



Slash

Physical / key.



Scancode(u16)

Physical keys that have no universal name.



Unknown

Unknown key code (default).

Implementations

Source

impl Key

pub const Esc: Key = Key::Escape

Alias of Escape.

pub const Ins: Key = Key::Insert

Alias of Insert.

pub const Del: Key = Key::Delete

Alias of Delete.

Source

impl Key

Spanish-layout aliases for the US ANSI physical layout keys.

Each alias names the symbol normally appearing on Spanish keyboards in that physical position.

The listed characters reflect the typical unshifted and shifted outputs on standard ES layouts.

pub const EsOrdinal: Self = Self::Backquote

Spanish key for ยบ and ยช.

pub const EsApostrophe: Self = Self::Minus

Spanish key for ' and ?.

pub const EsInvertedExclamationMark: Self = Self::Equal

Spanish key for ยก and ยฟ.

pub const EsBacktick: Self = Self::BracketLeft

Spanish key for \`` and ^`.

pub const EsPlus: Self = Self::BracketRight

Spanish key for + and *.

pub const EsEnye: Self = Self::Semicolon

Spanish key for รฑ and ร‘.

pub const EsAccent: Self = Self::Quote

Spanish key for ยด and ยจ.

pub const EsCedilla: Self = Self::Backslash

Spanish key for รง and ร‡.

pub const EsBracket: Self = Self::IntlBackslash

Spanish key for < and >.

pub const EsComma: Self = Self::Comma

Spanish key for , and ;.

pub const EsDot: Self = Self::Dot

Spanish key for . and :.

pub const EsMinus: Self = Self::Slash

Spanish key for - and _.

Source

impl Key

pub const fn to_ffi(self) -> KeyFfi

Available on ffiยทยท only.

Converts Key to KeyFfi.

pub const fn from_ffi(from: KeyFfi) -> Key

Available on ffiยทยท only.

Converts KeyFfi to Key.