pub enum StaticMapEntry<'a, V> {
Occupied(&'a mut V),
Vacant(usize),
}Expand description
๐๏ธ Represents an entry in a static map allowing for in-place mutation or insertion.
๐ data/id
Variants
Occupied(&'a mut V)
An entry that contains a value.
Provides a mutable reference to the stored value, allowing in-place modification.
Vacant(usize)
An entry that is vacant and can be used for insertion.
Stores the index where a new value should be inserted.