#[repr(i8)]pub enum WebPermissionState {
Granted = 1,
Prompt = 0,
Denied = -1,
Unknown = -2,
Error = -3,
}Available on crate feature
web only.Expand description
Variants
Granted = 1
The permission has been granted by the user.
Prompt = 0
The user has not yet granted or denied the permission.
Denied = -1
The user has not yet granted or denied the permission.
Unknown = -2
The queried permission is unsupported or unrecognized.
Error = -3
An error occurred while querying the permission state.