pub struct AppUnix { /* private fields */ }Available on crate feature
std only.Expand description
๐ Unix enviroment for directories.
๐ sys/env
This constructs directories specific to an application using
its unixy_name, which is derived from the applicationโs name.
This is no standard or official specification, but an old convention of placing the configuration directory under the userโs home directory.
Vim and Cargo are notable examples whose configuration/data/cache directory layouts are similar to these.
Implementations