pub struct EventKey {
pub semantic: Key,
pub physical: Key,
pub mods: KeyMods,
pub state: KeyState,
}event only.Expand description
๐ซ ๐ฎ Represents a keyboard event.
๐ ui/event
๐ฆ size_of::<EventKey>() == 20 bytes / 160 bits
โ๏ธOption<T>
See also EventKeyFfi.
Fields
semantic: KeyThe key representing the human-readable code.
This corresponds to X11โs keysym.
physical: KeyThe key representing the hardware scan code.
This corresponds to X11โs scancode XKB mapped.
mods: KeyModsThe active modifiers of the key (e.g., Shift, Ctrl).
state: KeyStateThe state of the key (pressed or released).
Implementations
Sourceimpl EventKey
impl EventKey
Sourcepub const fn to_ffi(&self) -> EventKeyFfi
Available on ffiยทยท only.
pub const fn to_ffi(&self) -> EventKeyFfi
ffiยทยท only.Converts EventKey to EventKeyFfi.
Sourcepub const fn from_ffi(from: &EventKeyFfi) -> EventKey
Available on ffiยทยท only.
pub const fn from_ffi(from: &EventKeyFfi) -> EventKey
ffiยทยท only.Converts EventKeyFfi to EventKey.
Sourceimpl EventKey
impl EventKey
Sourcepub const fn new(
semantic: Key,
physical: Key,
mods: KeyMods,
state: KeyState,
) -> Self
pub const fn new( semantic: Key, physical: Key, mods: KeyMods, state: KeyState, ) -> Self
Creates a key event from fully specified fields.
Sourcepub const fn press(key: Key) -> Self
pub const fn press(key: Key) -> Self
Creates a key press whose semantic and physical keys are the same.
Sourcepub const fn modified_press(key: Key, mods: KeyMods) -> Self
pub const fn modified_press(key: Key, mods: KeyMods) -> Self
Creates a modified key press whose semantic and physical keys are the same.
Sourcepub const fn text(c: char) -> Self
pub const fn text(c: char) -> Self
Creates a text-producing key press with unknown physical origin.
Sourcepub const fn modified_text(c: char, mods: KeyMods) -> Self
pub const fn modified_text(c: char, mods: KeyMods) -> Self
Creates a modified text-producing key press with unknown physical origin.
Sourcepub const fn with_state(self, state: KeyState) -> Self
pub const fn with_state(self, state: KeyState) -> Self
Returns this key event with a different state.