EventTagSet

Struct EventTagSet 

pub struct EventTagSet { /* private fields */ }
Available on crate feature event only.
๐ŸŽซ ๐Ÿ—ƒ๏ธ A compact set of EventTags.


๐Ÿ“ ui/event

๐Ÿ“ฆ size_of::<EventTagSet>() == 1 bytes / 8 bits


Used to declare, filter, and query coarse event categories.

Implementations

Source

impl EventTagSet

Common event category groups.

pub const INPUT: Self

Events caused by direct user input.

pub const POINTING: Self

Events related to pointing devices.

Source

impl EventTagSet

Named constants

pub const None: Self

1 The bit index that corresponds to EventTag::None.

pub const Key: Self

1 The bit index that corresponds to EventTag::Key.

pub const Mouse: Self

1 The bit index that corresponds to EventTag::Mouse.

pub const Pointer: Self

1 The bit index that corresponds to EventTag::Pointer.

pub const Wheel: Self

1 The bit index that corresponds to EventTag::Wheel.

pub const Window: Self

1 The bit index that corresponds to EventTag::Window.

pub const Control: Self

1 The bit index that corresponds to EventTag::Control.

Source

impl EventTagSet

Convenience methods derived from each named constant.

pub const fn has_none(self) -> bool

Returns true if None is present.

pub const fn contains_none(self) -> bool

Returns true if all bits in None are present.

pub const fn intersects_none(self) -> bool

Returns true if the set shares any bit with None.

pub const fn with_none(self) -> Self

Returns self with None inserted.

pub const fn with_none_if(self, condition: bool) -> Self

Returns self with None inserted if condition is true.

pub const fn without_none(self) -> Self

Returns self with None removed.

pub const fn set_none(&mut self)

Sets None.

pub const fn set_none_if(&mut self, condition: bool)

Sets None if condition is true.

pub const fn unset_none(&mut self)

Unsets None.

pub const fn has_key(self) -> bool

Returns true if Key is present.

pub const fn contains_key(self) -> bool

Returns true if all bits in Key are present.

pub const fn intersects_key(self) -> bool

Returns true if the set shares any bit with Key.

pub const fn with_key(self) -> Self

Returns self with Key inserted.

pub const fn with_key_if(self, condition: bool) -> Self

Returns self with Key inserted if condition is true.

pub const fn without_key(self) -> Self

Returns self with Key removed.

pub const fn set_key(&mut self)

Sets Key.

pub const fn set_key_if(&mut self, condition: bool)

Sets Key if condition is true.

pub const fn unset_key(&mut self)

Unsets Key.

pub const fn has_mouse(self) -> bool

Returns true if Mouse is present.

pub const fn contains_mouse(self) -> bool

Returns true if all bits in Mouse are present.

pub const fn intersects_mouse(self) -> bool

Returns true if the set shares any bit with Mouse.

pub const fn with_mouse(self) -> Self

Returns self with Mouse inserted.

pub const fn with_mouse_if(self, condition: bool) -> Self

Returns self with Mouse inserted if condition is true.

pub const fn without_mouse(self) -> Self

Returns self with Mouse removed.

pub const fn set_mouse(&mut self)

Sets Mouse.

pub const fn set_mouse_if(&mut self, condition: bool)

Sets Mouse if condition is true.

pub const fn unset_mouse(&mut self)

Unsets Mouse.

pub const fn has_pointer(self) -> bool

Returns true if Pointer is present.

pub const fn contains_pointer(self) -> bool

Returns true if all bits in Pointer are present.

pub const fn intersects_pointer(self) -> bool

Returns true if the set shares any bit with Pointer.

pub const fn with_pointer(self) -> Self

Returns self with Pointer inserted.

pub const fn with_pointer_if(self, condition: bool) -> Self

Returns self with Pointer inserted if condition is true.

pub const fn without_pointer(self) -> Self

Returns self with Pointer removed.

pub const fn set_pointer(&mut self)

Sets Pointer.

pub const fn set_pointer_if(&mut self, condition: bool)

Sets Pointer if condition is true.

pub const fn unset_pointer(&mut self)

Unsets Pointer.

pub const fn has_wheel(self) -> bool

Returns true if Wheel is present.

pub const fn contains_wheel(self) -> bool

Returns true if all bits in Wheel are present.

pub const fn intersects_wheel(self) -> bool

Returns true if the set shares any bit with Wheel.

pub const fn with_wheel(self) -> Self

Returns self with Wheel inserted.

pub const fn with_wheel_if(self, condition: bool) -> Self

Returns self with Wheel inserted if condition is true.

pub const fn without_wheel(self) -> Self

Returns self with Wheel removed.

pub const fn set_wheel(&mut self)

Sets Wheel.

pub const fn set_wheel_if(&mut self, condition: bool)

Sets Wheel if condition is true.

pub const fn unset_wheel(&mut self)

Unsets Wheel.

pub const fn has_window(self) -> bool

Returns true if Window is present.

pub const fn contains_window(self) -> bool

Returns true if all bits in Window are present.

pub const fn intersects_window(self) -> bool

Returns true if the set shares any bit with Window.

pub const fn with_window(self) -> Self

Returns self with Window inserted.

pub const fn with_window_if(self, condition: bool) -> Self

Returns self with Window inserted if condition is true.

pub const fn without_window(self) -> Self

Returns self with Window removed.

pub const fn set_window(&mut self)

Sets Window.

pub const fn set_window_if(&mut self, condition: bool)

Sets Window if condition is true.

pub const fn unset_window(&mut self)

Unsets Window.

pub const fn has_control(self) -> bool

Returns true if Control is present.

pub const fn contains_control(self) -> bool

Returns true if all bits in Control are present.

pub const fn intersects_control(self) -> bool

Returns true if the set shares any bit with Control.

pub const fn with_control(self) -> Self

Returns self with Control inserted.

pub const fn with_control_if(self, condition: bool) -> Self

Returns self with Control inserted if condition is true.

pub const fn without_control(self) -> Self

Returns self with Control removed.

pub const fn set_control(&mut self)

Sets Control.

pub const fn set_control_if(&mut self, condition: bool)

Sets Control if condition is true.

pub const fn unset_control(&mut self)

Unsets Control.

Source

impl EventTagSet

Common set methods

pub const fn new() -> Self

Returns an empty set.

pub const fn from_bits(bits: u8) -> Self

Returns a set from raw bits.

pub const fn bits(self) -> u8

Returns the raw backing bits.

pub const fn all() -> Self

Returns the union of all declared sets.

pub const fn is_empty(self) -> bool

Returns true if no bits are set.

pub const fn is_full(self) -> bool

Returns true if all the declared bits are set.

pub const fn contains(self, other: Self) -> bool

Returns true if all bits in other are also set in self.

pub const fn has(self, other: Self) -> bool

An alias of contains.

pub const fn with(self, other: Self) -> Self

Returns self with other inserted.

pub const fn with_if(self, condition: bool, other: Self) -> Self

Returns self with other inserted if condition is true.

pub const fn without(self, other: Self) -> Self

Returns self with other removed.

pub const fn toggled(self, other: Self) -> Self

Returns self with other toggled.

Source

impl EventTagSet

Set operations

pub const fn intersects(self, other: Self) -> bool

Returns true if self and other share any bit.

pub const fn is_subset(self, other: Self) -> bool

Returns true if all bits in self are also set in other.

pub const fn is_superset(self, other: Self) -> bool

Returns true if all bits in other are also set in self.

pub const fn union(self, other: Self) -> Self

Returns the union of self and other.

pub const fn intersection(self, other: Self) -> Self

Returns the intersection of self and other.

pub const fn difference(self, other: Self) -> Self

Returns the difference of self and other.

pub const fn symmetric_difference(self, other: Self) -> Self

Returns the symmetric difference of self and other.

Source

impl EventTagSet

Mutating set operations

pub const fn clear(&mut self)

Clears the set.

pub const fn insert(&mut self, other: Self)

Inserts all bits from other.

pub const fn remove(&mut self, other: Self)

Removes all bits from other.

pub const fn toggle(&mut self, other: Self)

Toggles all bits from other.