pub struct HasherBuildDefault<H>(/* private fields */);Expand description
๐
core
Create a default HasherBuild instance for T:Hasher+Default types.
๐data/codec/hash re-exported from core::hash ::BuildHasherDefault as HasherBuildDefault
๐
Used to create a default BuildHasher instance for types that implement
Hasher and Default.
BuildHasherDefault<H> can be used when a type H implements Hasher and
Default, and you need a corresponding BuildHasher instance, but none is
defined.
Any BuildHasherDefault is zero-sized. It can be created with
default. When using BuildHasherDefault with HashMap or
HashSet, this doesnโt need to be done, since they implement appropriate
Default instances themselves.
Examples
Using BuildHasherDefault to specify a custom BuildHasher for
HashMap:
use std::collections::HashMap;
use std::hash::{BuildHasherDefault, Hasher};
#[derive(Default)]
struct MyHasher;
impl Hasher for MyHasher {
fn write(&mut self, bytes: &[u8]) {
// Your hashing algorithm goes here!
unimplemented!()
}
fn finish(&self) -> u64 {
// Your hashing algorithm goes here!
unimplemented!()
}
}
type MyBuildHasher = BuildHasherDefault<MyHasher>;
let hash_map = HashMap::<u32, u32, MyBuildHasher>::default();Implementations
Sourceimpl<H> BuildHasherDefault<H>
impl<H> BuildHasherDefault<H>
1.85.0 (const: 1.85.0) ยท Sourcepub const fn new() -> BuildHasherDefault<H>
pub const fn new() -> BuildHasherDefault<H>
Creates a new BuildHasherDefault for Hasher H.