pub struct InvalidUtf8 {
pub valid_up_to: usize,
pub error_len: Option<usize>,
}Expand description
Fields
valid_up_to: usizeThe index in the given string up to which valid UTF-8 was verified.
error_len: Option<usize>The length of the error in bytes, if known.
Implementations
Sourceimpl InvalidUtf8
impl InvalidUtf8
Sourcepub const fn from_utf8_error(from: Utf8Error) -> InvalidUtf8
pub const fn from_utf8_error(from: Utf8Error) -> InvalidUtf8
Converts core::strUtf8Error to InvalidUtf8 in compile-time.