pub struct Js;Available on crate feature
js only.Expand description
Implementations
Sourceimpl Js
Strings
impl Js
Strings
Sourcepub fn read_str(
buffer: &mut [u8],
write_fn: impl FnMut(*mut u8, js_uint32) -> js_int32,
) -> &str ⓘ
pub fn read_str( buffer: &mut [u8], write_fn: impl FnMut(*mut u8, js_uint32) -> js_int32, ) -> &str ⓘ
Reads a JS string into a Rust &str backed by the given buffer,
truncating if the buffer is too small.
Panic
Panics if the result is not valid UTF-8.
Sourcepub fn read_string(
write_fn: impl FnMut(*mut u8, js_uint32) -> js_int32,
) -> String ⓘ
Available on unsafe·· and crate feature alloc only.
pub fn read_string( write_fn: impl FnMut(*mut u8, js_uint32) -> js_int32, ) -> String ⓘ
unsafe·· and crate feature alloc only.Allocates a String by calling a JS-backed FFI fn that writes a UTF-8 string into WASM memory.
Allocates a new String from JS (auto-sizing).
- Uses a dynamic buffer, starting with 128 bytes of
capacity. - Retries with exact required capacity if truncation is detected.
Sourcepub fn read_string_capped(
cap: js_uint32,
truncate: bool,
write_fn: impl FnMut(*mut u8, js_uint32) -> js_int32,
) -> String ⓘ
Available on unsafe·· and crate feature alloc only.
pub fn read_string_capped( cap: js_uint32, truncate: bool, write_fn: impl FnMut(*mut u8, js_uint32) -> js_int32, ) -> String ⓘ
unsafe·· and crate feature alloc only.Allocates a String by calling a JS-backed FFI fn that writes a UTF-8 string into WASM memory.
- Uses a dynamic buffer, starting with the given
capacity. - Retries with exact required capacity if truncation is detected (unless
truncate = true). - Assumes the FFI fn returns
js_int32: positive = bytes written, negative = required size.