LinuxSigactionFlags

Struct LinuxSigactionFlags 

pub struct LinuxSigactionFlags { /* private fields */ }
Available on crate feature linux only.
๐Ÿง ๐Ÿ“ถ โІ Input flags for LinuxSigaction.


๐Ÿ“ sys/os/term/session

๐Ÿ“ฆ size_of::<LinuxSigactionFlags>() == 1 bytes / 8 bits


Implementations

Source

impl LinuxSigactionFlags

pub const fn from_c_size_t(bits: c_size_t) -> Self

Returns flags from the raw Linux sa_flags word.

pub const fn as_c_size_t(self) -> c_size_t

Returns flags as a raw Linux sa_flags word.

Source

impl LinuxSigactionFlags

Named constants

pub const SA_NOCLDSTOP: Self

1 Do not notify when child processes stop or resume.

pub const SA_NOCLDWAIT: Self

1 Do not create zombies when child processes terminate.

pub const SA_NODEFER: Self

1 Do not mask the signal while its handler is running.

pub const SA_ONSTACK: Self

1 Run the handler on an alternate signal stack.

pub const SA_RESETHAND: Self

1 Reset the signal action to the default on handler entry.

pub const SA_RESTART: Self

1 Restart certain interrupted system calls.

pub const SA_RESTORER: Self

1 Use the explicit Linux signal-restorer trampoline.

pub const SA_SIGINFO: Self

1 Use a three-argument SA_SIGINFO handler.

Source

impl LinuxSigactionFlags

Convenience methods derived from each named constant.

pub const fn has_sa_nocldstop(self) -> bool

Returns true if SA_NOCLDSTOP is present.

pub const fn contains_sa_nocldstop(self) -> bool

Returns true if all bits in SA_NOCLDSTOP are present.

pub const fn intersects_sa_nocldstop(self) -> bool

Returns true if the set shares any bit with SA_NOCLDSTOP.

pub const fn with_sa_nocldstop(self) -> Self

Returns self with SA_NOCLDSTOP inserted.

pub const fn with_sa_nocldstop_if(self, condition: bool) -> Self

Returns self with SA_NOCLDSTOP inserted if condition is true.

pub const fn without_sa_nocldstop(self) -> Self

Returns self with SA_NOCLDSTOP removed.

pub const fn set_sa_nocldstop(&mut self)

Sets SA_NOCLDSTOP.

pub const fn set_sa_nocldstop_if(&mut self, condition: bool)

Sets SA_NOCLDSTOP if condition is true.

pub const fn unset_sa_nocldstop(&mut self)

Unsets SA_NOCLDSTOP.

pub const fn has_sa_nocldwait(self) -> bool

Returns true if SA_NOCLDWAIT is present.

pub const fn contains_sa_nocldwait(self) -> bool

Returns true if all bits in SA_NOCLDWAIT are present.

pub const fn intersects_sa_nocldwait(self) -> bool

Returns true if the set shares any bit with SA_NOCLDWAIT.

pub const fn with_sa_nocldwait(self) -> Self

Returns self with SA_NOCLDWAIT inserted.

pub const fn with_sa_nocldwait_if(self, condition: bool) -> Self

Returns self with SA_NOCLDWAIT inserted if condition is true.

pub const fn without_sa_nocldwait(self) -> Self

Returns self with SA_NOCLDWAIT removed.

pub const fn set_sa_nocldwait(&mut self)

Sets SA_NOCLDWAIT.

pub const fn set_sa_nocldwait_if(&mut self, condition: bool)

Sets SA_NOCLDWAIT if condition is true.

pub const fn unset_sa_nocldwait(&mut self)

Unsets SA_NOCLDWAIT.

pub const fn has_sa_nodefer(self) -> bool

Returns true if SA_NODEFER is present.

pub const fn contains_sa_nodefer(self) -> bool

Returns true if all bits in SA_NODEFER are present.

pub const fn intersects_sa_nodefer(self) -> bool

Returns true if the set shares any bit with SA_NODEFER.

pub const fn with_sa_nodefer(self) -> Self

Returns self with SA_NODEFER inserted.

pub const fn with_sa_nodefer_if(self, condition: bool) -> Self

Returns self with SA_NODEFER inserted if condition is true.

pub const fn without_sa_nodefer(self) -> Self

Returns self with SA_NODEFER removed.

pub const fn set_sa_nodefer(&mut self)

Sets SA_NODEFER.

pub const fn set_sa_nodefer_if(&mut self, condition: bool)

Sets SA_NODEFER if condition is true.

pub const fn unset_sa_nodefer(&mut self)

Unsets SA_NODEFER.

pub const fn has_sa_onstack(self) -> bool

Returns true if SA_ONSTACK is present.

pub const fn contains_sa_onstack(self) -> bool

Returns true if all bits in SA_ONSTACK are present.

pub const fn intersects_sa_onstack(self) -> bool

Returns true if the set shares any bit with SA_ONSTACK.

pub const fn with_sa_onstack(self) -> Self

Returns self with SA_ONSTACK inserted.

pub const fn with_sa_onstack_if(self, condition: bool) -> Self

Returns self with SA_ONSTACK inserted if condition is true.

pub const fn without_sa_onstack(self) -> Self

Returns self with SA_ONSTACK removed.

pub const fn set_sa_onstack(&mut self)

Sets SA_ONSTACK.

pub const fn set_sa_onstack_if(&mut self, condition: bool)

Sets SA_ONSTACK if condition is true.

pub const fn unset_sa_onstack(&mut self)

Unsets SA_ONSTACK.

pub const fn has_sa_resethand(self) -> bool

Returns true if SA_RESETHAND is present.

pub const fn contains_sa_resethand(self) -> bool

Returns true if all bits in SA_RESETHAND are present.

pub const fn intersects_sa_resethand(self) -> bool

Returns true if the set shares any bit with SA_RESETHAND.

pub const fn with_sa_resethand(self) -> Self

Returns self with SA_RESETHAND inserted.

pub const fn with_sa_resethand_if(self, condition: bool) -> Self

Returns self with SA_RESETHAND inserted if condition is true.

pub const fn without_sa_resethand(self) -> Self

Returns self with SA_RESETHAND removed.

pub const fn set_sa_resethand(&mut self)

Sets SA_RESETHAND.

pub const fn set_sa_resethand_if(&mut self, condition: bool)

Sets SA_RESETHAND if condition is true.

pub const fn unset_sa_resethand(&mut self)

Unsets SA_RESETHAND.

pub const fn has_sa_restart(self) -> bool

Returns true if SA_RESTART is present.

pub const fn contains_sa_restart(self) -> bool

Returns true if all bits in SA_RESTART are present.

pub const fn intersects_sa_restart(self) -> bool

Returns true if the set shares any bit with SA_RESTART.

pub const fn with_sa_restart(self) -> Self

Returns self with SA_RESTART inserted.

pub const fn with_sa_restart_if(self, condition: bool) -> Self

Returns self with SA_RESTART inserted if condition is true.

pub const fn without_sa_restart(self) -> Self

Returns self with SA_RESTART removed.

pub const fn set_sa_restart(&mut self)

Sets SA_RESTART.

pub const fn set_sa_restart_if(&mut self, condition: bool)

Sets SA_RESTART if condition is true.

pub const fn unset_sa_restart(&mut self)

Unsets SA_RESTART.

pub const fn has_sa_restorer(self) -> bool

Returns true if SA_RESTORER is present.

pub const fn contains_sa_restorer(self) -> bool

Returns true if all bits in SA_RESTORER are present.

pub const fn intersects_sa_restorer(self) -> bool

Returns true if the set shares any bit with SA_RESTORER.

pub const fn with_sa_restorer(self) -> Self

Returns self with SA_RESTORER inserted.

pub const fn with_sa_restorer_if(self, condition: bool) -> Self

Returns self with SA_RESTORER inserted if condition is true.

pub const fn without_sa_restorer(self) -> Self

Returns self with SA_RESTORER removed.

pub const fn set_sa_restorer(&mut self)

Sets SA_RESTORER.

pub const fn set_sa_restorer_if(&mut self, condition: bool)

Sets SA_RESTORER if condition is true.

pub const fn unset_sa_restorer(&mut self)

Unsets SA_RESTORER.

pub const fn has_sa_siginfo(self) -> bool

Returns true if SA_SIGINFO is present.

pub const fn contains_sa_siginfo(self) -> bool

Returns true if all bits in SA_SIGINFO are present.

pub const fn intersects_sa_siginfo(self) -> bool

Returns true if the set shares any bit with SA_SIGINFO.

pub const fn with_sa_siginfo(self) -> Self

Returns self with SA_SIGINFO inserted.

pub const fn with_sa_siginfo_if(self, condition: bool) -> Self

Returns self with SA_SIGINFO inserted if condition is true.

pub const fn without_sa_siginfo(self) -> Self

Returns self with SA_SIGINFO removed.

pub const fn set_sa_siginfo(&mut self)

Sets SA_SIGINFO.

pub const fn set_sa_siginfo_if(&mut self, condition: bool)

Sets SA_SIGINFO if condition is true.

pub const fn unset_sa_siginfo(&mut self)

Unsets SA_SIGINFO.

Source

impl LinuxSigactionFlags

Common set methods

pub const fn new() -> Self

Returns an empty set.

pub const fn from_bits(bits: u8) -> Self

Returns a set from raw bits.

pub const fn bits(self) -> u8

Returns the raw backing bits.

pub const fn all() -> Self

Returns the union of all declared sets.

pub const fn is_empty(self) -> bool

Returns true if no bits are set.

pub const fn is_full(self) -> bool

Returns true if all the declared bits are set.

pub const fn contains(self, other: Self) -> bool

Returns true if all bits in other are also set in self.

pub const fn has(self, other: Self) -> bool

An alias of contains.

pub const fn with(self, other: Self) -> Self

Returns self with other inserted.

pub const fn with_if(self, condition: bool, other: Self) -> Self

Returns self with other inserted if condition is true.

pub const fn without(self, other: Self) -> Self

Returns self with other removed.

pub const fn toggled(self, other: Self) -> Self

Returns self with other toggled.

Source

impl LinuxSigactionFlags

Set operations

pub const fn intersects(self, other: Self) -> bool

Returns true if self and other share any bit.

pub const fn is_subset(self, other: Self) -> bool

Returns true if all bits in self are also set in other.

pub const fn is_superset(self, other: Self) -> bool

Returns true if all bits in other are also set in self.

pub const fn union(self, other: Self) -> Self

Returns the union of self and other.

pub const fn intersection(self, other: Self) -> Self

Returns the intersection of self and other.

pub const fn difference(self, other: Self) -> Self

Returns the difference of self and other.

pub const fn symmetric_difference(self, other: Self) -> Self

Returns the symmetric difference of self and other.

Source

impl LinuxSigactionFlags

Mutating set operations

pub const fn clear(&mut self)

Clears the set.

pub const fn insert(&mut self, other: Self)

Inserts all bits from other.

pub const fn remove(&mut self, other: Self)

Removes all bits from other.

pub const fn toggle(&mut self, other: Self)

Toggles all bits from other.