RunCapText

Struct RunCapText 

pub struct RunCapText { /* private fields */ }
𝐓 Runtime text capabilities.


📍 run/regime

📦 size_of::<RunCapText>() == 1 bytes / 8 bits


Implementations

Source

impl RunCapText

Named constants

pub const WRITE: Self

1 Text output.

pub const CELL_GRID: Self

1 Fixed-cell text layout.

pub const PROPORTIONAL: Self

1 Variable-width text layout.

pub const CURSOR: Self

1 Addressable text cursor.

pub const STYLE: Self

1 Text styling, such as bold, underline, inverse, or reset.

pub const EDIT: Self

1 Text input or editable text regions.

pub const COLOR_PAIR: Self

1 Text color is assigned as a foreground/background pair.

pub const MEASURE: Self

1 Text extents or advances can be measured.

Source

impl RunCapText

Convenience methods derived from each named constant.

pub const fn has_write(self) -> bool

Returns true if WRITE is present.

pub const fn contains_write(self) -> bool

Returns true if all bits in WRITE are present.

pub const fn intersects_write(self) -> bool

Returns true if the set shares any bit with WRITE.

pub const fn with_write(self) -> Self

Returns self with WRITE inserted.

pub const fn with_write_if(self, condition: bool) -> Self

Returns self with WRITE inserted if condition is true.

pub const fn without_write(self) -> Self

Returns self with WRITE removed.

pub const fn set_write(&mut self)

Sets WRITE.

pub const fn set_write_if(&mut self, condition: bool)

Sets WRITE if condition is true.

pub const fn unset_write(&mut self)

Unsets WRITE.

pub const fn has_cell_grid(self) -> bool

Returns true if CELL_GRID is present.

pub const fn contains_cell_grid(self) -> bool

Returns true if all bits in CELL_GRID are present.

pub const fn intersects_cell_grid(self) -> bool

Returns true if the set shares any bit with CELL_GRID.

pub const fn with_cell_grid(self) -> Self

Returns self with CELL_GRID inserted.

pub const fn with_cell_grid_if(self, condition: bool) -> Self

Returns self with CELL_GRID inserted if condition is true.

pub const fn without_cell_grid(self) -> Self

Returns self with CELL_GRID removed.

pub const fn set_cell_grid(&mut self)

Sets CELL_GRID.

pub const fn set_cell_grid_if(&mut self, condition: bool)

Sets CELL_GRID if condition is true.

pub const fn unset_cell_grid(&mut self)

Unsets CELL_GRID.

pub const fn has_proportional(self) -> bool

Returns true if PROPORTIONAL is present.

pub const fn contains_proportional(self) -> bool

Returns true if all bits in PROPORTIONAL are present.

pub const fn intersects_proportional(self) -> bool

Returns true if the set shares any bit with PROPORTIONAL.

pub const fn with_proportional(self) -> Self

Returns self with PROPORTIONAL inserted.

pub const fn with_proportional_if(self, condition: bool) -> Self

Returns self with PROPORTIONAL inserted if condition is true.

pub const fn without_proportional(self) -> Self

Returns self with PROPORTIONAL removed.

pub const fn set_proportional(&mut self)

Sets PROPORTIONAL.

pub const fn set_proportional_if(&mut self, condition: bool)

Sets PROPORTIONAL if condition is true.

pub const fn unset_proportional(&mut self)

Unsets PROPORTIONAL.

pub const fn has_cursor(self) -> bool

Returns true if CURSOR is present.

pub const fn contains_cursor(self) -> bool

Returns true if all bits in CURSOR are present.

pub const fn intersects_cursor(self) -> bool

Returns true if the set shares any bit with CURSOR.

pub const fn with_cursor(self) -> Self

Returns self with CURSOR inserted.

pub const fn with_cursor_if(self, condition: bool) -> Self

Returns self with CURSOR inserted if condition is true.

pub const fn without_cursor(self) -> Self

Returns self with CURSOR removed.

pub const fn set_cursor(&mut self)

Sets CURSOR.

pub const fn set_cursor_if(&mut self, condition: bool)

Sets CURSOR if condition is true.

pub const fn unset_cursor(&mut self)

Unsets CURSOR.

pub const fn has_style(self) -> bool

Returns true if STYLE is present.

pub const fn contains_style(self) -> bool

Returns true if all bits in STYLE are present.

pub const fn intersects_style(self) -> bool

Returns true if the set shares any bit with STYLE.

pub const fn with_style(self) -> Self

Returns self with STYLE inserted.

pub const fn with_style_if(self, condition: bool) -> Self

Returns self with STYLE inserted if condition is true.

pub const fn without_style(self) -> Self

Returns self with STYLE removed.

pub const fn set_style(&mut self)

Sets STYLE.

pub const fn set_style_if(&mut self, condition: bool)

Sets STYLE if condition is true.

pub const fn unset_style(&mut self)

Unsets STYLE.

pub const fn has_edit(self) -> bool

Returns true if EDIT is present.

pub const fn contains_edit(self) -> bool

Returns true if all bits in EDIT are present.

pub const fn intersects_edit(self) -> bool

Returns true if the set shares any bit with EDIT.

pub const fn with_edit(self) -> Self

Returns self with EDIT inserted.

pub const fn with_edit_if(self, condition: bool) -> Self

Returns self with EDIT inserted if condition is true.

pub const fn without_edit(self) -> Self

Returns self with EDIT removed.

pub const fn set_edit(&mut self)

Sets EDIT.

pub const fn set_edit_if(&mut self, condition: bool)

Sets EDIT if condition is true.

pub const fn unset_edit(&mut self)

Unsets EDIT.

pub const fn has_color_pair(self) -> bool

Returns true if COLOR_PAIR is present.

pub const fn contains_color_pair(self) -> bool

Returns true if all bits in COLOR_PAIR are present.

pub const fn intersects_color_pair(self) -> bool

Returns true if the set shares any bit with COLOR_PAIR.

pub const fn with_color_pair(self) -> Self

Returns self with COLOR_PAIR inserted.

pub const fn with_color_pair_if(self, condition: bool) -> Self

Returns self with COLOR_PAIR inserted if condition is true.

pub const fn without_color_pair(self) -> Self

Returns self with COLOR_PAIR removed.

pub const fn set_color_pair(&mut self)

Sets COLOR_PAIR.

pub const fn set_color_pair_if(&mut self, condition: bool)

Sets COLOR_PAIR if condition is true.

pub const fn unset_color_pair(&mut self)

Unsets COLOR_PAIR.

pub const fn has_measure(self) -> bool

Returns true if MEASURE is present.

pub const fn contains_measure(self) -> bool

Returns true if all bits in MEASURE are present.

pub const fn intersects_measure(self) -> bool

Returns true if the set shares any bit with MEASURE.

pub const fn with_measure(self) -> Self

Returns self with MEASURE inserted.

pub const fn with_measure_if(self, condition: bool) -> Self

Returns self with MEASURE inserted if condition is true.

pub const fn without_measure(self) -> Self

Returns self with MEASURE removed.

pub const fn set_measure(&mut self)

Sets MEASURE.

pub const fn set_measure_if(&mut self, condition: bool)

Sets MEASURE if condition is true.

pub const fn unset_measure(&mut self)

Unsets MEASURE.

Source

impl RunCapText

Common set methods

pub const fn new() -> Self

Returns an empty set.

pub const fn from_bits(bits: u8) -> Self

Returns a set from raw bits.

pub const fn bits(self) -> u8

Returns the raw backing bits.

pub const fn all() -> Self

Returns the union of all declared sets.

pub const fn is_empty(self) -> bool

Returns true if no bits are set.

pub const fn is_full(self) -> bool

Returns true if all the declared bits are set.

pub const fn contains(self, other: Self) -> bool

Returns true if all bits in other are also set in self.

pub const fn has(self, other: Self) -> bool

An alias of contains.

pub const fn with(self, other: Self) -> Self

Returns self with other inserted.

pub const fn with_if(self, condition: bool, other: Self) -> Self

Returns self with other inserted if condition is true.

pub const fn without(self, other: Self) -> Self

Returns self with other removed.

pub const fn toggled(self, other: Self) -> Self

Returns self with other toggled.

Source

impl RunCapText

Set operations

pub const fn intersects(self, other: Self) -> bool

Returns true if self and other share any bit.

pub const fn is_subset(self, other: Self) -> bool

Returns true if all bits in self are also set in other.

pub const fn is_superset(self, other: Self) -> bool

Returns true if all bits in other are also set in self.

pub const fn union(self, other: Self) -> Self

Returns the union of self and other.

pub const fn intersection(self, other: Self) -> Self

Returns the intersection of self and other.

pub const fn difference(self, other: Self) -> Self

Returns the difference of self and other.

pub const fn symmetric_difference(self, other: Self) -> Self

Returns the symmetric difference of self and other.

Source

impl RunCapText

Mutating set operations

pub const fn clear(&mut self)

Clears the set.

pub const fn insert(&mut self, other: Self)

Inserts all bits from other.

pub const fn remove(&mut self, other: Self)

Removes all bits from other.

pub const fn toggle(&mut self, other: Self)

Toggles all bits from other.