pub struct TimeUnixI64 {
pub seconds: i64,
}Available on crate feature
time only.Expand description
๐ 64-bit Unix time, supporting negative values.
๐ phys/time
Stores the number of seconds relative to the Unix Epoch (1970-01-01 00:00:00 UTC).
Fields
seconds: i64The number of seconds relative the Unix Epoch.
Implementations
Sourceimpl TimeUnixI64
impl TimeUnixI64
Sourcepub const fn new(seconds: i64) -> Self
pub const fn new(seconds: i64) -> Self
Returns a new TimeUnixI64 from the given amount of seconds.
Examples
assert_eq!["1970-01-01_00:00:01", TimeUnixI64::new(1).to_string()];
assert_eq!["1969-12-31_23:59:59", TimeUnixI64::new(-1).to_string()];
assert_eq!["2038-01-19_03:14:07", TimeUnixI64::new(i32::MAX as i64).to_string()];
assert_eq!["2106-02-07_06:28:15", TimeUnixI64::new(u32::MAX as i64).to_string()];
assert_eq!["1833-11-24_17:31:45", TimeUnixI64::new(u32::MAX as i64 * -1).to_string()];Sourcepub fn now() -> Self
Available on crate feature std only.
pub fn now() -> Self
std only.Returns a new TimeUnixI64 anchored to the current second.
Sourcepub const fn split(&self) -> TimeSplitYearSec<i32, u8, u8, u8, u8, u8>
pub const fn split(&self) -> TimeSplitYearSec<i32, u8, u8, u8, u8, u8>
Splits the TimeUnixI64 into { y, mo, d, h, m, s }.
Examples
assert_eq![(1970, 1, 1, 0, 0, 1), TimeUnixI64::new(1).split().to_tuple_y_s().unwrap()];
assert_eq![(1969, 12, 31, 23, 59, 59),
TimeUnixI64::new(-1).split().to_tuple_y_s().unwrap()];Trait Implementations
Sourceimpl Clone for TimeUnixI64
impl Clone for TimeUnixI64
Sourcefn clone(&self) -> TimeUnixI64
fn clone(&self) -> TimeUnixI64
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) ยท Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TimeUnixI64
Sourceimpl Debug for TimeUnixI64
impl Debug for TimeUnixI64
Sourceimpl Default for TimeUnixI64
impl Default for TimeUnixI64
Sourcefn default() -> TimeUnixI64
fn default() -> TimeUnixI64
Returns the โdefault valueโ for a type. Read more
Sourceimpl Display for TimeUnixI64
impl Display for TimeUnixI64
impl Eq for TimeUnixI64
Sourceimpl From<TimeUnixU32> for TimeUnixI64
impl From<TimeUnixU32> for TimeUnixI64
Sourcefn from(ut: TimeUnixU32) -> TimeUnixI64
fn from(ut: TimeUnixU32) -> TimeUnixI64
Converts to this type from the input type.
Sourceimpl From<i8> for TimeUnixI64
impl From<i8> for TimeUnixI64
Sourcefn from(seconds: i8) -> TimeUnixI64
fn from(seconds: i8) -> TimeUnixI64
Converts to this type from the input type.
Sourceimpl From<i16> for TimeUnixI64
impl From<i16> for TimeUnixI64
Sourcefn from(seconds: i16) -> TimeUnixI64
fn from(seconds: i16) -> TimeUnixI64
Converts to this type from the input type.
Sourceimpl From<i32> for TimeUnixI64
impl From<i32> for TimeUnixI64
Sourcefn from(seconds: i32) -> TimeUnixI64
fn from(seconds: i32) -> TimeUnixI64
Converts to this type from the input type.
Sourceimpl From<i64> for TimeUnixI64
impl From<i64> for TimeUnixI64
Sourcefn from(seconds: i64) -> TimeUnixI64
fn from(seconds: i64) -> TimeUnixI64
Converts to this type from the input type.
Sourceimpl From<u8> for TimeUnixI64
impl From<u8> for TimeUnixI64
Sourcefn from(seconds: u8) -> TimeUnixI64
fn from(seconds: u8) -> TimeUnixI64
Converts to this type from the input type.
Sourceimpl From<u16> for TimeUnixI64
impl From<u16> for TimeUnixI64
Sourcefn from(seconds: u16) -> TimeUnixI64
fn from(seconds: u16) -> TimeUnixI64
Converts to this type from the input type.
Sourceimpl From<u32> for TimeUnixI64
impl From<u32> for TimeUnixI64
Sourcefn from(seconds: u32) -> TimeUnixI64
fn from(seconds: u32) -> TimeUnixI64
Converts to this type from the input type.
Sourceimpl Ord for TimeUnixI64
impl Ord for TimeUnixI64
Sourcefn cmp(&self, other: &TimeUnixI64) -> Ordering
fn cmp(&self, other: &TimeUnixI64) -> Ordering
1.21.0 (const: unstable) ยท Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TimeUnixI64
impl PartialEq for TimeUnixI64
Sourcefn eq(&self, other: &TimeUnixI64) -> bool
fn eq(&self, other: &TimeUnixI64) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for TimeUnixI64
impl PartialOrd for TimeUnixI64
impl StructuralPartialEq for TimeUnixI64
Sourceimpl TryFrom<SystemTime> for TimeUnixI64
Available on crate feature std only.
impl TryFrom<SystemTime> for TimeUnixI64
Available on crate feature
std only.Sourceimpl TryFrom<TimeUnixI64> for TimeUnixU32
impl TryFrom<TimeUnixI64> for TimeUnixU32
Sourcetype Error = TryFromIntError
type Error = TryFromIntError
The type returned in the event of a conversion error.
Sourcefn try_from(ut: TimeUnixI64) -> Result<TimeUnixU32, Self::Error> โ
fn try_from(ut: TimeUnixI64) -> Result<TimeUnixU32, Self::Error> โ
Performs the conversion.
Sourceimpl TryFrom<i128> for TimeUnixI64
impl TryFrom<i128> for TimeUnixI64
Sourceimpl TryFrom<isize> for TimeUnixI64
impl TryFrom<isize> for TimeUnixI64
Sourceimpl TryFrom<u64> for TimeUnixI64
impl TryFrom<u64> for TimeUnixI64
Sourceimpl TryFrom<u128> for TimeUnixI64
impl TryFrom<u128> for TimeUnixI64