WebWindow

Struct WebWindow 

#[repr(C)]
pub struct WebWindow;
Available on crate feature web only.
🌐 Handle to the browser’s global Window and Screen associated APIs.


📍 sys/os/browser/web


Implementations

Source

impl WebWindow

pub fn document(&self) -> WebDocument

Available on WebAssembly and crate feature unsafe_ffi only.

(document) Returns the document object.

pub fn state() -> WebWindowState

Available on WebAssembly and crate feature unsafe_ffi only.

Returns a new up-to-date WebWindowState.

pub fn is_closed() -> js_bool

Available on WebAssembly and crate feature unsafe_ffi only.

(closed) Whether the current window is closed or not.

pub fn is_coi() -> js_bool

Available on WebAssembly and crate feature unsafe_ffi only.

(crossOriginIsolated) Whether the website is in a cross-origin isolation state.

pub fn is_secure() -> js_bool

Available on WebAssembly and crate feature unsafe_ffi only.

(isSecureContext) Whether the current context is secure.

pub fn is_popup() -> js_bool

Available on WebAssembly and crate feature unsafe_ffi only.

(locationbar) Whether the window is a popup or not.

pub fn name(buffer: &mut [u8]) -> &str

Available on WebAssembly and crate feature unsafe_ffi only.

(name) Gets the window name.

pub fn name_alloc() -> String

Available on WebAssembly and crate feature alloc and crate feature unsafe_ffi only.

(name) Gets the window name.

pub fn set_name(name: &str)

Available on WebAssembly and crate feature unsafe_ffi only.

(name) Sets the current window name.

pub fn set_timeout(callback: extern "C" fn(), delay_ms: js_uint32) -> JsTimeout

Available on WebAssembly and crate feature unsafe_ffi only.

(setTimeout) Calls a function after a delay in milliseconds.

pub fn set_interval( callback: extern "C" fn(), interval_ms: js_uint32, ) -> JsTimeout

Available on WebAssembly and crate feature unsafe_ffi only.

(setInterval) Calls a function repeatedly at a fixed interval in milliseconds.

pub fn clear_timeout(id: JsTimeout)

Available on WebAssembly and crate feature unsafe_ffi only.

(clearTimeout) (clearInterval) Cancels a timeout or interval.

pub fn eval(js_code: &str)

Available on WebAssembly and crate feature unsafe_ffi only.

Executes JavaScript code immediately.

Security Warning
  • Avoid passing untrusted input, as this executes arbitrary JS.
  • Ensure all evaluated code is safe and controlled.
pub fn eval_timeout(js_code: &str, delay_ms: js_uint32) -> JsTimeout

Available on WebAssembly and crate feature unsafe_ffi only.

(setTimeout) Executes JavaScript code after a delay in milliseconds.

pub fn eval_interval(js_code: &str, interval_ms: js_uint32) -> JsTimeout

Available on WebAssembly and crate feature unsafe_ffi only.

(setInterval) Executes JavaScript code repeatedly at a fixed interval in milliseconds.

pub fn request_animation_frame(callback: extern "C" fn()) -> js_uint32

Available on WebAssembly and crate feature unsafe_ffi only.

(requestAnimationFrame) Requests an animation frame, executing the given callback.

pub fn cancel_animation_frame(id: js_uint32)

Available on WebAssembly and crate feature unsafe_ffi only.

Cancels a request for an animation frame.