Default

Derive Macro Default 

1.38.0 ยท Source
#[derive(Default)]
๐ŸŒฑ core A trait for giving a type a useful default value. (Derivable)


๐Ÿ“code re-exported from core::default



๐Ÿ“œ
Derive macro generating an impl of the trait Default.