panic_

Macro panic_ 

macro_rules! panic_ {
    ($($tt:tt)*) => { ... };
}
βŒ— core Panics the current thread.


πŸ“ code/panic


Re-exported from core::panic.


The reason of the _ suffix is to avoid conflicting with the Rust’s prelude when glob importing from this crate. Since this macro has the same name as its sibling module core::panic, in order to be able to re-export only the macro we have to wrap it with our own.