ConstInit

Trait ConstInit 

pub trait ConstInit {
    const INIT: Self;
}
๐ŸŒฑ A trait for giving a type a useful const-friendly initial value.


๐Ÿ“ code


Comparison with Default

Default represents the typeโ€™s natural baseline, usually a neutral or zero-like state. ConstInit simply provides a valid const-time initializer, without requiring that meaning.

When a type has a clear Default, these traits should return the same value to keep behavior consistent. They only diverge for types that cannot offer a safe or meaningful Default, but still need a guaranteed const initializer.

  • Use Default for semantic baselines.
  • Use ConstInit for invariant-safe const initialization.

Required Associated Constants

const INIT: Self

Returns the compile-time โ€œinitial valueโ€ for a type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ConstInit for &mut str

Available on crate feature unsafe_str only.
Source

const INIT: Self

Source

impl ConstInit for &str

Source

const INIT: Self = ""

Source

impl ConstInit for ()

Source

const INIT: Self = ()

Source

impl ConstInit for bool

Source

const INIT: Self = false

Source

impl ConstInit for char

Source

const INIT: Self = '\x00'

Source

impl ConstInit for f32

Source

const INIT: Self = 0.0

Source

impl ConstInit for f64

Source

const INIT: Self = 0.0

Source

impl ConstInit for i8

Source

const INIT: Self = 0

Source

impl ConstInit for i16

Source

const INIT: Self = 0

Source

impl ConstInit for i32

Source

const INIT: Self = 0

Source

impl ConstInit for i64

Source

const INIT: Self = 0

Source

impl ConstInit for i128

Source

const INIT: Self = 0

Source

impl ConstInit for isize

Source

const INIT: Self = 0

Source

impl ConstInit for u8

Source

const INIT: Self = 0

Source

impl ConstInit for u16

Source

const INIT: Self = 0

Source

impl ConstInit for u32

Source

const INIT: Self = 0

Source

impl ConstInit for u64

Source

const INIT: Self = 0

Source

impl ConstInit for u128

Source

const INIT: Self = 0

Source

impl ConstInit for usize

Source

const INIT: Self = 0

Source

impl<T: ConstInit> ConstInit for (T, T)

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for (T, T, T)

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for (T, T, T, T)

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for (T, T, T, T, T)

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for (T, T, T, T, T, T)

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for (T, T, T, T, T, T, T)

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for (T, T, T, T, T, T, T, T)

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for (T, T, T, T, T, T, T, T, T)

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for (T, T, T, T, T, T, T, T, T, T)

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for (T, T, T, T, T, T, T, T, T, T, T)

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for (T, T, T, T, T, T, T, T, T, T, T, T)

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for (T,)

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for Range<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for RangeFrom<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for RangeInclusive<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for RangeToInclusive<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for Weak<T>

Available on crate feature std only.
Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 0]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 1]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 2]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 3]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 4]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 5]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 6]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 7]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 8]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 9]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 10]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 11]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 12]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 13]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 14]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 15]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 16]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 17]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 18]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 19]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 20]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 21]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 22]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 23]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 24]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 25]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 26]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 27]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 28]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 29]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 30]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 31]

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for [T; 32]

Source

const INIT: Self

Source

impl<T> ConstInit for &[T]

Source

const INIT: Self

Source

impl<T> ConstInit for *const T

Source

const INIT: Self

Source

impl<T> ConstInit for *mut T

Source

const INIT: Self

Implementors

Source

impl ConstInit for &CStr

Source

const INIT: Self

Source

impl ConstInit for Adler32

Source

const INIT: Self

Source

impl ConstInit for AppControlSet

Source

const INIT: Self

Source

impl ConstInit for ArenaHandleExample

Source

const INIT: Self

Source

impl ConstInit for AsciiSet

Source

const INIT: Self

Source

impl ConstInit for AtomicF32

Available on crate feature dep_portable_atomic only.
Source

const INIT: Self

Source

impl ConstInit for AtomicF64

Available on crate feature dep_portable_atomic only.
Source

const INIT: Self

Source

impl ConstInit for AtomicI8

Available on crate feature dep_portable_atomic only.
Source

const INIT: Self

Source

impl ConstInit for AtomicI16

Available on crate feature dep_portable_atomic only.
Source

const INIT: Self

Source

impl ConstInit for AtomicI32

Available on crate feature dep_portable_atomic only.
Source

const INIT: Self

Source

impl ConstInit for AtomicI64

Available on crate feature dep_portable_atomic only.
Source

const INIT: Self

Source

impl ConstInit for AtomicI128

Available on crate feature dep_portable_atomic only.
Source

const INIT: Self

Source

impl ConstInit for AtomicIsize

Available on crate feature dep_portable_atomic only.
Source

const INIT: Self

Source

impl ConstInit for AtomicU8

Available on crate feature dep_portable_atomic only.
Source

const INIT: Self

Source

impl ConstInit for AtomicU16

Available on crate feature dep_portable_atomic only.
Source

const INIT: Self

Source

impl ConstInit for AtomicU32

Available on crate feature dep_portable_atomic only.
Source

const INIT: Self

Source

impl ConstInit for AtomicU64

Available on crate feature dep_portable_atomic only.
Source

const INIT: Self

Source

impl ConstInit for AtomicU128

Available on crate feature dep_portable_atomic only.
Source

const INIT: Self

Source

impl ConstInit for AtomicUsize

Available on crate feature dep_portable_atomic only.
Source

const INIT: Self

Source

impl ConstInit for AudioChannel

Available on crate feature audio only.
Source

const INIT: Self = Self::L

Source

impl ConstInit for AudioChannels

Available on crate feature audio only.
Source

const INIT: Self = Self::Stereo

Source

impl ConstInit for AudioDevice<'_>

Source

const INIT: Self

Source

impl ConstInit for AudioDeviceDir

Source

const INIT: Self = Self::Duplex

Source

impl ConstInit for AudioStreamDir

Source

const INIT: Self = Self::Playback

Source

impl ConstInit for BinTag4

Source

const INIT: Self

Source

impl ConstInit for BitfieldExample

Available on crate features _docs_examples only.
Source

const INIT: Self

Source

impl ConstInit for Boundary1d

Source

const INIT: Self = Self::Left

Source

impl ConstInit for Boundary2d

Source

const INIT: Self = Self::Left

Source

impl ConstInit for Boundary3d

Source

const INIT: Self = Self::Left

Source

impl ConstInit for Boxed

Available on crate feature alloc only.
Source

const INIT: Self = Boxed

Source

impl ConstInit for CharAscii

Source

const INIT: Self = Self::Null

Source

impl ConstInit for Condvar

Available on crate feature std only.
Source

const INIT: Self

Source

impl ConstInit for CryptoError

Source

const INIT: Self = Self::LengthOverflow

Source

impl ConstInit for DeviceId

Available on crate feature event only.
Source

const INIT: Self

Source

impl ConstInit for Duration

Source

const INIT: Self

Source

impl ConstInit for EnumSetExample

Available on doc or test only.
Source

const INIT: Self

Source

impl ConstInit for Event

Available on crate feature event only.
Source

const INIT: Self = Self::None

Source

impl ConstInit for EventButton

Available on crate feature event only.
Source

const INIT: Self = Self::Left

Source

impl ConstInit for EventButtonState

Available on crate feature event only.
Source

const INIT: Self = Self::Pressed

Source

impl ConstInit for EventButtons

Available on crate feature event only.
Source

const INIT: Self

Source

impl ConstInit for EventKey

Available on crate feature event only.
Source

const INIT: Self

Source

impl ConstInit for EventKind

Available on crate feature event only.
Source

const INIT: Self = Self::None

Source

impl ConstInit for EventMouse

Available on crate feature event only.
Source

const INIT: Self

Source

impl ConstInit for EventPointer

Available on crate feature event only.
Source

const INIT: Self

Source

impl ConstInit for EventPointerKind

Available on crate feature event only.
Source

const INIT: Self = Self::Mouse

Source

impl ConstInit for EventTagSet

Available on crate feature event only.
Source

const INIT: Self

Source

impl ConstInit for EventTarget

Available on crate feature event only.
Source

const INIT: Self = Self::Global

Source

impl ConstInit for EventTimestamp

Available on crate feature event only.
Source

const INIT: Self

Source

impl ConstInit for EventWheel

Available on crate feature event only.
Source

const INIT: Self

Source

impl ConstInit for EventWheelUnit

Available on crate feature event only.
Source

const INIT: Self = Self::Step

Source

impl ConstInit for EventWindow

Available on crate feature event only.
Source

const INIT: Self = Self::FocusLost

Source

impl ConstInit for ExitCode

Available on crate feature std only.
Source

const INIT: Self = Self::SUCCESS

Source

impl ConstInit for FloatCategory

Source

const INIT: Self = FloatCategory::Nan

Source

impl ConstInit for FmtNumConf

Source

const INIT: Self

Source

impl ConstInit for FmtNumGroup

Source

const INIT: Self

Source

impl ConstInit for FmtNumSign

Source

const INIT: Self = FmtNumSign::NegativeOnly

Source

impl ConstInit for GraphemeString

Available on crate feature grapheme only.
Source

const INIT: Self

Source

impl ConstInit for HandleSpanExample

Available on crate features _docs_examples only.
Source

const INIT: Self

Source

impl ConstInit for HasherFnv<u32>

Source

const INIT: Self

Source

impl ConstInit for HasherFnv<u64>

Source

const INIT: Self

Source

impl ConstInit for HasherFnv<u128>

Source

const INIT: Self

Source

impl ConstInit for HasherFnv<usize>

Source

const INIT: Self

Source

impl ConstInit for HasherFx<u32>

Source

const INIT: Self

Source

impl ConstInit for HasherFx<u64>

Source

const INIT: Self

Source

impl ConstInit for HasherFx<usize>

Source

const INIT: Self

Source

impl ConstInit for HasherPengy

Source

const INIT: Self

Source

impl ConstInit for HttpError

Available on crate feature http only.
Source

const INIT: Self = Self::EmptyRequestLine

Source

impl ConstInit for Key

Available on crate feature event only.
Source

const INIT: Self = Self::Unknown

Source

impl ConstInit for KeyDead

Available on crate feature event only.
Source

const INIT: Self = KeyDead::Unknown

Source

impl ConstInit for KeyFfi

Available on ffiยทยท only.
Source

const INIT: Self = Self::Unknown

Source

impl ConstInit for KeyMedia

Available on crate feature event only.
Source

const INIT: Self = Self::Play

Source

impl ConstInit for KeyMod

Available on crate feature event only.
Source

const INIT: Self = Self::LeftShift

Source

impl ConstInit for KeyMods

Available on crate feature event only.
Source

const INIT: Self

Source

impl ConstInit for KeyPad

Available on crate feature event only.
Source

const INIT: Self = Self::Num0

Source

impl ConstInit for KeyState

Available on crate feature event only.
Source

const INIT: Self = Self::Press

Source

impl ConstInit for Lcg16

Available on crate feature rand only.

Creates a new PRNG initialized with the default fixed seed.

Source

const INIT: Self

Source

impl ConstInit for LinuxSigactionFlags

Available on crate feature linux only.
Source

const INIT: Self

Source

impl ConstInit for LinuxSignalSet

Available on crate feature linux only.
Source

const INIT: Self

Source

impl ConstInit for LinuxTermiosControlFlags

Available on crate feature linux only.
Source

const INIT: Self

Source

impl ConstInit for LinuxTermiosInputFlags

Available on crate feature linux only.
Source

const INIT: Self

Source

impl ConstInit for LinuxTermiosLocalFlags

Available on crate feature linux only.
Source

const INIT: Self

Source

impl ConstInit for LinuxTermiosOutputFlags

Available on crate feature linux only.
Source

const INIT: Self

Source

impl ConstInit for LinuxTimespec

Available on crate feature linux only.
Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonNiche<i8>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonNiche<i16>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonNiche<i32>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonNiche<i64>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonNiche<i128>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonNiche<isize>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonNiche<u8>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonNiche<u16>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonNiche<u32>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonNiche<u64>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonNiche<u128>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonNiche<usize>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonZero<i8>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonZero<i16>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonZero<i32>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonZero<i64>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonZero<i128>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonZero<isize>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonZero<u8>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonZero<u16>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonZero<u32>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonZero<u64>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonZero<u128>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<NonZero<usize>>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<i8>
where i8: ConstInit,

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<i16>
where i16: ConstInit,

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<i32>
where i32: ConstInit,

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<i64>
where i64: ConstInit,

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<i128>
where i128: ConstInit,

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<isize>

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<u8>
where u8: ConstInit,

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<u16>
where u16: ConstInit,

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<u32>
where u32: ConstInit,

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<u64>
where u64: ConstInit,

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<u128>
where u128: ConstInit,

Source

const INIT: Self

Source

impl ConstInit for MaybeNiche<usize>

Source

const INIT: Self

Source

impl ConstInit for Md5

Available on crate features _docs_examples only.
Source

impl ConstInit for NonZeroI8

This implementation returns the same as Self::MIN.

Source

const INIT: Self = Self::MIN

Source

impl ConstInit for NonZeroI16

This implementation returns the same as Self::MIN.

Source

const INIT: Self = Self::MIN

Source

impl ConstInit for NonZeroI32

This implementation returns the same as Self::MIN.

Source

const INIT: Self = Self::MIN

Source

impl ConstInit for NonZeroI64

This implementation returns the same as Self::MIN.

Source

const INIT: Self = Self::MIN

Source

impl ConstInit for NonZeroI128

This implementation returns the same as Self::MIN.

Source

const INIT: Self = Self::MIN

Source

impl ConstInit for NonZeroIsize

This implementation returns the same as Self::MIN.

Source

const INIT: Self = Self::MIN

Source

impl ConstInit for NonZeroU8

This implementation returns the same as Self::MIN.

Source

const INIT: Self = Self::MIN

Source

impl ConstInit for NonZeroU16

This implementation returns the same as Self::MIN.

Source

const INIT: Self = Self::MIN

Source

impl ConstInit for NonZeroU32

This implementation returns the same as Self::MIN.

Source

const INIT: Self = Self::MIN

Source

impl ConstInit for NonZeroU64

This implementation returns the same as Self::MIN.

Source

const INIT: Self = Self::MIN

Source

impl ConstInit for NonZeroU128

This implementation returns the same as Self::MIN.

Source

const INIT: Self = Self::MIN

Source

impl ConstInit for NonZeroUsize

This implementation returns the same as Self::MIN.

Source

const INIT: Self = Self::MIN

Source

impl ConstInit for Once

Available on crate feature std only.
Source

const INIT: Self

Source

impl ConstInit for Ordering

Source

const INIT: Self = Ordering::Equal

Source

impl ConstInit for ParseIntErrorKind

Source

const INIT: Self = ParseIntErrorKind::Empty

Source

impl ConstInit for Pcg32

Creates a new PRNG initialized with the default fixed seed.

Source

const INIT: Self

Source

impl ConstInit for PcmLayout

Available on crate feature audio only.
Source

const INIT: Self = Self::Interleaved

Source

impl ConstInit for PcmSample

Available on crate feature audio only.
Source

const INIT: Self = Self::I16

Source

impl ConstInit for PcmSpec

Available on crate feature audio only.
Source

const INIT: Self

Source

impl ConstInit for PhantomPinned

Source

const INIT: Self = Self

Source

impl ConstInit for RandQualities

Source

const INIT: Self

Source

impl ConstInit for RangeFull

Source

const INIT: Self = Self

Source

impl ConstInit for RasterFormat

Source

const INIT: Self = Self::UNKNOWN

Source

impl ConstInit for ReprMode

Source

const INIT: Self = Self::Raw

Source

impl ConstInit for RunCapInput

Source

const INIT: Self

Source

impl ConstInit for RunCapSystem

Source

const INIT: Self

Source

impl ConstInit for RunCapText

Source

const INIT: Self

Source

impl ConstInit for Sha1

Available on crate features _docs_examples only.
Source

impl ConstInit for Sha256

Available on crate features _docs_examples only.
Source

impl ConstInit for Sha512

Available on crate features _docs_examples only.
Source

impl ConstInit for Sign

Source

const INIT: Self = Sign::Zero

Source

impl ConstInit for SplitMix64

Provides a fixed default initialized value.

Source

const INIT: Self

Source

impl ConstInit for String

Available on crate feature alloc only.
Source

const INIT: Self

Source

impl ConstInit for TermCaps

Available on crate feature term only.
Source

const INIT: Self

Source

impl ConstInit for TermColor

Available on crate feature term only.
Source

const INIT: Self

Source

impl ConstInit for TermInputParser

Available on crate features event and term only.
Source

const INIT: Self

Source

impl ConstInit for TermMode

Available on crate feature term only.
Source

const INIT: Self

Source

impl ConstInit for TermStyle

Available on crate feature term only.
Source

const INIT: Self

Source

impl ConstInit for TermStyleExt

Available on crate feature term only.
Source

const INIT: Self

Source

impl ConstInit for TermelMeta

Available on crate feature term only.
Source

const INIT: Self

Source

impl ConstInit for TextCohesion

Source

const INIT: Self = Self::Atomic

Source

impl ConstInit for TextCursor

Source

const INIT: Self

Source

impl ConstInit for TextFit

Source

const INIT: Self = Self::None

Source

impl ConstInit for TextIndex

Source

const INIT: Self

Source

impl ConstInit for TextLayout

Source

const INIT: Self = Self

Source

impl ConstInit for TextLayoutSpan

Source

const INIT: Self

Source

impl ConstInit for TextLayoutStep

Source

const INIT: Self

Source

impl ConstInit for TextParseError

Source

const INIT: Self

Source

impl ConstInit for TextParseErrorKind

Source

const INIT: Self = Self::UnexpectedEof

Source

impl ConstInit for TextRange

Source

const INIT: Self

Source

impl ConstInit for TextScanner<'_>

Source

const INIT: Self

Source

impl ConstInit for TextSymbol

Source

const INIT: Self

Source

impl ConstInit for Version

Source

const INIT: Self = Self::ZERO

Source

impl ConstInit for WindowId

Available on crate feature event only.
Source

const INIT: Self

Source

impl ConstInit for Xabc

Available on crate feature rand only.

Creates a new PRNG initialized with the default fixed seed.

Source

const INIT: Self

Source

impl ConstInit for XorShift16

Creates a new PRNG initialized with the default fixed seed.

Source

const INIT: Self

Source

impl ConstInit for XorShift32

Creates a new PRNG initialized with the default fixed seed.

Source

const INIT: Self

Source

impl ConstInit for XorShift64

Creates a new PRNG initialized with the default fixed seed.

Source

const INIT: Self

Source

impl ConstInit for XorShift128

Creates a new PRNG initialized with the default fixed seed.

Source

const INIT: Self

Source

impl ConstInit for XorShift128p

Creates a new PRNG initialized with the default fixed seed.

Source

const INIT: Self

Source

impl ConstInit for Xoroshiro128pp

Available on crate feature rand only.

Creates a new PRNG initialized with the default fixed seed.

Source

const INIT: Self

Source

impl ConstInit for Xyza8a

Available on crate feature rand only.

Creates a new PRNG initialized with the default fixed seed.

Source

const INIT: Self

Source

impl ConstInit for Xyza8b

Available on crate feature rand only.
Source

const INIT: Self

Source

impl ConstInit for char7

Source

const INIT: Self

Source

impl ConstInit for char8

Source

const INIT: Self

Source

impl ConstInit for char16

Source

const INIT: Self

Source

impl ConstInit for charu

Source

const INIT: Self

Source

impl ConstInit for charu_niche

Source

const INIT: Self

Source

impl ConstInit for f32bits

Source

const INIT: Self

Source

impl ConstInit for f32bits_niche

Source

const INIT: Self

Source

impl ConstInit for f64bits

Source

const INIT: Self

Source

impl ConstInit for f64bits_niche

Source

const INIT: Self

Source

impl<'a> ConstInit for VersionFull<'a>

Source

const INIT: Self = Self::ZERO

Source

impl<B: ConstInit, C: ConstInit> ConstInit for ControlFlow<B, C>

Source

const INIT: Self

Source

impl<K, V> ConstInit for BTreeMap<K, V>

Available on crate feature alloc only.
Source

const INIT: Self

Source

impl<N: ConstInit, H: ConstInit> ConstInit for Mismatch<N, H>

Source

const INIT: Self

Source

impl<S: ConstInit, V: ConstInit> ConstInit for Own<S, V>

Source

const INIT: Self

Source

impl<T: ConstInit, E> ConstInit for Result<T, E>

Source

const INIT: Self

Source

impl<T: ConstInit, N: ConstInit> ConstInit for CycleCount<T, N>

Source

const INIT: Self

Source

impl<T: ConstInit, const C: usize, const R: usize, const CR: usize, const RMAJ: bool> ConstInit for Array2d<T, C, R, CR, RMAJ, Bare>

Source

const INIT: Self

Source

impl<T: ConstInit, const CAP: usize, IDX: ConstInit> ConstInit for Destaque<T, CAP, IDX, Bare>

Available on _destaqueยทยท only.
Source

const INIT: Self

Source

impl<T: ConstInit, const CAP: usize, IDX: ConstInit> ConstInit for Stack<T, CAP, IDX, Bare>

Available on _stackยทยท only.
Source

const INIT: Self

Source

impl<T: ConstInit, const CAP: usize> ConstInit for Array<T, CAP, Bare>

Source

const INIT: Self

Source

impl<T: ConstInit, const D: usize> ConstInit for Distance<T, D>

Source

const INIT: Self

Source

impl<T: ConstInit, const D: usize> ConstInit for Extent<T, D>

Source

const INIT: Self

Source

impl<T: ConstInit, const D: usize> ConstInit for Orientation<T, D>

Source

const INIT: Self

Source

impl<T: ConstInit, const D: usize> ConstInit for Point<T, D>

Source

const INIT: Self

Source

impl<T: ConstInit, const D: usize> ConstInit for Position<T, D>

Source

const INIT: Self

Source

impl<T: ConstInit, const D: usize> ConstInit for Stride<T, D>

Source

const INIT: Self

Source

impl<T: ConstInit, const D: usize> ConstInit for Vector<T, D>

Available on crate feature lin only.
Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for Angle<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for Atomic<T>

Available on crate feature dep_atomic only.
Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for BareBox<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for Cast<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for Cell<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for Cmp<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for Cycle<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for Float<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for Lane4_i32Example<T>

Available on crate feature _docs_examples only.
Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for LazyCell<T>

Available on crate feature std only.
Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for LazyLock<T>

Available on crate feature std only.
Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for ManuallyDrop<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for Mutex<T>

Available on crate feature std only.
Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for OnceCell<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for OnceLock<T>

Available on crate feature std only.
Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for Option<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for PanicAssertUnwindSafe<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for devela::zall::Range<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for devela::zall::RangeFrom<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for devela::zall::RangeInclusive<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for RangeTo<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for devela::zall::RangeToInclusive<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for RcWeak<T>

Available on crate feature alloc only.
Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for RefCell<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for Reverse<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for RwLock<T>

Available on crate feature std only.
Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for Saturating<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for UnsafeCell<T>

Source

const INIT: Self

Source

impl<T: ConstInit> ConstInit for Wrapping<T>

Source

const INIT: Self

Source

impl<T: Copy + ConstInit> ConstInit for NonNiche<T>

Source

const INIT: Self

Source

impl<T: MemPod, const CAP: usize> ConstInit for DstArray<T, CAP>

Available on crate feature unsafe_layout only.
Source

const INIT: Self

Source

impl<T: Ord> ConstInit for BinaryHeap<T>

Available on crate feature alloc only.
Source

const INIT: Self

Source

impl<T> ConstInit for AtomicPtr<T>

Available on crate feature dep_portable_atomic only.
Source

const INIT: Self

Source

impl<T> ConstInit for BTreeSet<T>

Available on crate feature alloc only.
Source

const INIT: Self

Source

impl<T> ConstInit for Bound<T>

Source

const INIT: Self = Self::Unbounded

Source

impl<T> ConstInit for ConstList<'_, T>

Source

const INIT: Self

Source

impl<T> ConstInit for Interval<T>

Provides a const default value for Interval, the unbounded interval $(-\infty, \infty)$.

See the default implementation for more information.

Source

const INIT: Self

Source

impl<T> ConstInit for LinkedList<T>

Available on crate feature alloc only.
Source

const INIT: Self

Source

impl<T> ConstInit for PcmBuf<T, &[&[T]]>

Available on crate feature audio only.
Source

const INIT: Self

Source

impl<T> ConstInit for PcmBuf<T, &[T]>

Available on crate feature audio only.
Source

const INIT: Self

Source

impl<T> ConstInit for PcmBuf<T, &mut [&mut [T]]>

Available on crate feature audio only.
Source

const INIT: Self

Source

impl<T> ConstInit for PcmBuf<T, &mut [T]>

Available on crate feature audio only.
Source

const INIT: Self

Source

impl<T> ConstInit for PhantomData<T>

Source

const INIT: Self = Self

Source

impl<T> ConstInit for TypeResource<T>

Source

const INIT: Self

Source

impl<T> ConstInit for Vec<T>

Available on crate feature alloc only.
Source

const INIT: Self

Source

impl<T> ConstInit for VecDeque<T>

Available on crate feature alloc only.
Source

const INIT: Self

Source

impl<V: ConstInit, T: ConstInit> ConstInit for Timed<V, T>

Source

const INIT: Self

Source

impl<V: Copy + ConstInit, const N: usize> ConstInit for MapStaticConstU8Example<u8, V, N>

Source

const INIT: Self

Source

impl<Y: ConstInit, R: ConstInit> ConstInit for CoroutineState<Y, R>

Source

const INIT: Self

Source

impl<const A: usize, const B: usize, const C: usize> ConstInit for XorShift8<A, B, C>

Creates a new PRNG initialized with the default fixed seed.

Source

const INIT: Self

Source

impl<const CAP: usize> ConstInit for EventQueue<CAP>

Available on crate feature event only.
Source

const INIT: Self

Source

impl<const CAP: usize> ConstInit for GraphemeNonul<CAP>

Available on crate feature grapheme only.
Source

const INIT: Self

Source

impl<const CAP: usize> ConstInit for GraphemeU8<CAP>

Available on crate feature grapheme only.
Source

const INIT: Self

Source

impl<const CAP: usize> ConstInit for StringNonul<CAP>

Source

const INIT: Self

Source

impl<const CAP: usize> ConstInit for StringSmallAlloc<CAP>

Available on crate feature alloc only.
Source

const INIT: Self

Source

impl<const CAP: usize> ConstInit for StringU8<CAP>

Source

const INIT: Self

Source

impl<const LEN: usize, _0: ConstInit, _1, _2, _3, _4, _5, _6, _7, _8, _9, _10, _11> ConstInit for Oneof<LEN, _0, _1, _2, _3, _4, _5, _6, _7, _8, _9, _10, _11>

Source

const INIT: Self

Source

impl<const N: usize> ConstInit for Digest<N>

Source

const INIT: Self

Source

impl<const RADIX: usize, const LUT: bool, const PAD: bool, const CASE: bool, CODE> ConstInit for Base<RADIX, LUT, PAD, CASE, CODE>

Source

const INIT: Self

Source

impl<const V: i8> ConstInit for MaybeNiche<NonValueI8<V>>

Source

const INIT: Self

Source

impl<const V: i8> ConstInit for NonValueI8<V>

Source

const INIT: Self

Source

impl<const V: i16> ConstInit for MaybeNiche<NonValueI16<V>>

Source

const INIT: Self

Source

impl<const V: i16> ConstInit for NonValueI16<V>

Source

const INIT: Self

Source

impl<const V: i32> ConstInit for MaybeNiche<NonValueI32<V>>

Source

const INIT: Self

Source

impl<const V: i32> ConstInit for NonValueI32<V>

Source

const INIT: Self

Source

impl<const V: i64> ConstInit for MaybeNiche<NonValueI64<V>>

Source

const INIT: Self

Source

impl<const V: i64> ConstInit for NonValueI64<V>

Source

const INIT: Self

Source

impl<const V: i128> ConstInit for MaybeNiche<NonValueI128<V>>

Source

const INIT: Self

Source

impl<const V: i128> ConstInit for NonValueI128<V>

Source

const INIT: Self

Source

impl<const V: isize> ConstInit for MaybeNiche<NonValueIsize<V>>

Source

const INIT: Self

Source

impl<const V: isize> ConstInit for NonValueIsize<V>

Source

const INIT: Self

Source

impl<const V: u8> ConstInit for MaybeNiche<NonValueU8<V>>

Source

const INIT: Self

Source

impl<const V: u8> ConstInit for NonValueU8<V>

Source

const INIT: Self

Source

impl<const V: u16> ConstInit for MaybeNiche<NonValueU16<V>>

Source

const INIT: Self

Source

impl<const V: u16> ConstInit for NonValueU16<V>

Source

const INIT: Self

Source

impl<const V: u32> ConstInit for MaybeNiche<NonValueU32<V>>

Source

const INIT: Self

Source

impl<const V: u32> ConstInit for NonValueU32<V>

Source

const INIT: Self

Source

impl<const V: u64> ConstInit for MaybeNiche<NonValueU64<V>>

Source

const INIT: Self

Source

impl<const V: u64> ConstInit for NonValueU64<V>

Source

const INIT: Self

Source

impl<const V: u128> ConstInit for MaybeNiche<NonValueU128<V>>

Source

const INIT: Self

Source

impl<const V: u128> ConstInit for NonValueU128<V>

Source

const INIT: Self

Source

impl<const V: usize> ConstInit for MaybeNiche<NonValueUsize<V>>

Source

const INIT: Self

Source

impl<const V: usize> ConstInit for NonValueUsize<V>

Source

const INIT: Self