pub struct ConstList<'a, T: 'a>(/* private fields */);Expand description
๐๏ธ ๐ An immutable, append-only, linear, functional, non-contiguous, list.
๐ data/topol
A safe, predictable, and lightweight structure, suitable where immutability is an asset and compile-time guarantees matter more than list manipulation.
Examples
const MY_LIST: ConstList<'static, i32> = ConstList::new()
.push(2)
.push(4)
.push(8);
assert_eq!(8, *MY_LIST.pop().0.unwrap());Vendored
This is adapted work from const_list.
Implementations
Sourceimpl<'a, T: 'a> ConstList<'a, T>
impl<'a, T: 'a> ConstList<'a, T>
Sourcepub const fn get(&self, index: usize) -> Option<&T> โ
pub const fn get(&self, index: usize) -> Option<&T> โ
Gets a reference to the item at the provided index in this list, if any.
Sourcepub const fn push(&'a self, value: T) -> Self
pub const fn push(&'a self, value: T) -> Self
Pushes a new item onto the beginning of this list, producing a new list head.
Sourcepub const fn pop(&'a self) -> (Option<&'a T>, &'a Self) โ
pub const fn pop(&'a self) -> (Option<&'a T>, &'a Self) โ
Removes the first item (if any) from this list, and produces the rest of the list.
Sourcepub const fn iter(&self) -> ConstListIter<'_, T> โ
pub const fn iter(&self) -> ConstListIter<'_, T> โ
Creates an iterator over the contents of the list.