HasherFnv

Struct HasherFnv 

pub struct HasherFnv<T> { /* private fields */ }
Available on crate feature hash only.
๐Ÿ”€ A Fowlerโ€“Nollโ€“Vo hasher, implemented for u32, u64, u128 & usize.


๐Ÿ“ data/codec/hash


It uses the fnv-1a variation which gives better avalanche characteristics.

See

Implementations

Source

impl HasherFnv<u32>

pub const fn new() -> Self

Returns a default FNV hasher.

pub const fn with(input: &[u8]) -> Self

Returns an FNV hasher with the given input data.

pub const fn get(&self) -> u32

Returns the current hash value.

pub const fn get_hash_mod_lazy(&self, range: u32) -> u32

Returns the hash value with lazy mod mapping to the given range.

pub const fn get_hash_mod_retry(&self, range: u32) -> u32

Returns the hash value with retried mod mapping to the given range.

pub const fn get_hash_n_bits(&self, n: usize) -> u32

Returns the hash value xor folded to n bits.

Panics

Panics in debug if n exceeds u32::BITS.

pub const fn update(&mut self, input: &[u8])

Updates the hasher with more data.

Allows the hasher to receive additional bytes incrementally.

pub const fn reset(&mut self)

Resets the inner state to the default basis value.

pub const fn hash(input: &[u8]) -> u32

Computes the FNV hash of the provided byte slice.

pub const fn hash_mod_lazy(input: &[u8], range: u32) -> u32

Maps the computed FNV hash to the given range using lazy mod mapping.

This method only does an additional mod at the end. But thereโ€™s a small bias against the larger values.

pub const fn hash_mod_retry(input: &[u8], range: u32) -> u32

Maps the computed FNV hash to the given range using retried mod mapping.

pub const fn hash_n_bits(input: &[u8], n: usize) -> u32

Computes the FNV hash of the provided byte slice, xor folded to n bits.

Panics

Panics in debug if n exceeds u32::BITS.

pub const fn fold_hash(hash: u32, n: usize) -> u32

Reduces a hash to n bits using xor folding.

Panics

Panics in debug if n exceeds u32::BITS.

pub const fn mod_retry_hash(hash: u32, range: u32) -> u32

Maps a hash to the given range using retried mod mapping.

Ensures that the hash value is uniform and unbiased within the range.

Source

impl HasherFnv<u64>

pub const fn new() -> Self

Returns a default FNV hasher.

pub const fn with(input: &[u8]) -> Self

Returns an FNV hasher with the given input data.

pub const fn get(&self) -> u64

Returns the current hash value.

pub const fn get_hash_mod_lazy(&self, range: u64) -> u64

Returns the hash value with lazy mod mapping to the given range.

pub const fn get_hash_mod_retry(&self, range: u64) -> u64

Returns the hash value with retried mod mapping to the given range.

pub const fn get_hash_n_bits(&self, n: usize) -> u64

Returns the hash value xor folded to n bits.

Panics

Panics in debug if n exceeds u64::BITS.

pub const fn update(&mut self, input: &[u8])

Updates the hasher with more data.

Allows the hasher to receive additional bytes incrementally.

pub const fn reset(&mut self)

Resets the inner state to the default basis value.

pub const fn hash(input: &[u8]) -> u64

Computes the FNV hash of the provided byte slice.

pub const fn hash_mod_lazy(input: &[u8], range: u64) -> u64

Maps the computed FNV hash to the given range using lazy mod mapping.

This method only does an additional mod at the end. But thereโ€™s a small bias against the larger values.

pub const fn hash_mod_retry(input: &[u8], range: u64) -> u64

Maps the computed FNV hash to the given range using retried mod mapping.

pub const fn hash_n_bits(input: &[u8], n: usize) -> u64

Computes the FNV hash of the provided byte slice, xor folded to n bits.

Panics

Panics in debug if n exceeds u64::BITS.

pub const fn fold_hash(hash: u64, n: usize) -> u64

Reduces a hash to n bits using xor folding.

Panics

Panics in debug if n exceeds u64::BITS.

pub const fn mod_retry_hash(hash: u64, range: u64) -> u64

Maps a hash to the given range using retried mod mapping.

Ensures that the hash value is uniform and unbiased within the range.

Source

impl HasherFnv<u128>

pub const fn new() -> Self

Returns a default FNV hasher.

pub const fn with(input: &[u8]) -> Self

Returns an FNV hasher with the given input data.

pub const fn get(&self) -> u128

Returns the current hash value.

pub const fn get_hash_mod_lazy(&self, range: u128) -> u128

Returns the hash value with lazy mod mapping to the given range.

pub const fn get_hash_mod_retry(&self, range: u128) -> u128

Returns the hash value with retried mod mapping to the given range.

pub const fn get_hash_n_bits(&self, n: usize) -> u128

Returns the hash value xor folded to n bits.

Panics

Panics in debug if n exceeds u128::BITS.

pub const fn update(&mut self, input: &[u8])

Updates the hasher with more data.

Allows the hasher to receive additional bytes incrementally.

pub const fn reset(&mut self)

Resets the inner state to the default basis value.

pub const fn hash(input: &[u8]) -> u128

Computes the FNV hash of the provided byte slice.

pub const fn hash_mod_lazy(input: &[u8], range: u128) -> u128

Maps the computed FNV hash to the given range using lazy mod mapping.

This method only does an additional mod at the end. But thereโ€™s a small bias against the larger values.

pub const fn hash_mod_retry(input: &[u8], range: u128) -> u128

Maps the computed FNV hash to the given range using retried mod mapping.

pub const fn hash_n_bits(input: &[u8], n: usize) -> u128

Computes the FNV hash of the provided byte slice, xor folded to n bits.

Panics

Panics in debug if n exceeds u128::BITS.

pub const fn fold_hash(hash: u128, n: usize) -> u128

Reduces a hash to n bits using xor folding.

Panics

Panics in debug if n exceeds u128::BITS.

pub const fn mod_retry_hash(hash: u128, range: u128) -> u128

Maps a hash to the given range using retried mod mapping.

Ensures that the hash value is uniform and unbiased within the range.

Source

impl HasherFnv<usize>

pub const fn new() -> Self

Returns a default FNV hasher.

pub const fn with(input: &[u8]) -> Self

Returns an FNV hasher with the given input data.

pub const fn get(&self) -> usize

Returns the current hash value.

pub const fn get_hash_mod_lazy(&self, range: usize) -> usize

Returns the hash value with lazy mod mapping to the given range.

pub const fn get_hash_mod_retry(&self, range: usize) -> usize

Returns the hash value with retried mod mapping to the given range.

pub const fn get_hash_n_bits(&self, n: usize) -> usize

Returns the hash value xor folded to n bits.

Panics

Panics in debug if n exceeds usize::BITS.

pub const fn update(&mut self, input: &[u8])

Updates the hasher with more data.

Allows the hasher to receive additional bytes incrementally.

pub const fn reset(&mut self)

Resets the inner state to the default basis value.

pub const fn hash(input: &[u8]) -> usize

Computes the FNV hash of the provided byte slice.

pub const fn hash_mod_lazy(input: &[u8], range: usize) -> usize

Maps the computed FNV hash to the given range using lazy mod mapping.

This method only does an additional mod at the end. But thereโ€™s a small bias against the larger values.

pub const fn hash_mod_retry(input: &[u8], range: usize) -> usize

Maps the computed FNV hash to the given range using retried mod mapping.

pub const fn hash_n_bits(input: &[u8], n: usize) -> usize

Computes the FNV hash of the provided byte slice, xor folded to n bits.

Panics

Panics in debug if n exceeds usize::BITS.

pub const fn fold_hash(hash: usize, n: usize) -> usize

Reduces a hash to n bits using xor folding.

Panics

Panics in debug if n exceeds usize::BITS.

pub const fn mod_retry_hash(hash: usize, range: usize) -> usize

Maps a hash to the given range using retried mod mapping.

Ensures that the hash value is uniform and unbiased within the range.