JsInstant

Struct JsInstant 

#[repr(C)]
pub struct JsInstant { pub ms: js_number, }
Available on crate feature js only.
🕘 A high-resolution timestamp based on JavaScript’s performance.now().


📍 lang/prog/ffi/js

📦 size_of::<JsInstant>() == 8 bytes / 64 bits


The internal representation is a double-precision floating-point millisecond value.

Fields

ms: js_number

Milliseconds since performance.timeOrigin.

Implementations

Source

impl JsInstant

pub const fn as_millis_f64(self) -> js_number

Returns the time in milliseconds.

pub const fn from_millis_f64(millis: js_number) -> Self

Returns a new JsInstant from a timestamp in milliseconds.

pub const fn as_secs_f64(self) -> js_number

Returns the time in f64 seconds.

pub const fn from_secs_f64(secs: js_number) -> Self

Returns a new JsInstant from a timestamp in milliseconds.

pub const fn since(self, earlier: Self) -> Self

Returns the duration between this and an earlier JsInstant.

pub const fn delta_since(self, earlier: Self) -> TimeDelta

Returns the duration between this and an earlier instant as a TimeDelta.

Source

impl JsInstant

pub fn now() -> Self

Available on crate feature web only.

Returns the current instant using performance.now().

pub fn origin() -> Self

Available on crate feature web only.

Returns the time origin using performance.timeOrigin().

pub fn reset(&mut self)

Available on crate feature web only.

Resets this instant to the current time.

pub fn elapsed(self) -> Self

Available on crate feature web only.

Returns the elapsed time since this instant.

pub fn delta_elapsed(self) -> TimeDelta

Available on crate feature web only.

Returns the elapsed time since this instant as a TimeDelta.