pub struct DurationErrorTryFromFloatSecs { /* private fields */ }Expand description
🕘 🚩
core
Error returned from converting floating-point seconds into a Duration.
📍phys/time re-exported from core::time ::TryFromFloatSecsError as DurationErrorTryFromFloatSecs
📜
An error which can be returned when converting a floating-point value of seconds
into a Duration.
This error is used as the error type for Duration::try_from_secs_f32 and
Duration::try_from_secs_f64.
Example
use std::time::Duration;
if let Err(e) = Duration::try_from_secs_f32(-1.0) {
println!("Failed conversion to Duration: {e}");
}Trait Implementations
1.66.0 · Sourceimpl Clone for TryFromFloatSecsError
impl Clone for TryFromFloatSecsError
Sourcefn clone(&self) -> TryFromFloatSecsError
fn clone(&self) -> TryFromFloatSecsError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read more1.66.0 · Sourceimpl Debug for TryFromFloatSecsError
impl Debug for TryFromFloatSecsError
1.66.0 · Sourceimpl Display for TryFromFloatSecsError
impl Display for TryFromFloatSecsError
impl Eq for TryFromFloatSecsError
1.66.0 · Sourceimpl Error for TryFromFloatSecsError
impl Error for TryFromFloatSecsError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)> ⓘ
fn source(&self) -> Option<&(dyn Error + 'static)> ⓘ
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str ⓘ
fn description(&self) -> &str ⓘ
👎Deprecated since 1.42.0:
use the Display impl or to_string()
1.66.0 · Sourceimpl PartialEq for TryFromFloatSecsError
impl PartialEq for TryFromFloatSecsError
Sourcefn eq(&self, other: &TryFromFloatSecsError) -> bool
fn eq(&self, other: &TryFromFloatSecsError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TryFromFloatSecsError