Timecode

Struct Timecode 

pub struct Timecode;
๐Ÿ•˜ Timecode splitting and formatting.


๐Ÿ“ phys/time


Examples

assert_eq!(Timecode::secs_f64(3661.5), "01:01:01.500");
assert_eq!(Timecode::nanos_u64(1_002_003_004), "001s 002ms 003ยตs 004ns");

๐Ÿ“ phys/time


Implementations

Source

impl Timecode

pub const fn split_secs_f64( seconds: f64, ) -> TimeSplitHourNano<u32, u8, u8, u16, NoTime, NoTime>

Decomposes a number of seconds in { h, m, s, ms }.

The maximum decomposition for u64::MAX is { h: 5_124_095_576_030_431, .. } (more than 584_942_417 millenia).

pub const fn split_nanos_u64( nanos: u64, ) -> TimeSplitHourNano<NoTime, NoTime, u32, u16, u16, u16>

Splits a number of nanoseconds in { s, ms, ยตs, ns }.

The maximum decomposition for u64::MAX is { s: 1_266_874_889, .. } (more than 40 years).

pub const fn split_nanos_u32( nanos: u32, ) -> TimeSplitHourNano<NoTime, NoTime, u8, u16, u16, u16>

Splits a number of nanoseconds in { s, ms, ยตs, ns }.

The maximum decomposition for u32::MAX is { ns: 295, ยตs: 967, ms: 294, s: 4 } (more than 4 seconds).

pub const fn write_secs_f64(buf: &mut [u8], seconds: f64) -> usize

Writes the time code as HH:MM:SS.mmm or MM:SS.mmm.

Hours are clamped to 99.

Returns the number of bytes written, or 0 if buf is too small.

pub const fn secs_f64(seconds: f64) -> StringU8<12>

Returns the time code as HH:MM:SS.mmm or MM:SS.mmm.

Hours are clamped to 99.

Features

Uses unsafe_str if enabled.

pub fn nanos_u64_alloc(ns: u64) -> String โ“˜

Available on crate feature alloc only.

Returns the time code, up to seconds, as 001s 012ms 012ยตs 012ns.

The seconds are clamped to 999 (more than 16 minutes). TODO TEST

pub const fn write_nanos_u64(buf: &mut [u8], nanos: u64) -> usize

Writes a compact nanosecond time code.

Format examples:

  • 001s 002ms 003ยตs 004ns
  • 002ms 003ยตs 004ns
  • 003ยตs 004ns
  • 004ns

Seconds are clamped to 999.

Returns the number of bytes written, or 0 if buf is too small.

pub const fn nanos_u64(nanos: u64) -> StringU8<23>

Returns the time code, up to seconds, as 001s 002ms 003ยตs 004ns.

Seconds are clamped to 999.

Features

Uses unsafe_str if enabled.