RunCapSystem

Struct RunCapSystem 

pub struct RunCapSystem { /* private fields */ }
Runtime system capabilities.


📍 run/regime

📦 size_of::<RunCapSystem>() == 2 bytes / 16 bits


Implementations

Source

impl RunCapSystem

Named constants

pub const TIME: Self

1 Current or monotonic time can be queried.

pub const TIMER: Self

1 Timers, sleeps, delays, or scheduled wakeups are available.

pub const RANDOM: Self

1 Randomness or system entropy is available.

pub const ENV: Self

1 Environment variables or host environment metadata can be queried.

pub const FS: Self

1 Filesystem access is available.

pub const PROCESS: Self

1 Process spawning or process inspection is available.

pub const THREAD: Self

1 Thread spawning or host threading is available.

pub const NET: Self

1 Network access is available.

pub const SIGNAL: Self

1 Host signals, interrupts, or shutdown notifications are available.

Source

impl RunCapSystem

Convenience methods derived from each named constant.

pub const fn has_time(self) -> bool

Returns true if TIME is present.

pub const fn contains_time(self) -> bool

Returns true if all bits in TIME are present.

pub const fn intersects_time(self) -> bool

Returns true if the set shares any bit with TIME.

pub const fn with_time(self) -> Self

Returns self with TIME inserted.

pub const fn with_time_if(self, condition: bool) -> Self

Returns self with TIME inserted if condition is true.

pub const fn without_time(self) -> Self

Returns self with TIME removed.

pub const fn set_time(&mut self)

Sets TIME.

pub const fn set_time_if(&mut self, condition: bool)

Sets TIME if condition is true.

pub const fn unset_time(&mut self)

Unsets TIME.

pub const fn has_timer(self) -> bool

Returns true if TIMER is present.

pub const fn contains_timer(self) -> bool

Returns true if all bits in TIMER are present.

pub const fn intersects_timer(self) -> bool

Returns true if the set shares any bit with TIMER.

pub const fn with_timer(self) -> Self

Returns self with TIMER inserted.

pub const fn with_timer_if(self, condition: bool) -> Self

Returns self with TIMER inserted if condition is true.

pub const fn without_timer(self) -> Self

Returns self with TIMER removed.

pub const fn set_timer(&mut self)

Sets TIMER.

pub const fn set_timer_if(&mut self, condition: bool)

Sets TIMER if condition is true.

pub const fn unset_timer(&mut self)

Unsets TIMER.

pub const fn has_random(self) -> bool

Returns true if RANDOM is present.

pub const fn contains_random(self) -> bool

Returns true if all bits in RANDOM are present.

pub const fn intersects_random(self) -> bool

Returns true if the set shares any bit with RANDOM.

pub const fn with_random(self) -> Self

Returns self with RANDOM inserted.

pub const fn with_random_if(self, condition: bool) -> Self

Returns self with RANDOM inserted if condition is true.

pub const fn without_random(self) -> Self

Returns self with RANDOM removed.

pub const fn set_random(&mut self)

Sets RANDOM.

pub const fn set_random_if(&mut self, condition: bool)

Sets RANDOM if condition is true.

pub const fn unset_random(&mut self)

Unsets RANDOM.

pub const fn has_env(self) -> bool

Returns true if ENV is present.

pub const fn contains_env(self) -> bool

Returns true if all bits in ENV are present.

pub const fn intersects_env(self) -> bool

Returns true if the set shares any bit with ENV.

pub const fn with_env(self) -> Self

Returns self with ENV inserted.

pub const fn with_env_if(self, condition: bool) -> Self

Returns self with ENV inserted if condition is true.

pub const fn without_env(self) -> Self

Returns self with ENV removed.

pub const fn set_env(&mut self)

Sets ENV.

pub const fn set_env_if(&mut self, condition: bool)

Sets ENV if condition is true.

pub const fn unset_env(&mut self)

Unsets ENV.

pub const fn has_fs(self) -> bool

Returns true if FS is present.

pub const fn contains_fs(self) -> bool

Returns true if all bits in FS are present.

pub const fn intersects_fs(self) -> bool

Returns true if the set shares any bit with FS.

pub const fn with_fs(self) -> Self

Returns self with FS inserted.

pub const fn with_fs_if(self, condition: bool) -> Self

Returns self with FS inserted if condition is true.

pub const fn without_fs(self) -> Self

Returns self with FS removed.

pub const fn set_fs(&mut self)

Sets FS.

pub const fn set_fs_if(&mut self, condition: bool)

Sets FS if condition is true.

pub const fn unset_fs(&mut self)

Unsets FS.

pub const fn has_process(self) -> bool

Returns true if PROCESS is present.

pub const fn contains_process(self) -> bool

Returns true if all bits in PROCESS are present.

pub const fn intersects_process(self) -> bool

Returns true if the set shares any bit with PROCESS.

pub const fn with_process(self) -> Self

Returns self with PROCESS inserted.

pub const fn with_process_if(self, condition: bool) -> Self

Returns self with PROCESS inserted if condition is true.

pub const fn without_process(self) -> Self

Returns self with PROCESS removed.

pub const fn set_process(&mut self)

Sets PROCESS.

pub const fn set_process_if(&mut self, condition: bool)

Sets PROCESS if condition is true.

pub const fn unset_process(&mut self)

Unsets PROCESS.

pub const fn has_thread(self) -> bool

Returns true if THREAD is present.

pub const fn contains_thread(self) -> bool

Returns true if all bits in THREAD are present.

pub const fn intersects_thread(self) -> bool

Returns true if the set shares any bit with THREAD.

pub const fn with_thread(self) -> Self

Returns self with THREAD inserted.

pub const fn with_thread_if(self, condition: bool) -> Self

Returns self with THREAD inserted if condition is true.

pub const fn without_thread(self) -> Self

Returns self with THREAD removed.

pub const fn set_thread(&mut self)

Sets THREAD.

pub const fn set_thread_if(&mut self, condition: bool)

Sets THREAD if condition is true.

pub const fn unset_thread(&mut self)

Unsets THREAD.

pub const fn has_net(self) -> bool

Returns true if NET is present.

pub const fn contains_net(self) -> bool

Returns true if all bits in NET are present.

pub const fn intersects_net(self) -> bool

Returns true if the set shares any bit with NET.

pub const fn with_net(self) -> Self

Returns self with NET inserted.

pub const fn with_net_if(self, condition: bool) -> Self

Returns self with NET inserted if condition is true.

pub const fn without_net(self) -> Self

Returns self with NET removed.

pub const fn set_net(&mut self)

Sets NET.

pub const fn set_net_if(&mut self, condition: bool)

Sets NET if condition is true.

pub const fn unset_net(&mut self)

Unsets NET.

pub const fn has_signal(self) -> bool

Returns true if SIGNAL is present.

pub const fn contains_signal(self) -> bool

Returns true if all bits in SIGNAL are present.

pub const fn intersects_signal(self) -> bool

Returns true if the set shares any bit with SIGNAL.

pub const fn with_signal(self) -> Self

Returns self with SIGNAL inserted.

pub const fn with_signal_if(self, condition: bool) -> Self

Returns self with SIGNAL inserted if condition is true.

pub const fn without_signal(self) -> Self

Returns self with SIGNAL removed.

pub const fn set_signal(&mut self)

Sets SIGNAL.

pub const fn set_signal_if(&mut self, condition: bool)

Sets SIGNAL if condition is true.

pub const fn unset_signal(&mut self)

Unsets SIGNAL.

Source

impl RunCapSystem

Common set methods

pub const fn new() -> Self

Returns an empty set.

pub const fn from_bits(bits: u16) -> Self

Returns a set from raw bits.

pub const fn bits(self) -> u16

Returns the raw backing bits.

pub const fn all() -> Self

Returns the union of all declared sets.

pub const fn is_empty(self) -> bool

Returns true if no bits are set.

pub const fn is_full(self) -> bool

Returns true if all the declared bits are set.

pub const fn contains(self, other: Self) -> bool

Returns true if all bits in other are also set in self.

pub const fn has(self, other: Self) -> bool

An alias of contains.

pub const fn with(self, other: Self) -> Self

Returns self with other inserted.

pub const fn with_if(self, condition: bool, other: Self) -> Self

Returns self with other inserted if condition is true.

pub const fn without(self, other: Self) -> Self

Returns self with other removed.

pub const fn toggled(self, other: Self) -> Self

Returns self with other toggled.

Source

impl RunCapSystem

Set operations

pub const fn intersects(self, other: Self) -> bool

Returns true if self and other share any bit.

pub const fn is_subset(self, other: Self) -> bool

Returns true if all bits in self are also set in other.

pub const fn is_superset(self, other: Self) -> bool

Returns true if all bits in other are also set in self.

pub const fn union(self, other: Self) -> Self

Returns the union of self and other.

pub const fn intersection(self, other: Self) -> Self

Returns the intersection of self and other.

pub const fn difference(self, other: Self) -> Self

Returns the difference of self and other.

pub const fn symmetric_difference(self, other: Self) -> Self

Returns the symmetric difference of self and other.

Source

impl RunCapSystem

Mutating set operations

pub const fn clear(&mut self)

Clears the set.

pub const fn insert(&mut self, other: Self)

Inserts all bits from other.

pub const fn remove(&mut self, other: Self)

Removes all bits from other.

pub const fn toggle(&mut self, other: Self)

Toggles all bits from other.