pub struct CurrentGuard<'a, T: Any> { /* private fields */ }Available on crate features
std and unsafe_layout only.Expand description
๐
A guard that temporarily sets a global current ptr for T, restoring the old one on drop.
๐ sys/mem
When dropped, it restores the previous pointer or sets a placeholder if none existed.โ
This is useful for tracking the current instance of a type within a thread.
Vendored
This is adapted work from current.
Implementations
Sourceimpl<T: Any> CurrentGuard<'_, T>
impl<T: Any> CurrentGuard<'_, T>
Sourcepub fn new(current: &mut T) -> CurrentGuard<'_, T>
pub fn new(current: &mut T) -> CurrentGuard<'_, T>
Creates a new current guard for the given value.
When this guard is dropped, the previous pointer (if any) will be restored.
Safety
- This function modifies global state within a thread-local map.
- It ensures that only one mutable reference to a given
Texists at a time. - Improper use may lead to stale pointers if lifetimes are not respected.
Examples
let mut my_value = MyType::new();
let guard = CurrentGuard::new(&mut my_value);Trait Implementations
Sourceimpl<T: Any> Drop for CurrentGuard<'_, T>
impl<T: Any> Drop for CurrentGuard<'_, T>