IoChain

Struct IoChain 

1.0.0 ยท Source
#[non_exhaustive]
pub struct IoChain<T, U> { /* private fields */ }
๐Ÿ”Œ ?std Adapter to chain together two readers.


๐Ÿ“sys/io re-exported from std::io ::Chain as IoChain



๐Ÿ“œ
Adapter to chain together two readers.

This struct is generally created by calling chain on a reader. Please see the documentation of chain for more details.

Implementations

Source

impl<T, U> Chain<T, U>

1.20.0 ยท Source

pub fn into_inner(self) -> (T, U) โ“˜

Consumes the Chain, returning the wrapped readers.

Examples
use std::io;
use std::io::prelude::*;
use std::fs::File;

fn main() -> io::Result<()> {
    let mut foo_file = File::open("foo.txt")?;
    let mut bar_file = File::open("bar.txt")?;

    let chain = foo_file.chain(bar_file);
    let (foo_file, bar_file) = chain.into_inner();
    Ok(())
}
1.20.0 ยท Source

pub fn get_ref(&self) -> (&T, &U) โ“˜

Gets references to the underlying readers in this Chain.

Care should be taken to avoid modifying the internal I/O state of the underlying readers as doing so may corrupt the internal state of this Chain.

Examples
use std::io;
use std::io::prelude::*;
use std::fs::File;

fn main() -> io::Result<()> {
    let mut foo_file = File::open("foo.txt")?;
    let mut bar_file = File::open("bar.txt")?;

    let chain = foo_file.chain(bar_file);
    let (foo_file, bar_file) = chain.get_ref();
    Ok(())
}
1.20.0 ยท Source

pub fn get_mut(&mut self) -> (&mut T, &mut U) โ“˜

Gets mutable references to the underlying readers in this Chain.

Care should be taken to avoid modifying the internal I/O state of the underlying readers as doing so may corrupt the internal state of this Chain.

Examples
use std::io;
use std::io::prelude::*;
use std::fs::File;

fn main() -> io::Result<()> {
    let mut foo_file = File::open("foo.txt")?;
    let mut bar_file = File::open("bar.txt")?;

    let mut chain = foo_file.chain(bar_file);
    let (foo_file, bar_file) = chain.get_mut();
    Ok(())
}