#[repr(C)]pub struct LinuxSigset {
pub sig: [c_size_t; 1],
}linux only.Expand description
๐ง ๐ถ โ ๐ป A raw Linux kernel signal mask.
๐ sys/os/linux/process
๐ฆ size_of::<LinuxSigset>() == 4 bytes / 32 bits #๏ธโฃ #[cfg(target_pointer_width = โ32โ)]
๐ฆ size_of::<LinuxSigset>() == 8 bytes / 64 bits #๏ธโฃ #[cfg(target_pointer_width = โ64โ)]
This is the mask representation passed to raw Linux signal syscalls.
Signal numbers start at 1, while mask bits start at 0,
so signal n is stored in bit n - 1.
For the semantic Devela set, use LinuxSignalSet.
Fields
sig: [c_size_t; 1]Raw signal mask words.
Implementations
Sourceimpl LinuxSigset
impl LinuxSigset
Sourcepub const MAX_SIGNAL: usize
pub const MAX_SIGNAL: usize
Highest supported standard Linux signal number.
Sourcepub const fn from_signal_set(signals: LinuxSignalSet) -> Self
pub const fn from_signal_set(signals: LinuxSignalSet) -> Self
Returns a raw mask from a semantic signal set.
Sourcepub const fn to_signal_set(self) -> LinuxSignalSet
pub const fn to_signal_set(self) -> LinuxSignalSet
Returns this raw mask as a semantic signal set.
Sourcepub const fn with_signal(self, signal: LinuxSignal) -> Self
pub const fn with_signal(self, signal: LinuxSignal) -> Self
Returns a copy with signal added.
Sourcepub const fn without_signal(self, signal: LinuxSignal) -> Self
pub const fn without_signal(self, signal: LinuxSignal) -> Self
Returns a copy with signal removed.
Ignores unsupported signal numbers.
Sourcepub const fn has_signal(self, signal: LinuxSignal) -> bool
pub const fn has_signal(self, signal: LinuxSignal) -> bool
Returns whether this raw mask contains signal.
Sourcepub fn insert_signal(&mut self, signal: LinuxSignal)
pub fn insert_signal(&mut self, signal: LinuxSignal)
Adds signal to this raw mask.
Sourcepub fn remove_signal(&mut self, signal: LinuxSignal)
pub fn remove_signal(&mut self, signal: LinuxSignal)
Removes signal from this raw mask.
Panics
Panics if signal is not a supported standard Linux signal.
Sourcepub const fn with_signal_number(self, signal: c_int) -> Self
pub const fn with_signal_number(self, signal: c_int) -> Self
Returns a copy with the raw signal number added, if supported.