LinuxTermiosInputFlags

Struct LinuxTermiosInputFlags 

pub struct LinuxTermiosInputFlags { /* private fields */ }
Available on crate feature linux only.
๐Ÿง ๐Ÿฎ– โІ LinuxTermios input flags.


๐Ÿ“ sys/os/term/session

๐Ÿ“ฆ size_of::<LinuxTermiosInputFlags>() == 2 bytes / 16 bits


Implementations

Source

impl LinuxTermiosInputFlags

pub const fn from_c_uint(bits: c_uint) -> Self

Returns flags from the raw Linux c_iflag word.

pub const fn as_c_uint(self) -> c_uint

Returns flags as a raw Linux c_iflag word.

Source

impl LinuxTermiosInputFlags

Named constants

pub const IGNBRK: Self

1 Ignore BREAK condition on input.

pub const BRKINT: Self

1 Signal interrupt on BREAK.

pub const IGNPAR: Self

1 Ignore framing errors and parity errors.

pub const PARMRK: Self

1 Mark parity and framing errors.

pub const INPCK: Self

1 Enable input parity checking.

pub const ISTRIP: Self

1 Strip off eighth bit.

pub const INLCR: Self

1 Translate NL to CR on input.

pub const IGNCR: Self

1 Ignore CR on input.

pub const ICRNL: Self

1 Translate CR to NL on input.

pub const IUCLC: Self

1 Map uppercase characters to lowercase on input.

pub const IXON: Self

1 Enable XON/XOFF flow control on output.

pub const IXANY: Self

1 Any character restarts stopped output.

pub const IXOFF: Self

1 Enable XON/XOFF flow control on input.

pub const IMAXBEL: Self

1 Ring bell when input queue is full.

pub const IUTF8: Self

1 Input is UTF-8.

Source

impl LinuxTermiosInputFlags

Convenience methods derived from each named constant.

pub const fn has_ignbrk(self) -> bool

Returns true if IGNBRK is present.

pub const fn contains_ignbrk(self) -> bool

Returns true if all bits in IGNBRK are present.

pub const fn intersects_ignbrk(self) -> bool

Returns true if the set shares any bit with IGNBRK.

pub const fn with_ignbrk(self) -> Self

Returns self with IGNBRK inserted.

pub const fn with_ignbrk_if(self, condition: bool) -> Self

Returns self with IGNBRK inserted if condition is true.

pub const fn without_ignbrk(self) -> Self

Returns self with IGNBRK removed.

pub const fn set_ignbrk(&mut self)

Sets IGNBRK.

pub const fn set_ignbrk_if(&mut self, condition: bool)

Sets IGNBRK if condition is true.

pub const fn unset_ignbrk(&mut self)

Unsets IGNBRK.

pub const fn has_brkint(self) -> bool

Returns true if BRKINT is present.

pub const fn contains_brkint(self) -> bool

Returns true if all bits in BRKINT are present.

pub const fn intersects_brkint(self) -> bool

Returns true if the set shares any bit with BRKINT.

pub const fn with_brkint(self) -> Self

Returns self with BRKINT inserted.

pub const fn with_brkint_if(self, condition: bool) -> Self

Returns self with BRKINT inserted if condition is true.

pub const fn without_brkint(self) -> Self

Returns self with BRKINT removed.

pub const fn set_brkint(&mut self)

Sets BRKINT.

pub const fn set_brkint_if(&mut self, condition: bool)

Sets BRKINT if condition is true.

pub const fn unset_brkint(&mut self)

Unsets BRKINT.

pub const fn has_ignpar(self) -> bool

Returns true if IGNPAR is present.

pub const fn contains_ignpar(self) -> bool

Returns true if all bits in IGNPAR are present.

pub const fn intersects_ignpar(self) -> bool

Returns true if the set shares any bit with IGNPAR.

pub const fn with_ignpar(self) -> Self

Returns self with IGNPAR inserted.

pub const fn with_ignpar_if(self, condition: bool) -> Self

Returns self with IGNPAR inserted if condition is true.

pub const fn without_ignpar(self) -> Self

Returns self with IGNPAR removed.

pub const fn set_ignpar(&mut self)

Sets IGNPAR.

pub const fn set_ignpar_if(&mut self, condition: bool)

Sets IGNPAR if condition is true.

pub const fn unset_ignpar(&mut self)

Unsets IGNPAR.

pub const fn has_parmrk(self) -> bool

Returns true if PARMRK is present.

pub const fn contains_parmrk(self) -> bool

Returns true if all bits in PARMRK are present.

pub const fn intersects_parmrk(self) -> bool

Returns true if the set shares any bit with PARMRK.

pub const fn with_parmrk(self) -> Self

Returns self with PARMRK inserted.

pub const fn with_parmrk_if(self, condition: bool) -> Self

Returns self with PARMRK inserted if condition is true.

pub const fn without_parmrk(self) -> Self

Returns self with PARMRK removed.

pub const fn set_parmrk(&mut self)

Sets PARMRK.

pub const fn set_parmrk_if(&mut self, condition: bool)

Sets PARMRK if condition is true.

pub const fn unset_parmrk(&mut self)

Unsets PARMRK.

pub const fn has_inpck(self) -> bool

Returns true if INPCK is present.

pub const fn contains_inpck(self) -> bool

Returns true if all bits in INPCK are present.

pub const fn intersects_inpck(self) -> bool

Returns true if the set shares any bit with INPCK.

pub const fn with_inpck(self) -> Self

Returns self with INPCK inserted.

pub const fn with_inpck_if(self, condition: bool) -> Self

Returns self with INPCK inserted if condition is true.

pub const fn without_inpck(self) -> Self

Returns self with INPCK removed.

pub const fn set_inpck(&mut self)

Sets INPCK.

pub const fn set_inpck_if(&mut self, condition: bool)

Sets INPCK if condition is true.

pub const fn unset_inpck(&mut self)

Unsets INPCK.

pub const fn has_istrip(self) -> bool

Returns true if ISTRIP is present.

pub const fn contains_istrip(self) -> bool

Returns true if all bits in ISTRIP are present.

pub const fn intersects_istrip(self) -> bool

Returns true if the set shares any bit with ISTRIP.

pub const fn with_istrip(self) -> Self

Returns self with ISTRIP inserted.

pub const fn with_istrip_if(self, condition: bool) -> Self

Returns self with ISTRIP inserted if condition is true.

pub const fn without_istrip(self) -> Self

Returns self with ISTRIP removed.

pub const fn set_istrip(&mut self)

Sets ISTRIP.

pub const fn set_istrip_if(&mut self, condition: bool)

Sets ISTRIP if condition is true.

pub const fn unset_istrip(&mut self)

Unsets ISTRIP.

pub const fn has_inlcr(self) -> bool

Returns true if INLCR is present.

pub const fn contains_inlcr(self) -> bool

Returns true if all bits in INLCR are present.

pub const fn intersects_inlcr(self) -> bool

Returns true if the set shares any bit with INLCR.

pub const fn with_inlcr(self) -> Self

Returns self with INLCR inserted.

pub const fn with_inlcr_if(self, condition: bool) -> Self

Returns self with INLCR inserted if condition is true.

pub const fn without_inlcr(self) -> Self

Returns self with INLCR removed.

pub const fn set_inlcr(&mut self)

Sets INLCR.

pub const fn set_inlcr_if(&mut self, condition: bool)

Sets INLCR if condition is true.

pub const fn unset_inlcr(&mut self)

Unsets INLCR.

pub const fn has_igncr(self) -> bool

Returns true if IGNCR is present.

pub const fn contains_igncr(self) -> bool

Returns true if all bits in IGNCR are present.

pub const fn intersects_igncr(self) -> bool

Returns true if the set shares any bit with IGNCR.

pub const fn with_igncr(self) -> Self

Returns self with IGNCR inserted.

pub const fn with_igncr_if(self, condition: bool) -> Self

Returns self with IGNCR inserted if condition is true.

pub const fn without_igncr(self) -> Self

Returns self with IGNCR removed.

pub const fn set_igncr(&mut self)

Sets IGNCR.

pub const fn set_igncr_if(&mut self, condition: bool)

Sets IGNCR if condition is true.

pub const fn unset_igncr(&mut self)

Unsets IGNCR.

pub const fn has_icrnl(self) -> bool

Returns true if ICRNL is present.

pub const fn contains_icrnl(self) -> bool

Returns true if all bits in ICRNL are present.

pub const fn intersects_icrnl(self) -> bool

Returns true if the set shares any bit with ICRNL.

pub const fn with_icrnl(self) -> Self

Returns self with ICRNL inserted.

pub const fn with_icrnl_if(self, condition: bool) -> Self

Returns self with ICRNL inserted if condition is true.

pub const fn without_icrnl(self) -> Self

Returns self with ICRNL removed.

pub const fn set_icrnl(&mut self)

Sets ICRNL.

pub const fn set_icrnl_if(&mut self, condition: bool)

Sets ICRNL if condition is true.

pub const fn unset_icrnl(&mut self)

Unsets ICRNL.

pub const fn has_iuclc(self) -> bool

Returns true if IUCLC is present.

pub const fn contains_iuclc(self) -> bool

Returns true if all bits in IUCLC are present.

pub const fn intersects_iuclc(self) -> bool

Returns true if the set shares any bit with IUCLC.

pub const fn with_iuclc(self) -> Self

Returns self with IUCLC inserted.

pub const fn with_iuclc_if(self, condition: bool) -> Self

Returns self with IUCLC inserted if condition is true.

pub const fn without_iuclc(self) -> Self

Returns self with IUCLC removed.

pub const fn set_iuclc(&mut self)

Sets IUCLC.

pub const fn set_iuclc_if(&mut self, condition: bool)

Sets IUCLC if condition is true.

pub const fn unset_iuclc(&mut self)

Unsets IUCLC.

pub const fn has_ixon(self) -> bool

Returns true if IXON is present.

pub const fn contains_ixon(self) -> bool

Returns true if all bits in IXON are present.

pub const fn intersects_ixon(self) -> bool

Returns true if the set shares any bit with IXON.

pub const fn with_ixon(self) -> Self

Returns self with IXON inserted.

pub const fn with_ixon_if(self, condition: bool) -> Self

Returns self with IXON inserted if condition is true.

pub const fn without_ixon(self) -> Self

Returns self with IXON removed.

pub const fn set_ixon(&mut self)

Sets IXON.

pub const fn set_ixon_if(&mut self, condition: bool)

Sets IXON if condition is true.

pub const fn unset_ixon(&mut self)

Unsets IXON.

pub const fn has_ixany(self) -> bool

Returns true if IXANY is present.

pub const fn contains_ixany(self) -> bool

Returns true if all bits in IXANY are present.

pub const fn intersects_ixany(self) -> bool

Returns true if the set shares any bit with IXANY.

pub const fn with_ixany(self) -> Self

Returns self with IXANY inserted.

pub const fn with_ixany_if(self, condition: bool) -> Self

Returns self with IXANY inserted if condition is true.

pub const fn without_ixany(self) -> Self

Returns self with IXANY removed.

pub const fn set_ixany(&mut self)

Sets IXANY.

pub const fn set_ixany_if(&mut self, condition: bool)

Sets IXANY if condition is true.

pub const fn unset_ixany(&mut self)

Unsets IXANY.

pub const fn has_ixoff(self) -> bool

Returns true if IXOFF is present.

pub const fn contains_ixoff(self) -> bool

Returns true if all bits in IXOFF are present.

pub const fn intersects_ixoff(self) -> bool

Returns true if the set shares any bit with IXOFF.

pub const fn with_ixoff(self) -> Self

Returns self with IXOFF inserted.

pub const fn with_ixoff_if(self, condition: bool) -> Self

Returns self with IXOFF inserted if condition is true.

pub const fn without_ixoff(self) -> Self

Returns self with IXOFF removed.

pub const fn set_ixoff(&mut self)

Sets IXOFF.

pub const fn set_ixoff_if(&mut self, condition: bool)

Sets IXOFF if condition is true.

pub const fn unset_ixoff(&mut self)

Unsets IXOFF.

pub const fn has_imaxbel(self) -> bool

Returns true if IMAXBEL is present.

pub const fn contains_imaxbel(self) -> bool

Returns true if all bits in IMAXBEL are present.

pub const fn intersects_imaxbel(self) -> bool

Returns true if the set shares any bit with IMAXBEL.

pub const fn with_imaxbel(self) -> Self

Returns self with IMAXBEL inserted.

pub const fn with_imaxbel_if(self, condition: bool) -> Self

Returns self with IMAXBEL inserted if condition is true.

pub const fn without_imaxbel(self) -> Self

Returns self with IMAXBEL removed.

pub const fn set_imaxbel(&mut self)

Sets IMAXBEL.

pub const fn set_imaxbel_if(&mut self, condition: bool)

Sets IMAXBEL if condition is true.

pub const fn unset_imaxbel(&mut self)

Unsets IMAXBEL.

pub const fn has_iutf8(self) -> bool

Returns true if IUTF8 is present.

pub const fn contains_iutf8(self) -> bool

Returns true if all bits in IUTF8 are present.

pub const fn intersects_iutf8(self) -> bool

Returns true if the set shares any bit with IUTF8.

pub const fn with_iutf8(self) -> Self

Returns self with IUTF8 inserted.

pub const fn with_iutf8_if(self, condition: bool) -> Self

Returns self with IUTF8 inserted if condition is true.

pub const fn without_iutf8(self) -> Self

Returns self with IUTF8 removed.

pub const fn set_iutf8(&mut self)

Sets IUTF8.

pub const fn set_iutf8_if(&mut self, condition: bool)

Sets IUTF8 if condition is true.

pub const fn unset_iutf8(&mut self)

Unsets IUTF8.

Source

impl LinuxTermiosInputFlags

Common set methods

pub const fn new() -> Self

Returns an empty set.

pub const fn from_bits(bits: u16) -> Self

Returns a set from raw bits.

pub const fn bits(self) -> u16

Returns the raw backing bits.

pub const fn all() -> Self

Returns the union of all declared sets.

pub const fn is_empty(self) -> bool

Returns true if no bits are set.

pub const fn is_full(self) -> bool

Returns true if all the declared bits are set.

pub const fn contains(self, other: Self) -> bool

Returns true if all bits in other are also set in self.

pub const fn has(self, other: Self) -> bool

An alias of contains.

pub const fn with(self, other: Self) -> Self

Returns self with other inserted.

pub const fn with_if(self, condition: bool, other: Self) -> Self

Returns self with other inserted if condition is true.

pub const fn without(self, other: Self) -> Self

Returns self with other removed.

pub const fn toggled(self, other: Self) -> Self

Returns self with other toggled.

Source

impl LinuxTermiosInputFlags

Set operations

pub const fn intersects(self, other: Self) -> bool

Returns true if self and other share any bit.

pub const fn is_subset(self, other: Self) -> bool

Returns true if all bits in self are also set in other.

pub const fn is_superset(self, other: Self) -> bool

Returns true if all bits in other are also set in self.

pub const fn union(self, other: Self) -> Self

Returns the union of self and other.

pub const fn intersection(self, other: Self) -> Self

Returns the intersection of self and other.

pub const fn difference(self, other: Self) -> Self

Returns the difference of self and other.

pub const fn symmetric_difference(self, other: Self) -> Self

Returns the symmetric difference of self and other.

Source

impl LinuxTermiosInputFlags

Mutating set operations

pub const fn clear(&mut self)

Clears the set.

pub const fn insert(&mut self, other: Self)

Inserts all bits from other.

pub const fn remove(&mut self, other: Self)

Removes all bits from other.

pub const fn toggle(&mut self, other: Self)

Toggles all bits from other.