LinuxTermiosLocalFlags

Struct LinuxTermiosLocalFlags 

pub struct LinuxTermiosLocalFlags { /* private fields */ }
Available on crate feature linux only.
๐Ÿง ๐Ÿฎ– โІ LinuxTermios local flags.


๐Ÿ“ sys/os/linux/io/term

๐Ÿ“ฆ size_of::<LinuxTermiosLocalFlags>() == 4 bytes / 32 bits


Implementations

Source

impl LinuxTermiosLocalFlags

pub const fn from_c_uint(bits: c_uint) -> Self

Returns flags from the raw Linux c_lflag word.

pub const fn as_c_uint(self) -> c_uint

Returns flags as a raw Linux c_lflag word.

Source

impl LinuxTermiosLocalFlags

Named constants

pub const ISIG: Self

1 Enable signals.

pub const ICANON: Self

1 Enable canonical mode.

pub const XCASE: Self

1 Uppercase-only terminal compatibility mode.

pub const ECHO: Self

1 Echo input characters.

pub const ECHOE: Self

1 Echo erase processing.

pub const ECHOK: Self

1 Echo kill processing.

pub const ECHONL: Self

1 Echo newline.

pub const NOFLSH: Self

1 Disable flushing when generating signals.

pub const TOSTOP: Self

1 Send SIGTTOU for background output.

pub const ECHOCTL: Self

1 Echo control characters as ^X.

pub const ECHOPRT: Self

1 Visual erase mode.

pub const ECHOKE: Self

1 Echo line kill by erasing each character.

pub const FLUSHO: Self

1 Output is being flushed.

pub const PENDING: Self

1 Pending input reprint.

pub const IEXTEN: Self

1 Enable implementation-defined input processing.

pub const EXTPROC: Self

1 External processing.

Source

impl LinuxTermiosLocalFlags

Convenience methods derived from each named constant.

pub const fn has_isig(self) -> bool

Returns true if ISIG is present.

pub const fn contains_isig(self) -> bool

Returns true if all bits in ISIG are present.

pub const fn intersects_isig(self) -> bool

Returns true if the set shares any bit with ISIG.

pub const fn with_isig(self) -> Self

Returns self with ISIG inserted.

pub const fn with_isig_if(self, condition: bool) -> Self

Returns self with ISIG inserted if condition is true.

pub const fn without_isig(self) -> Self

Returns self with ISIG removed.

pub const fn set_isig(&mut self)

Sets ISIG.

pub const fn set_isig_if(&mut self, condition: bool)

Sets ISIG if condition is true.

pub const fn unset_isig(&mut self)

Unsets ISIG.

pub const fn has_icanon(self) -> bool

Returns true if ICANON is present.

pub const fn contains_icanon(self) -> bool

Returns true if all bits in ICANON are present.

pub const fn intersects_icanon(self) -> bool

Returns true if the set shares any bit with ICANON.

pub const fn with_icanon(self) -> Self

Returns self with ICANON inserted.

pub const fn with_icanon_if(self, condition: bool) -> Self

Returns self with ICANON inserted if condition is true.

pub const fn without_icanon(self) -> Self

Returns self with ICANON removed.

pub const fn set_icanon(&mut self)

Sets ICANON.

pub const fn set_icanon_if(&mut self, condition: bool)

Sets ICANON if condition is true.

pub const fn unset_icanon(&mut self)

Unsets ICANON.

pub const fn has_xcase(self) -> bool

Returns true if XCASE is present.

pub const fn contains_xcase(self) -> bool

Returns true if all bits in XCASE are present.

pub const fn intersects_xcase(self) -> bool

Returns true if the set shares any bit with XCASE.

pub const fn with_xcase(self) -> Self

Returns self with XCASE inserted.

pub const fn with_xcase_if(self, condition: bool) -> Self

Returns self with XCASE inserted if condition is true.

pub const fn without_xcase(self) -> Self

Returns self with XCASE removed.

pub const fn set_xcase(&mut self)

Sets XCASE.

pub const fn set_xcase_if(&mut self, condition: bool)

Sets XCASE if condition is true.

pub const fn unset_xcase(&mut self)

Unsets XCASE.

pub const fn has_echo(self) -> bool

Returns true if ECHO is present.

pub const fn contains_echo(self) -> bool

Returns true if all bits in ECHO are present.

pub const fn intersects_echo(self) -> bool

Returns true if the set shares any bit with ECHO.

pub const fn with_echo(self) -> Self

Returns self with ECHO inserted.

pub const fn with_echo_if(self, condition: bool) -> Self

Returns self with ECHO inserted if condition is true.

pub const fn without_echo(self) -> Self

Returns self with ECHO removed.

pub const fn set_echo(&mut self)

Sets ECHO.

pub const fn set_echo_if(&mut self, condition: bool)

Sets ECHO if condition is true.

pub const fn unset_echo(&mut self)

Unsets ECHO.

pub const fn has_echoe(self) -> bool

Returns true if ECHOE is present.

pub const fn contains_echoe(self) -> bool

Returns true if all bits in ECHOE are present.

pub const fn intersects_echoe(self) -> bool

Returns true if the set shares any bit with ECHOE.

pub const fn with_echoe(self) -> Self

Returns self with ECHOE inserted.

pub const fn with_echoe_if(self, condition: bool) -> Self

Returns self with ECHOE inserted if condition is true.

pub const fn without_echoe(self) -> Self

Returns self with ECHOE removed.

pub const fn set_echoe(&mut self)

Sets ECHOE.

pub const fn set_echoe_if(&mut self, condition: bool)

Sets ECHOE if condition is true.

pub const fn unset_echoe(&mut self)

Unsets ECHOE.

pub const fn has_echok(self) -> bool

Returns true if ECHOK is present.

pub const fn contains_echok(self) -> bool

Returns true if all bits in ECHOK are present.

pub const fn intersects_echok(self) -> bool

Returns true if the set shares any bit with ECHOK.

pub const fn with_echok(self) -> Self

Returns self with ECHOK inserted.

pub const fn with_echok_if(self, condition: bool) -> Self

Returns self with ECHOK inserted if condition is true.

pub const fn without_echok(self) -> Self

Returns self with ECHOK removed.

pub const fn set_echok(&mut self)

Sets ECHOK.

pub const fn set_echok_if(&mut self, condition: bool)

Sets ECHOK if condition is true.

pub const fn unset_echok(&mut self)

Unsets ECHOK.

pub const fn has_echonl(self) -> bool

Returns true if ECHONL is present.

pub const fn contains_echonl(self) -> bool

Returns true if all bits in ECHONL are present.

pub const fn intersects_echonl(self) -> bool

Returns true if the set shares any bit with ECHONL.

pub const fn with_echonl(self) -> Self

Returns self with ECHONL inserted.

pub const fn with_echonl_if(self, condition: bool) -> Self

Returns self with ECHONL inserted if condition is true.

pub const fn without_echonl(self) -> Self

Returns self with ECHONL removed.

pub const fn set_echonl(&mut self)

Sets ECHONL.

pub const fn set_echonl_if(&mut self, condition: bool)

Sets ECHONL if condition is true.

pub const fn unset_echonl(&mut self)

Unsets ECHONL.

pub const fn has_noflsh(self) -> bool

Returns true if NOFLSH is present.

pub const fn contains_noflsh(self) -> bool

Returns true if all bits in NOFLSH are present.

pub const fn intersects_noflsh(self) -> bool

Returns true if the set shares any bit with NOFLSH.

pub const fn with_noflsh(self) -> Self

Returns self with NOFLSH inserted.

pub const fn with_noflsh_if(self, condition: bool) -> Self

Returns self with NOFLSH inserted if condition is true.

pub const fn without_noflsh(self) -> Self

Returns self with NOFLSH removed.

pub const fn set_noflsh(&mut self)

Sets NOFLSH.

pub const fn set_noflsh_if(&mut self, condition: bool)

Sets NOFLSH if condition is true.

pub const fn unset_noflsh(&mut self)

Unsets NOFLSH.

pub const fn has_tostop(self) -> bool

Returns true if TOSTOP is present.

pub const fn contains_tostop(self) -> bool

Returns true if all bits in TOSTOP are present.

pub const fn intersects_tostop(self) -> bool

Returns true if the set shares any bit with TOSTOP.

pub const fn with_tostop(self) -> Self

Returns self with TOSTOP inserted.

pub const fn with_tostop_if(self, condition: bool) -> Self

Returns self with TOSTOP inserted if condition is true.

pub const fn without_tostop(self) -> Self

Returns self with TOSTOP removed.

pub const fn set_tostop(&mut self)

Sets TOSTOP.

pub const fn set_tostop_if(&mut self, condition: bool)

Sets TOSTOP if condition is true.

pub const fn unset_tostop(&mut self)

Unsets TOSTOP.

pub const fn has_echoctl(self) -> bool

Returns true if ECHOCTL is present.

pub const fn contains_echoctl(self) -> bool

Returns true if all bits in ECHOCTL are present.

pub const fn intersects_echoctl(self) -> bool

Returns true if the set shares any bit with ECHOCTL.

pub const fn with_echoctl(self) -> Self

Returns self with ECHOCTL inserted.

pub const fn with_echoctl_if(self, condition: bool) -> Self

Returns self with ECHOCTL inserted if condition is true.

pub const fn without_echoctl(self) -> Self

Returns self with ECHOCTL removed.

pub const fn set_echoctl(&mut self)

Sets ECHOCTL.

pub const fn set_echoctl_if(&mut self, condition: bool)

Sets ECHOCTL if condition is true.

pub const fn unset_echoctl(&mut self)

Unsets ECHOCTL.

pub const fn has_echoprt(self) -> bool

Returns true if ECHOPRT is present.

pub const fn contains_echoprt(self) -> bool

Returns true if all bits in ECHOPRT are present.

pub const fn intersects_echoprt(self) -> bool

Returns true if the set shares any bit with ECHOPRT.

pub const fn with_echoprt(self) -> Self

Returns self with ECHOPRT inserted.

pub const fn with_echoprt_if(self, condition: bool) -> Self

Returns self with ECHOPRT inserted if condition is true.

pub const fn without_echoprt(self) -> Self

Returns self with ECHOPRT removed.

pub const fn set_echoprt(&mut self)

Sets ECHOPRT.

pub const fn set_echoprt_if(&mut self, condition: bool)

Sets ECHOPRT if condition is true.

pub const fn unset_echoprt(&mut self)

Unsets ECHOPRT.

pub const fn has_echoke(self) -> bool

Returns true if ECHOKE is present.

pub const fn contains_echoke(self) -> bool

Returns true if all bits in ECHOKE are present.

pub const fn intersects_echoke(self) -> bool

Returns true if the set shares any bit with ECHOKE.

pub const fn with_echoke(self) -> Self

Returns self with ECHOKE inserted.

pub const fn with_echoke_if(self, condition: bool) -> Self

Returns self with ECHOKE inserted if condition is true.

pub const fn without_echoke(self) -> Self

Returns self with ECHOKE removed.

pub const fn set_echoke(&mut self)

Sets ECHOKE.

pub const fn set_echoke_if(&mut self, condition: bool)

Sets ECHOKE if condition is true.

pub const fn unset_echoke(&mut self)

Unsets ECHOKE.

pub const fn has_flusho(self) -> bool

Returns true if FLUSHO is present.

pub const fn contains_flusho(self) -> bool

Returns true if all bits in FLUSHO are present.

pub const fn intersects_flusho(self) -> bool

Returns true if the set shares any bit with FLUSHO.

pub const fn with_flusho(self) -> Self

Returns self with FLUSHO inserted.

pub const fn with_flusho_if(self, condition: bool) -> Self

Returns self with FLUSHO inserted if condition is true.

pub const fn without_flusho(self) -> Self

Returns self with FLUSHO removed.

pub const fn set_flusho(&mut self)

Sets FLUSHO.

pub const fn set_flusho_if(&mut self, condition: bool)

Sets FLUSHO if condition is true.

pub const fn unset_flusho(&mut self)

Unsets FLUSHO.

pub const fn has_pending(self) -> bool

Returns true if PENDING is present.

pub const fn contains_pending(self) -> bool

Returns true if all bits in PENDING are present.

pub const fn intersects_pending(self) -> bool

Returns true if the set shares any bit with PENDING.

pub const fn with_pending(self) -> Self

Returns self with PENDING inserted.

pub const fn with_pending_if(self, condition: bool) -> Self

Returns self with PENDING inserted if condition is true.

pub const fn without_pending(self) -> Self

Returns self with PENDING removed.

pub const fn set_pending(&mut self)

Sets PENDING.

pub const fn set_pending_if(&mut self, condition: bool)

Sets PENDING if condition is true.

pub const fn unset_pending(&mut self)

Unsets PENDING.

pub const fn has_iexten(self) -> bool

Returns true if IEXTEN is present.

pub const fn contains_iexten(self) -> bool

Returns true if all bits in IEXTEN are present.

pub const fn intersects_iexten(self) -> bool

Returns true if the set shares any bit with IEXTEN.

pub const fn with_iexten(self) -> Self

Returns self with IEXTEN inserted.

pub const fn with_iexten_if(self, condition: bool) -> Self

Returns self with IEXTEN inserted if condition is true.

pub const fn without_iexten(self) -> Self

Returns self with IEXTEN removed.

pub const fn set_iexten(&mut self)

Sets IEXTEN.

pub const fn set_iexten_if(&mut self, condition: bool)

Sets IEXTEN if condition is true.

pub const fn unset_iexten(&mut self)

Unsets IEXTEN.

pub const fn has_extproc(self) -> bool

Returns true if EXTPROC is present.

pub const fn contains_extproc(self) -> bool

Returns true if all bits in EXTPROC are present.

pub const fn intersects_extproc(self) -> bool

Returns true if the set shares any bit with EXTPROC.

pub const fn with_extproc(self) -> Self

Returns self with EXTPROC inserted.

pub const fn with_extproc_if(self, condition: bool) -> Self

Returns self with EXTPROC inserted if condition is true.

pub const fn without_extproc(self) -> Self

Returns self with EXTPROC removed.

pub const fn set_extproc(&mut self)

Sets EXTPROC.

pub const fn set_extproc_if(&mut self, condition: bool)

Sets EXTPROC if condition is true.

pub const fn unset_extproc(&mut self)

Unsets EXTPROC.

Source

impl LinuxTermiosLocalFlags

Common set methods

pub const fn new() -> Self

Returns an empty set.

pub const fn from_bits(bits: u32) -> Self

Returns a set from raw bits.

pub const fn bits(self) -> u32

Returns the raw backing bits.

pub const fn all() -> Self

Returns the union of all declared sets.

pub const fn is_empty(self) -> bool

Returns true if no bits are set.

pub const fn is_full(self) -> bool

Returns true if all the declared bits are set.

pub const fn contains(self, other: Self) -> bool

Returns true if all bits in other are also set in self.

pub const fn has(self, other: Self) -> bool

An alias of contains.

pub const fn with(self, other: Self) -> Self

Returns self with other inserted.

pub const fn with_if(self, condition: bool, other: Self) -> Self

Returns self with other inserted if condition is true.

pub const fn without(self, other: Self) -> Self

Returns self with other removed.

pub const fn toggled(self, other: Self) -> Self

Returns self with other toggled.

Source

impl LinuxTermiosLocalFlags

Set operations

pub const fn intersects(self, other: Self) -> bool

Returns true if self and other share any bit.

pub const fn is_subset(self, other: Self) -> bool

Returns true if all bits in self are also set in other.

pub const fn is_superset(self, other: Self) -> bool

Returns true if all bits in other are also set in self.

pub const fn union(self, other: Self) -> Self

Returns the union of self and other.

pub const fn intersection(self, other: Self) -> Self

Returns the intersection of self and other.

pub const fn difference(self, other: Self) -> Self

Returns the difference of self and other.

pub const fn symmetric_difference(self, other: Self) -> Self

Returns the symmetric difference of self and other.

Source

impl LinuxTermiosLocalFlags

Mutating set operations

pub const fn clear(&mut self)

Clears the set.

pub const fn insert(&mut self, other: Self)

Inserts all bits from other.

pub const fn remove(&mut self, other: Self)

Removes all bits from other.

pub const fn toggle(&mut self, other: Self)

Toggles all bits from other.