TermStyle

Struct TermStyle 

pub struct TermStyle { /* private fields */ }
Available on crate feature term only.
๐Ÿฎ– ๐“ โІ A compact set of broadly supported terminal text styles.


๐Ÿ“ sys/os/term

๐Ÿ“ฆ size_of::<TermStyle>() == 1 bytes / 8 bits


Its bits occupy the low byte of TermStyleExt with the same meanings.

Implementations

Source

impl TermStyle

pub const fn extended(self) -> TermStyleExt

Returns the corresponding extended style set.

Source

impl TermStyle

Named constants

pub const BOLD: Self

1 Increased intensity.

pub const ITALIC: Self

1 Italic text.

pub const UNDERLINE: Self

1 Underlined text.

pub const DIM: Self

1 Reduced intensity.

1 Blinking text.

pub const INVERSE: Self

1 Swapped foreground and background.

pub const HIDDEN: Self

1 Concealed text.

pub const CROSSED: Self

1 Crossed-out text.

Source

impl TermStyle

Convenience methods derived from each named constant.

pub const fn has_bold(self) -> bool

Returns true if BOLD is present.

pub const fn contains_bold(self) -> bool

Returns true if all bits in BOLD are present.

pub const fn intersects_bold(self) -> bool

Returns true if the set shares any bit with BOLD.

pub const fn with_bold(self) -> Self

Returns self with BOLD inserted.

pub const fn with_bold_if(self, condition: bool) -> Self

Returns self with BOLD inserted if condition is true.

pub const fn without_bold(self) -> Self

Returns self with BOLD removed.

pub const fn set_bold(&mut self)

Sets BOLD.

pub const fn set_bold_if(&mut self, condition: bool)

Sets BOLD if condition is true.

pub const fn unset_bold(&mut self)

Unsets BOLD.

pub const fn has_italic(self) -> bool

Returns true if ITALIC is present.

pub const fn contains_italic(self) -> bool

Returns true if all bits in ITALIC are present.

pub const fn intersects_italic(self) -> bool

Returns true if the set shares any bit with ITALIC.

pub const fn with_italic(self) -> Self

Returns self with ITALIC inserted.

pub const fn with_italic_if(self, condition: bool) -> Self

Returns self with ITALIC inserted if condition is true.

pub const fn without_italic(self) -> Self

Returns self with ITALIC removed.

pub const fn set_italic(&mut self)

Sets ITALIC.

pub const fn set_italic_if(&mut self, condition: bool)

Sets ITALIC if condition is true.

pub const fn unset_italic(&mut self)

Unsets ITALIC.

pub const fn has_underline(self) -> bool

Returns true if UNDERLINE is present.

pub const fn contains_underline(self) -> bool

Returns true if all bits in UNDERLINE are present.

pub const fn intersects_underline(self) -> bool

Returns true if the set shares any bit with UNDERLINE.

pub const fn with_underline(self) -> Self

Returns self with UNDERLINE inserted.

pub const fn with_underline_if(self, condition: bool) -> Self

Returns self with UNDERLINE inserted if condition is true.

pub const fn without_underline(self) -> Self

Returns self with UNDERLINE removed.

pub const fn set_underline(&mut self)

Sets UNDERLINE.

pub const fn set_underline_if(&mut self, condition: bool)

Sets UNDERLINE if condition is true.

pub const fn unset_underline(&mut self)

Unsets UNDERLINE.

pub const fn has_dim(self) -> bool

Returns true if DIM is present.

pub const fn contains_dim(self) -> bool

Returns true if all bits in DIM are present.

pub const fn intersects_dim(self) -> bool

Returns true if the set shares any bit with DIM.

pub const fn with_dim(self) -> Self

Returns self with DIM inserted.

pub const fn with_dim_if(self, condition: bool) -> Self

Returns self with DIM inserted if condition is true.

pub const fn without_dim(self) -> Self

Returns self with DIM removed.

pub const fn set_dim(&mut self)

Sets DIM.

pub const fn set_dim_if(&mut self, condition: bool)

Sets DIM if condition is true.

pub const fn unset_dim(&mut self)

Unsets DIM.

Returns true if BLINK is present.

Returns true if all bits in BLINK are present.

Returns true if the set shares any bit with BLINK.

Returns self with BLINK inserted.

Returns self with BLINK inserted if condition is true.

Returns self with BLINK removed.

Sets BLINK.

Sets BLINK if condition is true.

Unsets BLINK.

pub const fn has_inverse(self) -> bool

Returns true if INVERSE is present.

pub const fn contains_inverse(self) -> bool

Returns true if all bits in INVERSE are present.

pub const fn intersects_inverse(self) -> bool

Returns true if the set shares any bit with INVERSE.

pub const fn with_inverse(self) -> Self

Returns self with INVERSE inserted.

pub const fn with_inverse_if(self, condition: bool) -> Self

Returns self with INVERSE inserted if condition is true.

pub const fn without_inverse(self) -> Self

Returns self with INVERSE removed.

pub const fn set_inverse(&mut self)

Sets INVERSE.

pub const fn set_inverse_if(&mut self, condition: bool)

Sets INVERSE if condition is true.

pub const fn unset_inverse(&mut self)

Unsets INVERSE.

pub const fn has_hidden(self) -> bool

Returns true if HIDDEN is present.

pub const fn contains_hidden(self) -> bool

Returns true if all bits in HIDDEN are present.

pub const fn intersects_hidden(self) -> bool

Returns true if the set shares any bit with HIDDEN.

pub const fn with_hidden(self) -> Self

Returns self with HIDDEN inserted.

pub const fn with_hidden_if(self, condition: bool) -> Self

Returns self with HIDDEN inserted if condition is true.

pub const fn without_hidden(self) -> Self

Returns self with HIDDEN removed.

pub const fn set_hidden(&mut self)

Sets HIDDEN.

pub const fn set_hidden_if(&mut self, condition: bool)

Sets HIDDEN if condition is true.

pub const fn unset_hidden(&mut self)

Unsets HIDDEN.

pub const fn has_crossed(self) -> bool

Returns true if CROSSED is present.

pub const fn contains_crossed(self) -> bool

Returns true if all bits in CROSSED are present.

pub const fn intersects_crossed(self) -> bool

Returns true if the set shares any bit with CROSSED.

pub const fn with_crossed(self) -> Self

Returns self with CROSSED inserted.

pub const fn with_crossed_if(self, condition: bool) -> Self

Returns self with CROSSED inserted if condition is true.

pub const fn without_crossed(self) -> Self

Returns self with CROSSED removed.

pub const fn set_crossed(&mut self)

Sets CROSSED.

pub const fn set_crossed_if(&mut self, condition: bool)

Sets CROSSED if condition is true.

pub const fn unset_crossed(&mut self)

Unsets CROSSED.

Source

impl TermStyle

Common set methods

pub const fn new() -> Self

Returns an empty set.

pub const fn from_bits(bits: u8) -> Self

Returns a set from raw bits.

pub const fn bits(self) -> u8

Returns the raw backing bits.

pub const fn all() -> Self

Returns the union of all declared sets.

pub const fn is_empty(self) -> bool

Returns true if no bits are set.

pub const fn is_full(self) -> bool

Returns true if all the declared bits are set.

pub const fn contains(self, other: Self) -> bool

Returns true if all bits in other are also set in self.

pub const fn has(self, other: Self) -> bool

An alias of contains.

pub const fn with(self, other: Self) -> Self

Returns self with other inserted.

pub const fn with_if(self, condition: bool, other: Self) -> Self

Returns self with other inserted if condition is true.

pub const fn without(self, other: Self) -> Self

Returns self with other removed.

pub const fn toggled(self, other: Self) -> Self

Returns self with other toggled.

Source

impl TermStyle

Set operations

pub const fn intersects(self, other: Self) -> bool

Returns true if self and other share any bit.

pub const fn is_subset(self, other: Self) -> bool

Returns true if all bits in self are also set in other.

pub const fn is_superset(self, other: Self) -> bool

Returns true if all bits in other are also set in self.

pub const fn union(self, other: Self) -> Self

Returns the union of self and other.

pub const fn intersection(self, other: Self) -> Self

Returns the intersection of self and other.

pub const fn difference(self, other: Self) -> Self

Returns the difference of self and other.

pub const fn symmetric_difference(self, other: Self) -> Self

Returns the symmetric difference of self and other.

Source

impl TermStyle

Mutating set operations

pub const fn clear(&mut self)

Clears the set.

pub const fn insert(&mut self, other: Self)

Inserts all bits from other.

pub const fn remove(&mut self, other: Self)

Removes all bits from other.

pub const fn toggle(&mut self, other: Self)

Toggles all bits from other.