DebugStruct

Struct DebugStruct 

1.2.0 · Source
pub struct DebugStruct<'a, 'b>
where 'b: 'a,
{ /* private fields */ }
🖹 🐛 core A struct to help with Debug implementations.


📍text/fmt re-exported from core::fmt



📜
A struct to help with fmt::Debug implementations.

This is useful when you wish to output a formatted struct as a part of your Debug::fmt implementation.

This can be constructed by the Formatter::debug_struct method.

Examples

use std::fmt;

struct Foo {
    bar: i32,
    baz: String,
}

impl fmt::Debug for Foo {
    fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
        fmt.debug_struct("Foo")
           .field("bar", &self.bar)
           .field("baz", &self.baz)
           .finish()
    }
}

assert_eq!(
    format!("{:?}", Foo { bar: 10, baz: "Hello World".to_string() }),
    r#"Foo { bar: 10, baz: "Hello World" }"#,
);

Implementations

Source

impl<'a, 'b> DebugStruct<'a, 'b>
where 'b: 'a,

1.2.0 · Source

pub fn field( &mut self, name: &str, value: &dyn Debug, ) -> &mut DebugStruct<'a, 'b>

Adds a new field to the generated struct output.

Examples
use std::fmt;

struct Bar {
    bar: i32,
    another: String,
}

impl fmt::Debug for Bar {
    fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
        fmt.debug_struct("Bar")
           .field("bar", &self.bar) // We add `bar` field.
           .field("another", &self.another) // We add `another` field.
           // We even add a field which doesn't exist (because why not?).
           .field("nonexistent_field", &1)
           .finish() // We're good to go!
    }
}

assert_eq!(
    format!("{:?}", Bar { bar: 10, another: "Hello World".to_string() }),
    r#"Bar { bar: 10, another: "Hello World", nonexistent_field: 1 }"#,
);
pub fn field_with<F>( &mut self, name: &str, value_fmt: F, ) -> &mut DebugStruct<'a, 'b>
where F: FnOnce(&mut Formatter<'_>) -> Result<(), Error>,

🔬This is a nightly-only experimental API. (debug_closure_helpers)

Adds a new field to the generated struct output.

This method is equivalent to DebugStruct::field, but formats the value using a provided closure rather than by calling Debug::fmt.

1.53.0 · Source

pub fn finish_non_exhaustive(&mut self) -> Result<(), Error>

Marks the struct as non-exhaustive, indicating to the reader that there are some other fields that are not shown in the debug representation.

Examples
use std::fmt;

struct Bar {
    bar: i32,
    hidden: f32,
}

impl fmt::Debug for Bar {
    fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
        fmt.debug_struct("Bar")
           .field("bar", &self.bar)
           .finish_non_exhaustive() // Show that some other field(s) exist.
    }
}

assert_eq!(
    format!("{:?}", Bar { bar: 10, hidden: 1.0 }),
    "Bar { bar: 10, .. }",
);
1.2.0 · Source

pub fn finish(&mut self) -> Result<(), Error>

Finishes output and returns any error encountered.

Examples
use std::fmt;

struct Bar {
    bar: i32,
    baz: String,
}

impl fmt::Debug for Bar {
    fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
        fmt.debug_struct("Bar")
           .field("bar", &self.bar)
           .field("baz", &self.baz)
           .finish() // You need to call it to "finish" the
                     // struct formatting.
    }
}

assert_eq!(
    format!("{:?}", Bar { bar: 10, baz: "Hello World".to_string() }),
    r#"Bar { bar: 10, baz: "Hello World" }"#,
);