TryLockError

Enum TryLockError 

1.0.0 · Source
pub enum TryLockError<T> {
    Poisoned(PoisonError<T>),
    WouldBlock,
}
Available on crate features std only.
🧵 🚩+ std An enumeration of possible errors associated with a TryLockResult.


📍work/sync re-exported from std::sync



📜
An enumeration of possible errors associated with a TryLockResult which can occur while trying to acquire a lock, from the try_lock method on a Mutex or the try_read and try_write methods on an RwLock.

Variants

1.0.0

Poisoned(PoisonError<T>)

The lock could not be acquired because another thread failed while holding the lock.

1.0.0

WouldBlock

The lock could not be acquired at this time because the operation would otherwise block.