CoroWork

Struct CoroWork 

pub struct CoroWork<'a, T, E> { /* private fields */ }
๐Ÿงต โฌก A future that alternates between Ready and Pending status each time itโ€™s polled.


๐Ÿ“ work/task/coro


This allows the coroutine to yield control back and be resumed later.