pub struct ExitStatusError { /* private fields */ }Available on crate feature
std only.Expand description
๐ฅ๏ธ โฌก ๐ฉ Indicates that a process terminated unsuccessfully.
๐ work/process
This type is a stable placeholder for the unstable standard libraryโs
ExitStatusError
Implementations
Sourceimpl ExitStatusError
impl ExitStatusError
Sourcepub fn code(&self) -> Option<i32> โ
pub fn code(&self) -> Option<i32> โ
Reports the exit code, if applicable, from an ExitStatusError.
Sourcepub const fn into_status(&self) -> ExitStatus
pub const fn into_status(&self) -> ExitStatus
Converts an ExitStatusError (back) to an ExitStatus.