pub struct Output {
pub status: ExitStatus,
pub stdout: Vec<u8>,
pub stderr: Vec<u8>,
}Available on crate features
std only.Expand description
🖥️ ⬡
std
The output of a finished process.
📍work/process re-exported from std::process
📜
The output of a finished process.
This is returned in a Result by either the output method of a
Command, or the wait_with_output method of a Child
process.
Fields
status: ExitStatusThe status (exit code) of the process.
stdout: Vec<u8>The data that the process wrote to stdout.
stderr: Vec<u8>The data that the process wrote to stderr.
Implementations
Sourceimpl Output
impl Output
Sourcepub fn exit_ok(self) -> Result<Output, ExitStatusError> ⓘ
🔬This is a nightly-only experimental API. (exit_status_error)
pub fn exit_ok(self) -> Result<Output, ExitStatusError> ⓘ
exit_status_error)Returns an error if a nonzero exit status was received.
If the Command exited successfully,
self is returned.
This is equivalent to calling exit_ok
on Output.status.
Note that this will throw away the Output::stderr field in the error case.
If the child process outputs useful informantion to stderr, you can:
- Use
cmd.stderr(Stdio::inherit())to forward the stderr child process to the parent’s stderr, usually printing it to console where the user can see it. This is usually correct for command-line applications. - Capture
stderrusing a custom error type. This is usually correct for libraries.
Examples
#![feature(exit_status_error)]
use std::process::Command;
assert!(Command::new("false").output().unwrap().exit_ok().is_err());Trait Implementations
impl Eq for Output
Sourceimpl OutputExt for Output
impl OutputExt for Output
Sourcefn stdout_string(self) -> Result<String, InvalidUtf8> ⓘ
fn stdout_string(self) -> Result<String, InvalidUtf8> ⓘ
Returns stdout as a UTF-8 string. Read more
impl StructuralPartialEq for Output