SpinLockGuard

Struct SpinLockGuard 

pub struct SpinLockGuard<'a, T, const SPIN: usize, const YIELD: usize, const SLEEP: u64>(/* private fields */);
Available on crate feature unsafe_sync only.
A guard that grants exclusive access to a SpinLock value.

Guarantees

  • If a SpinLockGuard exists, the lock is held.
  • The protected value can be safely accessed through Deref and DerefMut.
  • Dropping SpinLockGuard releases the lock, allowing other threads to acquire it.