pub enum PcmWavError {
Show 19 variants
Raw(PcmRawError),
Riff(RiffError),
NotWave,
MissingFmt,
MissingData,
TruncatedFmt,
UnsupportedFormat(u16),
UnsupportedChannelCount(u16),
UnsupportedBitsPerSample(u16),
InvalidBlockAlign,
InvalidByteRate,
InvalidDataLength,
Overflow,
NotEnoughSpace,
SizeOutOfRange,
UnsupportedEncoding,
InvalidExtensibleFormat,
UnsupportedSubformat,
Io(IoErrorKind),
}audio only.Expand description
๐ ๐ฉ WAVE encoding and decoding error.
๐ media/audio::PcmWavError
๐ฆ size_of::<PcmWavError>() == 4 bytes / 32 bits
Variants
Raw(PcmRawError)
Raw PCM byte/sample conversion failed.
Riff(RiffError)
RIFF-level parsing failed.
NotWave
The RIFF form type is not WAVE.
MissingFmt
The required fmt chunk was not found.
MissingData
The required data chunk was not found.
TruncatedFmt
The fmt chunk is shorter than the base 16-byte PCM format.
UnsupportedFormat(u16)
The WAVE format code is not supported by this parser.
UnsupportedChannelCount(u16)
The channel count is zero or cannot map to current PCM metadata.
UnsupportedBitsPerSample(u16)
The bits-per-sample field is not supported by current PCM metadata.
InvalidBlockAlign
block_align does not match the parsed format.
InvalidByteRate
byte_rate does not match the parsed format.
InvalidDataLength
The data chunk length is not a multiple of block_align.
Overflow
A size computation overflowed.
NotEnoughSpace
The destination buffer is too small.
SizeOutOfRange
The encoded WAVE file would exceed RIFFโs 32-bit size fields.
UnsupportedEncoding
The WAVE format metadata cannot be represented by the current writer.
InvalidExtensibleFormat
The WAVE extensible fmt extension is malformed.
UnsupportedSubformat
The WAVE extensible subformat GUID is not supported.
Io(IoErrorKind)
std only.Reading the file failed.