pub struct EnumSetExample { /* private fields */ }Expand description
✨ ⌗ ⊆
An example set of enum variants, generated by enumset!.
📍 data/codec/bin::EnumSetExample
📦 size_of::<EnumSetExample>() == 1 bytes / 8 bits
⚗️Option<T> ❗🟰 T
Represents a set of EnumExample variants.
Implementations
Sourceimpl EnumSetExample
Named subsets.
impl EnumSetExample
Named subsets.
Sourcepub const BORROW_OR_ALLOC: Self
pub const BORROW_OR_ALLOC: Self
Variants that can hold either borrowed or allocated data.
Sourceimpl EnumSetExample
Named constants
impl EnumSetExample
Named constants
Sourceimpl EnumSetExample
Convenience methods derived from each named constant.
impl EnumSetExample
Convenience methods derived from each named constant.
Sourcepub const fn has_variant0(self) -> bool
pub const fn has_variant0(self) -> bool
Returns true if Variant0 is present.
Sourcepub const fn contains_variant0(self) -> bool
pub const fn contains_variant0(self) -> bool
Returns true if all bits in Variant0 are present.
Sourcepub const fn intersects_variant0(self) -> bool
pub const fn intersects_variant0(self) -> bool
Returns true if the set shares any bit with Variant0.
Sourcepub const fn with_variant0(self) -> Self
pub const fn with_variant0(self) -> Self
Returns self with Variant0 inserted.
Sourcepub const fn with_variant0_if(self, condition: bool) -> Self
pub const fn with_variant0_if(self, condition: bool) -> Self
Returns self with Variant0 inserted if condition is true.
Sourcepub const fn without_variant0(self) -> Self
pub const fn without_variant0(self) -> Self
Returns self with Variant0 removed.
Sourcepub const fn set_variant0(&mut self)
pub const fn set_variant0(&mut self)
Sets Variant0.
Sourcepub const fn set_variant0_if(&mut self, condition: bool)
pub const fn set_variant0_if(&mut self, condition: bool)
Sets Variant0 if condition is true.
Sourcepub const fn unset_variant0(&mut self)
pub const fn unset_variant0(&mut self)
Unsets Variant0.
Sourcepub const fn has_variant1(self) -> bool
pub const fn has_variant1(self) -> bool
Returns true if Variant1 is present.
Sourcepub const fn contains_variant1(self) -> bool
pub const fn contains_variant1(self) -> bool
Returns true if all bits in Variant1 are present.
Sourcepub const fn intersects_variant1(self) -> bool
pub const fn intersects_variant1(self) -> bool
Returns true if the set shares any bit with Variant1.
Sourcepub const fn with_variant1(self) -> Self
pub const fn with_variant1(self) -> Self
Returns self with Variant1 inserted.
Sourcepub const fn with_variant1_if(self, condition: bool) -> Self
pub const fn with_variant1_if(self, condition: bool) -> Self
Returns self with Variant1 inserted if condition is true.
Sourcepub const fn without_variant1(self) -> Self
pub const fn without_variant1(self) -> Self
Returns self with Variant1 removed.
Sourcepub const fn set_variant1(&mut self)
pub const fn set_variant1(&mut self)
Sets Variant1.
Sourcepub const fn set_variant1_if(&mut self, condition: bool)
pub const fn set_variant1_if(&mut self, condition: bool)
Sets Variant1 if condition is true.
Sourcepub const fn unset_variant1(&mut self)
pub const fn unset_variant1(&mut self)
Unsets Variant1.
Sourcepub const fn has_variant2(self) -> bool
pub const fn has_variant2(self) -> bool
Returns true if Variant2 is present.
Sourcepub const fn contains_variant2(self) -> bool
pub const fn contains_variant2(self) -> bool
Returns true if all bits in Variant2 are present.
Sourcepub const fn intersects_variant2(self) -> bool
pub const fn intersects_variant2(self) -> bool
Returns true if the set shares any bit with Variant2.
Sourcepub const fn with_variant2(self) -> Self
pub const fn with_variant2(self) -> Self
Returns self with Variant2 inserted.
Sourcepub const fn with_variant2_if(self, condition: bool) -> Self
pub const fn with_variant2_if(self, condition: bool) -> Self
Returns self with Variant2 inserted if condition is true.
Sourcepub const fn without_variant2(self) -> Self
pub const fn without_variant2(self) -> Self
Returns self with Variant2 removed.
Sourcepub const fn set_variant2(&mut self)
pub const fn set_variant2(&mut self)
Sets Variant2.
Sourcepub const fn set_variant2_if(&mut self, condition: bool)
pub const fn set_variant2_if(&mut self, condition: bool)
Sets Variant2 if condition is true.
Sourcepub const fn unset_variant2(&mut self)
pub const fn unset_variant2(&mut self)
Unsets Variant2.
Sourcepub const fn has_variant3(self) -> bool
pub const fn has_variant3(self) -> bool
Returns true if Variant3 is present.
Sourcepub const fn contains_variant3(self) -> bool
pub const fn contains_variant3(self) -> bool
Returns true if all bits in Variant3 are present.
Sourcepub const fn intersects_variant3(self) -> bool
pub const fn intersects_variant3(self) -> bool
Returns true if the set shares any bit with Variant3.
Sourcepub const fn with_variant3(self) -> Self
pub const fn with_variant3(self) -> Self
Returns self with Variant3 inserted.
Sourcepub const fn with_variant3_if(self, condition: bool) -> Self
pub const fn with_variant3_if(self, condition: bool) -> Self
Returns self with Variant3 inserted if condition is true.
Sourcepub const fn without_variant3(self) -> Self
pub const fn without_variant3(self) -> Self
Returns self with Variant3 removed.
Sourcepub const fn set_variant3(&mut self)
pub const fn set_variant3(&mut self)
Sets Variant3.
Sourcepub const fn set_variant3_if(&mut self, condition: bool)
pub const fn set_variant3_if(&mut self, condition: bool)
Sets Variant3 if condition is true.
Sourcepub const fn unset_variant3(&mut self)
pub const fn unset_variant3(&mut self)
Unsets Variant3.
Sourcepub const fn has_variant4(self) -> bool
pub const fn has_variant4(self) -> bool
Returns true if Variant4 is present.
Sourcepub const fn contains_variant4(self) -> bool
pub const fn contains_variant4(self) -> bool
Returns true if all bits in Variant4 are present.
Sourcepub const fn intersects_variant4(self) -> bool
pub const fn intersects_variant4(self) -> bool
Returns true if the set shares any bit with Variant4.
Sourcepub const fn with_variant4(self) -> Self
pub const fn with_variant4(self) -> Self
Returns self with Variant4 inserted.
Sourcepub const fn with_variant4_if(self, condition: bool) -> Self
pub const fn with_variant4_if(self, condition: bool) -> Self
Returns self with Variant4 inserted if condition is true.
Sourcepub const fn without_variant4(self) -> Self
pub const fn without_variant4(self) -> Self
Returns self with Variant4 removed.
Sourcepub const fn set_variant4(&mut self)
pub const fn set_variant4(&mut self)
Sets Variant4.
Sourcepub const fn set_variant4_if(&mut self, condition: bool)
pub const fn set_variant4_if(&mut self, condition: bool)
Sets Variant4 if condition is true.
Sourcepub const fn unset_variant4(&mut self)
pub const fn unset_variant4(&mut self)
Unsets Variant4.
Sourceimpl EnumSetExample
Common set methods
impl EnumSetExample
Common set methods
Sourceimpl EnumSetExample
Set operations
impl EnumSetExample
Set operations
Sourcepub const fn intersects(self, other: Self) -> bool
pub const fn intersects(self, other: Self) -> bool
Returns true if self and other share any bit.
Sourcepub const fn is_subset(self, other: Self) -> bool
pub const fn is_subset(self, other: Self) -> bool
Returns true if all bits in self are also set in other.
Sourcepub const fn is_superset(self, other: Self) -> bool
pub const fn is_superset(self, other: Self) -> bool
Returns true if all bits in other are also set in self.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection of self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference of self and other.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference of self and other.
Sourceimpl EnumSetExample
Mutating set operations
impl EnumSetExample
Mutating set operations
Sourceimpl EnumSetExample
Associated set methods
impl EnumSetExample
Associated set methods
Sourcepub const fn contains_variant<'a, 'b, T>(
self,
value: &EnumExample<'a, 'b, T>,
) -> boolwhere
T: Clone,
pub const fn contains_variant<'a, 'b, T>(
self,
value: &EnumExample<'a, 'b, T>,
) -> boolwhere
T: Clone,
Returns true if the set contains the variant of value.
Sourcepub const fn has_variant<'a, 'b, T>(
self,
value: &EnumExample<'a, 'b, T>,
) -> boolwhere
T: Clone,
pub const fn has_variant<'a, 'b, T>(
self,
value: &EnumExample<'a, 'b, T>,
) -> boolwhere
T: Clone,
An alias of contains_variant.
Sourcepub const fn with_variant<'a, 'b, T>(
self,
value: &EnumExample<'a, 'b, T>,
) -> Selfwhere
T: Clone,
pub const fn with_variant<'a, 'b, T>(
self,
value: &EnumExample<'a, 'b, T>,
) -> Selfwhere
T: Clone,
Returns self with the variant of value inserted.
Sourcepub const fn without_variant<'a, 'b, T>(
self,
value: &EnumExample<'a, 'b, T>,
) -> Selfwhere
T: Clone,
pub const fn without_variant<'a, 'b, T>(
self,
value: &EnumExample<'a, 'b, T>,
) -> Selfwhere
T: Clone,
Returns self with the variant of value removed.
Sourcepub const fn toggled_variant<'a, 'b, T>(
self,
value: &EnumExample<'a, 'b, T>,
) -> Selfwhere
T: Clone,
pub const fn toggled_variant<'a, 'b, T>(
self,
value: &EnumExample<'a, 'b, T>,
) -> Selfwhere
T: Clone,
Returns self with the variant of value toggled.
Sourcepub const fn insert_variant<'a, 'b, T>(
&mut self,
value: &EnumExample<'a, 'b, T>,
)where
T: Clone,
pub const fn insert_variant<'a, 'b, T>(
&mut self,
value: &EnumExample<'a, 'b, T>,
)where
T: Clone,
Inserts the variant of value.
Sourcepub const fn remove_variant<'a, 'b, T>(
&mut self,
value: &EnumExample<'a, 'b, T>,
)where
T: Clone,
pub const fn remove_variant<'a, 'b, T>(
&mut self,
value: &EnumExample<'a, 'b, T>,
)where
T: Clone,
Removes the variant of value.
Sourcepub const fn toggle_variant<'a, 'b, T>(
&mut self,
value: &EnumExample<'a, 'b, T>,
)where
T: Clone,
pub const fn toggle_variant<'a, 'b, T>(
&mut self,
value: &EnumExample<'a, 'b, T>,
)where
T: Clone,
Toggles the variant of value.
Sourcepub fn for_each_set(self, f: impl FnMut(Self))
pub fn for_each_set(self, f: impl FnMut(Self))
Calls f for each associated set constant present in this set.
Sourcepub fn for_each_set_while(self, f: impl FnMut(Self) -> bool) -> bool
pub fn for_each_set_while(self, f: impl FnMut(Self) -> bool) -> bool
Calls f for each associated set constant present in this set while it returns true.
Returns true if all set constants were visited,
or false if iteration stopped early.