pub struct Md5 { /* private fields */ }Expand description
✨ 🔐 🔀 Incremental Md5 state.
📦 size_of::<Md5>() == 92 bytes / 736 bits #️⃣ #[cfg(target_pointer_width = “32”)]
⚗️Option<T> ❗🟰 T
📦 size_of::<Md5>() == 96 bytes / 768 bits #️⃣ #[cfg(target_pointer_width = “64”)]
⚗️Option<T> ❗🟰 T
This implementation is allocation-free, compile-time friendly, and supports incremental updates.
Use update to feed bytes and finalize
to consume the state and return the digest.
Generated with digest!.
Implementations
Sourceimpl Md5
impl Md5
Sourcepub const DIGEST_LEN: usize = 16
pub const DIGEST_LEN: usize = 16
The digest size in bytes.
Sourcepub const fn update(&mut self, bytes: &[u8]) -> Result<(), CryptoError> ⓘ
pub const fn update(&mut self, bytes: &[u8]) -> Result<(), CryptoError> ⓘ
Updates the digest state with bytes.
Errors
Returns LengthOverflow
if the total message length would exceed MD5’s 64-bit bit-length field.
Sourcepub const fn digest_bytes(
bytes: &[u8],
) -> Result<Digest<{ Md5::DIGEST_LEN }>, CryptoError> ⓘ
pub const fn digest_bytes( bytes: &[u8], ) -> Result<Digest<{ Md5::DIGEST_LEN }>, CryptoError> ⓘ
Computes the MD5 digest of bytes.
Errors
Returns LengthOverflow
if bytes exceeds MD5’s supported message length.
Sourcepub const fn hmac(
key: &[u8],
message: &[u8],
) -> Result<Digest<{ Md5::DIGEST_LEN }>, CryptoError> ⓘ
pub const fn hmac( key: &[u8], message: &[u8], ) -> Result<Digest<{ Md5::DIGEST_LEN }>, CryptoError> ⓘ
Computes the HMAC of message using the given key.
If the key is longer than the block size, it is first hashed.
Errors
Returns LengthOverflow if key hashing or the
inner/outer digest computation exceeds the hash input length limit.