pub struct RangeToInclusive<Idx> {
pub last: Idx,
}Expand description
๐
core
A range value bounded inclusively above (..=end).
๐code/ops::RangeToInclusive re-exported from core::range
๐
A range only bounded inclusively above.
The RangeToInclusive contains all values with x <= last.
It cannot serve as an Iterator because it doesnโt have a starting point.
Examples
#![feature(new_range)]
assert_eq!((..=5), std::range::RangeToInclusive { last: 5 });It does not have an IntoIterator implementation, so you canโt use it in a
for loop directly. This wonโt compile:
// error[E0277]: the trait bound `std::range::RangeToInclusive<{integer}>:
// std::iter::Iterator` is not satisfied
for i in ..=5 {
// ...
}When used as a slicing index, RangeToInclusive produces a slice of all
array elements up to and including the index indicated by last.
let arr = [0, 1, 2, 3, 4];
assert_eq!(arr[ .. ], [0, 1, 2, 3, 4]);
assert_eq!(arr[ .. 3], [0, 1, 2 ]);
assert_eq!(arr[ ..=3], [0, 1, 2, 3 ]); // This is a `RangeToInclusive`
assert_eq!(arr[1.. ], [ 1, 2, 3, 4]);
assert_eq!(arr[1.. 3], [ 1, 2 ]);
assert_eq!(arr[1..=3], [ 1, 2, 3 ]);Edition notes
It is planned that the syntax ..=last will construct this
type in a future edition, but it does not do so today.
Fields
last: IdxThe upper bound of the range (inclusive)
Implementations
Sourceimpl<Idx> RangeToInclusive<Idx>where
Idx: PartialOrd,
impl<Idx> RangeToInclusive<Idx>where
Idx: PartialOrd,
1.96.0 (const: unstable) ยท Sourcepub fn contains<U>(&self, item: &U) -> bool
pub fn contains<U>(&self, item: &U) -> bool
Returns true if item is contained in the range.
Examples
assert!( (..=5).contains(&-1_000_000_000));
assert!( (..=5).contains(&5));
assert!(!(..=5).contains(&6));
assert!( (..=1.0).contains(&1.0));
assert!(!(..=1.0).contains(&f32::NAN));
assert!(!(..=f32::NAN).contains(&0.5));Trait Implementations
1.96.0 ยท Sourceimpl<Idx> Clone for RangeToInclusive<Idx>where
Idx: Clone,
impl<Idx> Clone for RangeToInclusive<Idx>where
Idx: Clone,
Sourcefn clone(&self) -> RangeToInclusive<Idx>
fn clone(&self) -> RangeToInclusive<Idx>
1.0.0 (const: unstable) ยท Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl<T: ConstInit> ConstInit for RangeToInclusive<T>
impl<T: ConstInit> ConstInit for RangeToInclusive<T>
impl<Idx> Copy for RangeToInclusive<Idx>where
Idx: Copy,
1.96.0 ยท Sourceimpl<Idx> Debug for RangeToInclusive<Idx>where
Idx: Debug,
impl<Idx> Debug for RangeToInclusive<Idx>where
Idx: Debug,
impl<Idx> Eq for RangeToInclusive<Idx>where
Idx: Eq,
1.96.0 ยท Sourceimpl<T> From<RangeToInclusive<T>> for RangeToInclusive<T>
impl<T> From<RangeToInclusive<T>> for RangeToInclusive<T>
Sourcefn from(value: RangeToInclusive<T>) -> RangeToInclusive<T>
fn from(value: RangeToInclusive<T>) -> RangeToInclusive<T>
1.96.0 ยท Sourceimpl<T> From<RangeToInclusive<T>> for RangeToInclusive<T>
impl<T> From<RangeToInclusive<T>> for RangeToInclusive<T>
Sourcefn from(value: RangeToInclusive<T>) -> RangeToInclusive<T>
fn from(value: RangeToInclusive<T>) -> RangeToInclusive<T>
Sourceimpl<T> From<RangeToInclusive<T>> for Interval<T>
impl<T> From<RangeToInclusive<T>> for Interval<T>
Sourcefn from(r: RangeToInclusive<T>) -> Self
fn from(r: RangeToInclusive<T>) -> Self
1.96.0 ยท Sourceimpl<Idx> Hash for RangeToInclusive<Idx>where
Idx: Hash,
impl<Idx> Hash for RangeToInclusive<Idx>where
Idx: Hash,
Sourceimpl<T> IntoBounds<T> for RangeToInclusive<T>
impl<T> IntoBounds<T> for RangeToInclusive<T>
Sourceimpl<T> OneSidedRange<T> for RangeToInclusive<T>where
RangeToInclusive<T>: RangeBounds<T>,
impl<T> OneSidedRange<T> for RangeToInclusive<T>where
RangeToInclusive<T>: RangeBounds<T>,
Sourcefn bound(self) -> (OneSidedRangeBound, T) โ
fn bound(self) -> (OneSidedRangeBound, T) โ
one_sided_range)split_off and
split_off_mut that returns the bound of the one-sided range.1.96.0 ยท Sourceimpl<Idx> PartialEq for RangeToInclusive<Idx>where
Idx: PartialEq,
impl<Idx> PartialEq for RangeToInclusive<Idx>where
Idx: PartialEq,
1.96.0 (const: unstable) ยท Sourceimpl<T> RangeBounds<T> for RangeToInclusive<T>
impl<T> RangeBounds<T> for RangeToInclusive<T>
1.96.0 (const: unstable) ยท Sourceimpl<T> RangeBounds<T> for RangeToInclusive<&T>
impl<T> RangeBounds<T> for RangeToInclusive<&T>
Sourceimpl SliceIndex<ByteStr> for RangeToInclusive<usize>
impl SliceIndex<ByteStr> for RangeToInclusive<usize>
Sourcefn get(
self,
slice: &ByteStr,
) -> Option<&<RangeToInclusive<usize> as SliceIndex<ByteStr>>::Output> โ
fn get( self, slice: &ByteStr, ) -> Option<&<RangeToInclusive<usize> as SliceIndex<ByteStr>>::Output> โ
slice_index_methods)Sourcefn get_mut(
self,
slice: &mut ByteStr,
) -> Option<&mut <RangeToInclusive<usize> as SliceIndex<ByteStr>>::Output> โ
fn get_mut( self, slice: &mut ByteStr, ) -> Option<&mut <RangeToInclusive<usize> as SliceIndex<ByteStr>>::Output> โ
slice_index_methods)Sourceunsafe fn get_unchecked(
self,
slice: *const ByteStr,
) -> *const <RangeToInclusive<usize> as SliceIndex<ByteStr>>::Output
unsafe fn get_unchecked( self, slice: *const ByteStr, ) -> *const <RangeToInclusive<usize> as SliceIndex<ByteStr>>::Output
slice_index_methods)Sourceunsafe fn get_unchecked_mut(
self,
slice: *mut ByteStr,
) -> *mut <RangeToInclusive<usize> as SliceIndex<ByteStr>>::Output
unsafe fn get_unchecked_mut( self, slice: *mut ByteStr, ) -> *mut <RangeToInclusive<usize> as SliceIndex<ByteStr>>::Output
slice_index_methods)Sourcefn index(
self,
slice: &ByteStr,
) -> &<RangeToInclusive<usize> as SliceIndex<ByteStr>>::Output
fn index( self, slice: &ByteStr, ) -> &<RangeToInclusive<usize> as SliceIndex<ByteStr>>::Output
slice_index_methods)Sourcefn index_mut(
self,
slice: &mut ByteStr,
) -> &mut <RangeToInclusive<usize> as SliceIndex<ByteStr>>::Output
fn index_mut( self, slice: &mut ByteStr, ) -> &mut <RangeToInclusive<usize> as SliceIndex<ByteStr>>::Output
slice_index_methods)1.96.0 (const: unstable) ยท Sourceimpl<T> SliceIndex<[T]> for RangeToInclusive<usize>
The methods index and index_mut panic if the end of the range is out of bounds.
impl<T> SliceIndex<[T]> for RangeToInclusive<usize>
The methods index and index_mut panic if the end of the range is out of bounds.
Sourcefn get(self, slice: &[T]) -> Option<&[T]> โ
fn get(self, slice: &[T]) -> Option<&[T]> โ
slice_index_methods)Sourcefn get_mut(self, slice: &mut [T]) -> Option<&mut [T]> โ
fn get_mut(self, slice: &mut [T]) -> Option<&mut [T]> โ
slice_index_methods)Sourceunsafe fn get_unchecked(self, slice: *const [T]) -> *const [T]
unsafe fn get_unchecked(self, slice: *const [T]) -> *const [T]
slice_index_methods)Sourceunsafe fn get_unchecked_mut(self, slice: *mut [T]) -> *mut [T]
unsafe fn get_unchecked_mut(self, slice: *mut [T]) -> *mut [T]
slice_index_methods)1.96.0 (const: unstable) ยท Sourceimpl SliceIndex<str> for RangeToInclusive<usize>
Implements substring slicing with syntax &self[..= last] or &mut self[..= last].
impl SliceIndex<str> for RangeToInclusive<usize>
Implements substring slicing with syntax &self[..= last] or &mut self[..= last].
Returns a slice of the given string from the byte range [0, last].
Equivalent to &self [0 .. last + 1], except if last has the maximum
value for usize.
This operation is O(1).
Panics
Panics if last does not point to the ending byte offset of a character
(last + 1 is either a starting byte offset as defined by
is_char_boundary, or equal to len), or if last >= len.
Sourcefn get(
self,
slice: &str,
) -> Option<&<RangeToInclusive<usize> as SliceIndex<str>>::Output> โ
fn get( self, slice: &str, ) -> Option<&<RangeToInclusive<usize> as SliceIndex<str>>::Output> โ
slice_index_methods)Sourcefn get_mut(
self,
slice: &mut str,
) -> Option<&mut <RangeToInclusive<usize> as SliceIndex<str>>::Output> โ
fn get_mut( self, slice: &mut str, ) -> Option<&mut <RangeToInclusive<usize> as SliceIndex<str>>::Output> โ
slice_index_methods)Sourceunsafe fn get_unchecked(
self,
slice: *const str,
) -> *const <RangeToInclusive<usize> as SliceIndex<str>>::Output
unsafe fn get_unchecked( self, slice: *const str, ) -> *const <RangeToInclusive<usize> as SliceIndex<str>>::Output
slice_index_methods)Sourceunsafe fn get_unchecked_mut(
self,
slice: *mut str,
) -> *mut <RangeToInclusive<usize> as SliceIndex<str>>::Output
unsafe fn get_unchecked_mut( self, slice: *mut str, ) -> *mut <RangeToInclusive<usize> as SliceIndex<str>>::Output
slice_index_methods)Sourcefn index(
self,
slice: &str,
) -> &<RangeToInclusive<usize> as SliceIndex<str>>::Output
fn index( self, slice: &str, ) -> &<RangeToInclusive<usize> as SliceIndex<str>>::Output
slice_index_methods)Sourcefn index_mut(
self,
slice: &mut str,
) -> &mut <RangeToInclusive<usize> as SliceIndex<str>>::Output
fn index_mut( self, slice: &mut str, ) -> &mut <RangeToInclusive<usize> as SliceIndex<str>>::Output
slice_index_methods)impl<Idx> StructuralPartialEq for RangeToInclusive<Idx>where
Idx: PartialEq,
Sourceimpl<T> TryFrom<Interval<T>> for RangeToInclusive<T>
Errors
Returns IncompatibleBounds if the bounds are not compatible.
impl<T> TryFrom<Interval<T>> for RangeToInclusive<T>
Errors
Returns IncompatibleBounds if the bounds are not compatible.