pub trait PrimSplit<T, const LEN: usize> {
// Required methods
fn into_array_be(self) -> [T; LEN] ⓘ;
fn into_array_le(self) -> [T; LEN] ⓘ;
fn into_array_ne(self) -> [T; LEN] ⓘ;
}Expand description
Required Methods
Sourcefn into_array_be(self) -> [T; LEN] ⓘ
fn into_array_be(self) -> [T; LEN] ⓘ
Splits self into an array of T in big-endian order.
Sourcefn into_array_le(self) -> [T; LEN] ⓘ
fn into_array_le(self) -> [T; LEN] ⓘ
Splits self into an array of T in little-endian order.
Sourcefn into_array_ne(self) -> [T; LEN] ⓘ
fn into_array_ne(self) -> [T; LEN] ⓘ
Splits self into an array of T in native-endian order.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".