pub struct LinuxSignalSet { /* private fields */ }linux only.Expand description
๐ง ๐ถ โ A compact semantic set of standard Linux signals.
๐ sys/os/linux/process
๐ฆ size_of::<LinuxSignalSet>() == 4 bytes / 32 bits
This is not the raw Linux sigset_t mask. Signal bits are stored
compactly from zero: SIGHUP is bit 0, SIGINT is bit 1, โฆ
Implementations
Sourceimpl LinuxSignalSet
impl LinuxSignalSet
Sourcepub const fn from_signal(signal: LinuxSignal) -> Self
pub const fn from_signal(signal: LinuxSignal) -> Self
Returns a singleton set containing signal.
Sourcepub const fn to_signal(self) -> Option<LinuxSignal> โ
pub const fn to_signal(self) -> Option<LinuxSignal> โ
Returns the only signal in this set, if it contains exactly one.
Sourcepub fn for_each(self, f: impl FnMut(LinuxSignal))
pub fn for_each(self, f: impl FnMut(LinuxSignal))
Calls f for each signal in this set.
Sourcepub fn for_each_catchable(self, f: impl FnMut(LinuxSignal))
pub fn for_each_catchable(self, f: impl FnMut(LinuxSignal))
Calls f for each catchable signal in this set.
Sourcepub const fn all_catchable(self) -> bool
pub const fn all_catchable(self) -> bool
Returns whether all signals in this set are catchable.
Sourcepub const fn catchable_only(self) -> Self
pub const fn catchable_only(self) -> Self
Returns this set without without signals that cannot be caught.
Sourceimpl LinuxSignalSet
Named constants
impl LinuxSignalSet
Named constants
Sourceimpl LinuxSignalSet
Convenience methods derived from each named constant.
impl LinuxSignalSet
Convenience methods derived from each named constant.
Sourcepub const fn has_sighup(self) -> bool
pub const fn has_sighup(self) -> bool
Returns true if SIGHUP is present.
Sourcepub const fn contains_sighup(self) -> bool
pub const fn contains_sighup(self) -> bool
Returns true if all bits in SIGHUP are present.
Sourcepub const fn intersects_sighup(self) -> bool
pub const fn intersects_sighup(self) -> bool
Returns true if the set shares any bit with SIGHUP.
Sourcepub const fn with_sighup(self) -> Self
pub const fn with_sighup(self) -> Self
Returns self with SIGHUP inserted.
Sourcepub const fn with_sighup_if(self, condition: bool) -> Self
pub const fn with_sighup_if(self, condition: bool) -> Self
Returns self with SIGHUP inserted if condition is true.
Sourcepub const fn without_sighup(self) -> Self
pub const fn without_sighup(self) -> Self
Returns self with SIGHUP removed.
Sourcepub const fn set_sighup(&mut self)
pub const fn set_sighup(&mut self)
Sets SIGHUP.
Sourcepub const fn set_sighup_if(&mut self, condition: bool)
pub const fn set_sighup_if(&mut self, condition: bool)
Sets SIGHUP if condition is true.
Sourcepub const fn unset_sighup(&mut self)
pub const fn unset_sighup(&mut self)
Unsets SIGHUP.
Sourcepub const fn has_sigint(self) -> bool
pub const fn has_sigint(self) -> bool
Returns true if SIGINT is present.
Sourcepub const fn contains_sigint(self) -> bool
pub const fn contains_sigint(self) -> bool
Returns true if all bits in SIGINT are present.
Sourcepub const fn intersects_sigint(self) -> bool
pub const fn intersects_sigint(self) -> bool
Returns true if the set shares any bit with SIGINT.
Sourcepub const fn with_sigint(self) -> Self
pub const fn with_sigint(self) -> Self
Returns self with SIGINT inserted.
Sourcepub const fn with_sigint_if(self, condition: bool) -> Self
pub const fn with_sigint_if(self, condition: bool) -> Self
Returns self with SIGINT inserted if condition is true.
Sourcepub const fn without_sigint(self) -> Self
pub const fn without_sigint(self) -> Self
Returns self with SIGINT removed.
Sourcepub const fn set_sigint(&mut self)
pub const fn set_sigint(&mut self)
Sets SIGINT.
Sourcepub const fn set_sigint_if(&mut self, condition: bool)
pub const fn set_sigint_if(&mut self, condition: bool)
Sets SIGINT if condition is true.
Sourcepub const fn unset_sigint(&mut self)
pub const fn unset_sigint(&mut self)
Unsets SIGINT.
Sourcepub const fn has_sigquit(self) -> bool
pub const fn has_sigquit(self) -> bool
Returns true if SIGQUIT is present.
Sourcepub const fn contains_sigquit(self) -> bool
pub const fn contains_sigquit(self) -> bool
Returns true if all bits in SIGQUIT are present.
Sourcepub const fn intersects_sigquit(self) -> bool
pub const fn intersects_sigquit(self) -> bool
Returns true if the set shares any bit with SIGQUIT.
Sourcepub const fn with_sigquit(self) -> Self
pub const fn with_sigquit(self) -> Self
Returns self with SIGQUIT inserted.
Sourcepub const fn with_sigquit_if(self, condition: bool) -> Self
pub const fn with_sigquit_if(self, condition: bool) -> Self
Returns self with SIGQUIT inserted if condition is true.
Sourcepub const fn without_sigquit(self) -> Self
pub const fn without_sigquit(self) -> Self
Returns self with SIGQUIT removed.
Sourcepub const fn set_sigquit(&mut self)
pub const fn set_sigquit(&mut self)
Sets SIGQUIT.
Sourcepub const fn set_sigquit_if(&mut self, condition: bool)
pub const fn set_sigquit_if(&mut self, condition: bool)
Sets SIGQUIT if condition is true.
Sourcepub const fn unset_sigquit(&mut self)
pub const fn unset_sigquit(&mut self)
Unsets SIGQUIT.
Sourcepub const fn has_sigill(self) -> bool
pub const fn has_sigill(self) -> bool
Returns true if SIGILL is present.
Sourcepub const fn contains_sigill(self) -> bool
pub const fn contains_sigill(self) -> bool
Returns true if all bits in SIGILL are present.
Sourcepub const fn intersects_sigill(self) -> bool
pub const fn intersects_sigill(self) -> bool
Returns true if the set shares any bit with SIGILL.
Sourcepub const fn with_sigill(self) -> Self
pub const fn with_sigill(self) -> Self
Returns self with SIGILL inserted.
Sourcepub const fn with_sigill_if(self, condition: bool) -> Self
pub const fn with_sigill_if(self, condition: bool) -> Self
Returns self with SIGILL inserted if condition is true.
Sourcepub const fn without_sigill(self) -> Self
pub const fn without_sigill(self) -> Self
Returns self with SIGILL removed.
Sourcepub const fn set_sigill(&mut self)
pub const fn set_sigill(&mut self)
Sets SIGILL.
Sourcepub const fn set_sigill_if(&mut self, condition: bool)
pub const fn set_sigill_if(&mut self, condition: bool)
Sets SIGILL if condition is true.
Sourcepub const fn unset_sigill(&mut self)
pub const fn unset_sigill(&mut self)
Unsets SIGILL.
Sourcepub const fn has_sigtrap(self) -> bool
pub const fn has_sigtrap(self) -> bool
Returns true if SIGTRAP is present.
Sourcepub const fn contains_sigtrap(self) -> bool
pub const fn contains_sigtrap(self) -> bool
Returns true if all bits in SIGTRAP are present.
Sourcepub const fn intersects_sigtrap(self) -> bool
pub const fn intersects_sigtrap(self) -> bool
Returns true if the set shares any bit with SIGTRAP.
Sourcepub const fn with_sigtrap(self) -> Self
pub const fn with_sigtrap(self) -> Self
Returns self with SIGTRAP inserted.
Sourcepub const fn with_sigtrap_if(self, condition: bool) -> Self
pub const fn with_sigtrap_if(self, condition: bool) -> Self
Returns self with SIGTRAP inserted if condition is true.
Sourcepub const fn without_sigtrap(self) -> Self
pub const fn without_sigtrap(self) -> Self
Returns self with SIGTRAP removed.
Sourcepub const fn set_sigtrap(&mut self)
pub const fn set_sigtrap(&mut self)
Sets SIGTRAP.
Sourcepub const fn set_sigtrap_if(&mut self, condition: bool)
pub const fn set_sigtrap_if(&mut self, condition: bool)
Sets SIGTRAP if condition is true.
Sourcepub const fn unset_sigtrap(&mut self)
pub const fn unset_sigtrap(&mut self)
Unsets SIGTRAP.
Sourcepub const fn has_sigabrt(self) -> bool
pub const fn has_sigabrt(self) -> bool
Returns true if SIGABRT is present.
Sourcepub const fn contains_sigabrt(self) -> bool
pub const fn contains_sigabrt(self) -> bool
Returns true if all bits in SIGABRT are present.
Sourcepub const fn intersects_sigabrt(self) -> bool
pub const fn intersects_sigabrt(self) -> bool
Returns true if the set shares any bit with SIGABRT.
Sourcepub const fn with_sigabrt(self) -> Self
pub const fn with_sigabrt(self) -> Self
Returns self with SIGABRT inserted.
Sourcepub const fn with_sigabrt_if(self, condition: bool) -> Self
pub const fn with_sigabrt_if(self, condition: bool) -> Self
Returns self with SIGABRT inserted if condition is true.
Sourcepub const fn without_sigabrt(self) -> Self
pub const fn without_sigabrt(self) -> Self
Returns self with SIGABRT removed.
Sourcepub const fn set_sigabrt(&mut self)
pub const fn set_sigabrt(&mut self)
Sets SIGABRT.
Sourcepub const fn set_sigabrt_if(&mut self, condition: bool)
pub const fn set_sigabrt_if(&mut self, condition: bool)
Sets SIGABRT if condition is true.
Sourcepub const fn unset_sigabrt(&mut self)
pub const fn unset_sigabrt(&mut self)
Unsets SIGABRT.
Sourcepub const fn has_sigbus(self) -> bool
pub const fn has_sigbus(self) -> bool
Returns true if SIGBUS is present.
Sourcepub const fn contains_sigbus(self) -> bool
pub const fn contains_sigbus(self) -> bool
Returns true if all bits in SIGBUS are present.
Sourcepub const fn intersects_sigbus(self) -> bool
pub const fn intersects_sigbus(self) -> bool
Returns true if the set shares any bit with SIGBUS.
Sourcepub const fn with_sigbus(self) -> Self
pub const fn with_sigbus(self) -> Self
Returns self with SIGBUS inserted.
Sourcepub const fn with_sigbus_if(self, condition: bool) -> Self
pub const fn with_sigbus_if(self, condition: bool) -> Self
Returns self with SIGBUS inserted if condition is true.
Sourcepub const fn without_sigbus(self) -> Self
pub const fn without_sigbus(self) -> Self
Returns self with SIGBUS removed.
Sourcepub const fn set_sigbus(&mut self)
pub const fn set_sigbus(&mut self)
Sets SIGBUS.
Sourcepub const fn set_sigbus_if(&mut self, condition: bool)
pub const fn set_sigbus_if(&mut self, condition: bool)
Sets SIGBUS if condition is true.
Sourcepub const fn unset_sigbus(&mut self)
pub const fn unset_sigbus(&mut self)
Unsets SIGBUS.
Sourcepub const fn has_sigfpe(self) -> bool
pub const fn has_sigfpe(self) -> bool
Returns true if SIGFPE is present.
Sourcepub const fn contains_sigfpe(self) -> bool
pub const fn contains_sigfpe(self) -> bool
Returns true if all bits in SIGFPE are present.
Sourcepub const fn intersects_sigfpe(self) -> bool
pub const fn intersects_sigfpe(self) -> bool
Returns true if the set shares any bit with SIGFPE.
Sourcepub const fn with_sigfpe(self) -> Self
pub const fn with_sigfpe(self) -> Self
Returns self with SIGFPE inserted.
Sourcepub const fn with_sigfpe_if(self, condition: bool) -> Self
pub const fn with_sigfpe_if(self, condition: bool) -> Self
Returns self with SIGFPE inserted if condition is true.
Sourcepub const fn without_sigfpe(self) -> Self
pub const fn without_sigfpe(self) -> Self
Returns self with SIGFPE removed.
Sourcepub const fn set_sigfpe(&mut self)
pub const fn set_sigfpe(&mut self)
Sets SIGFPE.
Sourcepub const fn set_sigfpe_if(&mut self, condition: bool)
pub const fn set_sigfpe_if(&mut self, condition: bool)
Sets SIGFPE if condition is true.
Sourcepub const fn unset_sigfpe(&mut self)
pub const fn unset_sigfpe(&mut self)
Unsets SIGFPE.
Sourcepub const fn has_sigkill(self) -> bool
pub const fn has_sigkill(self) -> bool
Returns true if SIGKILL is present.
Sourcepub const fn contains_sigkill(self) -> bool
pub const fn contains_sigkill(self) -> bool
Returns true if all bits in SIGKILL are present.
Sourcepub const fn intersects_sigkill(self) -> bool
pub const fn intersects_sigkill(self) -> bool
Returns true if the set shares any bit with SIGKILL.
Sourcepub const fn with_sigkill(self) -> Self
pub const fn with_sigkill(self) -> Self
Returns self with SIGKILL inserted.
Sourcepub const fn with_sigkill_if(self, condition: bool) -> Self
pub const fn with_sigkill_if(self, condition: bool) -> Self
Returns self with SIGKILL inserted if condition is true.
Sourcepub const fn without_sigkill(self) -> Self
pub const fn without_sigkill(self) -> Self
Returns self with SIGKILL removed.
Sourcepub const fn set_sigkill(&mut self)
pub const fn set_sigkill(&mut self)
Sets SIGKILL.
Sourcepub const fn set_sigkill_if(&mut self, condition: bool)
pub const fn set_sigkill_if(&mut self, condition: bool)
Sets SIGKILL if condition is true.
Sourcepub const fn unset_sigkill(&mut self)
pub const fn unset_sigkill(&mut self)
Unsets SIGKILL.
Sourcepub const fn has_sigusr1(self) -> bool
pub const fn has_sigusr1(self) -> bool
Returns true if SIGUSR1 is present.
Sourcepub const fn contains_sigusr1(self) -> bool
pub const fn contains_sigusr1(self) -> bool
Returns true if all bits in SIGUSR1 are present.
Sourcepub const fn intersects_sigusr1(self) -> bool
pub const fn intersects_sigusr1(self) -> bool
Returns true if the set shares any bit with SIGUSR1.
Sourcepub const fn with_sigusr1(self) -> Self
pub const fn with_sigusr1(self) -> Self
Returns self with SIGUSR1 inserted.
Sourcepub const fn with_sigusr1_if(self, condition: bool) -> Self
pub const fn with_sigusr1_if(self, condition: bool) -> Self
Returns self with SIGUSR1 inserted if condition is true.
Sourcepub const fn without_sigusr1(self) -> Self
pub const fn without_sigusr1(self) -> Self
Returns self with SIGUSR1 removed.
Sourcepub const fn set_sigusr1(&mut self)
pub const fn set_sigusr1(&mut self)
Sets SIGUSR1.
Sourcepub const fn set_sigusr1_if(&mut self, condition: bool)
pub const fn set_sigusr1_if(&mut self, condition: bool)
Sets SIGUSR1 if condition is true.
Sourcepub const fn unset_sigusr1(&mut self)
pub const fn unset_sigusr1(&mut self)
Unsets SIGUSR1.
Sourcepub const fn has_sigsegv(self) -> bool
pub const fn has_sigsegv(self) -> bool
Returns true if SIGSEGV is present.
Sourcepub const fn contains_sigsegv(self) -> bool
pub const fn contains_sigsegv(self) -> bool
Returns true if all bits in SIGSEGV are present.
Sourcepub const fn intersects_sigsegv(self) -> bool
pub const fn intersects_sigsegv(self) -> bool
Returns true if the set shares any bit with SIGSEGV.
Sourcepub const fn with_sigsegv(self) -> Self
pub const fn with_sigsegv(self) -> Self
Returns self with SIGSEGV inserted.
Sourcepub const fn with_sigsegv_if(self, condition: bool) -> Self
pub const fn with_sigsegv_if(self, condition: bool) -> Self
Returns self with SIGSEGV inserted if condition is true.
Sourcepub const fn without_sigsegv(self) -> Self
pub const fn without_sigsegv(self) -> Self
Returns self with SIGSEGV removed.
Sourcepub const fn set_sigsegv(&mut self)
pub const fn set_sigsegv(&mut self)
Sets SIGSEGV.
Sourcepub const fn set_sigsegv_if(&mut self, condition: bool)
pub const fn set_sigsegv_if(&mut self, condition: bool)
Sets SIGSEGV if condition is true.
Sourcepub const fn unset_sigsegv(&mut self)
pub const fn unset_sigsegv(&mut self)
Unsets SIGSEGV.
Sourcepub const fn has_sigusr2(self) -> bool
pub const fn has_sigusr2(self) -> bool
Returns true if SIGUSR2 is present.
Sourcepub const fn contains_sigusr2(self) -> bool
pub const fn contains_sigusr2(self) -> bool
Returns true if all bits in SIGUSR2 are present.
Sourcepub const fn intersects_sigusr2(self) -> bool
pub const fn intersects_sigusr2(self) -> bool
Returns true if the set shares any bit with SIGUSR2.
Sourcepub const fn with_sigusr2(self) -> Self
pub const fn with_sigusr2(self) -> Self
Returns self with SIGUSR2 inserted.
Sourcepub const fn with_sigusr2_if(self, condition: bool) -> Self
pub const fn with_sigusr2_if(self, condition: bool) -> Self
Returns self with SIGUSR2 inserted if condition is true.
Sourcepub const fn without_sigusr2(self) -> Self
pub const fn without_sigusr2(self) -> Self
Returns self with SIGUSR2 removed.
Sourcepub const fn set_sigusr2(&mut self)
pub const fn set_sigusr2(&mut self)
Sets SIGUSR2.
Sourcepub const fn set_sigusr2_if(&mut self, condition: bool)
pub const fn set_sigusr2_if(&mut self, condition: bool)
Sets SIGUSR2 if condition is true.
Sourcepub const fn unset_sigusr2(&mut self)
pub const fn unset_sigusr2(&mut self)
Unsets SIGUSR2.
Sourcepub const fn has_sigpipe(self) -> bool
pub const fn has_sigpipe(self) -> bool
Returns true if SIGPIPE is present.
Sourcepub const fn contains_sigpipe(self) -> bool
pub const fn contains_sigpipe(self) -> bool
Returns true if all bits in SIGPIPE are present.
Sourcepub const fn intersects_sigpipe(self) -> bool
pub const fn intersects_sigpipe(self) -> bool
Returns true if the set shares any bit with SIGPIPE.
Sourcepub const fn with_sigpipe(self) -> Self
pub const fn with_sigpipe(self) -> Self
Returns self with SIGPIPE inserted.
Sourcepub const fn with_sigpipe_if(self, condition: bool) -> Self
pub const fn with_sigpipe_if(self, condition: bool) -> Self
Returns self with SIGPIPE inserted if condition is true.
Sourcepub const fn without_sigpipe(self) -> Self
pub const fn without_sigpipe(self) -> Self
Returns self with SIGPIPE removed.
Sourcepub const fn set_sigpipe(&mut self)
pub const fn set_sigpipe(&mut self)
Sets SIGPIPE.
Sourcepub const fn set_sigpipe_if(&mut self, condition: bool)
pub const fn set_sigpipe_if(&mut self, condition: bool)
Sets SIGPIPE if condition is true.
Sourcepub const fn unset_sigpipe(&mut self)
pub const fn unset_sigpipe(&mut self)
Unsets SIGPIPE.
Sourcepub const fn has_sigalrm(self) -> bool
pub const fn has_sigalrm(self) -> bool
Returns true if SIGALRM is present.
Sourcepub const fn contains_sigalrm(self) -> bool
pub const fn contains_sigalrm(self) -> bool
Returns true if all bits in SIGALRM are present.
Sourcepub const fn intersects_sigalrm(self) -> bool
pub const fn intersects_sigalrm(self) -> bool
Returns true if the set shares any bit with SIGALRM.
Sourcepub const fn with_sigalrm(self) -> Self
pub const fn with_sigalrm(self) -> Self
Returns self with SIGALRM inserted.
Sourcepub const fn with_sigalrm_if(self, condition: bool) -> Self
pub const fn with_sigalrm_if(self, condition: bool) -> Self
Returns self with SIGALRM inserted if condition is true.
Sourcepub const fn without_sigalrm(self) -> Self
pub const fn without_sigalrm(self) -> Self
Returns self with SIGALRM removed.
Sourcepub const fn set_sigalrm(&mut self)
pub const fn set_sigalrm(&mut self)
Sets SIGALRM.
Sourcepub const fn set_sigalrm_if(&mut self, condition: bool)
pub const fn set_sigalrm_if(&mut self, condition: bool)
Sets SIGALRM if condition is true.
Sourcepub const fn unset_sigalrm(&mut self)
pub const fn unset_sigalrm(&mut self)
Unsets SIGALRM.
Sourcepub const fn has_sigterm(self) -> bool
pub const fn has_sigterm(self) -> bool
Returns true if SIGTERM is present.
Sourcepub const fn contains_sigterm(self) -> bool
pub const fn contains_sigterm(self) -> bool
Returns true if all bits in SIGTERM are present.
Sourcepub const fn intersects_sigterm(self) -> bool
pub const fn intersects_sigterm(self) -> bool
Returns true if the set shares any bit with SIGTERM.
Sourcepub const fn with_sigterm(self) -> Self
pub const fn with_sigterm(self) -> Self
Returns self with SIGTERM inserted.
Sourcepub const fn with_sigterm_if(self, condition: bool) -> Self
pub const fn with_sigterm_if(self, condition: bool) -> Self
Returns self with SIGTERM inserted if condition is true.
Sourcepub const fn without_sigterm(self) -> Self
pub const fn without_sigterm(self) -> Self
Returns self with SIGTERM removed.
Sourcepub const fn set_sigterm(&mut self)
pub const fn set_sigterm(&mut self)
Sets SIGTERM.
Sourcepub const fn set_sigterm_if(&mut self, condition: bool)
pub const fn set_sigterm_if(&mut self, condition: bool)
Sets SIGTERM if condition is true.
Sourcepub const fn unset_sigterm(&mut self)
pub const fn unset_sigterm(&mut self)
Unsets SIGTERM.
Sourcepub const fn has_sigstkflt(self) -> bool
pub const fn has_sigstkflt(self) -> bool
Returns true if SIGSTKFLT is present.
Sourcepub const fn contains_sigstkflt(self) -> bool
pub const fn contains_sigstkflt(self) -> bool
Returns true if all bits in SIGSTKFLT are present.
Sourcepub const fn intersects_sigstkflt(self) -> bool
pub const fn intersects_sigstkflt(self) -> bool
Returns true if the set shares any bit with SIGSTKFLT.
Sourcepub const fn with_sigstkflt(self) -> Self
pub const fn with_sigstkflt(self) -> Self
Returns self with SIGSTKFLT inserted.
Sourcepub const fn with_sigstkflt_if(self, condition: bool) -> Self
pub const fn with_sigstkflt_if(self, condition: bool) -> Self
Returns self with SIGSTKFLT inserted if condition is true.
Sourcepub const fn without_sigstkflt(self) -> Self
pub const fn without_sigstkflt(self) -> Self
Returns self with SIGSTKFLT removed.
Sourcepub const fn set_sigstkflt(&mut self)
pub const fn set_sigstkflt(&mut self)
Sets SIGSTKFLT.
Sourcepub const fn set_sigstkflt_if(&mut self, condition: bool)
pub const fn set_sigstkflt_if(&mut self, condition: bool)
Sets SIGSTKFLT if condition is true.
Sourcepub const fn unset_sigstkflt(&mut self)
pub const fn unset_sigstkflt(&mut self)
Unsets SIGSTKFLT.
Sourcepub const fn has_sigchld(self) -> bool
pub const fn has_sigchld(self) -> bool
Returns true if SIGCHLD is present.
Sourcepub const fn contains_sigchld(self) -> bool
pub const fn contains_sigchld(self) -> bool
Returns true if all bits in SIGCHLD are present.
Sourcepub const fn intersects_sigchld(self) -> bool
pub const fn intersects_sigchld(self) -> bool
Returns true if the set shares any bit with SIGCHLD.
Sourcepub const fn with_sigchld(self) -> Self
pub const fn with_sigchld(self) -> Self
Returns self with SIGCHLD inserted.
Sourcepub const fn with_sigchld_if(self, condition: bool) -> Self
pub const fn with_sigchld_if(self, condition: bool) -> Self
Returns self with SIGCHLD inserted if condition is true.
Sourcepub const fn without_sigchld(self) -> Self
pub const fn without_sigchld(self) -> Self
Returns self with SIGCHLD removed.
Sourcepub const fn set_sigchld(&mut self)
pub const fn set_sigchld(&mut self)
Sets SIGCHLD.
Sourcepub const fn set_sigchld_if(&mut self, condition: bool)
pub const fn set_sigchld_if(&mut self, condition: bool)
Sets SIGCHLD if condition is true.
Sourcepub const fn unset_sigchld(&mut self)
pub const fn unset_sigchld(&mut self)
Unsets SIGCHLD.
Sourcepub const fn has_sigcont(self) -> bool
pub const fn has_sigcont(self) -> bool
Returns true if SIGCONT is present.
Sourcepub const fn contains_sigcont(self) -> bool
pub const fn contains_sigcont(self) -> bool
Returns true if all bits in SIGCONT are present.
Sourcepub const fn intersects_sigcont(self) -> bool
pub const fn intersects_sigcont(self) -> bool
Returns true if the set shares any bit with SIGCONT.
Sourcepub const fn with_sigcont(self) -> Self
pub const fn with_sigcont(self) -> Self
Returns self with SIGCONT inserted.
Sourcepub const fn with_sigcont_if(self, condition: bool) -> Self
pub const fn with_sigcont_if(self, condition: bool) -> Self
Returns self with SIGCONT inserted if condition is true.
Sourcepub const fn without_sigcont(self) -> Self
pub const fn without_sigcont(self) -> Self
Returns self with SIGCONT removed.
Sourcepub const fn set_sigcont(&mut self)
pub const fn set_sigcont(&mut self)
Sets SIGCONT.
Sourcepub const fn set_sigcont_if(&mut self, condition: bool)
pub const fn set_sigcont_if(&mut self, condition: bool)
Sets SIGCONT if condition is true.
Sourcepub const fn unset_sigcont(&mut self)
pub const fn unset_sigcont(&mut self)
Unsets SIGCONT.
Sourcepub const fn has_sigstop(self) -> bool
pub const fn has_sigstop(self) -> bool
Returns true if SIGSTOP is present.
Sourcepub const fn contains_sigstop(self) -> bool
pub const fn contains_sigstop(self) -> bool
Returns true if all bits in SIGSTOP are present.
Sourcepub const fn intersects_sigstop(self) -> bool
pub const fn intersects_sigstop(self) -> bool
Returns true if the set shares any bit with SIGSTOP.
Sourcepub const fn with_sigstop(self) -> Self
pub const fn with_sigstop(self) -> Self
Returns self with SIGSTOP inserted.
Sourcepub const fn with_sigstop_if(self, condition: bool) -> Self
pub const fn with_sigstop_if(self, condition: bool) -> Self
Returns self with SIGSTOP inserted if condition is true.
Sourcepub const fn without_sigstop(self) -> Self
pub const fn without_sigstop(self) -> Self
Returns self with SIGSTOP removed.
Sourcepub const fn set_sigstop(&mut self)
pub const fn set_sigstop(&mut self)
Sets SIGSTOP.
Sourcepub const fn set_sigstop_if(&mut self, condition: bool)
pub const fn set_sigstop_if(&mut self, condition: bool)
Sets SIGSTOP if condition is true.
Sourcepub const fn unset_sigstop(&mut self)
pub const fn unset_sigstop(&mut self)
Unsets SIGSTOP.
Sourcepub const fn has_sigtstp(self) -> bool
pub const fn has_sigtstp(self) -> bool
Returns true if SIGTSTP is present.
Sourcepub const fn contains_sigtstp(self) -> bool
pub const fn contains_sigtstp(self) -> bool
Returns true if all bits in SIGTSTP are present.
Sourcepub const fn intersects_sigtstp(self) -> bool
pub const fn intersects_sigtstp(self) -> bool
Returns true if the set shares any bit with SIGTSTP.
Sourcepub const fn with_sigtstp(self) -> Self
pub const fn with_sigtstp(self) -> Self
Returns self with SIGTSTP inserted.
Sourcepub const fn with_sigtstp_if(self, condition: bool) -> Self
pub const fn with_sigtstp_if(self, condition: bool) -> Self
Returns self with SIGTSTP inserted if condition is true.
Sourcepub const fn without_sigtstp(self) -> Self
pub const fn without_sigtstp(self) -> Self
Returns self with SIGTSTP removed.
Sourcepub const fn set_sigtstp(&mut self)
pub const fn set_sigtstp(&mut self)
Sets SIGTSTP.
Sourcepub const fn set_sigtstp_if(&mut self, condition: bool)
pub const fn set_sigtstp_if(&mut self, condition: bool)
Sets SIGTSTP if condition is true.
Sourcepub const fn unset_sigtstp(&mut self)
pub const fn unset_sigtstp(&mut self)
Unsets SIGTSTP.
Sourcepub const fn has_sigttin(self) -> bool
pub const fn has_sigttin(self) -> bool
Returns true if SIGTTIN is present.
Sourcepub const fn contains_sigttin(self) -> bool
pub const fn contains_sigttin(self) -> bool
Returns true if all bits in SIGTTIN are present.
Sourcepub const fn intersects_sigttin(self) -> bool
pub const fn intersects_sigttin(self) -> bool
Returns true if the set shares any bit with SIGTTIN.
Sourcepub const fn with_sigttin(self) -> Self
pub const fn with_sigttin(self) -> Self
Returns self with SIGTTIN inserted.
Sourcepub const fn with_sigttin_if(self, condition: bool) -> Self
pub const fn with_sigttin_if(self, condition: bool) -> Self
Returns self with SIGTTIN inserted if condition is true.
Sourcepub const fn without_sigttin(self) -> Self
pub const fn without_sigttin(self) -> Self
Returns self with SIGTTIN removed.
Sourcepub const fn set_sigttin(&mut self)
pub const fn set_sigttin(&mut self)
Sets SIGTTIN.
Sourcepub const fn set_sigttin_if(&mut self, condition: bool)
pub const fn set_sigttin_if(&mut self, condition: bool)
Sets SIGTTIN if condition is true.
Sourcepub const fn unset_sigttin(&mut self)
pub const fn unset_sigttin(&mut self)
Unsets SIGTTIN.
Sourcepub const fn has_sigttou(self) -> bool
pub const fn has_sigttou(self) -> bool
Returns true if SIGTTOU is present.
Sourcepub const fn contains_sigttou(self) -> bool
pub const fn contains_sigttou(self) -> bool
Returns true if all bits in SIGTTOU are present.
Sourcepub const fn intersects_sigttou(self) -> bool
pub const fn intersects_sigttou(self) -> bool
Returns true if the set shares any bit with SIGTTOU.
Sourcepub const fn with_sigttou(self) -> Self
pub const fn with_sigttou(self) -> Self
Returns self with SIGTTOU inserted.
Sourcepub const fn with_sigttou_if(self, condition: bool) -> Self
pub const fn with_sigttou_if(self, condition: bool) -> Self
Returns self with SIGTTOU inserted if condition is true.
Sourcepub const fn without_sigttou(self) -> Self
pub const fn without_sigttou(self) -> Self
Returns self with SIGTTOU removed.
Sourcepub const fn set_sigttou(&mut self)
pub const fn set_sigttou(&mut self)
Sets SIGTTOU.
Sourcepub const fn set_sigttou_if(&mut self, condition: bool)
pub const fn set_sigttou_if(&mut self, condition: bool)
Sets SIGTTOU if condition is true.
Sourcepub const fn unset_sigttou(&mut self)
pub const fn unset_sigttou(&mut self)
Unsets SIGTTOU.
Sourcepub const fn has_sigurg(self) -> bool
pub const fn has_sigurg(self) -> bool
Returns true if SIGURG is present.
Sourcepub const fn contains_sigurg(self) -> bool
pub const fn contains_sigurg(self) -> bool
Returns true if all bits in SIGURG are present.
Sourcepub const fn intersects_sigurg(self) -> bool
pub const fn intersects_sigurg(self) -> bool
Returns true if the set shares any bit with SIGURG.
Sourcepub const fn with_sigurg(self) -> Self
pub const fn with_sigurg(self) -> Self
Returns self with SIGURG inserted.
Sourcepub const fn with_sigurg_if(self, condition: bool) -> Self
pub const fn with_sigurg_if(self, condition: bool) -> Self
Returns self with SIGURG inserted if condition is true.
Sourcepub const fn without_sigurg(self) -> Self
pub const fn without_sigurg(self) -> Self
Returns self with SIGURG removed.
Sourcepub const fn set_sigurg(&mut self)
pub const fn set_sigurg(&mut self)
Sets SIGURG.
Sourcepub const fn set_sigurg_if(&mut self, condition: bool)
pub const fn set_sigurg_if(&mut self, condition: bool)
Sets SIGURG if condition is true.
Sourcepub const fn unset_sigurg(&mut self)
pub const fn unset_sigurg(&mut self)
Unsets SIGURG.
Sourcepub const fn has_sigxcpu(self) -> bool
pub const fn has_sigxcpu(self) -> bool
Returns true if SIGXCPU is present.
Sourcepub const fn contains_sigxcpu(self) -> bool
pub const fn contains_sigxcpu(self) -> bool
Returns true if all bits in SIGXCPU are present.
Sourcepub const fn intersects_sigxcpu(self) -> bool
pub const fn intersects_sigxcpu(self) -> bool
Returns true if the set shares any bit with SIGXCPU.
Sourcepub const fn with_sigxcpu(self) -> Self
pub const fn with_sigxcpu(self) -> Self
Returns self with SIGXCPU inserted.
Sourcepub const fn with_sigxcpu_if(self, condition: bool) -> Self
pub const fn with_sigxcpu_if(self, condition: bool) -> Self
Returns self with SIGXCPU inserted if condition is true.
Sourcepub const fn without_sigxcpu(self) -> Self
pub const fn without_sigxcpu(self) -> Self
Returns self with SIGXCPU removed.
Sourcepub const fn set_sigxcpu(&mut self)
pub const fn set_sigxcpu(&mut self)
Sets SIGXCPU.
Sourcepub const fn set_sigxcpu_if(&mut self, condition: bool)
pub const fn set_sigxcpu_if(&mut self, condition: bool)
Sets SIGXCPU if condition is true.
Sourcepub const fn unset_sigxcpu(&mut self)
pub const fn unset_sigxcpu(&mut self)
Unsets SIGXCPU.
Sourcepub const fn has_sigxfsz(self) -> bool
pub const fn has_sigxfsz(self) -> bool
Returns true if SIGXFSZ is present.
Sourcepub const fn contains_sigxfsz(self) -> bool
pub const fn contains_sigxfsz(self) -> bool
Returns true if all bits in SIGXFSZ are present.
Sourcepub const fn intersects_sigxfsz(self) -> bool
pub const fn intersects_sigxfsz(self) -> bool
Returns true if the set shares any bit with SIGXFSZ.
Sourcepub const fn with_sigxfsz(self) -> Self
pub const fn with_sigxfsz(self) -> Self
Returns self with SIGXFSZ inserted.
Sourcepub const fn with_sigxfsz_if(self, condition: bool) -> Self
pub const fn with_sigxfsz_if(self, condition: bool) -> Self
Returns self with SIGXFSZ inserted if condition is true.
Sourcepub const fn without_sigxfsz(self) -> Self
pub const fn without_sigxfsz(self) -> Self
Returns self with SIGXFSZ removed.
Sourcepub const fn set_sigxfsz(&mut self)
pub const fn set_sigxfsz(&mut self)
Sets SIGXFSZ.
Sourcepub const fn set_sigxfsz_if(&mut self, condition: bool)
pub const fn set_sigxfsz_if(&mut self, condition: bool)
Sets SIGXFSZ if condition is true.
Sourcepub const fn unset_sigxfsz(&mut self)
pub const fn unset_sigxfsz(&mut self)
Unsets SIGXFSZ.
Sourcepub const fn has_sigvtalrm(self) -> bool
pub const fn has_sigvtalrm(self) -> bool
Returns true if SIGVTALRM is present.
Sourcepub const fn contains_sigvtalrm(self) -> bool
pub const fn contains_sigvtalrm(self) -> bool
Returns true if all bits in SIGVTALRM are present.
Sourcepub const fn intersects_sigvtalrm(self) -> bool
pub const fn intersects_sigvtalrm(self) -> bool
Returns true if the set shares any bit with SIGVTALRM.
Sourcepub const fn with_sigvtalrm(self) -> Self
pub const fn with_sigvtalrm(self) -> Self
Returns self with SIGVTALRM inserted.
Sourcepub const fn with_sigvtalrm_if(self, condition: bool) -> Self
pub const fn with_sigvtalrm_if(self, condition: bool) -> Self
Returns self with SIGVTALRM inserted if condition is true.
Sourcepub const fn without_sigvtalrm(self) -> Self
pub const fn without_sigvtalrm(self) -> Self
Returns self with SIGVTALRM removed.
Sourcepub const fn set_sigvtalrm(&mut self)
pub const fn set_sigvtalrm(&mut self)
Sets SIGVTALRM.
Sourcepub const fn set_sigvtalrm_if(&mut self, condition: bool)
pub const fn set_sigvtalrm_if(&mut self, condition: bool)
Sets SIGVTALRM if condition is true.
Sourcepub const fn unset_sigvtalrm(&mut self)
pub const fn unset_sigvtalrm(&mut self)
Unsets SIGVTALRM.
Sourcepub const fn has_sigprof(self) -> bool
pub const fn has_sigprof(self) -> bool
Returns true if SIGPROF is present.
Sourcepub const fn contains_sigprof(self) -> bool
pub const fn contains_sigprof(self) -> bool
Returns true if all bits in SIGPROF are present.
Sourcepub const fn intersects_sigprof(self) -> bool
pub const fn intersects_sigprof(self) -> bool
Returns true if the set shares any bit with SIGPROF.
Sourcepub const fn with_sigprof(self) -> Self
pub const fn with_sigprof(self) -> Self
Returns self with SIGPROF inserted.
Sourcepub const fn with_sigprof_if(self, condition: bool) -> Self
pub const fn with_sigprof_if(self, condition: bool) -> Self
Returns self with SIGPROF inserted if condition is true.
Sourcepub const fn without_sigprof(self) -> Self
pub const fn without_sigprof(self) -> Self
Returns self with SIGPROF removed.
Sourcepub const fn set_sigprof(&mut self)
pub const fn set_sigprof(&mut self)
Sets SIGPROF.
Sourcepub const fn set_sigprof_if(&mut self, condition: bool)
pub const fn set_sigprof_if(&mut self, condition: bool)
Sets SIGPROF if condition is true.
Sourcepub const fn unset_sigprof(&mut self)
pub const fn unset_sigprof(&mut self)
Unsets SIGPROF.
Sourcepub const fn has_sigwinch(self) -> bool
pub const fn has_sigwinch(self) -> bool
Returns true if SIGWINCH is present.
Sourcepub const fn contains_sigwinch(self) -> bool
pub const fn contains_sigwinch(self) -> bool
Returns true if all bits in SIGWINCH are present.
Sourcepub const fn intersects_sigwinch(self) -> bool
pub const fn intersects_sigwinch(self) -> bool
Returns true if the set shares any bit with SIGWINCH.
Sourcepub const fn with_sigwinch(self) -> Self
pub const fn with_sigwinch(self) -> Self
Returns self with SIGWINCH inserted.
Sourcepub const fn with_sigwinch_if(self, condition: bool) -> Self
pub const fn with_sigwinch_if(self, condition: bool) -> Self
Returns self with SIGWINCH inserted if condition is true.
Sourcepub const fn without_sigwinch(self) -> Self
pub const fn without_sigwinch(self) -> Self
Returns self with SIGWINCH removed.
Sourcepub const fn set_sigwinch(&mut self)
pub const fn set_sigwinch(&mut self)
Sets SIGWINCH.
Sourcepub const fn set_sigwinch_if(&mut self, condition: bool)
pub const fn set_sigwinch_if(&mut self, condition: bool)
Sets SIGWINCH if condition is true.
Sourcepub const fn unset_sigwinch(&mut self)
pub const fn unset_sigwinch(&mut self)
Unsets SIGWINCH.
Sourcepub const fn contains_sigio(self) -> bool
pub const fn contains_sigio(self) -> bool
Returns true if all bits in SIGIO are present.
Sourcepub const fn intersects_sigio(self) -> bool
pub const fn intersects_sigio(self) -> bool
Returns true if the set shares any bit with SIGIO.
Sourcepub const fn with_sigio(self) -> Self
pub const fn with_sigio(self) -> Self
Returns self with SIGIO inserted.
Sourcepub const fn with_sigio_if(self, condition: bool) -> Self
pub const fn with_sigio_if(self, condition: bool) -> Self
Returns self with SIGIO inserted if condition is true.
Sourcepub const fn without_sigio(self) -> Self
pub const fn without_sigio(self) -> Self
Returns self with SIGIO removed.
Sourcepub const fn set_sigio_if(&mut self, condition: bool)
pub const fn set_sigio_if(&mut self, condition: bool)
Sets SIGIO if condition is true.
Sourcepub const fn unset_sigio(&mut self)
pub const fn unset_sigio(&mut self)
Unsets SIGIO.
Sourcepub const fn has_sigpwr(self) -> bool
pub const fn has_sigpwr(self) -> bool
Returns true if SIGPWR is present.
Sourcepub const fn contains_sigpwr(self) -> bool
pub const fn contains_sigpwr(self) -> bool
Returns true if all bits in SIGPWR are present.
Sourcepub const fn intersects_sigpwr(self) -> bool
pub const fn intersects_sigpwr(self) -> bool
Returns true if the set shares any bit with SIGPWR.
Sourcepub const fn with_sigpwr(self) -> Self
pub const fn with_sigpwr(self) -> Self
Returns self with SIGPWR inserted.
Sourcepub const fn with_sigpwr_if(self, condition: bool) -> Self
pub const fn with_sigpwr_if(self, condition: bool) -> Self
Returns self with SIGPWR inserted if condition is true.
Sourcepub const fn without_sigpwr(self) -> Self
pub const fn without_sigpwr(self) -> Self
Returns self with SIGPWR removed.
Sourcepub const fn set_sigpwr(&mut self)
pub const fn set_sigpwr(&mut self)
Sets SIGPWR.
Sourcepub const fn set_sigpwr_if(&mut self, condition: bool)
pub const fn set_sigpwr_if(&mut self, condition: bool)
Sets SIGPWR if condition is true.
Sourcepub const fn unset_sigpwr(&mut self)
pub const fn unset_sigpwr(&mut self)
Unsets SIGPWR.
Sourcepub const fn has_sigsys(self) -> bool
pub const fn has_sigsys(self) -> bool
Returns true if SIGSYS is present.
Sourcepub const fn contains_sigsys(self) -> bool
pub const fn contains_sigsys(self) -> bool
Returns true if all bits in SIGSYS are present.
Sourcepub const fn intersects_sigsys(self) -> bool
pub const fn intersects_sigsys(self) -> bool
Returns true if the set shares any bit with SIGSYS.
Sourcepub const fn with_sigsys(self) -> Self
pub const fn with_sigsys(self) -> Self
Returns self with SIGSYS inserted.
Sourcepub const fn with_sigsys_if(self, condition: bool) -> Self
pub const fn with_sigsys_if(self, condition: bool) -> Self
Returns self with SIGSYS inserted if condition is true.
Sourcepub const fn without_sigsys(self) -> Self
pub const fn without_sigsys(self) -> Self
Returns self with SIGSYS removed.
Sourcepub const fn set_sigsys(&mut self)
pub const fn set_sigsys(&mut self)
Sets SIGSYS.
Sourcepub const fn set_sigsys_if(&mut self, condition: bool)
pub const fn set_sigsys_if(&mut self, condition: bool)
Sets SIGSYS if condition is true.
Sourcepub const fn unset_sigsys(&mut self)
pub const fn unset_sigsys(&mut self)
Unsets SIGSYS.
Sourceimpl LinuxSignalSet
Common set methods
impl LinuxSignalSet
Common set methods
Sourceimpl LinuxSignalSet
Set operations
impl LinuxSignalSet
Set operations
Sourcepub const fn intersects(self, other: Self) -> bool
pub const fn intersects(self, other: Self) -> bool
Returns true if self and other share any bit.
Sourcepub const fn is_subset(self, other: Self) -> bool
pub const fn is_subset(self, other: Self) -> bool
Returns true if all bits in self are also set in other.
Sourcepub const fn is_superset(self, other: Self) -> bool
pub const fn is_superset(self, other: Self) -> bool
Returns true if all bits in other are also set in self.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection of self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference of self and other.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference of self and other.
Sourceimpl LinuxSignalSet
Mutating set operations
impl LinuxSignalSet
Mutating set operations