pub struct ThreadScope<'scope, 'env>where
'env: 'scope,{ /* private fields */ }std only.Expand description
🧵
std
A scope to spawn scoped threads in.
📍work/thread re-exported from std::thread ::Scope as ThreadScope
📜
A scope to spawn scoped threads in.
See scope for details.
Implementations
Sourceimpl<'scope, 'env> Scope<'scope, 'env>
impl<'scope, 'env> Scope<'scope, 'env>
1.63.0 · Sourcepub fn spawn<F, T>(&'scope self, f: F) -> ScopedJoinHandle<'scope, T>
pub fn spawn<F, T>(&'scope self, f: F) -> ScopedJoinHandle<'scope, T>
Spawns a new thread within a scope, returning a ScopedJoinHandle for it.
Unlike non-scoped threads, threads spawned with this function may
borrow non-'static data from outside the scope. See scope for
details.
The join handle provides a join method that can be used to join the spawned
thread. If the spawned thread panics, join will return an Err containing
the panic payload.
If the join handle is dropped, the spawned thread will be implicitly joined at the
end of the scope. In that case, if the spawned thread panics, scope will
panic after all threads are joined.
This function creates a thread with the default parameters of Builder.
To specify the new thread’s stack size or the name, use Builder::spawn_scoped.
Panics
Panics if the OS fails to create a thread; use Builder::spawn_scoped
to recover from such errors.