pub enum HashMapEntry<'a, K, V, S, A = Global>where
A: Allocator,{
Occupied(OccupiedEntry<'a, K, V, S, A>),
Vacant(VacantEntry<'a, K, V, S, A>),
}dep_hashbrown or std only.Expand description
๐๏ธ ๐
โกstd
A view into a single entry in a map, which may either be vacant or occupied.
๐ data/id
Re-exported from either the hashmap crate
or from std::collections.
A view into a single entry in a map, which may either be vacant or occupied.
This enum is constructed from the entry method on HashMap.
Examples
use hashbrown::hash_map::{Entry, HashMap, OccupiedEntry};
let mut map = HashMap::new();
map.extend([("a", 10), ("b", 20), ("c", 30)]);
assert_eq!(map.len(), 3);
// Existing key (insert)
let entry: Entry<_, _, _> = map.entry("a");
let _raw_o: OccupiedEntry<_, _, _> = entry.insert(1);
assert_eq!(map.len(), 3);
// Nonexistent key (insert)
map.entry("d").insert(4);
// Existing key (or_insert)
let v = map.entry("b").or_insert(2);
assert_eq!(std::mem::replace(v, 2), 20);
// Nonexistent key (or_insert)
map.entry("e").or_insert(5);
// Existing key (or_insert_with)
let v = map.entry("c").or_insert_with(|| 3);
assert_eq!(std::mem::replace(v, 3), 30);
// Nonexistent key (or_insert_with)
map.entry("f").or_insert_with(|| 6);
println!("Our HashMap: {:?}", map);
let mut vec: Vec<_> = map.iter().map(|(&k, &v)| (k, v)).collect();
// The `Iter` iterator produces items in arbitrary order, so the
// items must be sorted to test them against a sorted array.
vec.sort_unstable();
assert_eq!(vec, [("a", 1), ("b", 2), ("c", 3), ("d", 4), ("e", 5), ("f", 6)]);Variants
Occupied(OccupiedEntry<'a, K, V, S, A>)
An occupied entry.
Examples
use hashbrown::hash_map::{Entry, HashMap};
let mut map: HashMap<_, _> = [("a", 100), ("b", 200)].into();
match map.entry("a") {
Entry::Vacant(_) => unreachable!(),
Entry::Occupied(_) => { }
}Vacant(VacantEntry<'a, K, V, S, A>)
A vacant entry.
Examples
use hashbrown::hash_map::{Entry, HashMap};
let mut map: HashMap<&str, i32> = HashMap::new();
match map.entry("a") {
Entry::Occupied(_) => unreachable!(),
Entry::Vacant(_) => { }
}Implementations
Sourceimpl<'a, K, V, S, A> Entry<'a, K, V, S, A>where
A: Allocator,
impl<'a, K, V, S, A> Entry<'a, K, V, S, A>where
A: Allocator,
Sourcepub fn insert(self, value: V) -> OccupiedEntry<'a, K, V, S, A>where
K: Hash,
S: BuildHasher,
pub fn insert(self, value: V) -> OccupiedEntry<'a, K, V, S, A>where
K: Hash,
S: BuildHasher,
Sets the value of the entry, and returns an OccupiedEntry.
Examples
use hashbrown::HashMap;
let mut map: HashMap<&str, u32> = HashMap::new();
let entry = map.entry("horseyland").insert(37);
assert_eq!(entry.key(), &"horseyland");Sourcepub fn or_insert(self, default: V) -> &'a mut Vwhere
K: Hash,
S: BuildHasher,
pub fn or_insert(self, default: V) -> &'a mut Vwhere
K: Hash,
S: BuildHasher,
Ensures a value is in the entry by inserting the default if empty, and returns a mutable reference to the value in the entry.
Examples
use hashbrown::HashMap;
let mut map: HashMap<&str, u32> = HashMap::new();
// nonexistent key
map.entry("poneyland").or_insert(3);
assert_eq!(map["poneyland"], 3);
// existing key
*map.entry("poneyland").or_insert(10) *= 2;
assert_eq!(map["poneyland"], 6);Sourcepub fn or_insert_entry(self, default: V) -> OccupiedEntry<'a, K, V, S, A>where
K: Hash,
S: BuildHasher,
pub fn or_insert_entry(self, default: V) -> OccupiedEntry<'a, K, V, S, A>where
K: Hash,
S: BuildHasher,
Ensures a value is in the entry by inserting the default if empty,
and returns an OccupiedEntry.
Examples
use hashbrown::HashMap;
let mut map: HashMap<&str, u32> = HashMap::new();
// nonexistent key
let entry = map.entry("poneyland").or_insert_entry(3);
assert_eq!(entry.key(), &"poneyland");
assert_eq!(entry.get(), &3);
// existing key
let mut entry = map.entry("poneyland").or_insert_entry(10);
assert_eq!(entry.key(), &"poneyland");
assert_eq!(entry.get(), &3);Sourcepub fn or_insert_with<F>(self, default: F) -> &'a mut V
pub fn or_insert_with<F>(self, default: F) -> &'a mut V
Ensures a value is in the entry by inserting the result of the default function if empty, and returns a mutable reference to the value in the entry.
Examples
use hashbrown::HashMap;
let mut map: HashMap<&str, u32> = HashMap::new();
// nonexistent key
map.entry("poneyland").or_insert_with(|| 3);
assert_eq!(map["poneyland"], 3);
// existing key
*map.entry("poneyland").or_insert_with(|| 10) *= 2;
assert_eq!(map["poneyland"], 6);Sourcepub fn or_insert_with_key<F>(self, default: F) -> &'a mut V
pub fn or_insert_with_key<F>(self, default: F) -> &'a mut V
Ensures a value is in the entry by inserting, if empty, the result of the default function.
This method allows for generating key-derived values for insertion by providing the default
function a reference to the key that was moved during the .entry(key) method call.
The reference to the moved key is provided so that cloning or copying the key is
unnecessary, unlike with .or_insert_with(|| ... ).
Examples
use hashbrown::HashMap;
let mut map: HashMap<&str, usize> = HashMap::new();
// nonexistent key
map.entry("poneyland").or_insert_with_key(|key| key.chars().count());
assert_eq!(map["poneyland"], 9);
// existing key
*map.entry("poneyland").or_insert_with_key(|key| key.chars().count() * 10) *= 2;
assert_eq!(map["poneyland"], 18);Sourcepub fn key(&self) -> &K
pub fn key(&self) -> &K
Returns a reference to this entryโs key.
Examples
use hashbrown::HashMap;
let mut map: HashMap<&str, u32> = HashMap::new();
map.entry("poneyland").or_insert(3);
// existing key
assert_eq!(map.entry("poneyland").key(), &"poneyland");
// nonexistent key
assert_eq!(map.entry("horseland").key(), &"horseland");Sourcepub fn and_modify<F>(self, f: F) -> Entry<'a, K, V, S, A>
pub fn and_modify<F>(self, f: F) -> Entry<'a, K, V, S, A>
Provides in-place mutable access to an occupied entry before any potential inserts into the map.
Examples
use hashbrown::HashMap;
let mut map: HashMap<&str, u32> = HashMap::new();
map.entry("poneyland")
.and_modify(|e| { *e += 1 })
.or_insert(42);
assert_eq!(map["poneyland"], 42);
map.entry("poneyland")
.and_modify(|e| { *e += 1 })
.or_insert(42);
assert_eq!(map["poneyland"], 43);Sourcepub fn and_replace_entry_with<F>(self, f: F) -> Entry<'a, K, V, S, A>
pub fn and_replace_entry_with<F>(self, f: F) -> Entry<'a, K, V, S, A>
Provides shared access to the key and owned access to the value of an occupied entry and allows to replace or remove it based on the value of the returned option.
Examples
use hashbrown::HashMap;
use hashbrown::hash_map::Entry;
let mut map: HashMap<&str, u32> = HashMap::new();
let entry = map
.entry("poneyland")
.and_replace_entry_with(|_k, _v| panic!());
match entry {
Entry::Vacant(e) => {
assert_eq!(e.key(), &"poneyland");
}
Entry::Occupied(_) => panic!(),
}
map.insert("poneyland", 42);
let entry = map
.entry("poneyland")
.and_replace_entry_with(|k, v| {
assert_eq!(k, &"poneyland");
assert_eq!(v, 42);
Some(v + 1)
});
match entry {
Entry::Occupied(e) => {
assert_eq!(e.key(), &"poneyland");
assert_eq!(e.get(), &43);
}
Entry::Vacant(_) => panic!(),
}
assert_eq!(map["poneyland"], 43);
let entry = map
.entry("poneyland")
.and_replace_entry_with(|_k, _v| None);
match entry {
Entry::Vacant(e) => assert_eq!(e.key(), &"poneyland"),
Entry::Occupied(_) => panic!(),
}
assert!(!map.contains_key("poneyland"));Sourceimpl<'a, K, V, S, A> Entry<'a, K, V, S, A>where
V: Default,
A: Allocator,
impl<'a, K, V, S, A> Entry<'a, K, V, S, A>where
V: Default,
A: Allocator,
Sourcepub fn or_default(self) -> &'a mut Vwhere
K: Hash,
S: BuildHasher,
pub fn or_default(self) -> &'a mut Vwhere
K: Hash,
S: BuildHasher,
Ensures a value is in the entry by inserting the default value if empty, and returns a mutable reference to the value in the entry.
Examples
use hashbrown::HashMap;
let mut map: HashMap<&str, Option<u32>> = HashMap::new();
// nonexistent key
map.entry("poneyland").or_default();
assert_eq!(map["poneyland"], None);
map.insert("horseland", Some(3));
// existing key
assert_eq!(map.entry("horseland").or_default(), &mut Some(3));Trait Implementations