pub struct CacheAlign<T> { /* private fields */ }Expand description
๐ซ Aligns and pads a value to the length of a cache line.
๐ sys/mem
In concurrent programming, sometimes it is desirable to make sure commonly accessed pieces of
data are not placed into the same cache line. Updating an atomic value invalidates the whole
cache line it belongs to, which makes the next access to the same cache line slower for other
CPU cores. Use CacheAlign to ensure updating one piece of data doesnโt invalidate other
cached data.
Size and alignment
Cache lines are assumed to be N bytes long, depending on the architecture:
- On x86-64, aarch64, and powerpc64, N = 128.
- On arm, mips, mips64, sparc, and hexagon, N = 32.
- On m68k, N = 16.
- On s390x, N = 256.
- On all others, N = 64.
Note that N is just a reasonable guess and is not guaranteed to match the actual cache line length of the machine the program is running on. On modern Intel architectures, spatial prefetcher is pulling pairs of 64-byte cache lines at a time, so we pessimistically assume that cache lines are 128 bytes long.
The size of CacheAlign<T> is the smallest multiple of N bytes large enough to accommodate
a value of type T.
The alignment of CacheAlign<T> is the maximum of N bytes and the alignment of T.
Examples
Alignment and padding:
let array = [CacheAlign::new(1i8), CacheAlign::new(2i8)];
let addr1 = &*array[0] as *const i8 as usize;
let addr2 = &*array[1] as *const i8 as usize;
assert!(addr2 - addr1 >= 32);
assert_eq!(addr1 % 32, 0);
assert_eq!(addr2 % 32, 0);When building a concurrent queue with a head and a tail index, it is wise to place them in different cache lines so that concurrent threads pushing and popping elements donโt invalidate each otherโs cache lines:
struct Queue<T> {
head: CacheAlign<AtomicUsize>,
tail: CacheAlign<AtomicUsize>,
buffer: *mut T,
}Vendored
This is adapted work from crossbeam-utils.
Implementations
Sourceimpl<T> CacheAlign<T>
impl<T> CacheAlign<T>
Sourcepub const fn new(t: T) -> CacheAlign<T>
pub const fn new(t: T) -> CacheAlign<T>
Pads and aligns a value to the length of a cache line.
let padded_value = CacheAlign::new(1);Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
The inner value.
let padded_value = CacheAlign::new(7);
let value = padded_value.into_inner();
assert_eq!(value, 7);Sourcepub const fn into_inner_copy(self) -> Twhere
Self: Copy,
pub const fn into_inner_copy(self) -> Twhere
Self: Copy,
A copy of the inner value, in compile-time.