pub struct EventTagSet { /* private fields */ }event only.Expand description
Implementations
Sourceimpl EventTagSet
Common event category groups.
impl EventTagSet
Common event category groups.
Sourceimpl EventTagSet
Named constants
impl EventTagSet
Named constants
Sourceimpl EventTagSet
Convenience methods derived from each named constant.
impl EventTagSet
Convenience methods derived from each named constant.
Sourcepub const fn contains_none(self) -> bool
pub const fn contains_none(self) -> bool
Returns true if all bits in None are present.
Sourcepub const fn intersects_none(self) -> bool
pub const fn intersects_none(self) -> bool
Returns true if the set shares any bit with None.
Sourcepub const fn with_none_if(self, condition: bool) -> Self
pub const fn with_none_if(self, condition: bool) -> Self
Returns self with None inserted if condition is true.
Sourcepub const fn without_none(self) -> Self
pub const fn without_none(self) -> Self
Returns self with None removed.
Sourcepub const fn set_none_if(&mut self, condition: bool)
pub const fn set_none_if(&mut self, condition: bool)
Sets None if condition is true.
Sourcepub const fn unset_none(&mut self)
pub const fn unset_none(&mut self)
Unsets None.
Sourcepub const fn contains_key(self) -> bool
pub const fn contains_key(self) -> bool
Returns true if all bits in Key are present.
Sourcepub const fn intersects_key(self) -> bool
pub const fn intersects_key(self) -> bool
Returns true if the set shares any bit with Key.
Sourcepub const fn with_key_if(self, condition: bool) -> Self
pub const fn with_key_if(self, condition: bool) -> Self
Returns self with Key inserted if condition is true.
Sourcepub const fn without_key(self) -> Self
pub const fn without_key(self) -> Self
Returns self with Key removed.
Sourcepub const fn set_key_if(&mut self, condition: bool)
pub const fn set_key_if(&mut self, condition: bool)
Sets Key if condition is true.
Sourcepub const fn contains_mouse(self) -> bool
pub const fn contains_mouse(self) -> bool
Returns true if all bits in Mouse are present.
Sourcepub const fn intersects_mouse(self) -> bool
pub const fn intersects_mouse(self) -> bool
Returns true if the set shares any bit with Mouse.
Sourcepub const fn with_mouse(self) -> Self
pub const fn with_mouse(self) -> Self
Returns self with Mouse inserted.
Sourcepub const fn with_mouse_if(self, condition: bool) -> Self
pub const fn with_mouse_if(self, condition: bool) -> Self
Returns self with Mouse inserted if condition is true.
Sourcepub const fn without_mouse(self) -> Self
pub const fn without_mouse(self) -> Self
Returns self with Mouse removed.
Sourcepub const fn set_mouse_if(&mut self, condition: bool)
pub const fn set_mouse_if(&mut self, condition: bool)
Sets Mouse if condition is true.
Sourcepub const fn unset_mouse(&mut self)
pub const fn unset_mouse(&mut self)
Unsets Mouse.
Sourcepub const fn has_pointer(self) -> bool
pub const fn has_pointer(self) -> bool
Returns true if Pointer is present.
Sourcepub const fn contains_pointer(self) -> bool
pub const fn contains_pointer(self) -> bool
Returns true if all bits in Pointer are present.
Sourcepub const fn intersects_pointer(self) -> bool
pub const fn intersects_pointer(self) -> bool
Returns true if the set shares any bit with Pointer.
Sourcepub const fn with_pointer(self) -> Self
pub const fn with_pointer(self) -> Self
Returns self with Pointer inserted.
Sourcepub const fn with_pointer_if(self, condition: bool) -> Self
pub const fn with_pointer_if(self, condition: bool) -> Self
Returns self with Pointer inserted if condition is true.
Sourcepub const fn without_pointer(self) -> Self
pub const fn without_pointer(self) -> Self
Returns self with Pointer removed.
Sourcepub const fn set_pointer(&mut self)
pub const fn set_pointer(&mut self)
Sets Pointer.
Sourcepub const fn set_pointer_if(&mut self, condition: bool)
pub const fn set_pointer_if(&mut self, condition: bool)
Sets Pointer if condition is true.
Sourcepub const fn unset_pointer(&mut self)
pub const fn unset_pointer(&mut self)
Unsets Pointer.
Sourcepub const fn contains_wheel(self) -> bool
pub const fn contains_wheel(self) -> bool
Returns true if all bits in Wheel are present.
Sourcepub const fn intersects_wheel(self) -> bool
pub const fn intersects_wheel(self) -> bool
Returns true if the set shares any bit with Wheel.
Sourcepub const fn with_wheel(self) -> Self
pub const fn with_wheel(self) -> Self
Returns self with Wheel inserted.
Sourcepub const fn with_wheel_if(self, condition: bool) -> Self
pub const fn with_wheel_if(self, condition: bool) -> Self
Returns self with Wheel inserted if condition is true.
Sourcepub const fn without_wheel(self) -> Self
pub const fn without_wheel(self) -> Self
Returns self with Wheel removed.
Sourcepub const fn set_wheel_if(&mut self, condition: bool)
pub const fn set_wheel_if(&mut self, condition: bool)
Sets Wheel if condition is true.
Sourcepub const fn unset_wheel(&mut self)
pub const fn unset_wheel(&mut self)
Unsets Wheel.
Sourcepub const fn has_window(self) -> bool
pub const fn has_window(self) -> bool
Returns true if Window is present.
Sourcepub const fn contains_window(self) -> bool
pub const fn contains_window(self) -> bool
Returns true if all bits in Window are present.
Sourcepub const fn intersects_window(self) -> bool
pub const fn intersects_window(self) -> bool
Returns true if the set shares any bit with Window.
Sourcepub const fn with_window(self) -> Self
pub const fn with_window(self) -> Self
Returns self with Window inserted.
Sourcepub const fn with_window_if(self, condition: bool) -> Self
pub const fn with_window_if(self, condition: bool) -> Self
Returns self with Window inserted if condition is true.
Sourcepub const fn without_window(self) -> Self
pub const fn without_window(self) -> Self
Returns self with Window removed.
Sourcepub const fn set_window(&mut self)
pub const fn set_window(&mut self)
Sets Window.
Sourcepub const fn set_window_if(&mut self, condition: bool)
pub const fn set_window_if(&mut self, condition: bool)
Sets Window if condition is true.
Sourcepub const fn unset_window(&mut self)
pub const fn unset_window(&mut self)
Unsets Window.
Sourcepub const fn has_control(self) -> bool
pub const fn has_control(self) -> bool
Returns true if Control is present.
Sourcepub const fn contains_control(self) -> bool
pub const fn contains_control(self) -> bool
Returns true if all bits in Control are present.
Sourcepub const fn intersects_control(self) -> bool
pub const fn intersects_control(self) -> bool
Returns true if the set shares any bit with Control.
Sourcepub const fn with_control(self) -> Self
pub const fn with_control(self) -> Self
Returns self with Control inserted.
Sourcepub const fn with_control_if(self, condition: bool) -> Self
pub const fn with_control_if(self, condition: bool) -> Self
Returns self with Control inserted if condition is true.
Sourcepub const fn without_control(self) -> Self
pub const fn without_control(self) -> Self
Returns self with Control removed.
Sourcepub const fn set_control(&mut self)
pub const fn set_control(&mut self)
Sets Control.
Sourcepub const fn set_control_if(&mut self, condition: bool)
pub const fn set_control_if(&mut self, condition: bool)
Sets Control if condition is true.
Sourcepub const fn unset_control(&mut self)
pub const fn unset_control(&mut self)
Unsets Control.
Sourceimpl EventTagSet
Common set methods
impl EventTagSet
Common set methods
Sourceimpl EventTagSet
Set operations
impl EventTagSet
Set operations
Sourcepub const fn intersects(self, other: Self) -> bool
pub const fn intersects(self, other: Self) -> bool
Returns true if self and other share any bit.
Sourcepub const fn is_subset(self, other: Self) -> bool
pub const fn is_subset(self, other: Self) -> bool
Returns true if all bits in self are also set in other.
Sourcepub const fn is_superset(self, other: Self) -> bool
pub const fn is_superset(self, other: Self) -> bool
Returns true if all bits in other are also set in self.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection of self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference of self and other.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference of self and other.
Sourceimpl EventTagSet
Mutating set operations
impl EventTagSet
Mutating set operations