pub struct IdSeqUsizeExample { /* private fields */ }doc or test only.Expand description
✨ 🏗️
A unique sequential identifier usize generator.
The counter starts at usize::MIN + 1,
and increments with each new identifier generated.
The implementation guards against wrap-around
after usize::MAX,
by returning None in the checked methods, or panicking in the unchecked methods.
See also the id_seq macro.
Implementations
Sourceimpl IdSeqUsizeExample
impl IdSeqUsizeExample
Sourcepub fn new_unchecked() -> Self
pub fn new_unchecked() -> Self
Generates some unique IdSeqUsizeExample ID.
Alias of new_balanced_unchecked.
Panics
Panics on overflow.
Sourcepub fn new_strong() -> Option<Self> ⓘ
pub fn new_strong() -> Option<Self> ⓘ
Generates some unique IdSeqUsizeExample ID with SeqCst ordering.
Ensures the strongest memory consistency across all threads, even at the cost of performance.
Returns None on overflow.
Sourcepub fn new_strong_unchecked() -> Self
pub fn new_strong_unchecked() -> Self
Sourcepub fn new_balanced() -> Option<Self> ⓘ
pub fn new_balanced() -> Option<Self> ⓘ
Generates some unique IdSeqUsizeExample ID with AcqRel ordering.
Balances performance and memory safety, ensuring consistent visibility across threads.
Returns None on overflow.
Sourcepub fn new_balanced_unchecked() -> Self
pub fn new_balanced_unchecked() -> Self
Sourcepub fn new_fast() -> Option<Self> ⓘ
pub fn new_fast() -> Option<Self> ⓘ
Generates some unique IdSeqUsizeExample ID with Relaxed ordering.
Offers maximum performance in low-contention scenarios where memory ordering is not a concern.
Returns None on overflow.
Sourcepub fn new_fast_unchecked() -> Self
pub fn new_fast_unchecked() -> Self
Sourcepub fn iter_strong() -> impl Iterator<Item = IdSeqUsizeExample>
pub fn iter_strong() -> impl Iterator<Item = IdSeqUsizeExample>
Iterator over generated IDs with SeqCst ordering.
Ensures the strongest memory consistency across all threads, even at the cost of performance.
Sourcepub fn iter_strong_unchecked() -> impl Iterator<Item = IdSeqUsizeExample>
pub fn iter_strong_unchecked() -> impl Iterator<Item = IdSeqUsizeExample>
Iterator over generated IDs with SeqCst ordering.
Ensures the strongest memory consistency across all threads, even at the cost of performance.
Panics
Panics on overflow.
Sourcepub fn iter_balanced() -> impl Iterator<Item = IdSeqUsizeExample>
pub fn iter_balanced() -> impl Iterator<Item = IdSeqUsizeExample>
Iterator over generated IDs with AcqRel ordering.
Balances performance and memory safety, ensuring consistent visibility across threads.
Sourcepub fn iter_balanced_unchecked() -> impl Iterator<Item = IdSeqUsizeExample>
pub fn iter_balanced_unchecked() -> impl Iterator<Item = IdSeqUsizeExample>
Iterator over generated IDs with AcqRel ordering.
Balances performance and memory safety, ensuring consistent visibility across threads.
Panics
Panics on overflow.
Sourcepub fn iter_fast() -> impl Iterator<Item = IdSeqUsizeExample>
pub fn iter_fast() -> impl Iterator<Item = IdSeqUsizeExample>
Iterator over generated IDs with Relaxed ordering.
Offers maximum performance in low-contention scenarios where memory ordering is not a concern.
Sourcepub fn iter_fast_unchecked() -> impl Iterator<Item = IdSeqUsizeExample>
pub fn iter_fast_unchecked() -> impl Iterator<Item = IdSeqUsizeExample>
Iterator over generated IDs with Relaxed ordering.
Offers maximum performance in low-contention scenarios where memory ordering is not a concern.
Panics
Panics on overflow.
Sourcepub fn value(&self) -> usize
pub fn value(&self) -> usize
Returns the underlying unique ID value
as a usize.
The value is guaranteed to be a valid sequential identifier, from
usize::MIN to usize::MAX.
Sourcepub fn generated_ids() -> usize
pub fn generated_ids() -> usize
Returns the number of IDs generated so far.
Alias of generated_ids_balanced.
Sourcepub fn generated_ids_strong() -> usize
pub fn generated_ids_strong() -> usize
Returns the number of IDs generated so far with SeqCst ordering.
Ensures the strongest memory consistency across all threads, even at the cost of performance.
Sourcepub fn generated_ids_balanced() -> usize
pub fn generated_ids_balanced() -> usize
Returns the number of IDs generated so far with Acquire ordering.
Balances performance and memory safety, ensuring consistent visibility across threads.
Sourcepub fn generated_ids_fast() -> usize
pub fn generated_ids_fast() -> usize
Returns the number of IDs generated so far with Relaxed ordering.
Offers maximum performance in low-contention scenarios where memory ordering is not a concern.
Sourcepub fn remaining_ids() -> usize
pub fn remaining_ids() -> usize
Returns the number of remaining IDs.
Alias of remaining_ids_balanced.
Sourcepub fn remaining_ids_strong() -> usize
pub fn remaining_ids_strong() -> usize
Returns the number of remaining IDs with SeqCst ordering.
Ensures the strongest memory consistency across all threads, even at the cost of performance.
Sourcepub fn remaining_ids_balanced() -> usize
pub fn remaining_ids_balanced() -> usize
Returns the number of remaining IDs with Acquire ordering.
Balances performance and memory safety, ensuring consistent visibility across threads.
Sourcepub fn remaining_ids_fast() -> usize
pub fn remaining_ids_fast() -> usize
Returns the number of remaining IDs with Relaxed ordering.
Offers maximum performance in low-contention scenarios where memory ordering is not a concern.