pub struct LinuxSigactionFlags { /* private fields */ }linux only.Expand description
๐ง ๐ถ โ
Input flags for LinuxSigaction.
๐ sys/os/term/session
๐ฆ size_of::<LinuxSigactionFlags>() == 1 bytes / 8 bits
Implementations
Sourceimpl LinuxSigactionFlags
impl LinuxSigactionFlags
Sourcepub const fn from_c_size_t(bits: c_size_t) -> Self
pub const fn from_c_size_t(bits: c_size_t) -> Self
Returns flags from the raw Linux sa_flags word.
Sourcepub const fn as_c_size_t(self) -> c_size_t
pub const fn as_c_size_t(self) -> c_size_t
Returns flags as a raw Linux sa_flags word.
Sourceimpl LinuxSigactionFlags
Named constants
impl LinuxSigactionFlags
Named constants
Sourcepub const SA_NOCLDSTOP: Self
pub const SA_NOCLDSTOP: Self
1
Do not notify when child processes stop or resume.
Sourcepub const SA_NOCLDWAIT: Self
pub const SA_NOCLDWAIT: Self
1
Do not create zombies when child processes terminate.
Sourcepub const SA_NODEFER: Self
pub const SA_NODEFER: Self
1
Do not mask the signal while its handler is running.
Sourcepub const SA_ONSTACK: Self
pub const SA_ONSTACK: Self
1
Run the handler on an alternate signal stack.
Sourcepub const SA_RESETHAND: Self
pub const SA_RESETHAND: Self
1
Reset the signal action to the default on handler entry.
Sourcepub const SA_RESTART: Self
pub const SA_RESTART: Self
1
Restart certain interrupted system calls.
Sourcepub const SA_RESTORER: Self
pub const SA_RESTORER: Self
1
Use the explicit Linux signal-restorer trampoline.
Sourcepub const SA_SIGINFO: Self
pub const SA_SIGINFO: Self
1
Use a three-argument SA_SIGINFO handler.
Sourceimpl LinuxSigactionFlags
Convenience methods derived from each named constant.
impl LinuxSigactionFlags
Convenience methods derived from each named constant.
Sourcepub const fn has_sa_nocldstop(self) -> bool
pub const fn has_sa_nocldstop(self) -> bool
Returns true if SA_NOCLDSTOP is present.
Sourcepub const fn contains_sa_nocldstop(self) -> bool
pub const fn contains_sa_nocldstop(self) -> bool
Returns true if all bits in SA_NOCLDSTOP are present.
Sourcepub const fn intersects_sa_nocldstop(self) -> bool
pub const fn intersects_sa_nocldstop(self) -> bool
Returns true if the set shares any bit with SA_NOCLDSTOP.
Sourcepub const fn with_sa_nocldstop(self) -> Self
pub const fn with_sa_nocldstop(self) -> Self
Returns self with SA_NOCLDSTOP inserted.
Sourcepub const fn with_sa_nocldstop_if(self, condition: bool) -> Self
pub const fn with_sa_nocldstop_if(self, condition: bool) -> Self
Returns self with SA_NOCLDSTOP inserted if condition is true.
Sourcepub const fn without_sa_nocldstop(self) -> Self
pub const fn without_sa_nocldstop(self) -> Self
Returns self with SA_NOCLDSTOP removed.
Sourcepub const fn set_sa_nocldstop(&mut self)
pub const fn set_sa_nocldstop(&mut self)
Sets SA_NOCLDSTOP.
Sourcepub const fn set_sa_nocldstop_if(&mut self, condition: bool)
pub const fn set_sa_nocldstop_if(&mut self, condition: bool)
Sets SA_NOCLDSTOP if condition is true.
Sourcepub const fn unset_sa_nocldstop(&mut self)
pub const fn unset_sa_nocldstop(&mut self)
Unsets SA_NOCLDSTOP.
Sourcepub const fn has_sa_nocldwait(self) -> bool
pub const fn has_sa_nocldwait(self) -> bool
Returns true if SA_NOCLDWAIT is present.
Sourcepub const fn contains_sa_nocldwait(self) -> bool
pub const fn contains_sa_nocldwait(self) -> bool
Returns true if all bits in SA_NOCLDWAIT are present.
Sourcepub const fn intersects_sa_nocldwait(self) -> bool
pub const fn intersects_sa_nocldwait(self) -> bool
Returns true if the set shares any bit with SA_NOCLDWAIT.
Sourcepub const fn with_sa_nocldwait(self) -> Self
pub const fn with_sa_nocldwait(self) -> Self
Returns self with SA_NOCLDWAIT inserted.
Sourcepub const fn with_sa_nocldwait_if(self, condition: bool) -> Self
pub const fn with_sa_nocldwait_if(self, condition: bool) -> Self
Returns self with SA_NOCLDWAIT inserted if condition is true.
Sourcepub const fn without_sa_nocldwait(self) -> Self
pub const fn without_sa_nocldwait(self) -> Self
Returns self with SA_NOCLDWAIT removed.
Sourcepub const fn set_sa_nocldwait(&mut self)
pub const fn set_sa_nocldwait(&mut self)
Sets SA_NOCLDWAIT.
Sourcepub const fn set_sa_nocldwait_if(&mut self, condition: bool)
pub const fn set_sa_nocldwait_if(&mut self, condition: bool)
Sets SA_NOCLDWAIT if condition is true.
Sourcepub const fn unset_sa_nocldwait(&mut self)
pub const fn unset_sa_nocldwait(&mut self)
Unsets SA_NOCLDWAIT.
Sourcepub const fn has_sa_nodefer(self) -> bool
pub const fn has_sa_nodefer(self) -> bool
Returns true if SA_NODEFER is present.
Sourcepub const fn contains_sa_nodefer(self) -> bool
pub const fn contains_sa_nodefer(self) -> bool
Returns true if all bits in SA_NODEFER are present.
Sourcepub const fn intersects_sa_nodefer(self) -> bool
pub const fn intersects_sa_nodefer(self) -> bool
Returns true if the set shares any bit with SA_NODEFER.
Sourcepub const fn with_sa_nodefer(self) -> Self
pub const fn with_sa_nodefer(self) -> Self
Returns self with SA_NODEFER inserted.
Sourcepub const fn with_sa_nodefer_if(self, condition: bool) -> Self
pub const fn with_sa_nodefer_if(self, condition: bool) -> Self
Returns self with SA_NODEFER inserted if condition is true.
Sourcepub const fn without_sa_nodefer(self) -> Self
pub const fn without_sa_nodefer(self) -> Self
Returns self with SA_NODEFER removed.
Sourcepub const fn set_sa_nodefer(&mut self)
pub const fn set_sa_nodefer(&mut self)
Sets SA_NODEFER.
Sourcepub const fn set_sa_nodefer_if(&mut self, condition: bool)
pub const fn set_sa_nodefer_if(&mut self, condition: bool)
Sets SA_NODEFER if condition is true.
Sourcepub const fn unset_sa_nodefer(&mut self)
pub const fn unset_sa_nodefer(&mut self)
Unsets SA_NODEFER.
Sourcepub const fn has_sa_onstack(self) -> bool
pub const fn has_sa_onstack(self) -> bool
Returns true if SA_ONSTACK is present.
Sourcepub const fn contains_sa_onstack(self) -> bool
pub const fn contains_sa_onstack(self) -> bool
Returns true if all bits in SA_ONSTACK are present.
Sourcepub const fn intersects_sa_onstack(self) -> bool
pub const fn intersects_sa_onstack(self) -> bool
Returns true if the set shares any bit with SA_ONSTACK.
Sourcepub const fn with_sa_onstack(self) -> Self
pub const fn with_sa_onstack(self) -> Self
Returns self with SA_ONSTACK inserted.
Sourcepub const fn with_sa_onstack_if(self, condition: bool) -> Self
pub const fn with_sa_onstack_if(self, condition: bool) -> Self
Returns self with SA_ONSTACK inserted if condition is true.
Sourcepub const fn without_sa_onstack(self) -> Self
pub const fn without_sa_onstack(self) -> Self
Returns self with SA_ONSTACK removed.
Sourcepub const fn set_sa_onstack(&mut self)
pub const fn set_sa_onstack(&mut self)
Sets SA_ONSTACK.
Sourcepub const fn set_sa_onstack_if(&mut self, condition: bool)
pub const fn set_sa_onstack_if(&mut self, condition: bool)
Sets SA_ONSTACK if condition is true.
Sourcepub const fn unset_sa_onstack(&mut self)
pub const fn unset_sa_onstack(&mut self)
Unsets SA_ONSTACK.
Sourcepub const fn has_sa_resethand(self) -> bool
pub const fn has_sa_resethand(self) -> bool
Returns true if SA_RESETHAND is present.
Sourcepub const fn contains_sa_resethand(self) -> bool
pub const fn contains_sa_resethand(self) -> bool
Returns true if all bits in SA_RESETHAND are present.
Sourcepub const fn intersects_sa_resethand(self) -> bool
pub const fn intersects_sa_resethand(self) -> bool
Returns true if the set shares any bit with SA_RESETHAND.
Sourcepub const fn with_sa_resethand(self) -> Self
pub const fn with_sa_resethand(self) -> Self
Returns self with SA_RESETHAND inserted.
Sourcepub const fn with_sa_resethand_if(self, condition: bool) -> Self
pub const fn with_sa_resethand_if(self, condition: bool) -> Self
Returns self with SA_RESETHAND inserted if condition is true.
Sourcepub const fn without_sa_resethand(self) -> Self
pub const fn without_sa_resethand(self) -> Self
Returns self with SA_RESETHAND removed.
Sourcepub const fn set_sa_resethand(&mut self)
pub const fn set_sa_resethand(&mut self)
Sets SA_RESETHAND.
Sourcepub const fn set_sa_resethand_if(&mut self, condition: bool)
pub const fn set_sa_resethand_if(&mut self, condition: bool)
Sets SA_RESETHAND if condition is true.
Sourcepub const fn unset_sa_resethand(&mut self)
pub const fn unset_sa_resethand(&mut self)
Unsets SA_RESETHAND.
Sourcepub const fn has_sa_restart(self) -> bool
pub const fn has_sa_restart(self) -> bool
Returns true if SA_RESTART is present.
Sourcepub const fn contains_sa_restart(self) -> bool
pub const fn contains_sa_restart(self) -> bool
Returns true if all bits in SA_RESTART are present.
Sourcepub const fn intersects_sa_restart(self) -> bool
pub const fn intersects_sa_restart(self) -> bool
Returns true if the set shares any bit with SA_RESTART.
Sourcepub const fn with_sa_restart(self) -> Self
pub const fn with_sa_restart(self) -> Self
Returns self with SA_RESTART inserted.
Sourcepub const fn with_sa_restart_if(self, condition: bool) -> Self
pub const fn with_sa_restart_if(self, condition: bool) -> Self
Returns self with SA_RESTART inserted if condition is true.
Sourcepub const fn without_sa_restart(self) -> Self
pub const fn without_sa_restart(self) -> Self
Returns self with SA_RESTART removed.
Sourcepub const fn set_sa_restart(&mut self)
pub const fn set_sa_restart(&mut self)
Sets SA_RESTART.
Sourcepub const fn set_sa_restart_if(&mut self, condition: bool)
pub const fn set_sa_restart_if(&mut self, condition: bool)
Sets SA_RESTART if condition is true.
Sourcepub const fn unset_sa_restart(&mut self)
pub const fn unset_sa_restart(&mut self)
Unsets SA_RESTART.
Sourcepub const fn has_sa_restorer(self) -> bool
pub const fn has_sa_restorer(self) -> bool
Returns true if SA_RESTORER is present.
Sourcepub const fn contains_sa_restorer(self) -> bool
pub const fn contains_sa_restorer(self) -> bool
Returns true if all bits in SA_RESTORER are present.
Sourcepub const fn intersects_sa_restorer(self) -> bool
pub const fn intersects_sa_restorer(self) -> bool
Returns true if the set shares any bit with SA_RESTORER.
Sourcepub const fn with_sa_restorer(self) -> Self
pub const fn with_sa_restorer(self) -> Self
Returns self with SA_RESTORER inserted.
Sourcepub const fn with_sa_restorer_if(self, condition: bool) -> Self
pub const fn with_sa_restorer_if(self, condition: bool) -> Self
Returns self with SA_RESTORER inserted if condition is true.
Sourcepub const fn without_sa_restorer(self) -> Self
pub const fn without_sa_restorer(self) -> Self
Returns self with SA_RESTORER removed.
Sourcepub const fn set_sa_restorer(&mut self)
pub const fn set_sa_restorer(&mut self)
Sets SA_RESTORER.
Sourcepub const fn set_sa_restorer_if(&mut self, condition: bool)
pub const fn set_sa_restorer_if(&mut self, condition: bool)
Sets SA_RESTORER if condition is true.
Sourcepub const fn unset_sa_restorer(&mut self)
pub const fn unset_sa_restorer(&mut self)
Unsets SA_RESTORER.
Sourcepub const fn has_sa_siginfo(self) -> bool
pub const fn has_sa_siginfo(self) -> bool
Returns true if SA_SIGINFO is present.
Sourcepub const fn contains_sa_siginfo(self) -> bool
pub const fn contains_sa_siginfo(self) -> bool
Returns true if all bits in SA_SIGINFO are present.
Sourcepub const fn intersects_sa_siginfo(self) -> bool
pub const fn intersects_sa_siginfo(self) -> bool
Returns true if the set shares any bit with SA_SIGINFO.
Sourcepub const fn with_sa_siginfo(self) -> Self
pub const fn with_sa_siginfo(self) -> Self
Returns self with SA_SIGINFO inserted.
Sourcepub const fn with_sa_siginfo_if(self, condition: bool) -> Self
pub const fn with_sa_siginfo_if(self, condition: bool) -> Self
Returns self with SA_SIGINFO inserted if condition is true.
Sourcepub const fn without_sa_siginfo(self) -> Self
pub const fn without_sa_siginfo(self) -> Self
Returns self with SA_SIGINFO removed.
Sourcepub const fn set_sa_siginfo(&mut self)
pub const fn set_sa_siginfo(&mut self)
Sets SA_SIGINFO.
Sourcepub const fn set_sa_siginfo_if(&mut self, condition: bool)
pub const fn set_sa_siginfo_if(&mut self, condition: bool)
Sets SA_SIGINFO if condition is true.
Sourcepub const fn unset_sa_siginfo(&mut self)
pub const fn unset_sa_siginfo(&mut self)
Unsets SA_SIGINFO.
Sourceimpl LinuxSigactionFlags
Common set methods
impl LinuxSigactionFlags
Common set methods
Sourceimpl LinuxSigactionFlags
Set operations
impl LinuxSigactionFlags
Set operations
Sourcepub const fn intersects(self, other: Self) -> bool
pub const fn intersects(self, other: Self) -> bool
Returns true if self and other share any bit.
Sourcepub const fn is_subset(self, other: Self) -> bool
pub const fn is_subset(self, other: Self) -> bool
Returns true if all bits in self are also set in other.
Sourcepub const fn is_superset(self, other: Self) -> bool
pub const fn is_superset(self, other: Self) -> bool
Returns true if all bits in other are also set in self.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection of self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference of self and other.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference of self and other.
Sourceimpl LinuxSigactionFlags
Mutating set operations
impl LinuxSigactionFlags
Mutating set operations