pub struct RunCapText { /* private fields */ }Expand description
Implementations
Sourceimpl RunCapText
Named constants
impl RunCapText
Named constants
Sourcepub const PROPORTIONAL: Self
pub const PROPORTIONAL: Self
1
Variable-width text layout.
Sourcepub const COLOR_PAIR: Self
pub const COLOR_PAIR: Self
1
Text color is assigned as a foreground/background pair.
Sourceimpl RunCapText
Convenience methods derived from each named constant.
impl RunCapText
Convenience methods derived from each named constant.
Sourcepub const fn contains_write(self) -> bool
pub const fn contains_write(self) -> bool
Returns true if all bits in WRITE are present.
Sourcepub const fn intersects_write(self) -> bool
pub const fn intersects_write(self) -> bool
Returns true if the set shares any bit with WRITE.
Sourcepub const fn with_write(self) -> Self
pub const fn with_write(self) -> Self
Returns self with WRITE inserted.
Sourcepub const fn with_write_if(self, condition: bool) -> Self
pub const fn with_write_if(self, condition: bool) -> Self
Returns self with WRITE inserted if condition is true.
Sourcepub const fn without_write(self) -> Self
pub const fn without_write(self) -> Self
Returns self with WRITE removed.
Sourcepub const fn set_write_if(&mut self, condition: bool)
pub const fn set_write_if(&mut self, condition: bool)
Sets WRITE if condition is true.
Sourcepub const fn unset_write(&mut self)
pub const fn unset_write(&mut self)
Unsets WRITE.
Sourcepub const fn has_cell_grid(self) -> bool
pub const fn has_cell_grid(self) -> bool
Returns true if CELL_GRID is present.
Sourcepub const fn contains_cell_grid(self) -> bool
pub const fn contains_cell_grid(self) -> bool
Returns true if all bits in CELL_GRID are present.
Sourcepub const fn intersects_cell_grid(self) -> bool
pub const fn intersects_cell_grid(self) -> bool
Returns true if the set shares any bit with CELL_GRID.
Sourcepub const fn with_cell_grid(self) -> Self
pub const fn with_cell_grid(self) -> Self
Returns self with CELL_GRID inserted.
Sourcepub const fn with_cell_grid_if(self, condition: bool) -> Self
pub const fn with_cell_grid_if(self, condition: bool) -> Self
Returns self with CELL_GRID inserted if condition is true.
Sourcepub const fn without_cell_grid(self) -> Self
pub const fn without_cell_grid(self) -> Self
Returns self with CELL_GRID removed.
Sourcepub const fn set_cell_grid(&mut self)
pub const fn set_cell_grid(&mut self)
Sets CELL_GRID.
Sourcepub const fn set_cell_grid_if(&mut self, condition: bool)
pub const fn set_cell_grid_if(&mut self, condition: bool)
Sets CELL_GRID if condition is true.
Sourcepub const fn unset_cell_grid(&mut self)
pub const fn unset_cell_grid(&mut self)
Unsets CELL_GRID.
Sourcepub const fn has_proportional(self) -> bool
pub const fn has_proportional(self) -> bool
Returns true if PROPORTIONAL is present.
Sourcepub const fn contains_proportional(self) -> bool
pub const fn contains_proportional(self) -> bool
Returns true if all bits in PROPORTIONAL are present.
Sourcepub const fn intersects_proportional(self) -> bool
pub const fn intersects_proportional(self) -> bool
Returns true if the set shares any bit with PROPORTIONAL.
Sourcepub const fn with_proportional(self) -> Self
pub const fn with_proportional(self) -> Self
Returns self with PROPORTIONAL inserted.
Sourcepub const fn with_proportional_if(self, condition: bool) -> Self
pub const fn with_proportional_if(self, condition: bool) -> Self
Returns self with PROPORTIONAL inserted if condition is true.
Sourcepub const fn without_proportional(self) -> Self
pub const fn without_proportional(self) -> Self
Returns self with PROPORTIONAL removed.
Sourcepub const fn set_proportional(&mut self)
pub const fn set_proportional(&mut self)
Sets PROPORTIONAL.
Sourcepub const fn set_proportional_if(&mut self, condition: bool)
pub const fn set_proportional_if(&mut self, condition: bool)
Sets PROPORTIONAL if condition is true.
Sourcepub const fn unset_proportional(&mut self)
pub const fn unset_proportional(&mut self)
Unsets PROPORTIONAL.
Sourcepub const fn has_cursor(self) -> bool
pub const fn has_cursor(self) -> bool
Returns true if CURSOR is present.
Sourcepub const fn contains_cursor(self) -> bool
pub const fn contains_cursor(self) -> bool
Returns true if all bits in CURSOR are present.
Sourcepub const fn intersects_cursor(self) -> bool
pub const fn intersects_cursor(self) -> bool
Returns true if the set shares any bit with CURSOR.
Sourcepub const fn with_cursor(self) -> Self
pub const fn with_cursor(self) -> Self
Returns self with CURSOR inserted.
Sourcepub const fn with_cursor_if(self, condition: bool) -> Self
pub const fn with_cursor_if(self, condition: bool) -> Self
Returns self with CURSOR inserted if condition is true.
Sourcepub const fn without_cursor(self) -> Self
pub const fn without_cursor(self) -> Self
Returns self with CURSOR removed.
Sourcepub const fn set_cursor(&mut self)
pub const fn set_cursor(&mut self)
Sets CURSOR.
Sourcepub const fn set_cursor_if(&mut self, condition: bool)
pub const fn set_cursor_if(&mut self, condition: bool)
Sets CURSOR if condition is true.
Sourcepub const fn unset_cursor(&mut self)
pub const fn unset_cursor(&mut self)
Unsets CURSOR.
Sourcepub const fn contains_style(self) -> bool
pub const fn contains_style(self) -> bool
Returns true if all bits in STYLE are present.
Sourcepub const fn intersects_style(self) -> bool
pub const fn intersects_style(self) -> bool
Returns true if the set shares any bit with STYLE.
Sourcepub const fn with_style(self) -> Self
pub const fn with_style(self) -> Self
Returns self with STYLE inserted.
Sourcepub const fn with_style_if(self, condition: bool) -> Self
pub const fn with_style_if(self, condition: bool) -> Self
Returns self with STYLE inserted if condition is true.
Sourcepub const fn without_style(self) -> Self
pub const fn without_style(self) -> Self
Returns self with STYLE removed.
Sourcepub const fn set_style_if(&mut self, condition: bool)
pub const fn set_style_if(&mut self, condition: bool)
Sets STYLE if condition is true.
Sourcepub const fn unset_style(&mut self)
pub const fn unset_style(&mut self)
Unsets STYLE.
Sourcepub const fn contains_edit(self) -> bool
pub const fn contains_edit(self) -> bool
Returns true if all bits in EDIT are present.
Sourcepub const fn intersects_edit(self) -> bool
pub const fn intersects_edit(self) -> bool
Returns true if the set shares any bit with EDIT.
Sourcepub const fn with_edit_if(self, condition: bool) -> Self
pub const fn with_edit_if(self, condition: bool) -> Self
Returns self with EDIT inserted if condition is true.
Sourcepub const fn without_edit(self) -> Self
pub const fn without_edit(self) -> Self
Returns self with EDIT removed.
Sourcepub const fn set_edit_if(&mut self, condition: bool)
pub const fn set_edit_if(&mut self, condition: bool)
Sets EDIT if condition is true.
Sourcepub const fn unset_edit(&mut self)
pub const fn unset_edit(&mut self)
Unsets EDIT.
Sourcepub const fn has_color_pair(self) -> bool
pub const fn has_color_pair(self) -> bool
Returns true if COLOR_PAIR is present.
Sourcepub const fn contains_color_pair(self) -> bool
pub const fn contains_color_pair(self) -> bool
Returns true if all bits in COLOR_PAIR are present.
Sourcepub const fn intersects_color_pair(self) -> bool
pub const fn intersects_color_pair(self) -> bool
Returns true if the set shares any bit with COLOR_PAIR.
Sourcepub const fn with_color_pair(self) -> Self
pub const fn with_color_pair(self) -> Self
Returns self with COLOR_PAIR inserted.
Sourcepub const fn with_color_pair_if(self, condition: bool) -> Self
pub const fn with_color_pair_if(self, condition: bool) -> Self
Returns self with COLOR_PAIR inserted if condition is true.
Sourcepub const fn without_color_pair(self) -> Self
pub const fn without_color_pair(self) -> Self
Returns self with COLOR_PAIR removed.
Sourcepub const fn set_color_pair(&mut self)
pub const fn set_color_pair(&mut self)
Sets COLOR_PAIR.
Sourcepub const fn set_color_pair_if(&mut self, condition: bool)
pub const fn set_color_pair_if(&mut self, condition: bool)
Sets COLOR_PAIR if condition is true.
Sourcepub const fn unset_color_pair(&mut self)
pub const fn unset_color_pair(&mut self)
Unsets COLOR_PAIR.
Sourcepub const fn has_measure(self) -> bool
pub const fn has_measure(self) -> bool
Returns true if MEASURE is present.
Sourcepub const fn contains_measure(self) -> bool
pub const fn contains_measure(self) -> bool
Returns true if all bits in MEASURE are present.
Sourcepub const fn intersects_measure(self) -> bool
pub const fn intersects_measure(self) -> bool
Returns true if the set shares any bit with MEASURE.
Sourcepub const fn with_measure(self) -> Self
pub const fn with_measure(self) -> Self
Returns self with MEASURE inserted.
Sourcepub const fn with_measure_if(self, condition: bool) -> Self
pub const fn with_measure_if(self, condition: bool) -> Self
Returns self with MEASURE inserted if condition is true.
Sourcepub const fn without_measure(self) -> Self
pub const fn without_measure(self) -> Self
Returns self with MEASURE removed.
Sourcepub const fn set_measure(&mut self)
pub const fn set_measure(&mut self)
Sets MEASURE.
Sourcepub const fn set_measure_if(&mut self, condition: bool)
pub const fn set_measure_if(&mut self, condition: bool)
Sets MEASURE if condition is true.
Sourcepub const fn unset_measure(&mut self)
pub const fn unset_measure(&mut self)
Unsets MEASURE.
Sourceimpl RunCapText
Common set methods
impl RunCapText
Common set methods
Sourceimpl RunCapText
Set operations
impl RunCapText
Set operations
Sourcepub const fn intersects(self, other: Self) -> bool
pub const fn intersects(self, other: Self) -> bool
Returns true if self and other share any bit.
Sourcepub const fn is_subset(self, other: Self) -> bool
pub const fn is_subset(self, other: Self) -> bool
Returns true if all bits in self are also set in other.
Sourcepub const fn is_superset(self, other: Self) -> bool
pub const fn is_superset(self, other: Self) -> bool
Returns true if all bits in other are also set in self.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection of self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference of self and other.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference of self and other.
Sourceimpl RunCapText
Mutating set operations
impl RunCapText
Mutating set operations