pub struct HasherFnv<T> { /* private fields */ }hash only.Expand description
๐ A FowlerโNollโVo hasher, implemented for u32, u64, u128 & usize.
๐ data/codec/hash
It uses the fnv-1a variation which gives better avalanche characteristics.
See
Implementations
Sourceimpl HasherFnv<u32>
impl HasherFnv<u32>
Sourcepub const fn get_hash_mod_lazy(&self, range: u32) -> u32
pub const fn get_hash_mod_lazy(&self, range: u32) -> u32
Returns the hash value with lazy mod mapping to the given range.
Sourcepub const fn get_hash_mod_retry(&self, range: u32) -> u32
pub const fn get_hash_mod_retry(&self, range: u32) -> u32
Returns the hash value with retried mod mapping to the given range.
Sourcepub const fn get_hash_n_bits(&self, n: usize) -> u32
pub const fn get_hash_n_bits(&self, n: usize) -> u32
Sourcepub const fn update(&mut self, input: &[u8])
pub const fn update(&mut self, input: &[u8])
Updates the hasher with more data.
Allows the hasher to receive additional bytes incrementally.
Sourcepub const fn hash_mod_lazy(input: &[u8], range: u32) -> u32
pub const fn hash_mod_lazy(input: &[u8], range: u32) -> u32
Maps the computed FNV hash to the given range using lazy mod mapping.
This method only does an additional mod at the end. But thereโs a small bias against the larger values.
Sourcepub const fn hash_mod_retry(input: &[u8], range: u32) -> u32
pub const fn hash_mod_retry(input: &[u8], range: u32) -> u32
Maps the computed FNV hash to the given range using retried mod mapping.
Sourcepub const fn hash_n_bits(input: &[u8], n: usize) -> u32
pub const fn hash_n_bits(input: &[u8], n: usize) -> u32
Sourcepub const fn mod_retry_hash(hash: u32, range: u32) -> u32
pub const fn mod_retry_hash(hash: u32, range: u32) -> u32
Maps a hash to the given range using retried mod mapping.
Ensures that the hash value is uniform and unbiased within the range.
Sourceimpl HasherFnv<u64>
impl HasherFnv<u64>
Sourcepub const fn get_hash_mod_lazy(&self, range: u64) -> u64
pub const fn get_hash_mod_lazy(&self, range: u64) -> u64
Returns the hash value with lazy mod mapping to the given range.
Sourcepub const fn get_hash_mod_retry(&self, range: u64) -> u64
pub const fn get_hash_mod_retry(&self, range: u64) -> u64
Returns the hash value with retried mod mapping to the given range.
Sourcepub const fn get_hash_n_bits(&self, n: usize) -> u64
pub const fn get_hash_n_bits(&self, n: usize) -> u64
Sourcepub const fn update(&mut self, input: &[u8])
pub const fn update(&mut self, input: &[u8])
Updates the hasher with more data.
Allows the hasher to receive additional bytes incrementally.
Sourcepub const fn hash_mod_lazy(input: &[u8], range: u64) -> u64
pub const fn hash_mod_lazy(input: &[u8], range: u64) -> u64
Maps the computed FNV hash to the given range using lazy mod mapping.
This method only does an additional mod at the end. But thereโs a small bias against the larger values.
Sourcepub const fn hash_mod_retry(input: &[u8], range: u64) -> u64
pub const fn hash_mod_retry(input: &[u8], range: u64) -> u64
Maps the computed FNV hash to the given range using retried mod mapping.
Sourcepub const fn hash_n_bits(input: &[u8], n: usize) -> u64
pub const fn hash_n_bits(input: &[u8], n: usize) -> u64
Sourcepub const fn mod_retry_hash(hash: u64, range: u64) -> u64
pub const fn mod_retry_hash(hash: u64, range: u64) -> u64
Maps a hash to the given range using retried mod mapping.
Ensures that the hash value is uniform and unbiased within the range.
Sourceimpl HasherFnv<u128>
impl HasherFnv<u128>
Sourcepub const fn get_hash_mod_lazy(&self, range: u128) -> u128
pub const fn get_hash_mod_lazy(&self, range: u128) -> u128
Returns the hash value with lazy mod mapping to the given range.
Sourcepub const fn get_hash_mod_retry(&self, range: u128) -> u128
pub const fn get_hash_mod_retry(&self, range: u128) -> u128
Returns the hash value with retried mod mapping to the given range.
Sourcepub const fn get_hash_n_bits(&self, n: usize) -> u128
pub const fn get_hash_n_bits(&self, n: usize) -> u128
Sourcepub const fn update(&mut self, input: &[u8])
pub const fn update(&mut self, input: &[u8])
Updates the hasher with more data.
Allows the hasher to receive additional bytes incrementally.
Sourcepub const fn hash_mod_lazy(input: &[u8], range: u128) -> u128
pub const fn hash_mod_lazy(input: &[u8], range: u128) -> u128
Maps the computed FNV hash to the given range using lazy mod mapping.
This method only does an additional mod at the end. But thereโs a small bias against the larger values.
Sourcepub const fn hash_mod_retry(input: &[u8], range: u128) -> u128
pub const fn hash_mod_retry(input: &[u8], range: u128) -> u128
Maps the computed FNV hash to the given range using retried mod mapping.
Sourcepub const fn hash_n_bits(input: &[u8], n: usize) -> u128
pub const fn hash_n_bits(input: &[u8], n: usize) -> u128
Computes the FNV hash of the provided byte slice, xor folded to n bits.
Panics
Panics in debug if n exceeds u128::BITS.
Sourcepub const fn mod_retry_hash(hash: u128, range: u128) -> u128
pub const fn mod_retry_hash(hash: u128, range: u128) -> u128
Maps a hash to the given range using retried mod mapping.
Ensures that the hash value is uniform and unbiased within the range.
Sourceimpl HasherFnv<usize>
impl HasherFnv<usize>
Sourcepub const fn get_hash_mod_lazy(&self, range: usize) -> usize
pub const fn get_hash_mod_lazy(&self, range: usize) -> usize
Returns the hash value with lazy mod mapping to the given range.
Sourcepub const fn get_hash_mod_retry(&self, range: usize) -> usize
pub const fn get_hash_mod_retry(&self, range: usize) -> usize
Returns the hash value with retried mod mapping to the given range.
Sourcepub const fn get_hash_n_bits(&self, n: usize) -> usize
pub const fn get_hash_n_bits(&self, n: usize) -> usize
Sourcepub const fn update(&mut self, input: &[u8])
pub const fn update(&mut self, input: &[u8])
Updates the hasher with more data.
Allows the hasher to receive additional bytes incrementally.
Sourcepub const fn hash_mod_lazy(input: &[u8], range: usize) -> usize
pub const fn hash_mod_lazy(input: &[u8], range: usize) -> usize
Maps the computed FNV hash to the given range using lazy mod mapping.
This method only does an additional mod at the end. But thereโs a small bias against the larger values.
Sourcepub const fn hash_mod_retry(input: &[u8], range: usize) -> usize
pub const fn hash_mod_retry(input: &[u8], range: usize) -> usize
Maps the computed FNV hash to the given range using retried mod mapping.
Sourcepub const fn hash_n_bits(input: &[u8], n: usize) -> usize
pub const fn hash_n_bits(input: &[u8], n: usize) -> usize
Computes the FNV hash of the provided byte slice, xor folded to n bits.
Panics
Panics in debug if n exceeds usize::BITS.
Sourcepub const fn mod_retry_hash(hash: usize, range: usize) -> usize
pub const fn mod_retry_hash(hash: usize, range: usize) -> usize
Maps a hash to the given range using retried mod mapping.
Ensures that the hash value is uniform and unbiased within the range.