#[repr(C)]pub struct JsInstant {
pub ms: js_number,
}js only.Expand description
⬡ 🕘
A high-resolution timestamp based on JavaScript’s performance.now().
📦 size_of::<JsInstant>() == 8 bytes / 64 bits
The internal representation is a double-precision floating-point millisecond value.
Fields
ms: js_numberMilliseconds since performance.timeOrigin.
Implementations
Sourceimpl JsInstant
impl JsInstant
Sourcepub const fn as_millis_f64(self) -> js_number
pub const fn as_millis_f64(self) -> js_number
Returns the time in milliseconds.
Sourcepub const fn from_millis_f64(millis: js_number) -> Self
pub const fn from_millis_f64(millis: js_number) -> Self
Returns a new JsInstant from a timestamp in milliseconds.
Sourcepub const fn as_secs_f64(self) -> js_number
pub const fn as_secs_f64(self) -> js_number
Returns the time in f64 seconds.
Sourcepub const fn from_secs_f64(secs: js_number) -> Self
pub const fn from_secs_f64(secs: js_number) -> Self
Returns a new JsInstant from a timestamp in milliseconds.
Sourcepub const fn since(self, earlier: Self) -> Self
pub const fn since(self, earlier: Self) -> Self
Returns the duration between this and an earlier JsInstant.
Sourcepub const fn delta_since(self, earlier: Self) -> TimeDelta
pub const fn delta_since(self, earlier: Self) -> TimeDelta
Returns the duration between this and an earlier instant as a TimeDelta.
Sourceimpl JsInstant
impl JsInstant
Sourcepub fn now() -> Self
Available on crate feature web only.
pub fn now() -> Self
web only.Returns the current instant using performance.now().
Sourcepub fn origin() -> Self
Available on crate feature web only.
pub fn origin() -> Self
web only.Returns the time origin using performance.timeOrigin().
Sourcepub fn reset(&mut self)
Available on crate feature web only.
pub fn reset(&mut self)
web only.Resets this instant to the current time.
Sourcepub fn elapsed(self) -> Self
Available on crate feature web only.
pub fn elapsed(self) -> Self
web only.Returns the elapsed time since this instant.
Sourcepub fn delta_elapsed(self) -> TimeDelta
Available on crate feature web only.
pub fn delta_elapsed(self) -> TimeDelta
web only.Returns the elapsed time since this instant as a TimeDelta.