pub struct RunCapSystem { /* private fields */ }Expand description
Implementations
Sourceimpl RunCapSystem
Named constants
impl RunCapSystem
Named constants
Sourceimpl RunCapSystem
Convenience methods derived from each named constant.
impl RunCapSystem
Convenience methods derived from each named constant.
Sourcepub const fn contains_time(self) -> bool
pub const fn contains_time(self) -> bool
Returns true if all bits in TIME are present.
Sourcepub const fn intersects_time(self) -> bool
pub const fn intersects_time(self) -> bool
Returns true if the set shares any bit with TIME.
Sourcepub const fn with_time_if(self, condition: bool) -> Self
pub const fn with_time_if(self, condition: bool) -> Self
Returns self with TIME inserted if condition is true.
Sourcepub const fn without_time(self) -> Self
pub const fn without_time(self) -> Self
Returns self with TIME removed.
Sourcepub const fn set_time_if(&mut self, condition: bool)
pub const fn set_time_if(&mut self, condition: bool)
Sets TIME if condition is true.
Sourcepub const fn unset_time(&mut self)
pub const fn unset_time(&mut self)
Unsets TIME.
Sourcepub const fn contains_timer(self) -> bool
pub const fn contains_timer(self) -> bool
Returns true if all bits in TIMER are present.
Sourcepub const fn intersects_timer(self) -> bool
pub const fn intersects_timer(self) -> bool
Returns true if the set shares any bit with TIMER.
Sourcepub const fn with_timer(self) -> Self
pub const fn with_timer(self) -> Self
Returns self with TIMER inserted.
Sourcepub const fn with_timer_if(self, condition: bool) -> Self
pub const fn with_timer_if(self, condition: bool) -> Self
Returns self with TIMER inserted if condition is true.
Sourcepub const fn without_timer(self) -> Self
pub const fn without_timer(self) -> Self
Returns self with TIMER removed.
Sourcepub const fn set_timer_if(&mut self, condition: bool)
pub const fn set_timer_if(&mut self, condition: bool)
Sets TIMER if condition is true.
Sourcepub const fn unset_timer(&mut self)
pub const fn unset_timer(&mut self)
Unsets TIMER.
Sourcepub const fn has_random(self) -> bool
pub const fn has_random(self) -> bool
Returns true if RANDOM is present.
Sourcepub const fn contains_random(self) -> bool
pub const fn contains_random(self) -> bool
Returns true if all bits in RANDOM are present.
Sourcepub const fn intersects_random(self) -> bool
pub const fn intersects_random(self) -> bool
Returns true if the set shares any bit with RANDOM.
Sourcepub const fn with_random(self) -> Self
pub const fn with_random(self) -> Self
Returns self with RANDOM inserted.
Sourcepub const fn with_random_if(self, condition: bool) -> Self
pub const fn with_random_if(self, condition: bool) -> Self
Returns self with RANDOM inserted if condition is true.
Sourcepub const fn without_random(self) -> Self
pub const fn without_random(self) -> Self
Returns self with RANDOM removed.
Sourcepub const fn set_random(&mut self)
pub const fn set_random(&mut self)
Sets RANDOM.
Sourcepub const fn set_random_if(&mut self, condition: bool)
pub const fn set_random_if(&mut self, condition: bool)
Sets RANDOM if condition is true.
Sourcepub const fn unset_random(&mut self)
pub const fn unset_random(&mut self)
Unsets RANDOM.
Sourcepub const fn contains_env(self) -> bool
pub const fn contains_env(self) -> bool
Returns true if all bits in ENV are present.
Sourcepub const fn intersects_env(self) -> bool
pub const fn intersects_env(self) -> bool
Returns true if the set shares any bit with ENV.
Sourcepub const fn with_env_if(self, condition: bool) -> Self
pub const fn with_env_if(self, condition: bool) -> Self
Returns self with ENV inserted if condition is true.
Sourcepub const fn without_env(self) -> Self
pub const fn without_env(self) -> Self
Returns self with ENV removed.
Sourcepub const fn set_env_if(&mut self, condition: bool)
pub const fn set_env_if(&mut self, condition: bool)
Sets ENV if condition is true.
Sourcepub const fn contains_fs(self) -> bool
pub const fn contains_fs(self) -> bool
Returns true if all bits in FS are present.
Sourcepub const fn intersects_fs(self) -> bool
pub const fn intersects_fs(self) -> bool
Returns true if the set shares any bit with FS.
Sourcepub const fn with_fs_if(self, condition: bool) -> Self
pub const fn with_fs_if(self, condition: bool) -> Self
Returns self with FS inserted if condition is true.
Sourcepub const fn without_fs(self) -> Self
pub const fn without_fs(self) -> Self
Returns self with FS removed.
Sourcepub const fn has_process(self) -> bool
pub const fn has_process(self) -> bool
Returns true if PROCESS is present.
Sourcepub const fn contains_process(self) -> bool
pub const fn contains_process(self) -> bool
Returns true if all bits in PROCESS are present.
Sourcepub const fn intersects_process(self) -> bool
pub const fn intersects_process(self) -> bool
Returns true if the set shares any bit with PROCESS.
Sourcepub const fn with_process(self) -> Self
pub const fn with_process(self) -> Self
Returns self with PROCESS inserted.
Sourcepub const fn with_process_if(self, condition: bool) -> Self
pub const fn with_process_if(self, condition: bool) -> Self
Returns self with PROCESS inserted if condition is true.
Sourcepub const fn without_process(self) -> Self
pub const fn without_process(self) -> Self
Returns self with PROCESS removed.
Sourcepub const fn set_process(&mut self)
pub const fn set_process(&mut self)
Sets PROCESS.
Sourcepub const fn set_process_if(&mut self, condition: bool)
pub const fn set_process_if(&mut self, condition: bool)
Sets PROCESS if condition is true.
Sourcepub const fn unset_process(&mut self)
pub const fn unset_process(&mut self)
Unsets PROCESS.
Sourcepub const fn has_thread(self) -> bool
pub const fn has_thread(self) -> bool
Returns true if THREAD is present.
Sourcepub const fn contains_thread(self) -> bool
pub const fn contains_thread(self) -> bool
Returns true if all bits in THREAD are present.
Sourcepub const fn intersects_thread(self) -> bool
pub const fn intersects_thread(self) -> bool
Returns true if the set shares any bit with THREAD.
Sourcepub const fn with_thread(self) -> Self
pub const fn with_thread(self) -> Self
Returns self with THREAD inserted.
Sourcepub const fn with_thread_if(self, condition: bool) -> Self
pub const fn with_thread_if(self, condition: bool) -> Self
Returns self with THREAD inserted if condition is true.
Sourcepub const fn without_thread(self) -> Self
pub const fn without_thread(self) -> Self
Returns self with THREAD removed.
Sourcepub const fn set_thread(&mut self)
pub const fn set_thread(&mut self)
Sets THREAD.
Sourcepub const fn set_thread_if(&mut self, condition: bool)
pub const fn set_thread_if(&mut self, condition: bool)
Sets THREAD if condition is true.
Sourcepub const fn unset_thread(&mut self)
pub const fn unset_thread(&mut self)
Unsets THREAD.
Sourcepub const fn contains_net(self) -> bool
pub const fn contains_net(self) -> bool
Returns true if all bits in NET are present.
Sourcepub const fn intersects_net(self) -> bool
pub const fn intersects_net(self) -> bool
Returns true if the set shares any bit with NET.
Sourcepub const fn with_net_if(self, condition: bool) -> Self
pub const fn with_net_if(self, condition: bool) -> Self
Returns self with NET inserted if condition is true.
Sourcepub const fn without_net(self) -> Self
pub const fn without_net(self) -> Self
Returns self with NET removed.
Sourcepub const fn set_net_if(&mut self, condition: bool)
pub const fn set_net_if(&mut self, condition: bool)
Sets NET if condition is true.
Sourcepub const fn has_signal(self) -> bool
pub const fn has_signal(self) -> bool
Returns true if SIGNAL is present.
Sourcepub const fn contains_signal(self) -> bool
pub const fn contains_signal(self) -> bool
Returns true if all bits in SIGNAL are present.
Sourcepub const fn intersects_signal(self) -> bool
pub const fn intersects_signal(self) -> bool
Returns true if the set shares any bit with SIGNAL.
Sourcepub const fn with_signal(self) -> Self
pub const fn with_signal(self) -> Self
Returns self with SIGNAL inserted.
Sourcepub const fn with_signal_if(self, condition: bool) -> Self
pub const fn with_signal_if(self, condition: bool) -> Self
Returns self with SIGNAL inserted if condition is true.
Sourcepub const fn without_signal(self) -> Self
pub const fn without_signal(self) -> Self
Returns self with SIGNAL removed.
Sourcepub const fn set_signal(&mut self)
pub const fn set_signal(&mut self)
Sets SIGNAL.
Sourcepub const fn set_signal_if(&mut self, condition: bool)
pub const fn set_signal_if(&mut self, condition: bool)
Sets SIGNAL if condition is true.
Sourcepub const fn unset_signal(&mut self)
pub const fn unset_signal(&mut self)
Unsets SIGNAL.
Sourceimpl RunCapSystem
Common set methods
impl RunCapSystem
Common set methods
Sourceimpl RunCapSystem
Set operations
impl RunCapSystem
Set operations
Sourcepub const fn intersects(self, other: Self) -> bool
pub const fn intersects(self, other: Self) -> bool
Returns true if self and other share any bit.
Sourcepub const fn is_subset(self, other: Self) -> bool
pub const fn is_subset(self, other: Self) -> bool
Returns true if all bits in self are also set in other.
Sourcepub const fn is_superset(self, other: Self) -> bool
pub const fn is_superset(self, other: Self) -> bool
Returns true if all bits in other are also set in self.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection of self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference of self and other.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference of self and other.
Sourceimpl RunCapSystem
Mutating set operations
impl RunCapSystem
Mutating set operations