pub struct AddrParseError(/* private fields */);Expand description
📡 🚩
core
An error which can be returned when parsing an IP or socket address.
📍sys/net re-exported from core::net
📜
An error which can be returned when parsing an IP address or a socket address.
This error is used as the error type for the FromStr implementation for
IpAddr, Ipv4Addr, Ipv6Addr, SocketAddr, SocketAddrV4, and
SocketAddrV6.
Potential causes
AddrParseError may be thrown because the provided string does not parse as the given type,
often because it includes information only handled by a different address type.
ⓘ
use std::net::IpAddr;
let _foo: IpAddr = "127.0.0.1:8080".parse().expect("Cannot handle the socket port");IpAddr doesn’t handle the port. Use SocketAddr instead.
use std::net::SocketAddr;
// No problem, the `panic!` message has disappeared.
let _foo: SocketAddr = "127.0.0.1:8080".parse().expect("unreachable panic");Trait Implementations
1.0.0 · Sourceimpl Clone for AddrParseError
impl Clone for AddrParseError
Sourcefn clone(&self) -> AddrParseError
fn clone(&self) -> AddrParseError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read more1.0.0 · Sourceimpl Debug for AddrParseError
impl Debug for AddrParseError
1.4.0 · Sourceimpl Display for AddrParseError
impl Display for AddrParseError
impl Eq for AddrParseError
1.4.0 · Sourceimpl Error for AddrParseError
impl Error for AddrParseError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)> ⓘ
fn source(&self) -> Option<&(dyn Error + 'static)> ⓘ
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str ⓘ
fn description(&self) -> &str ⓘ
👎Deprecated since 1.42.0:
use the Display impl or to_string()
1.0.0 · Sourceimpl PartialEq for AddrParseError
impl PartialEq for AddrParseError
Sourcefn eq(&self, other: &AddrParseError) -> bool
fn eq(&self, other: &AddrParseError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AddrParseError