pub struct LinuxTermiosInputFlags { /* private fields */ }linux only.Expand description
๐ง ๐ฎ โ
LinuxTermios input flags.
๐ sys/os/term/session
๐ฆ size_of::<LinuxTermiosInputFlags>() == 2 bytes / 16 bits
Implementations
Sourceimpl LinuxTermiosInputFlags
Named constants
impl LinuxTermiosInputFlags
Named constants
Sourceimpl LinuxTermiosInputFlags
Convenience methods derived from each named constant.
impl LinuxTermiosInputFlags
Convenience methods derived from each named constant.
Sourcepub const fn has_ignbrk(self) -> bool
pub const fn has_ignbrk(self) -> bool
Returns true if IGNBRK is present.
Sourcepub const fn contains_ignbrk(self) -> bool
pub const fn contains_ignbrk(self) -> bool
Returns true if all bits in IGNBRK are present.
Sourcepub const fn intersects_ignbrk(self) -> bool
pub const fn intersects_ignbrk(self) -> bool
Returns true if the set shares any bit with IGNBRK.
Sourcepub const fn with_ignbrk(self) -> Self
pub const fn with_ignbrk(self) -> Self
Returns self with IGNBRK inserted.
Sourcepub const fn with_ignbrk_if(self, condition: bool) -> Self
pub const fn with_ignbrk_if(self, condition: bool) -> Self
Returns self with IGNBRK inserted if condition is true.
Sourcepub const fn without_ignbrk(self) -> Self
pub const fn without_ignbrk(self) -> Self
Returns self with IGNBRK removed.
Sourcepub const fn set_ignbrk(&mut self)
pub const fn set_ignbrk(&mut self)
Sets IGNBRK.
Sourcepub const fn set_ignbrk_if(&mut self, condition: bool)
pub const fn set_ignbrk_if(&mut self, condition: bool)
Sets IGNBRK if condition is true.
Sourcepub const fn unset_ignbrk(&mut self)
pub const fn unset_ignbrk(&mut self)
Unsets IGNBRK.
Sourcepub const fn has_brkint(self) -> bool
pub const fn has_brkint(self) -> bool
Returns true if BRKINT is present.
Sourcepub const fn contains_brkint(self) -> bool
pub const fn contains_brkint(self) -> bool
Returns true if all bits in BRKINT are present.
Sourcepub const fn intersects_brkint(self) -> bool
pub const fn intersects_brkint(self) -> bool
Returns true if the set shares any bit with BRKINT.
Sourcepub const fn with_brkint(self) -> Self
pub const fn with_brkint(self) -> Self
Returns self with BRKINT inserted.
Sourcepub const fn with_brkint_if(self, condition: bool) -> Self
pub const fn with_brkint_if(self, condition: bool) -> Self
Returns self with BRKINT inserted if condition is true.
Sourcepub const fn without_brkint(self) -> Self
pub const fn without_brkint(self) -> Self
Returns self with BRKINT removed.
Sourcepub const fn set_brkint(&mut self)
pub const fn set_brkint(&mut self)
Sets BRKINT.
Sourcepub const fn set_brkint_if(&mut self, condition: bool)
pub const fn set_brkint_if(&mut self, condition: bool)
Sets BRKINT if condition is true.
Sourcepub const fn unset_brkint(&mut self)
pub const fn unset_brkint(&mut self)
Unsets BRKINT.
Sourcepub const fn has_ignpar(self) -> bool
pub const fn has_ignpar(self) -> bool
Returns true if IGNPAR is present.
Sourcepub const fn contains_ignpar(self) -> bool
pub const fn contains_ignpar(self) -> bool
Returns true if all bits in IGNPAR are present.
Sourcepub const fn intersects_ignpar(self) -> bool
pub const fn intersects_ignpar(self) -> bool
Returns true if the set shares any bit with IGNPAR.
Sourcepub const fn with_ignpar(self) -> Self
pub const fn with_ignpar(self) -> Self
Returns self with IGNPAR inserted.
Sourcepub const fn with_ignpar_if(self, condition: bool) -> Self
pub const fn with_ignpar_if(self, condition: bool) -> Self
Returns self with IGNPAR inserted if condition is true.
Sourcepub const fn without_ignpar(self) -> Self
pub const fn without_ignpar(self) -> Self
Returns self with IGNPAR removed.
Sourcepub const fn set_ignpar(&mut self)
pub const fn set_ignpar(&mut self)
Sets IGNPAR.
Sourcepub const fn set_ignpar_if(&mut self, condition: bool)
pub const fn set_ignpar_if(&mut self, condition: bool)
Sets IGNPAR if condition is true.
Sourcepub const fn unset_ignpar(&mut self)
pub const fn unset_ignpar(&mut self)
Unsets IGNPAR.
Sourcepub const fn has_parmrk(self) -> bool
pub const fn has_parmrk(self) -> bool
Returns true if PARMRK is present.
Sourcepub const fn contains_parmrk(self) -> bool
pub const fn contains_parmrk(self) -> bool
Returns true if all bits in PARMRK are present.
Sourcepub const fn intersects_parmrk(self) -> bool
pub const fn intersects_parmrk(self) -> bool
Returns true if the set shares any bit with PARMRK.
Sourcepub const fn with_parmrk(self) -> Self
pub const fn with_parmrk(self) -> Self
Returns self with PARMRK inserted.
Sourcepub const fn with_parmrk_if(self, condition: bool) -> Self
pub const fn with_parmrk_if(self, condition: bool) -> Self
Returns self with PARMRK inserted if condition is true.
Sourcepub const fn without_parmrk(self) -> Self
pub const fn without_parmrk(self) -> Self
Returns self with PARMRK removed.
Sourcepub const fn set_parmrk(&mut self)
pub const fn set_parmrk(&mut self)
Sets PARMRK.
Sourcepub const fn set_parmrk_if(&mut self, condition: bool)
pub const fn set_parmrk_if(&mut self, condition: bool)
Sets PARMRK if condition is true.
Sourcepub const fn unset_parmrk(&mut self)
pub const fn unset_parmrk(&mut self)
Unsets PARMRK.
Sourcepub const fn contains_inpck(self) -> bool
pub const fn contains_inpck(self) -> bool
Returns true if all bits in INPCK are present.
Sourcepub const fn intersects_inpck(self) -> bool
pub const fn intersects_inpck(self) -> bool
Returns true if the set shares any bit with INPCK.
Sourcepub const fn with_inpck(self) -> Self
pub const fn with_inpck(self) -> Self
Returns self with INPCK inserted.
Sourcepub const fn with_inpck_if(self, condition: bool) -> Self
pub const fn with_inpck_if(self, condition: bool) -> Self
Returns self with INPCK inserted if condition is true.
Sourcepub const fn without_inpck(self) -> Self
pub const fn without_inpck(self) -> Self
Returns self with INPCK removed.
Sourcepub const fn set_inpck_if(&mut self, condition: bool)
pub const fn set_inpck_if(&mut self, condition: bool)
Sets INPCK if condition is true.
Sourcepub const fn unset_inpck(&mut self)
pub const fn unset_inpck(&mut self)
Unsets INPCK.
Sourcepub const fn has_istrip(self) -> bool
pub const fn has_istrip(self) -> bool
Returns true if ISTRIP is present.
Sourcepub const fn contains_istrip(self) -> bool
pub const fn contains_istrip(self) -> bool
Returns true if all bits in ISTRIP are present.
Sourcepub const fn intersects_istrip(self) -> bool
pub const fn intersects_istrip(self) -> bool
Returns true if the set shares any bit with ISTRIP.
Sourcepub const fn with_istrip(self) -> Self
pub const fn with_istrip(self) -> Self
Returns self with ISTRIP inserted.
Sourcepub const fn with_istrip_if(self, condition: bool) -> Self
pub const fn with_istrip_if(self, condition: bool) -> Self
Returns self with ISTRIP inserted if condition is true.
Sourcepub const fn without_istrip(self) -> Self
pub const fn without_istrip(self) -> Self
Returns self with ISTRIP removed.
Sourcepub const fn set_istrip(&mut self)
pub const fn set_istrip(&mut self)
Sets ISTRIP.
Sourcepub const fn set_istrip_if(&mut self, condition: bool)
pub const fn set_istrip_if(&mut self, condition: bool)
Sets ISTRIP if condition is true.
Sourcepub const fn unset_istrip(&mut self)
pub const fn unset_istrip(&mut self)
Unsets ISTRIP.
Sourcepub const fn contains_inlcr(self) -> bool
pub const fn contains_inlcr(self) -> bool
Returns true if all bits in INLCR are present.
Sourcepub const fn intersects_inlcr(self) -> bool
pub const fn intersects_inlcr(self) -> bool
Returns true if the set shares any bit with INLCR.
Sourcepub const fn with_inlcr(self) -> Self
pub const fn with_inlcr(self) -> Self
Returns self with INLCR inserted.
Sourcepub const fn with_inlcr_if(self, condition: bool) -> Self
pub const fn with_inlcr_if(self, condition: bool) -> Self
Returns self with INLCR inserted if condition is true.
Sourcepub const fn without_inlcr(self) -> Self
pub const fn without_inlcr(self) -> Self
Returns self with INLCR removed.
Sourcepub const fn set_inlcr_if(&mut self, condition: bool)
pub const fn set_inlcr_if(&mut self, condition: bool)
Sets INLCR if condition is true.
Sourcepub const fn unset_inlcr(&mut self)
pub const fn unset_inlcr(&mut self)
Unsets INLCR.
Sourcepub const fn contains_igncr(self) -> bool
pub const fn contains_igncr(self) -> bool
Returns true if all bits in IGNCR are present.
Sourcepub const fn intersects_igncr(self) -> bool
pub const fn intersects_igncr(self) -> bool
Returns true if the set shares any bit with IGNCR.
Sourcepub const fn with_igncr(self) -> Self
pub const fn with_igncr(self) -> Self
Returns self with IGNCR inserted.
Sourcepub const fn with_igncr_if(self, condition: bool) -> Self
pub const fn with_igncr_if(self, condition: bool) -> Self
Returns self with IGNCR inserted if condition is true.
Sourcepub const fn without_igncr(self) -> Self
pub const fn without_igncr(self) -> Self
Returns self with IGNCR removed.
Sourcepub const fn set_igncr_if(&mut self, condition: bool)
pub const fn set_igncr_if(&mut self, condition: bool)
Sets IGNCR if condition is true.
Sourcepub const fn unset_igncr(&mut self)
pub const fn unset_igncr(&mut self)
Unsets IGNCR.
Sourcepub const fn contains_icrnl(self) -> bool
pub const fn contains_icrnl(self) -> bool
Returns true if all bits in ICRNL are present.
Sourcepub const fn intersects_icrnl(self) -> bool
pub const fn intersects_icrnl(self) -> bool
Returns true if the set shares any bit with ICRNL.
Sourcepub const fn with_icrnl(self) -> Self
pub const fn with_icrnl(self) -> Self
Returns self with ICRNL inserted.
Sourcepub const fn with_icrnl_if(self, condition: bool) -> Self
pub const fn with_icrnl_if(self, condition: bool) -> Self
Returns self with ICRNL inserted if condition is true.
Sourcepub const fn without_icrnl(self) -> Self
pub const fn without_icrnl(self) -> Self
Returns self with ICRNL removed.
Sourcepub const fn set_icrnl_if(&mut self, condition: bool)
pub const fn set_icrnl_if(&mut self, condition: bool)
Sets ICRNL if condition is true.
Sourcepub const fn unset_icrnl(&mut self)
pub const fn unset_icrnl(&mut self)
Unsets ICRNL.
Sourcepub const fn contains_iuclc(self) -> bool
pub const fn contains_iuclc(self) -> bool
Returns true if all bits in IUCLC are present.
Sourcepub const fn intersects_iuclc(self) -> bool
pub const fn intersects_iuclc(self) -> bool
Returns true if the set shares any bit with IUCLC.
Sourcepub const fn with_iuclc(self) -> Self
pub const fn with_iuclc(self) -> Self
Returns self with IUCLC inserted.
Sourcepub const fn with_iuclc_if(self, condition: bool) -> Self
pub const fn with_iuclc_if(self, condition: bool) -> Self
Returns self with IUCLC inserted if condition is true.
Sourcepub const fn without_iuclc(self) -> Self
pub const fn without_iuclc(self) -> Self
Returns self with IUCLC removed.
Sourcepub const fn set_iuclc_if(&mut self, condition: bool)
pub const fn set_iuclc_if(&mut self, condition: bool)
Sets IUCLC if condition is true.
Sourcepub const fn unset_iuclc(&mut self)
pub const fn unset_iuclc(&mut self)
Unsets IUCLC.
Sourcepub const fn contains_ixon(self) -> bool
pub const fn contains_ixon(self) -> bool
Returns true if all bits in IXON are present.
Sourcepub const fn intersects_ixon(self) -> bool
pub const fn intersects_ixon(self) -> bool
Returns true if the set shares any bit with IXON.
Sourcepub const fn with_ixon_if(self, condition: bool) -> Self
pub const fn with_ixon_if(self, condition: bool) -> Self
Returns self with IXON inserted if condition is true.
Sourcepub const fn without_ixon(self) -> Self
pub const fn without_ixon(self) -> Self
Returns self with IXON removed.
Sourcepub const fn set_ixon_if(&mut self, condition: bool)
pub const fn set_ixon_if(&mut self, condition: bool)
Sets IXON if condition is true.
Sourcepub const fn unset_ixon(&mut self)
pub const fn unset_ixon(&mut self)
Unsets IXON.
Sourcepub const fn contains_ixany(self) -> bool
pub const fn contains_ixany(self) -> bool
Returns true if all bits in IXANY are present.
Sourcepub const fn intersects_ixany(self) -> bool
pub const fn intersects_ixany(self) -> bool
Returns true if the set shares any bit with IXANY.
Sourcepub const fn with_ixany(self) -> Self
pub const fn with_ixany(self) -> Self
Returns self with IXANY inserted.
Sourcepub const fn with_ixany_if(self, condition: bool) -> Self
pub const fn with_ixany_if(self, condition: bool) -> Self
Returns self with IXANY inserted if condition is true.
Sourcepub const fn without_ixany(self) -> Self
pub const fn without_ixany(self) -> Self
Returns self with IXANY removed.
Sourcepub const fn set_ixany_if(&mut self, condition: bool)
pub const fn set_ixany_if(&mut self, condition: bool)
Sets IXANY if condition is true.
Sourcepub const fn unset_ixany(&mut self)
pub const fn unset_ixany(&mut self)
Unsets IXANY.
Sourcepub const fn contains_ixoff(self) -> bool
pub const fn contains_ixoff(self) -> bool
Returns true if all bits in IXOFF are present.
Sourcepub const fn intersects_ixoff(self) -> bool
pub const fn intersects_ixoff(self) -> bool
Returns true if the set shares any bit with IXOFF.
Sourcepub const fn with_ixoff(self) -> Self
pub const fn with_ixoff(self) -> Self
Returns self with IXOFF inserted.
Sourcepub const fn with_ixoff_if(self, condition: bool) -> Self
pub const fn with_ixoff_if(self, condition: bool) -> Self
Returns self with IXOFF inserted if condition is true.
Sourcepub const fn without_ixoff(self) -> Self
pub const fn without_ixoff(self) -> Self
Returns self with IXOFF removed.
Sourcepub const fn set_ixoff_if(&mut self, condition: bool)
pub const fn set_ixoff_if(&mut self, condition: bool)
Sets IXOFF if condition is true.
Sourcepub const fn unset_ixoff(&mut self)
pub const fn unset_ixoff(&mut self)
Unsets IXOFF.
Sourcepub const fn has_imaxbel(self) -> bool
pub const fn has_imaxbel(self) -> bool
Returns true if IMAXBEL is present.
Sourcepub const fn contains_imaxbel(self) -> bool
pub const fn contains_imaxbel(self) -> bool
Returns true if all bits in IMAXBEL are present.
Sourcepub const fn intersects_imaxbel(self) -> bool
pub const fn intersects_imaxbel(self) -> bool
Returns true if the set shares any bit with IMAXBEL.
Sourcepub const fn with_imaxbel(self) -> Self
pub const fn with_imaxbel(self) -> Self
Returns self with IMAXBEL inserted.
Sourcepub const fn with_imaxbel_if(self, condition: bool) -> Self
pub const fn with_imaxbel_if(self, condition: bool) -> Self
Returns self with IMAXBEL inserted if condition is true.
Sourcepub const fn without_imaxbel(self) -> Self
pub const fn without_imaxbel(self) -> Self
Returns self with IMAXBEL removed.
Sourcepub const fn set_imaxbel(&mut self)
pub const fn set_imaxbel(&mut self)
Sets IMAXBEL.
Sourcepub const fn set_imaxbel_if(&mut self, condition: bool)
pub const fn set_imaxbel_if(&mut self, condition: bool)
Sets IMAXBEL if condition is true.
Sourcepub const fn unset_imaxbel(&mut self)
pub const fn unset_imaxbel(&mut self)
Unsets IMAXBEL.
Sourcepub const fn contains_iutf8(self) -> bool
pub const fn contains_iutf8(self) -> bool
Returns true if all bits in IUTF8 are present.
Sourcepub const fn intersects_iutf8(self) -> bool
pub const fn intersects_iutf8(self) -> bool
Returns true if the set shares any bit with IUTF8.
Sourcepub const fn with_iutf8(self) -> Self
pub const fn with_iutf8(self) -> Self
Returns self with IUTF8 inserted.
Sourcepub const fn with_iutf8_if(self, condition: bool) -> Self
pub const fn with_iutf8_if(self, condition: bool) -> Self
Returns self with IUTF8 inserted if condition is true.
Sourcepub const fn without_iutf8(self) -> Self
pub const fn without_iutf8(self) -> Self
Returns self with IUTF8 removed.
Sourcepub const fn set_iutf8_if(&mut self, condition: bool)
pub const fn set_iutf8_if(&mut self, condition: bool)
Sets IUTF8 if condition is true.
Sourcepub const fn unset_iutf8(&mut self)
pub const fn unset_iutf8(&mut self)
Unsets IUTF8.
Sourceimpl LinuxTermiosInputFlags
Common set methods
impl LinuxTermiosInputFlags
Common set methods
Sourceimpl LinuxTermiosInputFlags
Set operations
impl LinuxTermiosInputFlags
Set operations
Sourcepub const fn intersects(self, other: Self) -> bool
pub const fn intersects(self, other: Self) -> bool
Returns true if self and other share any bit.
Sourcepub const fn is_subset(self, other: Self) -> bool
pub const fn is_subset(self, other: Self) -> bool
Returns true if all bits in self are also set in other.
Sourcepub const fn is_superset(self, other: Self) -> bool
pub const fn is_superset(self, other: Self) -> bool
Returns true if all bits in other are also set in self.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection of self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference of self and other.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference of self and other.
Sourceimpl LinuxTermiosInputFlags
Mutating set operations
impl LinuxTermiosInputFlags
Mutating set operations