pub struct LinuxTermiosLocalFlags { /* private fields */ }linux only.Expand description
๐ง ๐ฎ โ
LinuxTermios local flags.
๐ sys/os/linux/io/term
๐ฆ size_of::<LinuxTermiosLocalFlags>() == 4 bytes / 32 bits
Implementations
Sourceimpl LinuxTermiosLocalFlags
Named constants
impl LinuxTermiosLocalFlags
Named constants
Sourceimpl LinuxTermiosLocalFlags
Convenience methods derived from each named constant.
impl LinuxTermiosLocalFlags
Convenience methods derived from each named constant.
Sourcepub const fn contains_isig(self) -> bool
pub const fn contains_isig(self) -> bool
Returns true if all bits in ISIG are present.
Sourcepub const fn intersects_isig(self) -> bool
pub const fn intersects_isig(self) -> bool
Returns true if the set shares any bit with ISIG.
Sourcepub const fn with_isig_if(self, condition: bool) -> Self
pub const fn with_isig_if(self, condition: bool) -> Self
Returns self with ISIG inserted if condition is true.
Sourcepub const fn without_isig(self) -> Self
pub const fn without_isig(self) -> Self
Returns self with ISIG removed.
Sourcepub const fn set_isig_if(&mut self, condition: bool)
pub const fn set_isig_if(&mut self, condition: bool)
Sets ISIG if condition is true.
Sourcepub const fn unset_isig(&mut self)
pub const fn unset_isig(&mut self)
Unsets ISIG.
Sourcepub const fn has_icanon(self) -> bool
pub const fn has_icanon(self) -> bool
Returns true if ICANON is present.
Sourcepub const fn contains_icanon(self) -> bool
pub const fn contains_icanon(self) -> bool
Returns true if all bits in ICANON are present.
Sourcepub const fn intersects_icanon(self) -> bool
pub const fn intersects_icanon(self) -> bool
Returns true if the set shares any bit with ICANON.
Sourcepub const fn with_icanon(self) -> Self
pub const fn with_icanon(self) -> Self
Returns self with ICANON inserted.
Sourcepub const fn with_icanon_if(self, condition: bool) -> Self
pub const fn with_icanon_if(self, condition: bool) -> Self
Returns self with ICANON inserted if condition is true.
Sourcepub const fn without_icanon(self) -> Self
pub const fn without_icanon(self) -> Self
Returns self with ICANON removed.
Sourcepub const fn set_icanon(&mut self)
pub const fn set_icanon(&mut self)
Sets ICANON.
Sourcepub const fn set_icanon_if(&mut self, condition: bool)
pub const fn set_icanon_if(&mut self, condition: bool)
Sets ICANON if condition is true.
Sourcepub const fn unset_icanon(&mut self)
pub const fn unset_icanon(&mut self)
Unsets ICANON.
Sourcepub const fn contains_xcase(self) -> bool
pub const fn contains_xcase(self) -> bool
Returns true if all bits in XCASE are present.
Sourcepub const fn intersects_xcase(self) -> bool
pub const fn intersects_xcase(self) -> bool
Returns true if the set shares any bit with XCASE.
Sourcepub const fn with_xcase(self) -> Self
pub const fn with_xcase(self) -> Self
Returns self with XCASE inserted.
Sourcepub const fn with_xcase_if(self, condition: bool) -> Self
pub const fn with_xcase_if(self, condition: bool) -> Self
Returns self with XCASE inserted if condition is true.
Sourcepub const fn without_xcase(self) -> Self
pub const fn without_xcase(self) -> Self
Returns self with XCASE removed.
Sourcepub const fn set_xcase_if(&mut self, condition: bool)
pub const fn set_xcase_if(&mut self, condition: bool)
Sets XCASE if condition is true.
Sourcepub const fn unset_xcase(&mut self)
pub const fn unset_xcase(&mut self)
Unsets XCASE.
Sourcepub const fn contains_echo(self) -> bool
pub const fn contains_echo(self) -> bool
Returns true if all bits in ECHO are present.
Sourcepub const fn intersects_echo(self) -> bool
pub const fn intersects_echo(self) -> bool
Returns true if the set shares any bit with ECHO.
Sourcepub const fn with_echo_if(self, condition: bool) -> Self
pub const fn with_echo_if(self, condition: bool) -> Self
Returns self with ECHO inserted if condition is true.
Sourcepub const fn without_echo(self) -> Self
pub const fn without_echo(self) -> Self
Returns self with ECHO removed.
Sourcepub const fn set_echo_if(&mut self, condition: bool)
pub const fn set_echo_if(&mut self, condition: bool)
Sets ECHO if condition is true.
Sourcepub const fn unset_echo(&mut self)
pub const fn unset_echo(&mut self)
Unsets ECHO.
Sourcepub const fn contains_echoe(self) -> bool
pub const fn contains_echoe(self) -> bool
Returns true if all bits in ECHOE are present.
Sourcepub const fn intersects_echoe(self) -> bool
pub const fn intersects_echoe(self) -> bool
Returns true if the set shares any bit with ECHOE.
Sourcepub const fn with_echoe(self) -> Self
pub const fn with_echoe(self) -> Self
Returns self with ECHOE inserted.
Sourcepub const fn with_echoe_if(self, condition: bool) -> Self
pub const fn with_echoe_if(self, condition: bool) -> Self
Returns self with ECHOE inserted if condition is true.
Sourcepub const fn without_echoe(self) -> Self
pub const fn without_echoe(self) -> Self
Returns self with ECHOE removed.
Sourcepub const fn set_echoe_if(&mut self, condition: bool)
pub const fn set_echoe_if(&mut self, condition: bool)
Sets ECHOE if condition is true.
Sourcepub const fn unset_echoe(&mut self)
pub const fn unset_echoe(&mut self)
Unsets ECHOE.
Sourcepub const fn contains_echok(self) -> bool
pub const fn contains_echok(self) -> bool
Returns true if all bits in ECHOK are present.
Sourcepub const fn intersects_echok(self) -> bool
pub const fn intersects_echok(self) -> bool
Returns true if the set shares any bit with ECHOK.
Sourcepub const fn with_echok(self) -> Self
pub const fn with_echok(self) -> Self
Returns self with ECHOK inserted.
Sourcepub const fn with_echok_if(self, condition: bool) -> Self
pub const fn with_echok_if(self, condition: bool) -> Self
Returns self with ECHOK inserted if condition is true.
Sourcepub const fn without_echok(self) -> Self
pub const fn without_echok(self) -> Self
Returns self with ECHOK removed.
Sourcepub const fn set_echok_if(&mut self, condition: bool)
pub const fn set_echok_if(&mut self, condition: bool)
Sets ECHOK if condition is true.
Sourcepub const fn unset_echok(&mut self)
pub const fn unset_echok(&mut self)
Unsets ECHOK.
Sourcepub const fn has_echonl(self) -> bool
pub const fn has_echonl(self) -> bool
Returns true if ECHONL is present.
Sourcepub const fn contains_echonl(self) -> bool
pub const fn contains_echonl(self) -> bool
Returns true if all bits in ECHONL are present.
Sourcepub const fn intersects_echonl(self) -> bool
pub const fn intersects_echonl(self) -> bool
Returns true if the set shares any bit with ECHONL.
Sourcepub const fn with_echonl(self) -> Self
pub const fn with_echonl(self) -> Self
Returns self with ECHONL inserted.
Sourcepub const fn with_echonl_if(self, condition: bool) -> Self
pub const fn with_echonl_if(self, condition: bool) -> Self
Returns self with ECHONL inserted if condition is true.
Sourcepub const fn without_echonl(self) -> Self
pub const fn without_echonl(self) -> Self
Returns self with ECHONL removed.
Sourcepub const fn set_echonl(&mut self)
pub const fn set_echonl(&mut self)
Sets ECHONL.
Sourcepub const fn set_echonl_if(&mut self, condition: bool)
pub const fn set_echonl_if(&mut self, condition: bool)
Sets ECHONL if condition is true.
Sourcepub const fn unset_echonl(&mut self)
pub const fn unset_echonl(&mut self)
Unsets ECHONL.
Sourcepub const fn has_noflsh(self) -> bool
pub const fn has_noflsh(self) -> bool
Returns true if NOFLSH is present.
Sourcepub const fn contains_noflsh(self) -> bool
pub const fn contains_noflsh(self) -> bool
Returns true if all bits in NOFLSH are present.
Sourcepub const fn intersects_noflsh(self) -> bool
pub const fn intersects_noflsh(self) -> bool
Returns true if the set shares any bit with NOFLSH.
Sourcepub const fn with_noflsh(self) -> Self
pub const fn with_noflsh(self) -> Self
Returns self with NOFLSH inserted.
Sourcepub const fn with_noflsh_if(self, condition: bool) -> Self
pub const fn with_noflsh_if(self, condition: bool) -> Self
Returns self with NOFLSH inserted if condition is true.
Sourcepub const fn without_noflsh(self) -> Self
pub const fn without_noflsh(self) -> Self
Returns self with NOFLSH removed.
Sourcepub const fn set_noflsh(&mut self)
pub const fn set_noflsh(&mut self)
Sets NOFLSH.
Sourcepub const fn set_noflsh_if(&mut self, condition: bool)
pub const fn set_noflsh_if(&mut self, condition: bool)
Sets NOFLSH if condition is true.
Sourcepub const fn unset_noflsh(&mut self)
pub const fn unset_noflsh(&mut self)
Unsets NOFLSH.
Sourcepub const fn has_tostop(self) -> bool
pub const fn has_tostop(self) -> bool
Returns true if TOSTOP is present.
Sourcepub const fn contains_tostop(self) -> bool
pub const fn contains_tostop(self) -> bool
Returns true if all bits in TOSTOP are present.
Sourcepub const fn intersects_tostop(self) -> bool
pub const fn intersects_tostop(self) -> bool
Returns true if the set shares any bit with TOSTOP.
Sourcepub const fn with_tostop(self) -> Self
pub const fn with_tostop(self) -> Self
Returns self with TOSTOP inserted.
Sourcepub const fn with_tostop_if(self, condition: bool) -> Self
pub const fn with_tostop_if(self, condition: bool) -> Self
Returns self with TOSTOP inserted if condition is true.
Sourcepub const fn without_tostop(self) -> Self
pub const fn without_tostop(self) -> Self
Returns self with TOSTOP removed.
Sourcepub const fn set_tostop(&mut self)
pub const fn set_tostop(&mut self)
Sets TOSTOP.
Sourcepub const fn set_tostop_if(&mut self, condition: bool)
pub const fn set_tostop_if(&mut self, condition: bool)
Sets TOSTOP if condition is true.
Sourcepub const fn unset_tostop(&mut self)
pub const fn unset_tostop(&mut self)
Unsets TOSTOP.
Sourcepub const fn has_echoctl(self) -> bool
pub const fn has_echoctl(self) -> bool
Returns true if ECHOCTL is present.
Sourcepub const fn contains_echoctl(self) -> bool
pub const fn contains_echoctl(self) -> bool
Returns true if all bits in ECHOCTL are present.
Sourcepub const fn intersects_echoctl(self) -> bool
pub const fn intersects_echoctl(self) -> bool
Returns true if the set shares any bit with ECHOCTL.
Sourcepub const fn with_echoctl(self) -> Self
pub const fn with_echoctl(self) -> Self
Returns self with ECHOCTL inserted.
Sourcepub const fn with_echoctl_if(self, condition: bool) -> Self
pub const fn with_echoctl_if(self, condition: bool) -> Self
Returns self with ECHOCTL inserted if condition is true.
Sourcepub const fn without_echoctl(self) -> Self
pub const fn without_echoctl(self) -> Self
Returns self with ECHOCTL removed.
Sourcepub const fn set_echoctl(&mut self)
pub const fn set_echoctl(&mut self)
Sets ECHOCTL.
Sourcepub const fn set_echoctl_if(&mut self, condition: bool)
pub const fn set_echoctl_if(&mut self, condition: bool)
Sets ECHOCTL if condition is true.
Sourcepub const fn unset_echoctl(&mut self)
pub const fn unset_echoctl(&mut self)
Unsets ECHOCTL.
Sourcepub const fn has_echoprt(self) -> bool
pub const fn has_echoprt(self) -> bool
Returns true if ECHOPRT is present.
Sourcepub const fn contains_echoprt(self) -> bool
pub const fn contains_echoprt(self) -> bool
Returns true if all bits in ECHOPRT are present.
Sourcepub const fn intersects_echoprt(self) -> bool
pub const fn intersects_echoprt(self) -> bool
Returns true if the set shares any bit with ECHOPRT.
Sourcepub const fn with_echoprt(self) -> Self
pub const fn with_echoprt(self) -> Self
Returns self with ECHOPRT inserted.
Sourcepub const fn with_echoprt_if(self, condition: bool) -> Self
pub const fn with_echoprt_if(self, condition: bool) -> Self
Returns self with ECHOPRT inserted if condition is true.
Sourcepub const fn without_echoprt(self) -> Self
pub const fn without_echoprt(self) -> Self
Returns self with ECHOPRT removed.
Sourcepub const fn set_echoprt(&mut self)
pub const fn set_echoprt(&mut self)
Sets ECHOPRT.
Sourcepub const fn set_echoprt_if(&mut self, condition: bool)
pub const fn set_echoprt_if(&mut self, condition: bool)
Sets ECHOPRT if condition is true.
Sourcepub const fn unset_echoprt(&mut self)
pub const fn unset_echoprt(&mut self)
Unsets ECHOPRT.
Sourcepub const fn has_echoke(self) -> bool
pub const fn has_echoke(self) -> bool
Returns true if ECHOKE is present.
Sourcepub const fn contains_echoke(self) -> bool
pub const fn contains_echoke(self) -> bool
Returns true if all bits in ECHOKE are present.
Sourcepub const fn intersects_echoke(self) -> bool
pub const fn intersects_echoke(self) -> bool
Returns true if the set shares any bit with ECHOKE.
Sourcepub const fn with_echoke(self) -> Self
pub const fn with_echoke(self) -> Self
Returns self with ECHOKE inserted.
Sourcepub const fn with_echoke_if(self, condition: bool) -> Self
pub const fn with_echoke_if(self, condition: bool) -> Self
Returns self with ECHOKE inserted if condition is true.
Sourcepub const fn without_echoke(self) -> Self
pub const fn without_echoke(self) -> Self
Returns self with ECHOKE removed.
Sourcepub const fn set_echoke(&mut self)
pub const fn set_echoke(&mut self)
Sets ECHOKE.
Sourcepub const fn set_echoke_if(&mut self, condition: bool)
pub const fn set_echoke_if(&mut self, condition: bool)
Sets ECHOKE if condition is true.
Sourcepub const fn unset_echoke(&mut self)
pub const fn unset_echoke(&mut self)
Unsets ECHOKE.
Sourcepub const fn has_flusho(self) -> bool
pub const fn has_flusho(self) -> bool
Returns true if FLUSHO is present.
Sourcepub const fn contains_flusho(self) -> bool
pub const fn contains_flusho(self) -> bool
Returns true if all bits in FLUSHO are present.
Sourcepub const fn intersects_flusho(self) -> bool
pub const fn intersects_flusho(self) -> bool
Returns true if the set shares any bit with FLUSHO.
Sourcepub const fn with_flusho(self) -> Self
pub const fn with_flusho(self) -> Self
Returns self with FLUSHO inserted.
Sourcepub const fn with_flusho_if(self, condition: bool) -> Self
pub const fn with_flusho_if(self, condition: bool) -> Self
Returns self with FLUSHO inserted if condition is true.
Sourcepub const fn without_flusho(self) -> Self
pub const fn without_flusho(self) -> Self
Returns self with FLUSHO removed.
Sourcepub const fn set_flusho(&mut self)
pub const fn set_flusho(&mut self)
Sets FLUSHO.
Sourcepub const fn set_flusho_if(&mut self, condition: bool)
pub const fn set_flusho_if(&mut self, condition: bool)
Sets FLUSHO if condition is true.
Sourcepub const fn unset_flusho(&mut self)
pub const fn unset_flusho(&mut self)
Unsets FLUSHO.
Sourcepub const fn has_pending(self) -> bool
pub const fn has_pending(self) -> bool
Returns true if PENDING is present.
Sourcepub const fn contains_pending(self) -> bool
pub const fn contains_pending(self) -> bool
Returns true if all bits in PENDING are present.
Sourcepub const fn intersects_pending(self) -> bool
pub const fn intersects_pending(self) -> bool
Returns true if the set shares any bit with PENDING.
Sourcepub const fn with_pending(self) -> Self
pub const fn with_pending(self) -> Self
Returns self with PENDING inserted.
Sourcepub const fn with_pending_if(self, condition: bool) -> Self
pub const fn with_pending_if(self, condition: bool) -> Self
Returns self with PENDING inserted if condition is true.
Sourcepub const fn without_pending(self) -> Self
pub const fn without_pending(self) -> Self
Returns self with PENDING removed.
Sourcepub const fn set_pending(&mut self)
pub const fn set_pending(&mut self)
Sets PENDING.
Sourcepub const fn set_pending_if(&mut self, condition: bool)
pub const fn set_pending_if(&mut self, condition: bool)
Sets PENDING if condition is true.
Sourcepub const fn unset_pending(&mut self)
pub const fn unset_pending(&mut self)
Unsets PENDING.
Sourcepub const fn has_iexten(self) -> bool
pub const fn has_iexten(self) -> bool
Returns true if IEXTEN is present.
Sourcepub const fn contains_iexten(self) -> bool
pub const fn contains_iexten(self) -> bool
Returns true if all bits in IEXTEN are present.
Sourcepub const fn intersects_iexten(self) -> bool
pub const fn intersects_iexten(self) -> bool
Returns true if the set shares any bit with IEXTEN.
Sourcepub const fn with_iexten(self) -> Self
pub const fn with_iexten(self) -> Self
Returns self with IEXTEN inserted.
Sourcepub const fn with_iexten_if(self, condition: bool) -> Self
pub const fn with_iexten_if(self, condition: bool) -> Self
Returns self with IEXTEN inserted if condition is true.
Sourcepub const fn without_iexten(self) -> Self
pub const fn without_iexten(self) -> Self
Returns self with IEXTEN removed.
Sourcepub const fn set_iexten(&mut self)
pub const fn set_iexten(&mut self)
Sets IEXTEN.
Sourcepub const fn set_iexten_if(&mut self, condition: bool)
pub const fn set_iexten_if(&mut self, condition: bool)
Sets IEXTEN if condition is true.
Sourcepub const fn unset_iexten(&mut self)
pub const fn unset_iexten(&mut self)
Unsets IEXTEN.
Sourcepub const fn has_extproc(self) -> bool
pub const fn has_extproc(self) -> bool
Returns true if EXTPROC is present.
Sourcepub const fn contains_extproc(self) -> bool
pub const fn contains_extproc(self) -> bool
Returns true if all bits in EXTPROC are present.
Sourcepub const fn intersects_extproc(self) -> bool
pub const fn intersects_extproc(self) -> bool
Returns true if the set shares any bit with EXTPROC.
Sourcepub const fn with_extproc(self) -> Self
pub const fn with_extproc(self) -> Self
Returns self with EXTPROC inserted.
Sourcepub const fn with_extproc_if(self, condition: bool) -> Self
pub const fn with_extproc_if(self, condition: bool) -> Self
Returns self with EXTPROC inserted if condition is true.
Sourcepub const fn without_extproc(self) -> Self
pub const fn without_extproc(self) -> Self
Returns self with EXTPROC removed.
Sourcepub const fn set_extproc(&mut self)
pub const fn set_extproc(&mut self)
Sets EXTPROC.
Sourcepub const fn set_extproc_if(&mut self, condition: bool)
pub const fn set_extproc_if(&mut self, condition: bool)
Sets EXTPROC if condition is true.
Sourcepub const fn unset_extproc(&mut self)
pub const fn unset_extproc(&mut self)
Unsets EXTPROC.
Sourceimpl LinuxTermiosLocalFlags
Common set methods
impl LinuxTermiosLocalFlags
Common set methods
Sourceimpl LinuxTermiosLocalFlags
Set operations
impl LinuxTermiosLocalFlags
Set operations
Sourcepub const fn intersects(self, other: Self) -> bool
pub const fn intersects(self, other: Self) -> bool
Returns true if self and other share any bit.
Sourcepub const fn is_subset(self, other: Self) -> bool
pub const fn is_subset(self, other: Self) -> bool
Returns true if all bits in self are also set in other.
Sourcepub const fn is_superset(self, other: Self) -> bool
pub const fn is_superset(self, other: Self) -> bool
Returns true if all bits in other are also set in self.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection of self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference of self and other.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference of self and other.
Sourceimpl LinuxTermiosLocalFlags
Mutating set operations
impl LinuxTermiosLocalFlags
Mutating set operations