pub struct TermStyle { /* private fields */ }term only.Expand description
๐ฎ ๐ โ A compact set of broadly supported terminal text styles.
๐ sys/os/term
๐ฆ size_of::<TermStyle>() == 1 bytes / 8 bits
Its bits occupy the low byte of TermStyleExt with the same meanings.
Implementations
Sourceimpl TermStyle
impl TermStyle
Sourcepub const fn extended(self) -> TermStyleExt
pub const fn extended(self) -> TermStyleExt
Returns the corresponding extended style set.
Sourceimpl TermStyle
Convenience methods derived from each named constant.
impl TermStyle
Convenience methods derived from each named constant.
Sourcepub const fn contains_bold(self) -> bool
pub const fn contains_bold(self) -> bool
Returns true if all bits in BOLD are present.
Sourcepub const fn intersects_bold(self) -> bool
pub const fn intersects_bold(self) -> bool
Returns true if the set shares any bit with BOLD.
Sourcepub const fn with_bold_if(self, condition: bool) -> Self
pub const fn with_bold_if(self, condition: bool) -> Self
Returns self with BOLD inserted if condition is true.
Sourcepub const fn without_bold(self) -> Self
pub const fn without_bold(self) -> Self
Returns self with BOLD removed.
Sourcepub const fn set_bold_if(&mut self, condition: bool)
pub const fn set_bold_if(&mut self, condition: bool)
Sets BOLD if condition is true.
Sourcepub const fn unset_bold(&mut self)
pub const fn unset_bold(&mut self)
Unsets BOLD.
Sourcepub const fn has_italic(self) -> bool
pub const fn has_italic(self) -> bool
Returns true if ITALIC is present.
Sourcepub const fn contains_italic(self) -> bool
pub const fn contains_italic(self) -> bool
Returns true if all bits in ITALIC are present.
Sourcepub const fn intersects_italic(self) -> bool
pub const fn intersects_italic(self) -> bool
Returns true if the set shares any bit with ITALIC.
Sourcepub const fn with_italic(self) -> Self
pub const fn with_italic(self) -> Self
Returns self with ITALIC inserted.
Sourcepub const fn with_italic_if(self, condition: bool) -> Self
pub const fn with_italic_if(self, condition: bool) -> Self
Returns self with ITALIC inserted if condition is true.
Sourcepub const fn without_italic(self) -> Self
pub const fn without_italic(self) -> Self
Returns self with ITALIC removed.
Sourcepub const fn set_italic(&mut self)
pub const fn set_italic(&mut self)
Sets ITALIC.
Sourcepub const fn set_italic_if(&mut self, condition: bool)
pub const fn set_italic_if(&mut self, condition: bool)
Sets ITALIC if condition is true.
Sourcepub const fn unset_italic(&mut self)
pub const fn unset_italic(&mut self)
Unsets ITALIC.
Sourcepub const fn has_underline(self) -> bool
pub const fn has_underline(self) -> bool
Returns true if UNDERLINE is present.
Sourcepub const fn contains_underline(self) -> bool
pub const fn contains_underline(self) -> bool
Returns true if all bits in UNDERLINE are present.
Sourcepub const fn intersects_underline(self) -> bool
pub const fn intersects_underline(self) -> bool
Returns true if the set shares any bit with UNDERLINE.
Sourcepub const fn with_underline(self) -> Self
pub const fn with_underline(self) -> Self
Returns self with UNDERLINE inserted.
Sourcepub const fn with_underline_if(self, condition: bool) -> Self
pub const fn with_underline_if(self, condition: bool) -> Self
Returns self with UNDERLINE inserted if condition is true.
Sourcepub const fn without_underline(self) -> Self
pub const fn without_underline(self) -> Self
Returns self with UNDERLINE removed.
Sourcepub const fn set_underline(&mut self)
pub const fn set_underline(&mut self)
Sets UNDERLINE.
Sourcepub const fn set_underline_if(&mut self, condition: bool)
pub const fn set_underline_if(&mut self, condition: bool)
Sets UNDERLINE if condition is true.
Sourcepub const fn unset_underline(&mut self)
pub const fn unset_underline(&mut self)
Unsets UNDERLINE.
Sourcepub const fn contains_dim(self) -> bool
pub const fn contains_dim(self) -> bool
Returns true if all bits in DIM are present.
Sourcepub const fn intersects_dim(self) -> bool
pub const fn intersects_dim(self) -> bool
Returns true if the set shares any bit with DIM.
Sourcepub const fn with_dim_if(self, condition: bool) -> Self
pub const fn with_dim_if(self, condition: bool) -> Self
Returns self with DIM inserted if condition is true.
Sourcepub const fn without_dim(self) -> Self
pub const fn without_dim(self) -> Self
Returns self with DIM removed.
Sourcepub const fn set_dim_if(&mut self, condition: bool)
pub const fn set_dim_if(&mut self, condition: bool)
Sets DIM if condition is true.
Sourcepub const fn contains_blink(self) -> bool
pub const fn contains_blink(self) -> bool
Returns true if all bits in BLINK are present.
Sourcepub const fn intersects_blink(self) -> bool
pub const fn intersects_blink(self) -> bool
Returns true if the set shares any bit with BLINK.
Sourcepub const fn with_blink(self) -> Self
pub const fn with_blink(self) -> Self
Returns self with BLINK inserted.
Sourcepub const fn with_blink_if(self, condition: bool) -> Self
pub const fn with_blink_if(self, condition: bool) -> Self
Returns self with BLINK inserted if condition is true.
Sourcepub const fn without_blink(self) -> Self
pub const fn without_blink(self) -> Self
Returns self with BLINK removed.
Sourcepub const fn set_blink_if(&mut self, condition: bool)
pub const fn set_blink_if(&mut self, condition: bool)
Sets BLINK if condition is true.
Sourcepub const fn unset_blink(&mut self)
pub const fn unset_blink(&mut self)
Unsets BLINK.
Sourcepub const fn has_inverse(self) -> bool
pub const fn has_inverse(self) -> bool
Returns true if INVERSE is present.
Sourcepub const fn contains_inverse(self) -> bool
pub const fn contains_inverse(self) -> bool
Returns true if all bits in INVERSE are present.
Sourcepub const fn intersects_inverse(self) -> bool
pub const fn intersects_inverse(self) -> bool
Returns true if the set shares any bit with INVERSE.
Sourcepub const fn with_inverse(self) -> Self
pub const fn with_inverse(self) -> Self
Returns self with INVERSE inserted.
Sourcepub const fn with_inverse_if(self, condition: bool) -> Self
pub const fn with_inverse_if(self, condition: bool) -> Self
Returns self with INVERSE inserted if condition is true.
Sourcepub const fn without_inverse(self) -> Self
pub const fn without_inverse(self) -> Self
Returns self with INVERSE removed.
Sourcepub const fn set_inverse(&mut self)
pub const fn set_inverse(&mut self)
Sets INVERSE.
Sourcepub const fn set_inverse_if(&mut self, condition: bool)
pub const fn set_inverse_if(&mut self, condition: bool)
Sets INVERSE if condition is true.
Sourcepub const fn unset_inverse(&mut self)
pub const fn unset_inverse(&mut self)
Unsets INVERSE.
Returns true if HIDDEN is present.
Returns true if all bits in HIDDEN are present.
Returns true if the set shares any bit with HIDDEN.
Returns self with HIDDEN inserted.
Returns self with HIDDEN inserted if condition is true.
Returns self with HIDDEN removed.
Sets HIDDEN.
Sets HIDDEN if condition is true.
Unsets HIDDEN.
Sourcepub const fn has_crossed(self) -> bool
pub const fn has_crossed(self) -> bool
Returns true if CROSSED is present.
Sourcepub const fn contains_crossed(self) -> bool
pub const fn contains_crossed(self) -> bool
Returns true if all bits in CROSSED are present.
Sourcepub const fn intersects_crossed(self) -> bool
pub const fn intersects_crossed(self) -> bool
Returns true if the set shares any bit with CROSSED.
Sourcepub const fn with_crossed(self) -> Self
pub const fn with_crossed(self) -> Self
Returns self with CROSSED inserted.
Sourcepub const fn with_crossed_if(self, condition: bool) -> Self
pub const fn with_crossed_if(self, condition: bool) -> Self
Returns self with CROSSED inserted if condition is true.
Sourcepub const fn without_crossed(self) -> Self
pub const fn without_crossed(self) -> Self
Returns self with CROSSED removed.
Sourcepub const fn set_crossed(&mut self)
pub const fn set_crossed(&mut self)
Sets CROSSED.
Sourcepub const fn set_crossed_if(&mut self, condition: bool)
pub const fn set_crossed_if(&mut self, condition: bool)
Sets CROSSED if condition is true.
Sourcepub const fn unset_crossed(&mut self)
pub const fn unset_crossed(&mut self)
Unsets CROSSED.
Sourceimpl TermStyle
Common set methods
impl TermStyle
Common set methods
Sourceimpl TermStyle
Set operations
impl TermStyle
Set operations
Sourcepub const fn intersects(self, other: Self) -> bool
pub const fn intersects(self, other: Self) -> bool
Returns true if self and other share any bit.
Sourcepub const fn is_subset(self, other: Self) -> bool
pub const fn is_subset(self, other: Self) -> bool
Returns true if all bits in self are also set in other.
Sourcepub const fn is_superset(self, other: Self) -> bool
pub const fn is_superset(self, other: Self) -> bool
Returns true if all bits in other are also set in self.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection of self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference of self and other.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference of self and other.